#include <p.h>

/* Path Integral Monte Carlo code developed by A. Balaz 
   (antun@ipb.ac.rs) for the paper:
         
   "Systematic Speedup in the Convergence of Path Integrals"
   by A. Bogojevic, A. Balaz, and A. Belic
   Phys. Rev. Lett. 94 (2005) 180403

   Address: Institute of Physics, Belgrade, Serbia
   Scientific Computing Laboratory, http://www.scl.rs/speedup/

   Public use and modification of this code is allowed providing 
   the above paper is properly acknowledged. The author would be 
   grateful for all information and/or comments regarding the use   
   of the code.  
*/

/* USER CONFIGURABLE SECTION:

   1) Defining the level parameter p (1 <= p <= 18). 
   2) Supplying the C function for the evaluation of the potential V
      and its nonvanishing derivatives up to the order 2 p - 2 (without
      the derivative of the order 2 p - 3).
*/

/* 1) Defining the level parameter p (1 <= p <= 18)

      The level parameter p corresponds to the function Vp()
      (improved potential) which will be compiled. You need to adjust
      the following preprocessor variable. The value below is for p = 18.
*/

#define p2

/* 2) Supplying the C function for the evaluation of the potential V
      and its nonvanishing derivatives up to the order 2 p - 2 (without
      the derivative of the order 2 p - 3).

      Function V0(x) provides the value of the potential (variable V00),
      and all its nonvanishing derivatives up to the order 2 p - 2,
      (without the derivative of order 2 p - 3, since it is not present),
      variables V01, V02, ..., V34, at the point x. The default
      value for all these variables is zero, i.e. you need to
      define only nonzero derivatives.

      Parameters of the potential are par[0] ..., as entered by
      you on the command line. $\phi^4$ example is given below.
*/

void V0(double x) /* Example of the user supplied function V0() for the $\phi^4$ theory. */
{
   double x2, x4;

   x2 = x * x;
   x4 = x2 * x2;
   V00 = par[0] * x4 / 24. + 0.5 * x2;
   V01 = par[0] * x2 * x / 6. + x;
   V02 = par[0] * x2 / 2. + 1.;
   V03 = par[0] * x;
   V04 = par[0];

   return;
}

/* END OF THE USER CONFIGURABLE SECTION! */


/* Function func(q[]) returns exp(- action + norm), where the variable action is
   the action for the given path (q[0], q[step], ..., q[N]) plus the exponent of
   the Gaussian probability density function (*distrexp), and norm is the normalization
   (*norm) of the path integral (which also includes the normalization of Gaussians).
   Array *norm is defined in main(), array *distrexp in distr().
   The improved potential Vp() for every pair of points (q[i], q[i + step])
   is evaluated at the mid-point qbar.
*/

double func(double *q, double T, int s, int n)
{
   void V0(double); /* The user supplied function that returns the unimproved potential
                       and its derivatives. */
   double Vp(void); /* The function that, for a given p, returns the improved potential. */

   int i; /* Loop variable for the loop over the time steps. */

   action = 0; /* Initialiation of the action. */
   Nmax = two[s]; /* The maximal number of time steps. */
   Nc = two[n]; /* The current number of time steps. */
   step = two[s - n]; /* Index distance of path nodes at current bisection level. */
   eps = T / Nc; /* Current time step and related variables. */
   epsinv = 1. / eps;
   eps2 = eps * eps;
   eps3 = eps * eps2;
   eps4 = eps * eps3;
   eps5 = eps * eps4;
   eps6 = eps * eps5;
   eps7 = eps * eps6;
   eps8 = eps * eps7;
   eps9 = eps * eps8;
   eps10 = eps * eps9;
   eps11 = eps * eps10;
   eps12 = eps * eps11;
   eps13 = eps * eps12;
   eps14 = eps * eps13;
   eps15 = eps * eps14;
   eps16 = eps * eps15;
   eps17 = eps * eps16;

   for(i = 0; i < Nmax; i += step) /* Loop over path nodes at current bisection level. */
   {
      qbar = (q[i + step] + q[i]) * 0.5; /* Mid-point for nearest nodes. */
      delta = q[i + step] - q[i]; /* Distance between nearest nodes. */
      delta2 = delta * delta / 4; /* Square of (delta / 2). */
      V0(qbar); /* Initialization of unimproved potential and its derivatives at qbar. */
      action += 2 * delta2 * epsinv + eps * Vp() - distrexp[i]; /* Accumulation of the action minus
                                                                     the exponent of the Gaussian. */
   }

   return exp(- action + norm[n]); /* norm[n] includes the path integral norm for a
                                      given number of time steps 2^n and normalization of Gaussians
                                      used as probability density functions. */
}

/* For a chosen p, the function Vp() returns the value of the improved potential.
   This function uses the values of the potential and all its nonvanishing
   derivatives up to order 2p-2, defined in V0(), supplied by the user.

   V00 is the value of the potential, and Vnm (nm = 01, 02, ..., 34) are the
   derivatives of the potential. Additional variables Vnmk = (Vnm)^k and
   deltan = delta^n are introduced for optimization purposes.
*/

#ifdef p1 /* Uses: V00. */
double Vp(void)
{
   return V00;
}
#endif

#ifdef p2 /* Uses: V00, V02. */
double Vp(void)
{
   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02;
}
#endif

#ifdef p3 /* Uses: V00 - V04. */
double Vp(void)
{
   V012 = V01 * V01;
   delta4 = delta2 * delta2;
   
   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 + 
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) + 
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04;
}
#endif

#ifdef p4 /* Uses: V00 - V06. */
double Vp(void)
{
   V012 = V01 * V01;
   V022 = V02  *  V02;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;

   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 +
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) +
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 +
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) +
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 +
      0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 + 0.000297619047619047619*delta4*eps*V06;
}
#endif

#ifdef p5 /* Uses: V00 - V08. */
double Vp(void)
{
   V012 = V01  *  V01;
   V022 = V02  *  V02;
   V032 = V03  *  V03;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;
   delta8 = delta2 * delta6;

   return 00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 +
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) +
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 +
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) +
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 +
      0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 +
   0.000297619047619047619*delta4*eps*V06 +
   eps4*(0.00416666666666666667*V012*V02 - 0.000570436507936507937*V032 -
      0.000595238095238095238*V02*V04 - 0.000446428571428571429*V01*V05 + 4.1335978835978836e-6*V08) +
   delta2*eps3*(-0.000992063492063492063*V032 - 0.000793650793650793651*V02*V04 -
      0.000595238095238095238*V01*V05 + 8.2671957671957672e-6*V08) +
   delta4*eps2*(-0.000496031746031746032*V032 - 0.000396825396825396825*V02*V04 -
      0.000297619047619047619*V01*V05 + 8.2671957671957672e-6*V08) + 2.75573192239858907e-6*delta8*V08 +
   5.51146384479717813e-6*delta6*eps*V08;
}
#endif

#ifdef p6 /* Uses: V00 - V10. */
double Vp(void)
{
   V012 = V01 * V01;
   V022 = V02 * V02;
   V023 = V02 * V022;
   V032 = V03 * V03;
   V042 = V04 * V04;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;
   delta8 = delta2 * delta6;
   delta10 = delta2 * delta8;

   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 +
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) +
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 +
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) +
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 +
      0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 +
   0.000297619047619047619*delta4*eps*V06 +
   eps4*(0.00416666666666666667*V012*V02 - 0.000570436507936507937*V032 -
      0.000595238095238095238*V02*V04 - 0.000446428571428571429*V01*V05 + 4.1335978835978836e-6*V08) +
   delta2*eps3*(-0.000992063492063492063*V032 - 0.000793650793650793651*V02*V04 -
      0.000595238095238095238*V01*V05 + 8.2671957671957672e-6*V08) +
   delta4*eps2*(-0.000496031746031746032*V032 - 0.000396825396825396825*V02*V04 -
      0.000297619047619047619*V01*V05 + 8.2671957671957672e-6*V08) + 2.75573192239858907e-6*delta8*V08 +
   5.51146384479717813e-6*delta6*eps*V08 + eps5*
    (0.0001763668430335097*V023 + 0.00143849206349206349*V01*V02*V03 + 0.000446428571428571429*V012*V04 -
      0.0000388558201058201058*V042 - 0.0000785383597883597884*V03*V05 - 0.0000330687830687830688*V02*V06 -
      0.0000165343915343915344*V01*V07 + 9.39454064454064454e-8*V10) +
   delta6*eps2*(-0.0000154320987654320988*V042 - 0.0000385802469135802469*V03*V05 -
      0.0000110229276895943563*V02*V06 - 5.51146384479717813e-6*V01*V07 + 1.25260541927208594e-7*V10) +
   delta2*eps4*(0.0000661375661375661376*V023 + 0.00119047619047619048*V01*V02*V03 +
      0.000297619047619047619*V012*V04 - 0.0000644841269841269841*V042 - 0.00014880952380952381*V03*V05 -
      0.0000496031746031746032*V02*V06 - 0.0000248015873015873016*V01*V07 + 1.87890812890812891e-7*V10) +
   delta4*eps3*(-0.0000462962962962962963*V042 - 0.000115740740740740741*V03*V05 -
      0.0000330687830687830688*V02*V06 - 0.0000165343915343915344*V01*V07 + 1.87890812890812891e-7*V10) +
   2.50521083854417188e-8*delta10*V10 + 6.26302709636042969e-8*delta8*eps*V10;
}
#endif

#ifdef p7 /* Uses: V00 - V12. */
double Vp(void)
{
   V012 = V01 * V01;
   V013 = V01 * V012;
   V022 = V02 * V02;
   V023 = V02 * V022;
   V032 = V03 * V03;
   V042 = V04 * V04;
   V052 = V05 * V05;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;
   delta8 = delta2 * delta6;
   delta10 = delta2 * delta8;
   delta12 = delta2 * delta10;

   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 +
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) +
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 +
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) +
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 +
      0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 +
   0.000297619047619047619*delta4*eps*V06 +
   eps4*(0.00416666666666666667*V012*V02 - 0.000570436507936507937*V032 -
      0.000595238095238095238*V02*V04 - 0.000446428571428571429*V01*V05 + 4.1335978835978836e-6*V08) +
   delta2*eps3*(-0.000992063492063492063*V032 - 0.000793650793650793651*V02*V04 -
      0.000595238095238095238*V01*V05 + 8.2671957671957672e-6*V08) +
   delta4*eps2*(-0.000496031746031746032*V032 - 0.000396825396825396825*V02*V04 -
      0.000297619047619047619*V01*V05 + 8.2671957671957672e-6*V08) + 2.75573192239858907e-6*delta8*V08 +
   5.51146384479717813e-6*delta6*eps*V08 + eps5*
    (0.0001763668430335097*V023 + 0.00143849206349206349*V01*V02*V03 + 0.000446428571428571429*V012*V04 -
      0.0000388558201058201058*V042 - 0.0000785383597883597884*V03*V05 - 0.0000330687830687830688*V02*V06 -
      0.0000165343915343915344*V01*V07 + 9.39454064454064454e-8*V10) +
   delta6*eps2*(-0.0000154320987654320988*V042 - 0.0000385802469135802469*V03*V05 -
      0.0000110229276895943563*V02*V06 - 5.51146384479717813e-6*V01*V07 + 1.25260541927208594e-7*V10) +
   delta2*eps4*(0.0000661375661375661376*V023 + 0.00119047619047619048*V01*V02*V03 +
      0.000297619047619047619*V012*V04 - 0.0000644841269841269841*V042 - 0.00014880952380952381*V03*V05 -
      0.0000496031746031746032*V02*V06 - 0.0000248015873015873016*V01*V07 + 1.87890812890812891e-7*V10) +
   delta4*eps3*(-0.0000462962962962962963*V042 - 0.000115740740740740741*V03*V05 -
      0.0000330687830687830688*V02*V06 - 0.0000165343915343915344*V01*V07 + 1.87890812890812891e-7*V10) +
   2.50521083854417188e-8*delta10*V10 + 6.26302709636042969e-8*delta8*eps*V10 +
   delta8*eps2*(-7.89141414141414141e-7*V052 - 9.01875901875901876e-7*V04*V06 -
      7.51563251563251563e-7*V03*V07 - 1.67014055902944792e-7*V02*V08 - 6.26302709636042969e-8*V01*V09 +
      1.20442828776162109e-9*V12) + eps6*(-0.000421626984126984127*V012*V022 -
      0.00014880952380952381*V013*V03 + 0.000144675925925925926*V02*V032 +
      0.0000793650793650793651*V022*V04 + 0.000188492063492063492*V01*V03*V04 + 0.000111607142857142857*V01*V02*V05 -
      3.33506192881192881e-6*V052 + 0.0000248015873015873016*V012*V06 - 5.11063011063011063e-6*V04*V06 -
      3.56992544492544493e-6*V03*V07 - 1.25260541927208594e-6*V02*V08 - 4.69727032227032227e-7*V01*V09 +
      1.80664243164243164e-9*V12) + delta6*eps3*
    (-3.15656565656565657e-6*V052 - 3.6075036075036075e-6*V04*V06 - 3.00625300625300625e-6*V03*V07 -
      6.68056223611779167e-7*V02*V08 - 2.50521083854417188e-7*V01*V09 + 2.40885657552324219e-9*V12) +
   delta2*eps5*(0.00020667989417989418*V02*V032 + 0.0000727513227513227513*V022*V04 +
      0.000243055555555555556*V01*V03*V04 + 0.000124007936507936508*V01*V02*V05 - 6.57617845117845118e-6*V052 +
      0.0000248015873015873016*V012*V06 - 9.16907166907166907e-6*V04*V06 - 6.95196007696007696e-6*V03*V07 -
      2.0041686708353375e-6*V02*V08 - 7.51563251563251563e-7*V01*V09 + 3.61328486328486328e-9*V12) +
   delta4*eps4*(0.000082671957671957672*V02*V032 + 0.0000198412698412698413*V022*V04 +
      0.0000925925925925925926*V01*V03*V04 + 0.0000496031746031746032*V01*V02*V05 - 6.1377665544332211e-6*V052 +
      8.2671957671957672e-6*V012*V06 - 7.56573673240339907e-6*V04*V06 - 6.0751362834696168e-6*V03*V07 -
      1.50312650312650313e-6*V02*V08 - 5.63672438672438672e-7*V01*V09 + 3.61328486328486328e-9*V12) +
   1.60590438368216146e-10*delta12*V12 + 4.81771315104648438e-10*delta10*eps*V12;
}
#endif

#ifdef p8 /* Uses: V00 - V14. */
double Vp(void)
{
   V012 = V01 * V01;
   V013 = V01 * V012;
   V022 = V02 * V02;
   V023 = V02 * V022;
   V024 = V02 * V023;
   V032 = V03 * V03;
   V042 = V04 * V04;
   V052 = V05 * V05;
   V062 = V06 * V06;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;
   delta8 = delta2 * delta6;
   delta10 = delta2 * delta8;
   delta12 = delta2 * delta10;
   delta14 = delta2 * delta12;

   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 +
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) +
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 +
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) +
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 +
      0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 +
   0.000297619047619047619*delta4*eps*V06 +
   eps4*(0.00416666666666666667*V012*V02 - 0.000570436507936507937*V032 -
      0.000595238095238095238*V02*V04 - 0.000446428571428571429*V01*V05 + 4.1335978835978836e-6*V08) +
   delta2*eps3*(-0.000992063492063492063*V032 - 0.000793650793650793651*V02*V04 -
      0.000595238095238095238*V01*V05 + 8.2671957671957672e-6*V08) +
   delta4*eps2*(-0.000496031746031746032*V032 - 0.000396825396825396825*V02*V04 -
      0.000297619047619047619*V01*V05 + 8.2671957671957672e-6*V08) + 2.75573192239858907e-6*delta8*V08 +
   5.51146384479717813e-6*delta6*eps*V08 + eps5*
    (0.0001763668430335097*V023 + 0.00143849206349206349*V01*V02*V03 + 0.000446428571428571429*V012*V04 -
      0.0000388558201058201058*V042 - 0.0000785383597883597884*V03*V05 - 0.0000330687830687830688*V02*V06 -
      0.0000165343915343915344*V01*V07 + 9.39454064454064454e-8*V10) +
   delta6*eps2*(-0.0000154320987654320988*V042 - 0.0000385802469135802469*V03*V05 -
      0.0000110229276895943563*V02*V06 - 5.51146384479717813e-6*V01*V07 + 1.25260541927208594e-7*V10) +
   delta2*eps4*(0.0000661375661375661376*V023 + 0.00119047619047619048*V01*V02*V03 +
      0.000297619047619047619*V012*V04 - 0.0000644841269841269841*V042 - 0.00014880952380952381*V03*V05 -
      0.0000496031746031746032*V02*V06 - 0.0000248015873015873016*V01*V07 + 1.87890812890812891e-7*V10) +
   delta4*eps3*(-0.0000462962962962962963*V042 - 0.000115740740740740741*V03*V05 -
      0.0000330687830687830688*V02*V06 - 0.0000165343915343915344*V01*V07 + 1.87890812890812891e-7*V10) +
   2.50521083854417188e-8*delta10*V10 + 6.26302709636042969e-8*delta8*eps*V10 +
   delta8*eps2*(-7.89141414141414141e-7*V052 - 9.01875901875901876e-7*V04*V06 -
      7.51563251563251563e-7*V03*V07 - 1.67014055902944792e-7*V02*V08 - 6.26302709636042969e-8*V01*V09 +
      1.20442828776162109e-9*V12) + eps6*(-0.000421626984126984127*V012*V022 -
      0.00014880952380952381*V013*V03 + 0.000144675925925925926*V02*V032 +
      0.0000793650793650793651*V022*V04 + 0.000188492063492063492*V01*V03*V04 + 0.000111607142857142857*V01*V02*V05 -
      3.33506192881192881e-6*V052 + 0.0000248015873015873016*V012*V06 - 5.11063011063011063e-6*V04*V06 -
      3.56992544492544493e-6*V03*V07 - 1.25260541927208594e-6*V02*V08 - 4.69727032227032227e-7*V01*V09 +
      1.80664243164243164e-9*V12) + delta6*eps3*
    (-3.15656565656565657e-6*V052 - 3.6075036075036075e-6*V04*V06 - 3.00625300625300625e-6*V03*V07 -
      6.68056223611779167e-7*V02*V08 - 2.50521083854417188e-7*V01*V09 + 2.40885657552324219e-9*V12) +
   delta2*eps5*(0.00020667989417989418*V02*V032 + 0.0000727513227513227513*V022*V04 +
      0.000243055555555555556*V01*V03*V04 + 0.000124007936507936508*V01*V02*V05 - 6.57617845117845118e-6*V052 +
      0.0000248015873015873016*V012*V06 - 9.16907166907166907e-6*V04*V06 - 6.95196007696007696e-6*V03*V07 -
      2.0041686708353375e-6*V02*V08 - 7.51563251563251563e-7*V01*V09 + 3.61328486328486328e-9*V12) +
   delta4*eps4*(0.000082671957671957672*V02*V032 + 0.0000198412698412698413*V022*V04 +
      0.0000925925925925925926*V01*V03*V04 + 0.0000496031746031746032*V01*V02*V05 - 6.1377665544332211e-6*V052 +
      8.2671957671957672e-6*V012*V06 - 7.56573673240339907e-6*V04*V06 - 6.0751362834696168e-6*V03*V07 -
      1.50312650312650313e-6*V02*V08 - 5.63672438672438672e-7*V01*V09 + 3.61328486328486328e-9*V12) +
   1.60590438368216146e-10*delta12*V12 + 4.81771315104648438e-10*delta10*eps*V12 +
   delta10*eps2*(-1.3627245770102913e-8*V062 - 3.17969067969067969e-8*V05*V07 -
      1.41319585764030208e-8*V04*V08 - 8.83247411025188803e-9*V03*V09 - 1.60590438368216146e-9*V02*V10 -
      4.81771315104648438e-10*V01*V11 + 8.0295219184108073e-12*V14) +
   delta8*eps3*(-6.81362288505145648e-8*V062 - 1.58984533984533985e-7*V05*V07 -
      7.06597928820151042e-8*V04*V08 - 4.41623705512594401e-8*V03*V09 - 8.0295219184108073e-9*V02*V10 -
      2.40885657552324219e-9*V01*V11 + 2.00738047960270182e-11*V14) +
   eps7*(-0.0000132275132275132275*V024 - 0.000203373015873015873*V01*V022*V03 -
      0.0000777116402116402116*V012*V032 - 0.000124007936507936508*V012*V02*V04 +
      0.0000224842672759339426*V032*V04 + 0.000013452982202982203*V02*V042 -
      0.0000165343915343915344*V013*V05 + 0.0000264299743466410133*V02*V03*V05 + 0.0000173485850569183903*V01*V04*V05 +
      5.71188071188071188e-6*V022*V06 + 0.0000124383718133718134*V01*V03*V06 - 1.95667978406073644e-7*V062 +
      5.44883357383357383e-6*V01*V02*V07 - 3.61569371986038653e-7*V05*V07 + 9.39454064454064454e-7*V012*V08 -
      2.24023661523661524e-7*V04*V08 - 1.20442828776162109e-7*V03*V09 - 3.61328486328486328e-8*V02*V10 -
      1.08398545898545899e-8*V01*V11 + 3.01107071940405274e-11*V14) +
   delta6*eps4*(6.76406926406926407e-6*V032*V04 + 1.90396023729357063e-6*V02*V042 +
      7.01459034792368126e-6*V02*V03*V05 + 4.05844155844155844e-6*V01*V04*V05 + 6.51354818021484688e-7*V022*V06 +
      2.70562770562770563e-6*V01*V03*V06 - 1.88303759732331161e-7*V062 + 1.00208433541766875e-6*V01*V02*V07 -
      4.20586358086358086e-7*V05*V07 + 1.25260541927208594e-7*V012*V08 - 1.99453324453324453e-7*V04*V08 -
      1.22048733159844271e-7*V03*V09 - 2.40885657552324219e-8*V02*V10 - 7.22656972656972657e-9*V01*V11 +
      4.01476095920540365e-11*V14) + delta2*eps6*
    (-1.65343915343915344e-6*V024 - 0.000133928571428571429*V01*V022*V03 -
      0.0000562169312169312169*V012*V032 - 0.0000744047619047619048*V012*V02*V04 +
      0.0000395197009780343114*V032*V04 + 0.0000179623617123617124*V02*V042 -
      8.2671957671957672e-6*V013*V05 + 0.0000417743907327240661*V02*V03*V05 + 0.0000256408329324995992*V01*V04*V05 +
      6.68891293891293891e-6*V022*V06 + 0.0000185636123136123136*V01*V03*V06 - 3.70998324867372486e-7*V062 +
      6.95196007696007696e-6*V01*V02*V07 - 7.19525459108792442e-7*V05*V07 + 1.12734487734487734e-6*V012*V08 -
      4.17213958880625547e-7*V04*V08 - 2.37272372689039356e-7*V03*V09 - 6.02214143880810547e-8*V02*V10 -
      1.80664243164243164e-8*V01*V11 + 6.02214143880810547e-11*V14) +
   delta4*eps5*(0.0000263047138047138047*V032*V04 + 9.11896745230078563e-6*V02*V042 +
      0.0000267431257014590348*V02*V03*V05 + 0.0000157828282828282828*V01*V04*V05 + 3.20666987333654e-6*V022*V06 +
      0.0000109352453102453102*V01*V03*V06 - 3.36345202416630988e-7*V062 + 3.82044652877986211e-6*V01*V02*V07 -
      7.00254606504606505e-7*V05*V07 + 5.63672438672438672e-7*V012*V08 - 3.67591513424846758e-7*V04*V08 -
      2.18001520084853418e-7*V03*V09 - 4.81771315104648438e-8*V02*V10 - 1.44531394531394531e-8*V01*V11 +
      6.02214143880810547e-11*V14) + 7.64716373181981648e-13*delta14*V14 +
   2.67650730613693577e-12*delta12*eps*V14;
}
#endif

#ifdef p9 /* Uses: V00 - V16. */
double Vp(void)
{
   V012 = V01 * V01;
   V013 = V01 * V012;
   V014 = V01 * V013;
   V022 = V02 * V02;
   V023 = V02 * V022;
   V024 = V02 * V023;
   V032 = V03 * V03;
   V033 = V03 * V032;
   V042 = V04 * V04;
   V043 = V04 * V042;
   V052 = V05 * V05;
   V062 = V06 * V06;
   V072 = V07 * V07;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;
   delta8 = delta2 * delta6;
   delta10 = delta2 * delta8;
   delta12 = delta2 * delta10;
   delta14 = delta2 * delta12;
   delta16 = delta2 * delta14;

   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 + 
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) + 
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 + 
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) + 
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 
      0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 + 
   0.000297619047619047619*delta4*eps*V06 + 
   eps4*(0.00416666666666666667*V012*V02 - 0.000570436507936507937*V032 - 
      0.000595238095238095238*V02*V04 - 0.000446428571428571429*V01*V05 + 4.1335978835978836e-6*V08) + 
   delta2*eps3*(-0.000992063492063492063*V032 - 0.000793650793650793651*V02*V04 - 
      0.000595238095238095238*V01*V05 + 8.2671957671957672e-6*V08) + 
   delta4*eps2*(-0.000496031746031746032*V032 - 0.000396825396825396825*V02*V04 - 
      0.000297619047619047619*V01*V05 + 8.2671957671957672e-6*V08) + 2.75573192239858907e-6*delta8*V08 + 
   5.51146384479717813e-6*delta6*eps*V08 + eps5*
    (0.0001763668430335097*V023 + 0.00143849206349206349*V01*V02*V03 + 0.000446428571428571429*V012*V04 - 
      0.0000388558201058201058*V042 - 0.0000785383597883597884*V03*V05 - 0.0000330687830687830688*V02*V06 - 
      0.0000165343915343915344*V01*V07 + 9.39454064454064454e-8*V10) + 
   delta6*eps2*(-0.0000154320987654320988*V042 - 0.0000385802469135802469*V03*V05 - 
      0.0000110229276895943563*V02*V06 - 5.51146384479717813e-6*V01*V07 + 1.25260541927208594e-7*V10) + 
   delta2*eps4*(0.0000661375661375661376*V023 + 0.00119047619047619048*V01*V02*V03 + 
      0.000297619047619047619*V012*V04 - 0.0000644841269841269841*V042 - 0.00014880952380952381*V03*V05 - 
      0.0000496031746031746032*V02*V06 - 0.0000248015873015873016*V01*V07 + 1.87890812890812891e-7*V10) + 
   delta4*eps3*(-0.0000462962962962962963*V042 - 0.000115740740740740741*V03*V05 - 
      0.0000330687830687830688*V02*V06 - 0.0000165343915343915344*V01*V07 + 1.87890812890812891e-7*V10) + 
   2.50521083854417188e-8*delta10*V10 + 6.26302709636042969e-8*delta8*eps*V10 + 
   delta8*eps2*(-7.89141414141414141e-7*V052 - 9.01875901875901876e-7*V04*V06 - 
      7.51563251563251563e-7*V03*V07 - 1.67014055902944792e-7*V02*V08 - 6.26302709636042969e-8*V01*V09 + 
      1.20442828776162109e-9*V12) + eps6*(-0.000421626984126984127*V012*V022 - 
      0.00014880952380952381*V013*V03 + 0.000144675925925925926*V02*V032 + 
      0.0000793650793650793651*V022*V04 + 0.000188492063492063492*V01*V03*V04 + 0.000111607142857142857*V01*V02*V05 - 
      3.33506192881192881e-6*V052 + 0.0000248015873015873016*V012*V06 - 5.11063011063011063e-6*V04*V06 - 
      3.56992544492544493e-6*V03*V07 - 1.25260541927208594e-6*V02*V08 - 4.69727032227032227e-7*V01*V09 + 
      1.80664243164243164e-9*V12) + delta6*eps3*
    (-3.15656565656565657e-6*V052 - 3.6075036075036075e-6*V04*V06 - 3.00625300625300625e-6*V03*V07 - 
      6.68056223611779167e-7*V02*V08 - 2.50521083854417188e-7*V01*V09 + 2.40885657552324219e-9*V12) + 
   delta2*eps5*(0.00020667989417989418*V02*V032 + 0.0000727513227513227513*V022*V04 + 
      0.000243055555555555556*V01*V03*V04 + 0.000124007936507936508*V01*V02*V05 - 6.57617845117845118e-6*V052 + 
      0.0000248015873015873016*V012*V06 - 9.16907166907166907e-6*V04*V06 - 6.95196007696007696e-6*V03*V07 - 
      2.0041686708353375e-6*V02*V08 - 7.51563251563251563e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   delta4*eps4*(0.000082671957671957672*V02*V032 + 0.0000198412698412698413*V022*V04 + 
      0.0000925925925925925926*V01*V03*V04 + 0.0000496031746031746032*V01*V02*V05 - 6.1377665544332211e-6*V052 + 
      8.2671957671957672e-6*V012*V06 - 7.56573673240339907e-6*V04*V06 - 6.0751362834696168e-6*V03*V07 - 
      1.50312650312650313e-6*V02*V08 - 5.63672438672438672e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   1.60590438368216146e-10*delta12*V12 + 4.81771315104648438e-10*delta10*eps*V12 + 
   delta10*eps2*(-1.3627245770102913e-8*V062 - 3.17969067969067969e-8*V05*V07 - 
      1.41319585764030208e-8*V04*V08 - 8.83247411025188803e-9*V03*V09 - 1.60590438368216146e-9*V02*V10 - 
      4.81771315104648438e-10*V01*V11 + 8.0295219184108073e-12*V14) + 
   delta8*eps3*(-6.81362288505145648e-8*V062 - 1.58984533984533985e-7*V05*V07 - 
      7.06597928820151042e-8*V04*V08 - 4.41623705512594401e-8*V03*V09 - 8.0295219184108073e-9*V02*V10 - 
      2.40885657552324219e-9*V01*V11 + 2.00738047960270182e-11*V14) + 
   eps7*(-0.0000132275132275132275*V024 - 0.000203373015873015873*V01*V022*V03 - 
      0.0000777116402116402116*V012*V032 - 0.000124007936507936508*V012*V02*V04 + 
      0.0000224842672759339426*V032*V04 + 0.000013452982202982203*V02*V042 - 
      0.0000165343915343915344*V013*V05 + 0.0000264299743466410133*V02*V03*V05 + 0.0000173485850569183903*V01*V04*V05 + 
      5.71188071188071188e-6*V022*V06 + 0.0000124383718133718134*V01*V03*V06 - 1.95667978406073644e-7*V062 + 
      5.44883357383357383e-6*V01*V02*V07 - 3.61569371986038653e-7*V05*V07 + 9.39454064454064454e-7*V012*V08 - 
      2.24023661523661524e-7*V04*V08 - 1.20442828776162109e-7*V03*V09 - 3.61328486328486328e-8*V02*V10 - 
      1.08398545898545899e-8*V01*V11 + 3.01107071940405274e-11*V14) + 
   delta6*eps4*(6.76406926406926407e-6*V032*V04 + 1.90396023729357063e-6*V02*V042 + 
      7.01459034792368126e-6*V02*V03*V05 + 4.05844155844155844e-6*V01*V04*V05 + 6.51354818021484688e-7*V022*V06 + 
      2.70562770562770563e-6*V01*V03*V06 - 1.88303759732331161e-7*V062 + 1.00208433541766875e-6*V01*V02*V07 - 
      4.20586358086358086e-7*V05*V07 + 1.25260541927208594e-7*V012*V08 - 1.99453324453324453e-7*V04*V08 - 
      1.22048733159844271e-7*V03*V09 - 2.40885657552324219e-8*V02*V10 - 7.22656972656972657e-9*V01*V11 + 
      4.01476095920540365e-11*V14) + delta2*eps6*
    (-1.65343915343915344e-6*V024 - 0.000133928571428571429*V01*V022*V03 - 
      0.0000562169312169312169*V012*V032 - 0.0000744047619047619048*V012*V02*V04 + 
      0.0000395197009780343114*V032*V04 + 0.0000179623617123617124*V02*V042 - 
      8.2671957671957672e-6*V013*V05 + 0.0000417743907327240661*V02*V03*V05 + 0.0000256408329324995992*V01*V04*V05 + 
      6.68891293891293891e-6*V022*V06 + 0.0000185636123136123136*V01*V03*V06 - 3.70998324867372486e-7*V062 + 
      6.95196007696007696e-6*V01*V02*V07 - 7.19525459108792442e-7*V05*V07 + 1.12734487734487734e-6*V012*V08 - 
      4.17213958880625547e-7*V04*V08 - 2.37272372689039356e-7*V03*V09 - 6.02214143880810547e-8*V02*V10 - 
      1.80664243164243164e-8*V01*V11 + 6.02214143880810547e-11*V14) + 
   delta4*eps5*(0.0000263047138047138047*V032*V04 + 9.11896745230078563e-6*V02*V042 + 
      0.0000267431257014590348*V02*V03*V05 + 0.0000157828282828282828*V01*V04*V05 + 3.20666987333654e-6*V022*V06 + 
      0.0000109352453102453102*V01*V03*V06 - 3.36345202416630988e-7*V062 + 3.82044652877986211e-6*V01*V02*V07 - 
      7.00254606504606505e-7*V05*V07 + 5.63672438672438672e-7*V012*V08 - 3.67591513424846758e-7*V04*V08 - 
      2.18001520084853418e-7*V03*V09 - 4.81771315104648438e-8*V02*V10 - 1.44531394531394531e-8*V01*V11 + 
      6.02214143880810547e-11*V14) + 7.64716373181981648e-13*delta14*V14 + 
   2.67650730613693577e-12*delta12*eps*V14 + 
   delta12*eps2*(-3.28063324095070127e-10*V072 - 4.37417765460093502e-10*V06*V08 - 
      3.82740544777581815e-10*V05*V09 - 1.3917837991912066e-10*V04*V10 - 6.95891899595603299e-11*V03*V11 - 
      1.07060292245477431e-11*V02*V12 - 2.67650730613693577e-12*V01*V13 + 3.93604015608372907e-14*V16) + 
   delta10*eps3*(-1.96837994457042076e-9*V072 - 2.62450659276056101e-9*V06*V08 - 
      2.29644326866549089e-9*V05*V09 - 8.35070279514723959e-10*V04*V10 - 4.1753513975736198e-10*V03*V11 - 
      6.42361753472864584e-11*V02*V12 - 1.60590438368216146e-11*V01*V13 + 1.18081204682511872e-13*V16) + 
   delta8*eps4*(5.93542260208926876e-8*V043 + 5.93542260208926876e-7*V03*V04*V05 + 
      1.51757964257964258e-7*V02*V052 + 2.04408686551543694e-7*V032*V06 + 1.2498524403286308e-7*V02*V04*V06 + 
      1.22645211930926217e-7*V01*V05*V06 + 1.44531394531394531e-7*V02*V03*V07 + 8.47917514584181251e-8*V01*V04*V07 - 
      6.52972193150764579e-9*V072 + 1.09201498090386979e-8*V022*V08 + 4.23958757292090625e-8*V01*V03*V08 - 
      9.08483051340194197e-9*V06*V08 + 1.20442828776162109e-8*V01*V02*V09 - 7.72841484647040203e-9*V05*V09 + 
      1.20442828776162109e-9*V012*V10 - 2.9709231098119987e-9*V04*V10 - 1.46538775010997233e-9*V03*V11 - 
      2.40885657552324219e-10*V02*V12 - 6.02214143880810547e-11*V01*V13 + 2.9520301170627968e-13*V16) + 
   eps8*(0.0000427138447971781305*V012*V023 + 0.0000454695767195767196*V013*V02*V03 - 
      0.0000265865500240500241*V022*V032 - 0.0000157201980118646785*V01*V033 + 
      4.1335978835978836e-6*V014*V04 - 0.0000100208433541766875*V023*V04 - 
      0.000068329625621292288*V01*V02*V03*V04 - 0.0000103840989257655924*V012*V042 + 
      8.50711788211788212e-7*V043 - 0.0000202922077922077922*V01*V022*V05 - 
      0.0000166283369408369408*V012*V03*V05 + 4.77122221913888581e-6*V03*V04*V05 + 
      1.40881976819476819e-6*V02*V052 - 8.83086820586820587e-6*V012*V02*V06 + 
      1.726031766954386e-6*V032*V06 + 2.18586528110337634e-6*V02*V04*V06 + 1.33467860402384212e-6*V01*V05*V06 - 
      9.39454064454064454e-7*V013*V07 + 1.49830878997545664e-6*V02*V03*V07 + 9.8088639755306422e-7*V01*V04*V07 - 
      1.13969026729443396e-8*V072 + 2.66580127691238802e-7*V022*V08 + 5.46810442643775977e-7*V01*V03*V08 - 
      1.96493872089110184e-8*V06*V08 + 1.92708526041859375e-7*V01*V02*V09 - 1.41821430883930884e-8*V05*V09 + 
      2.70996364746364746e-8*V012*V10 - 7.34701255534588868e-9*V04*V10 - 3.22184566976233643e-9*V03*V11 - 
      8.43099801433134766e-10*V02*V12 - 2.10774950358283692e-10*V01*V13 + 4.4280451755941952e-13*V16) + 
   delta6*eps5*(3.56125356125356125e-7*V043 + 3.07900047483380817e-6*V03*V04*V05 + 
      7.79024216524216524e-7*V02*V052 + 1.07882362346648061e-6*V032*V06 + 7.57069209450161831e-7*V02*V04*V06 + 
      6.47294174079888366e-7*V01*V05*V06 + 7.41927825261158594e-7*V02*V03*V07 + 4.39857210690544024e-7*V01*V04*V07 - 
      1.45735822819156152e-8*V072 + 6.83044664526146008e-8*V022*V08 + 2.31410821688599466e-7*V01*V03*V08 - 
      2.17026506709046392e-8*V06*V08 + 6.18273187717632162e-8*V01*V02*V09 - 1.76649482205037761e-8*V05*V09 + 
      7.22656972656972657e-9*V012*V10 - 7.38716016493794272e-9*V04*V10 - 3.57313725369280925e-9*V03*V11 - 
      6.42361753472864584e-10*V02*V12 - 1.60590438368216146e-10*V01*V13 + 5.9040602341255936e-13*V16) + 
   delta2*eps7*(-0.0000311898749398749399*V022*V032 - 
      0.0000202922077922077922*V01*V033 - 6.91438191438191438e-6*V023*V04 - 
      0.0000756072631072631073*V01*V02*V03*V04 - 0.0000108976671476671477*V012*V042 + 
      1.41486599819933153e-6*V043 - 0.0000187139249639249639*V01*V022*V05 - 
      0.0000174362674362674363*V012*V03*V05 + 8.83134997718331052e-6*V03*V04*V05 + 
      2.36067944401277735e-6*V02*V052 - 7.89141414141414141e-6*V012*V02*V06 + 
      3.2333737690880548e-6*V032*V06 + 3.3093559879274165e-6*V02*V04*V06 + 2.16549323692180835e-6*V01*V05*V06 - 
      7.51563251563251563e-7*V013*V07 + 2.48834884251550918e-6*V02*V03*V07 + 1.55419426252759586e-6*V01*V04*V07 - 
      2.27636946386946387e-8*V072 + 3.52656602656602657e-7*V022*V08 + 8.77305564805564806e-7*V01*V03*V08 - 
      3.81287583668536049e-8*V06*V08 + 2.67383079883079883e-7*V01*V02*V09 - 2.83040647623980957e-8*V05*V09 + 
      3.61328486328486328e-8*V012*V10 - 1.39713681380348047e-8*V04*V10 - 6.3834699251365918e-9*V03*V11 - 
      1.44531394531394531e-9*V02*V12 - 3.61328486328486328e-10*V01*V13 + 8.8560903511883904e-13*V16) + 
   delta4*eps6*(-0.0000102087341670675004*V022*V032 - 7.13985088985088985e-6*V01*V033 - 
      9.01875901875901876e-7*V023*V04 - 0.0000239999198332531666*V01*V02*V03*V04 - 
      3.34445646945646946e-6*V012*V042 + 9.90714532381199048e-7*V043 - 
      6.12524050024050024e-6*V01*V022*V05 - 5.59914622414622415e-6*V012*V03*V05 + 
      7.18272853689520356e-6*V03*V04*V05 + 1.84751269820714265e-6*V02*V052 - 
      2.31732002565335899e-6*V012*V02*V06 + 2.5855634114562686e-6*V032*V06 + 
      2.17219215235088251e-6*V02*V04*V06 + 1.60770529074100503e-6*V01*V05*V06 - 1.87890812890812891e-7*V013*V07 + 
      1.8291250930139819e-6*V02*V03*V07 + 1.10662871079537746e-6*V01*V04*V07 - 2.25830303955303955e-8*V072 + 
      2.09088750755417422e-7*V022*V08 + 6.12813112813112813e-7*V01*V03*V08 - 3.60296119224690653e-8*V06*V08 + 
      1.69824388574388574e-7*V01*V02*V09 - 2.79427362760696094e-8*V05*V09 + 2.16797091797091797e-8*V012*V10 - 
      1.27669398502731836e-8*V04*V10 - 6.02214143880810547e-9*V03*V11 - 1.20442828776162109e-9*V02*V12 - 
      3.01107071940405274e-10*V01*V13 + 8.8560903511883904e-13*V16) + 2.81145725434552076e-15*delta16*V16 + 
   1.12458290173820831e-14*delta14*eps*V16;
}
#endif

#ifdef p10 /* Uses: V00 - V18. */
double Vp(void)
{

   V012 = V01 * V01;
   V013 = V01 * V012;
   V014 = V01 * V013;
   V022 = V02 * V02;
   V023 = V02 * V022;
   V024 = V02 * V023;
   V025 = V02 * V024;
   V032 = V03 * V03;
   V033 = V02 * V032;
   V034 = V03 * V033;
   V042 = V04 * V04;
   V043 = V04 * V042;
   V052 = V05 * V05;
   V062 = V06 * V06;
   V072 = V07 * V07;
   V082 = V08 * V08;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;
   delta8 = delta2 * delta6;
   delta10 = delta2 * delta8;
   delta12 = delta2 * delta10;
   delta14 = delta2 * delta12;
   delta16 = delta2 * delta14;
   delta18 = delta2 * delta16;

   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 + eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) + 
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 + 
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) + 
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 + 
   0.000297619047619047619*delta4*eps*V06 + eps4*(0.00416666666666666667*V012*V02 - 0.000570436507936507937*V032 - 0.000595238095238095238*V02*V04 - 
      0.000446428571428571429*V01*V05 + 4.1335978835978836e-6*V08) + delta2*eps3*
    (-0.000992063492063492063*V032 - 0.000793650793650793651*V02*V04 - 0.000595238095238095238*V01*V05 + 8.2671957671957672e-6*V08) + 
   delta4*eps2*(-0.000496031746031746032*V032 - 0.000396825396825396825*V02*V04 - 0.000297619047619047619*V01*V05 + 8.2671957671957672e-6*V08) + 
   2.75573192239858907e-6*delta8*V08 + 5.51146384479717813e-6*delta6*eps*V08 + 
   eps5*(0.0001763668430335097*V023 + 0.00143849206349206349*V01*V02*V03 + 0.000446428571428571429*V012*V04 - 0.0000388558201058201058*V042 - 
      0.0000785383597883597884*V03*V05 - 0.0000330687830687830688*V02*V06 - 0.0000165343915343915344*V01*V07 + 9.39454064454064454e-8*V10) + 
   delta6*eps2*(-0.0000154320987654320988*V042 - 0.0000385802469135802469*V03*V05 - 0.0000110229276895943563*V02*V06 - 5.51146384479717813e-6*V01*V07 + 
      1.25260541927208594e-7*V10) + delta2*eps4*(0.0000661375661375661376*V023 + 0.00119047619047619048*V01*V02*V03 + 
      0.000297619047619047619*V012*V04 - 0.0000644841269841269841*V042 - 0.00014880952380952381*V03*V05 - 0.0000496031746031746032*V02*V06 - 
      0.0000248015873015873016*V01*V07 + 1.87890812890812891e-7*V10) + delta4*eps3*
    (-0.0000462962962962962963*V042 - 0.000115740740740740741*V03*V05 - 0.0000330687830687830688*V02*V06 - 0.0000165343915343915344*V01*V07 + 1.87890812890812891e-7*V10) + 
   2.50521083854417188e-8*delta10*V10 + 6.26302709636042969e-8*delta8*eps*V10 + 
   delta8*eps2*(-7.89141414141414141e-7*V052 - 9.01875901875901876e-7*V04*V06 - 7.51563251563251563e-7*V03*V07 - 1.67014055902944792e-7*V02*V08 - 
      6.26302709636042969e-8*V01*V09 + 1.20442828776162109e-9*V12) + eps6*
    (-0.000421626984126984127*V012*V022 - 0.00014880952380952381*V013*V03 + 0.000144675925925925926*V02*V032 + 
      0.0000793650793650793651*V022*V04 + 0.000188492063492063492*V01*V03*V04 + 0.000111607142857142857*V01*V02*V05 - 3.33506192881192881e-6*V052 + 
      0.0000248015873015873016*V012*V06 - 5.11063011063011063e-6*V04*V06 - 3.56992544492544493e-6*V03*V07 - 1.25260541927208594e-6*V02*V08 - 4.69727032227032227e-7*V01*V09 + 
      1.80664243164243164e-9*V12) + delta6*eps3*(-3.15656565656565657e-6*V052 - 3.6075036075036075e-6*V04*V06 - 3.00625300625300625e-6*V03*V07 - 
      6.68056223611779167e-7*V02*V08 - 2.50521083854417188e-7*V01*V09 + 2.40885657552324219e-9*V12) + 
   delta2*eps5*(0.00020667989417989418*V02*V032 + 0.0000727513227513227513*V022*V04 + 0.000243055555555555556*V01*V03*V04 + 
      0.000124007936507936508*V01*V02*V05 - 6.57617845117845118e-6*V052 + 0.0000248015873015873016*V012*V06 - 9.16907166907166907e-6*V04*V06 - 
      6.95196007696007696e-6*V03*V07 - 2.0041686708353375e-6*V02*V08 - 7.51563251563251563e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   delta4*eps4*(0.000082671957671957672*V02*V032 + 0.0000198412698412698413*V022*V04 + 0.0000925925925925925926*V01*V03*V04 + 
      0.0000496031746031746032*V01*V02*V05 - 6.1377665544332211e-6*V052 + 8.2671957671957672e-6*V012*V06 - 7.56573673240339907e-6*V04*V06 - 
      6.0751362834696168e-6*V03*V07 - 1.50312650312650313e-6*V02*V08 - 5.63672438672438672e-7*V01*V09 + 3.61328486328486328e-9*V12) + 1.60590438368216146e-10*delta12*V12 + 
   4.81771315104648438e-10*delta10*eps*V12 + delta10*eps2*
    (-1.3627245770102913e-8*V062 - 3.17969067969067969e-8*V05*V07 - 1.41319585764030208e-8*V04*V08 - 8.83247411025188803e-9*V03*V09 - 1.60590438368216146e-9*V02*V10 - 
      4.81771315104648438e-10*V01*V11 + 8.0295219184108073e-12*V14) + delta8*eps3*
    (-6.81362288505145648e-8*V062 - 1.58984533984533985e-7*V05*V07 - 7.06597928820151042e-8*V04*V08 - 4.41623705512594401e-8*V03*V09 - 8.0295219184108073e-9*V02*V10 - 
      2.40885657552324219e-9*V01*V11 + 2.00738047960270182e-11*V14) + eps7*
    (-0.0000132275132275132275*V024 - 0.000203373015873015873*V01*V022*V03 - 0.0000777116402116402116*V012*V032 - 
      0.000124007936507936508*V012*V02*V04 + 0.0000224842672759339426*V032*V04 + 0.000013452982202982203*V02*V042 - 
      0.0000165343915343915344*V013*V05 + 0.0000264299743466410133*V02*V03*V05 + 0.0000173485850569183903*V01*V04*V05 + 5.71188071188071188e-6*V022*V06 + 
      0.0000124383718133718134*V01*V03*V06 - 1.95667978406073644e-7*V062 + 5.44883357383357383e-6*V01*V02*V07 - 3.61569371986038653e-7*V05*V07 + 
      9.39454064454064454e-7*V012*V08 - 2.24023661523661524e-7*V04*V08 - 1.20442828776162109e-7*V03*V09 - 3.61328486328486328e-8*V02*V10 - 1.08398545898545899e-8*V01*V11 + 
      3.01107071940405274e-11*V14) + delta6*eps4*(6.76406926406926407e-6*V032*V04 + 1.90396023729357063e-6*V02*V042 + 
      7.01459034792368126e-6*V02*V03*V05 + 4.05844155844155844e-6*V01*V04*V05 + 6.51354818021484688e-7*V022*V06 + 2.70562770562770563e-6*V01*V03*V06 - 
      1.88303759732331161e-7*V062 + 1.00208433541766875e-6*V01*V02*V07 - 4.20586358086358086e-7*V05*V07 + 1.25260541927208594e-7*V012*V08 - 
      1.99453324453324453e-7*V04*V08 - 1.22048733159844271e-7*V03*V09 - 2.40885657552324219e-8*V02*V10 - 7.22656972656972657e-9*V01*V11 + 4.01476095920540365e-11*V14) + 
   delta2*eps6*(-1.65343915343915344e-6*V024 - 0.000133928571428571429*V01*V022*V03 - 0.0000562169312169312169*V012*V032 - 
      0.0000744047619047619048*V012*V02*V04 + 0.0000395197009780343114*V032*V04 + 0.0000179623617123617124*V02*V042 - 8.2671957671957672e-6*V013*V05 + 
      0.0000417743907327240661*V02*V03*V05 + 0.0000256408329324995992*V01*V04*V05 + 6.68891293891293891e-6*V022*V06 + 0.0000185636123136123136*V01*V03*V06 - 
      3.70998324867372486e-7*V062 + 6.95196007696007696e-6*V01*V02*V07 - 7.19525459108792442e-7*V05*V07 + 1.12734487734487734e-6*V012*V08 - 
      4.17213958880625547e-7*V04*V08 - 2.37272372689039356e-7*V03*V09 - 6.02214143880810547e-8*V02*V10 - 1.80664243164243164e-8*V01*V11 + 6.02214143880810547e-11*V14) + 
   delta4*eps5*(0.0000263047138047138047*V032*V04 + 9.11896745230078563e-6*V02*V042 + 0.0000267431257014590348*V02*V03*V05 + 
      0.0000157828282828282828*V01*V04*V05 + 3.20666987333654e-6*V022*V06 + 0.0000109352453102453102*V01*V03*V06 - 3.36345202416630988e-7*V062 + 
      3.82044652877986211e-6*V01*V02*V07 - 7.00254606504606505e-7*V05*V07 + 5.63672438672438672e-7*V012*V08 - 3.67591513424846758e-7*V04*V08 - 
      2.18001520084853418e-7*V03*V09 - 4.81771315104648438e-8*V02*V10 - 1.44531394531394531e-8*V01*V11 + 6.02214143880810547e-11*V14) + 7.64716373181981648e-13*delta14*V14 + 
   2.67650730613693577e-12*delta12*eps*V14 + delta12*eps2*
    (-3.28063324095070127e-10*V072 - 4.37417765460093502e-10*V06*V08 - 3.82740544777581815e-10*V05*V09 - 1.3917837991912066e-10*V04*V10 - 6.95891899595603299e-11*V03*V11 - 
      1.07060292245477431e-11*V02*V12 - 2.67650730613693577e-12*V01*V13 + 3.93604015608372907e-14*V16) + 
   delta10*eps3*(-1.96837994457042076e-9*V072 - 2.62450659276056101e-9*V06*V08 - 2.29644326866549089e-9*V05*V09 - 8.35070279514723959e-10*V04*V10 - 
      4.1753513975736198e-10*V03*V11 - 6.42361753472864584e-11*V02*V12 - 1.60590438368216146e-11*V01*V13 + 1.18081204682511872e-13*V16) + 
   delta8*eps4*(5.93542260208926876e-8*V043 + 5.93542260208926876e-7*V03*V04*V05 + 1.51757964257964258e-7*V02*V052 + 
      2.04408686551543694e-7*V032*V06 + 1.2498524403286308e-7*V02*V04*V06 + 1.22645211930926217e-7*V01*V05*V06 + 1.44531394531394531e-7*V02*V03*V07 + 
      8.47917514584181251e-8*V01*V04*V07 - 6.52972193150764579e-9*V072 + 1.09201498090386979e-8*V022*V08 + 4.23958757292090625e-8*V01*V03*V08 - 
      9.08483051340194197e-9*V06*V08 + 1.20442828776162109e-8*V01*V02*V09 - 7.72841484647040203e-9*V05*V09 + 1.20442828776162109e-9*V012*V10 - 2.9709231098119987e-9*V04*V10 - 
      1.46538775010997233e-9*V03*V11 - 2.40885657552324219e-10*V02*V12 - 6.02214143880810547e-11*V01*V13 + 2.9520301170627968e-13*V16) + 
   eps8*(0.0000427138447971781305*V012*V023 + 0.0000454695767195767196*V013*V02*V03 - 0.0000265865500240500241*V022*V032 - 
      0.0000157201980118646785*V01*V033 + 4.1335978835978836e-6*V014*V04 - 0.0000100208433541766875*V023*V04 - 0.000068329625621292288*V01*V02*V03*V04 - 
      0.0000103840989257655924*V012*V042 + 8.50711788211788212e-7*V043 - 0.0000202922077922077922*V01*V022*V05 - 
      0.0000166283369408369408*V012*V03*V05 + 4.77122221913888581e-6*V03*V04*V05 + 1.40881976819476819e-6*V02*V052 - 8.83086820586820587e-6*V012*V02*V06 + 
      1.726031766954386e-6*V032*V06 + 2.18586528110337634e-6*V02*V04*V06 + 1.33467860402384212e-6*V01*V05*V06 - 9.39454064454064454e-7*V013*V07 + 
      1.49830878997545664e-6*V02*V03*V07 + 9.8088639755306422e-7*V01*V04*V07 - 1.13969026729443396e-8*V072 + 2.66580127691238802e-7*V022*V08 + 
      5.46810442643775977e-7*V01*V03*V08 - 1.96493872089110184e-8*V06*V08 + 1.92708526041859375e-7*V01*V02*V09 - 1.41821430883930884e-8*V05*V09 + 
      2.70996364746364746e-8*V012*V10 - 7.34701255534588868e-9*V04*V10 - 3.22184566976233643e-9*V03*V11 - 8.43099801433134766e-10*V02*V12 - 2.10774950358283692e-10*V01*V13 + 
      4.4280451755941952e-13*V16) + delta6*eps5*(3.56125356125356125e-7*V043 + 3.07900047483380817e-6*V03*V04*V05 + 7.79024216524216524e-7*V02*V052 + 
      1.07882362346648061e-6*V032*V06 + 7.57069209450161831e-7*V02*V04*V06 + 6.47294174079888366e-7*V01*V05*V06 + 7.41927825261158594e-7*V02*V03*V07 + 
      4.39857210690544024e-7*V01*V04*V07 - 1.45735822819156152e-8*V072 + 6.83044664526146008e-8*V022*V08 + 2.31410821688599466e-7*V01*V03*V08 - 
      2.17026506709046392e-8*V06*V08 + 6.18273187717632162e-8*V01*V02*V09 - 1.76649482205037761e-8*V05*V09 + 7.22656972656972657e-9*V012*V10 - 
      7.38716016493794272e-9*V04*V10 - 3.57313725369280925e-9*V03*V11 - 6.42361753472864584e-10*V02*V12 - 1.60590438368216146e-10*V01*V13 + 5.9040602341255936e-13*V16) + 
   delta2*eps7*(-0.0000311898749398749399*V022*V032 - 0.0000202922077922077922*V01*V033 - 6.91438191438191438e-6*V023*V04 - 
      0.0000756072631072631073*V01*V02*V03*V04 - 0.0000108976671476671477*V012*V042 + 1.41486599819933153e-6*V043 - 
      0.0000187139249639249639*V01*V022*V05 - 0.0000174362674362674363*V012*V03*V05 + 8.83134997718331052e-6*V03*V04*V05 + 2.36067944401277735e-6*V02*V052 - 
      7.89141414141414141e-6*V012*V02*V06 + 3.2333737690880548e-6*V032*V06 + 3.3093559879274165e-6*V02*V04*V06 + 2.16549323692180835e-6*V01*V05*V06 - 
      7.51563251563251563e-7*V013*V07 + 2.48834884251550918e-6*V02*V03*V07 + 1.55419426252759586e-6*V01*V04*V07 - 2.27636946386946387e-8*V072 + 
      3.52656602656602657e-7*V022*V08 + 8.77305564805564806e-7*V01*V03*V08 - 3.81287583668536049e-8*V06*V08 + 2.67383079883079883e-7*V01*V02*V09 - 
      2.83040647623980957e-8*V05*V09 + 3.61328486328486328e-8*V012*V10 - 1.39713681380348047e-8*V04*V10 - 6.3834699251365918e-9*V03*V11 - 1.44531394531394531e-9*V02*V12 - 
      3.61328486328486328e-10*V01*V13 + 8.8560903511883904e-13*V16) + delta4*eps6*
    (-0.0000102087341670675004*V022*V032 - 7.13985088985088985e-6*V01*V033 - 9.01875901875901876e-7*V023*V04 - 
      0.0000239999198332531666*V01*V02*V03*V04 - 3.34445646945646946e-6*V012*V042 + 9.90714532381199048e-7*V043 - 
      6.12524050024050024e-6*V01*V022*V05 - 5.59914622414622415e-6*V012*V03*V05 + 7.18272853689520356e-6*V03*V04*V05 + 1.84751269820714265e-6*V02*V052 - 
      2.31732002565335899e-6*V012*V02*V06 + 2.5855634114562686e-6*V032*V06 + 2.17219215235088251e-6*V02*V04*V06 + 1.60770529074100503e-6*V01*V05*V06 - 
      1.87890812890812891e-7*V013*V07 + 1.8291250930139819e-6*V02*V03*V07 + 1.10662871079537746e-6*V01*V04*V07 - 2.25830303955303955e-8*V072 + 
      2.09088750755417422e-7*V022*V08 + 6.12813112813112813e-7*V01*V03*V08 - 3.60296119224690653e-8*V06*V08 + 1.69824388574388574e-7*V01*V02*V09 - 
      2.79427362760696094e-8*V05*V09 + 2.16797091797091797e-8*V012*V10 - 1.27669398502731836e-8*V04*V10 - 6.02214143880810547e-9*V03*V11 - 1.20442828776162109e-9*V02*V12 - 
      3.01107071940405274e-10*V01*V13 + 8.8560903511883904e-13*V16) + 2.81145725434552076e-15*delta16*V16 + 1.12458290173820831e-14*delta14*eps*V16 + 
   delta14*eps2*(-3.57367455441252861e-12*V082 - 8.04076774742818938e-12*V07*V09 - 4.38587331677901239e-12*V06*V10 - 3.07011132174530867e-12*V05*V11 - 
      9.44649637460094976e-13*V04*V12 - 3.93604015608372907e-13*V03*V13 - 5.24805354144497209e-14*V02*V14 - 1.12458290173820831e-14*V01*V15 + 1.47971434439237935e-16*V18) + 
   delta12*eps3*(-2.50157218808877003e-11*V082 - 5.62853742319973257e-11*V07*V09 - 3.07011132174530867e-11*V06*V10 - 2.14907792522171607e-11*V05*V11 - 
      6.61254746222066484e-12*V04*V12 - 2.75522810925861035e-12*V03*V13 - 3.67363747901148046e-13*V02*V14 - 7.87208031216745814e-14*V01*V15 + 5.17900020537332772e-16*V18) + 
   delta10*eps4*(1.31523569023569024e-8*V04*V052 + 5.84549195660306771e-9*V042*V06 + 1.83715461493239271e-8*V03*V05*V06 + 
      2.06932250583044234e-9*V02*V062 + 1.25260541927208594e-8*V03*V04*V07 + 6.35938135938135938e-9*V02*V05*V07 + 2.62450659276056101e-9*V01*V06*V07 + 
      3.28063324095070127e-9*V032*V08 + 2.11061718998226935e-9*V02*V04*V08 + 1.96837994457042076e-9*V01*V05*V08 - 1.03457878350242703e-10*V082 + 
      1.76649482205037761e-9*V02*V03*V09 + 1.04383784939340495e-9*V01*V04*V09 - 2.25945573702732122e-10*V07*V09 + 1.12413306857751302e-10*V022*V10 + 
      4.1753513975736198e-10*V01*V03*V10 - 1.28213696627173129e-10*V06*V10 + 9.63542630209296876e-11*V01*V02*V11 - 8.8009857890032182e-11*V05*V11 + 
      8.0295219184108073e-12*V012*V12 - 2.84182099269245239e-11*V04*V12 - 1.17293996651295126e-11*V03*V13 - 1.65313686555516621e-12*V02*V14 - 
      3.54243614047535616e-13*V01*V15 + 1.55370006161199832e-15*V18) + delta8*eps5*
    (8.54903198653198653e-8*V04*V052 + 4.25885842552509219e-8*V042*V06 + 1.20563271604938272e-7*V03*V05*V06 + 1.51413841890032366e-8*V02*V062 + 
      8.1419352252685586e-8*V03*V04*V07 + 4.10710046126712793e-8*V02*V05*V07 + 1.72233245149911817e-8*V01*V06*V07 + 2.18708882730046751e-8*V032*V08 + 
      1.55696253579851463e-8*V02*V04*V08 + 1.31225329638028051e-8*V01*V05*V08 - 3.06889302360175895e-10*V082 + 1.14086123924086887e-8*V02*V03*V09 + 
      6.78494602105713217e-9*V01*V04*V09 - 6.39241035920541056e-10*V07*V09 + 8.56482337963819445e-10*V022*V10 + 2.87055408583186361e-9*V01*V03*V10 - 
      3.8595685187655309e-10*V06*V10 + 6.22287948676837566e-10*V01*V02*V11 - 2.57121823196169601e-10*V05*V11 + 6.02214143880810547e-11*V012*V12 - 
      8.91513095352964634e-11*V04*V12 - 3.63099704398724007e-11*V03*V13 - 5.5104562185172207e-12*V02*V14 - 1.18081204682511872e-12*V01*V15 + 3.88425015402999579e-15*V18) + 
   eps9*(1.06888995777884667e-6*V025 + 0.0000263923961840628507*V01*V023*V03 + 0.0000299748476831810165*V012*V02*V032 - 
      1.21518211175949271e-6*V034 + 0.0000238245550745550746*V012*V022*V04 + 0.0000102212602212602213*V013*V03*V04 - 
      0.0000101287830702513242*V02*V032*V04 - 3.09484386865339246e-6*V022*V042 - 6.45033978367311701e-6*V01*V03*V042 + 
      6.32565736732403399e-6*V013*V02*V05 - 5.97243869813314258e-6*V022*V03*V05 - 5.42102848650467698e-6*V01*V032*V05 - 
      7.74114737408388202e-6*V01*V02*V04*V05 - 9.78856075582266058e-7*V012*V052 + 2.90447881593714927e-7*V04*V052 + 4.69727032227032227e-7*V014*V06 - 
      8.74346112441350537e-7*V023*V06 - 5.52347371543800115e-6*V01*V02*V03*V06 - 1.67601358077548554e-6*V012*V04*V06 + 2.3201418290704005e-7*V042*V06 + 
      4.20311060192012573e-7*V03*V05*V06 + 1.000249016122032e-7*V02*V062 - 1.21213662880329547e-6*V01*V022*V07 - 1.0095517908017908e-6*V012*V03*V07 + 
      3.08183088131004798e-7*V03*V04*V07 + 1.83444465128492906e-7*V02*V05*V07 + 8.64564434132886514e-8*V01*V06*V07 - 4.09505617838951172e-7*V012*V02*V08 + 
      8.67546827988296242e-8*V032*V08 + 1.14248626153388058e-7*V02*V04*V08 + 6.72587168122882409e-8*V01*V05*V08 - 5.58025064485634825e-10*V082 - 
      3.61328486328486328e-8*V013*V09 + 6.05727059720115276e-8*V02*V03*V09 + 3.94450264241930909e-8*V01*V04*V09 - 1.01977880393934316e-9*V07*V09 + 
      9.15365498698832032e-9*V022*V10 + 1.79760921948421948e-8*V01*V03*V10 - 7.27717595714794594e-10*V06*V10 + 5.32959517334517335e-9*V01*V02*V11 - 
      4.32620013655552871e-10*V05*V11 + 6.32324851074851075e-10*V012*V12 - 1.92177160620788072e-10*V04*V12 - 7.12915273270665428e-11*V03*V13 - 
      1.65313686555516621e-11*V02*V14 - 3.54243614047535616e-12*V01*V15 + 5.82637523104499369e-15*V18) + 
   delta6*eps6*(-3.02827683780064732e-7*V034 - 1.85757254209635162e-6*V02*V032*V04 - 1.58222876476844731e-7*V022*V042 - 
      1.08321462488129155e-6*V01*V03*V042 - 9.25161515439293217e-7*V022*V03*V05 - 1.03112826327112041e-6*V01*V032*V05 - 
      1.11454352525781097e-6*V01*V02*V04*V05 - 1.39369559012416155e-7*V012*V052 + 2.68161943509165731e-7*V04*V052 - 3.51463645114438765e-8*V023*V06 - 
      7.62712816284244856e-7*V01*V02*V03*V06 - 2.12598798908322718e-7*V012*V04*V06 + 1.55031715051556321e-7*V042*V06 + 3.8440189109831967e-7*V03*V05*V06 + 
      5.61607704464847322e-8*V02*V062 - 1.32165930777041888e-7*V01*V022*V07 - 1.24296999296999297e-7*V012*V03*V07 + 2.6128064322508767e-7*V03*V04*V07 + 
      1.32968882968882969e-7*V02*V05*V07 + 5.73479926158497587e-8*V01*V06*V07 - 3.77387530165307943e-8*V012*V02*V08 + 7.26576144069530313e-8*V032*V08 + 
      5.89825738635262445e-8*V02*V04*V08 + 4.44778160551970076e-8*V01*V05*V08 - 6.7521831725198257e-10*V082 - 2.40885657552324219e-9*V013*V09 + 
      3.86086178910252984e-8*V02*V03*V09 + 2.32454659537992871e-8*V01*V04*V09 - 1.33786004905285951e-9*V07*V09 + 3.45269442491664714e-9*V022*V10 + 
      1.03580832747499414e-8*V01*V03*V10 - 8.61655419311815204e-10*V06*V10 + 2.28841374674708008e-9*V01*V02*V11 - 5.54981662007805799e-10*V05*V11 + 
      2.40885657552324219e-10*V012*V12 - 2.07822920241220895e-10*V04*V12 - 8.32472493011708698e-11*V03*V13 - 1.37761405462930517e-11*V02*V14 - 
      2.9520301170627968e-12*V01*V15 + 7.76850030805999158e-15*V18) + delta2*eps8*
    (4.1753513975736198e-8*V025 + 0.0000140291806958473625*V01*V023*V03 + 0.0000188517115600448934*V012*V02*V032 - 2.104308279903518e-6*V034 + 
      0.0000125886844636844637*V012*V022*V04 + 5.82461519961519962e-6*V013*V03*V04 - 0.0000153405163325798246*V02*V032*V04 - 
      3.46221514376276281e-6*V022*V042 - 9.37767864851198185e-6*V01*V03*V042 + 2.94362273528940196e-6*V013*V02*V05 - 
      7.97973888251666029e-6*V022*V03*V05 - 8.09444633849395754e-6*V01*V032*V05 - 9.9663114296050804e-6*V01*V02*V04*V05 - 
      1.24727152256914162e-6*V012*V052 + 5.53495019640852974e-7*V04*V052 + 1.87890812890812891e-7*V014*V06 - 8.40346822489679633e-7*V023*V06 - 
      7.21314895422038279e-6*V01*V02*V03*V06 - 2.10547829595448643e-6*V012*V04*V06 + 4.143130073189597e-7*V042*V06 + 8.11973933253695158e-7*V03*V05*V06 + 
      1.64565051717829496e-7*V02*V062 - 1.3248711165377832e-6*V01*V022*V07 - 1.25380984755984756e-6*V012*V03*V07 + 5.84147719564386231e-7*V03*V04*V07 + 
      3.1668434446212224e-7*V02*V05*V07 + 1.46458479791813125e-7*V01*V06*V07 - 4.40820753320753321e-7*V012*V02*V08 + 1.6699971747094763e-7*V032*V08 + 
      1.84426647720298514e-7*V02*V04*V08 + 1.14231420034991464e-7*V01*V05*V08 - 1.09940630202554417e-9*V082 - 3.61328486328486328e-8*V013*V09 + 
      1.03781570795459684e-7*V02*V03*V09 + 6.52800131966798633e-8*V01*V04*V09 - 2.03867199884356747e-9*V07*V09 + 1.30479731174175619e-8*V022*V10 + 
      3.01107071940405274e-8*V01*V03*V10 - 1.42836085807024182e-9*V06*V10 + 7.82878387045053712e-9*V01*V02*V11 - 8.64354418275986903e-10*V05*V11 + 
      9.03321215821215821e-10*V012*V12 - 3.70184576679674719e-10*V04*V12 - 1.41697445619014246e-10*V03*V13 - 2.89298951472154087e-11*V02*V14 - 
      6.19926324583187328e-12*V01*V15 + 1.16527504620899874e-14*V18) + delta4*eps7*
    (-1.3248711165377832e-6*V034 - 8.6670659587326254e-6*V02*V032*V04 - 1.31581381581381581e-6*V022*V042 - 
      5.14897910731244065e-6*V01*V03*V042 - 4.27957459207459207e-6*V022*V03*V05 - 4.63174942341609008e-6*V01*V032*V05 - 
      5.20023957523957524e-6*V01*V02*V04*V05 - 6.59063159063159063e-7*V012*V052 + 5.00520248784137673e-7*V04*V052 - 3.03928875357446786e-7*V023*V06 - 
      3.68334817739579644e-6*V01*V02*V03*V06 - 1.04922909982433792e-6*V012*V04*V06 + 3.34278174059920092e-7*V042*V06 + 7.29246916002868384e-7*V03*V05*V06 + 
      1.25604664295140486e-7*V02*V062 - 6.11367798867798868e-7*V01*V022*V07 - 6.07995399662066329e-7*V012*V03*V07 + 5.08188442216219994e-7*V03*V04*V07 + 
      2.63408466533466533e-7*V02*V05*V07 + 1.17724262069500165e-7*V01*V06*V07 - 1.95117382617382617e-7*V012*V02*V08 + 1.4478948630734345e-7*V032*V08 + 
      1.36065984280269995e-7*V02*V04*V08 + 9.21731762505572029e-8*V01*V05*V08 - 1.06818506921603716e-9*V082 - 1.44531394531394531e-8*V013*V09 + 
      8.19011235677902345e-8*V02*V03*V09 + 5.02246595996595997e-8*V01*V04*V09 - 2.03276793860944188e-9*V07*V09 + 8.67188367188367188e-9*V022*V10 + 
      2.30045802962469629e-8*V01*V03*V10 - 1.37834503351543501e-9*V06*V10 + 5.41992729492729493e-9*V01*V02*V11 - 8.5845035804186131e-10*V05*V11 + 
      6.02214143880810547e-10*V012*V12 - 3.45977929719759785e-10*V04*V12 - 1.35793385384888653e-10*V03*V13 - 2.47970529833274931e-11*V02*V14 - 
      5.31365421071303424e-12*V01*V15 + 1.16527504620899874e-14*V18) + 8.22063524662432972e-18*delta18*V18 + 3.69928586098094837e-17*delta16*eps*V18;
}
#endif

#ifdef p11 /* Uses: V00 - V20. */
double Vp(void)
{

   V012 = V01 * V01;
   V013 = V01 * V012;
   V014 = V01 * V013;
   V015 = V01 * V014;
   V022 = V02 * V02;
   V023 = V02 * V022;
   V024 = V02 * V023;
   V025 = V02 * V024;
   V032 = V03 * V03;
   V033 = V03 * V032;
   V034 = V03 * V033;
   V042 = V04 * V04;
   V043 = V04 * V042;
   V052 = V05 * V05;
   V062 = V06 * V06;
   V072 = V07 * V07;
   V082 = V08 * V08;
   V092 = V09 * V09;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;
   delta8 = delta2 * delta6;
   delta10 = delta2 * delta8;
   delta12 = delta2 * delta10;
   delta14 = delta2 * delta12;
   delta16 = delta2 * delta14;
   delta18 = delta2 * delta16;
   delta20 = delta2 * delta18;

   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 + 
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) + 
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 + 
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) + 
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 
      0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 + 
   0.000297619047619047619*delta4*eps*V06 + 
   eps4*(0.00416666666666666667*V012*V02 - 0.000570436507936507937*V032 - 
      0.000595238095238095238*V02*V04 - 0.000446428571428571429*V01*V05 + 4.1335978835978836e-6*V08) + 
   delta2*eps3*(-0.000992063492063492063*V032 - 0.000793650793650793651*V02*V04 - 
      0.000595238095238095238*V01*V05 + 8.2671957671957672e-6*V08) + 
   delta4*eps2*(-0.000496031746031746032*V032 - 0.000396825396825396825*V02*V04 - 
      0.000297619047619047619*V01*V05 + 8.2671957671957672e-6*V08) + 2.75573192239858907e-6*delta8*V08 + 
   5.51146384479717813e-6*delta6*eps*V08 + eps5*
    (0.0001763668430335097*V023 + 0.00143849206349206349*V01*V02*V03 + 0.000446428571428571429*V012*V04 - 
      0.0000388558201058201058*V042 - 0.0000785383597883597884*V03*V05 - 0.0000330687830687830688*V02*V06 - 
      0.0000165343915343915344*V01*V07 + 9.39454064454064454e-8*V10) + 
   delta6*eps2*(-0.0000154320987654320988*V042 - 0.0000385802469135802469*V03*V05 - 
      0.0000110229276895943563*V02*V06 - 5.51146384479717813e-6*V01*V07 + 1.25260541927208594e-7*V10) + 
   delta2*eps4*(0.0000661375661375661376*V023 + 0.00119047619047619048*V01*V02*V03 + 
      0.000297619047619047619*V012*V04 - 0.0000644841269841269841*V042 - 0.00014880952380952381*V03*V05 - 
      0.0000496031746031746032*V02*V06 - 0.0000248015873015873016*V01*V07 + 1.87890812890812891e-7*V10) + 
   delta4*eps3*(-0.0000462962962962962963*V042 - 0.000115740740740740741*V03*V05 - 
      0.0000330687830687830688*V02*V06 - 0.0000165343915343915344*V01*V07 + 1.87890812890812891e-7*V10) + 
   2.50521083854417188e-8*delta10*V10 + 6.26302709636042969e-8*delta8*eps*V10 + 
   delta8*eps2*(-7.89141414141414141e-7*V052 - 9.01875901875901876e-7*V04*V06 - 
      7.51563251563251563e-7*V03*V07 - 1.67014055902944792e-7*V02*V08 - 6.26302709636042969e-8*V01*V09 + 
      1.20442828776162109e-9*V12) + eps6*(-0.000421626984126984127*V012*V022 - 
      0.00014880952380952381*V013*V03 + 0.000144675925925925926*V02*V032 + 
      0.0000793650793650793651*V022*V04 + 0.000188492063492063492*V01*V03*V04 + 0.000111607142857142857*V01*V02*V05 - 
      3.33506192881192881e-6*V052 + 0.0000248015873015873016*V012*V06 - 5.11063011063011063e-6*V04*V06 - 
      3.56992544492544493e-6*V03*V07 - 1.25260541927208594e-6*V02*V08 - 4.69727032227032227e-7*V01*V09 + 
      1.80664243164243164e-9*V12) + delta6*eps3*
    (-3.15656565656565657e-6*V052 - 3.6075036075036075e-6*V04*V06 - 3.00625300625300625e-6*V03*V07 - 
      6.68056223611779167e-7*V02*V08 - 2.50521083854417188e-7*V01*V09 + 2.40885657552324219e-9*V12) + 
   delta2*eps5*(0.00020667989417989418*V02*V032 + 0.0000727513227513227513*V022*V04 + 
      0.000243055555555555556*V01*V03*V04 + 0.000124007936507936508*V01*V02*V05 - 6.57617845117845118e-6*V052 + 
      0.0000248015873015873016*V012*V06 - 9.16907166907166907e-6*V04*V06 - 6.95196007696007696e-6*V03*V07 - 
      2.0041686708353375e-6*V02*V08 - 7.51563251563251563e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   delta4*eps4*(0.000082671957671957672*V02*V032 + 0.0000198412698412698413*V022*V04 + 
      0.0000925925925925925926*V01*V03*V04 + 0.0000496031746031746032*V01*V02*V05 - 6.1377665544332211e-6*V052 + 
      8.2671957671957672e-6*V012*V06 - 7.56573673240339907e-6*V04*V06 - 6.0751362834696168e-6*V03*V07 - 
      1.50312650312650313e-6*V02*V08 - 5.63672438672438672e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   1.60590438368216146e-10*delta12*V12 + 4.81771315104648438e-10*delta10*eps*V12 + 
   delta10*eps2*(-1.3627245770102913e-8*V062 - 3.17969067969067969e-8*V05*V07 - 
      1.41319585764030208e-8*V04*V08 - 8.83247411025188803e-9*V03*V09 - 1.60590438368216146e-9*V02*V10 - 
      4.81771315104648438e-10*V01*V11 + 8.0295219184108073e-12*V14) + 
   delta8*eps3*(-6.81362288505145648e-8*V062 - 1.58984533984533985e-7*V05*V07 - 
      7.06597928820151042e-8*V04*V08 - 4.41623705512594401e-8*V03*V09 - 8.0295219184108073e-9*V02*V10 - 
      2.40885657552324219e-9*V01*V11 + 2.00738047960270182e-11*V14) + 
   eps7*(-0.0000132275132275132275*V024 - 0.000203373015873015873*V01*V022*V03 - 
      0.0000777116402116402116*V012*V032 - 0.000124007936507936508*V012*V02*V04 + 
      0.0000224842672759339426*V032*V04 + 0.000013452982202982203*V02*V042 - 
      0.0000165343915343915344*V013*V05 + 0.0000264299743466410133*V02*V03*V05 + 0.0000173485850569183903*V01*V04*V05 + 
      5.71188071188071188e-6*V022*V06 + 0.0000124383718133718134*V01*V03*V06 - 1.95667978406073644e-7*V062 + 
      5.44883357383357383e-6*V01*V02*V07 - 3.61569371986038653e-7*V05*V07 + 9.39454064454064454e-7*V012*V08 - 
      2.24023661523661524e-7*V04*V08 - 1.20442828776162109e-7*V03*V09 - 3.61328486328486328e-8*V02*V10 - 
      1.08398545898545899e-8*V01*V11 + 3.01107071940405274e-11*V14) + 
   delta6*eps4*(6.76406926406926407e-6*V032*V04 + 1.90396023729357063e-6*V02*V042 + 
      7.01459034792368126e-6*V02*V03*V05 + 4.05844155844155844e-6*V01*V04*V05 + 6.51354818021484688e-7*V022*V06 + 
      2.70562770562770563e-6*V01*V03*V06 - 1.88303759732331161e-7*V062 + 1.00208433541766875e-6*V01*V02*V07 - 
      4.20586358086358086e-7*V05*V07 + 1.25260541927208594e-7*V012*V08 - 1.99453324453324453e-7*V04*V08 - 
      1.22048733159844271e-7*V03*V09 - 2.40885657552324219e-8*V02*V10 - 7.22656972656972657e-9*V01*V11 + 
      4.01476095920540365e-11*V14) + delta2*eps6*
    (-1.65343915343915344e-6*V024 - 0.000133928571428571429*V01*V022*V03 - 
      0.0000562169312169312169*V012*V032 - 0.0000744047619047619048*V012*V02*V04 + 
      0.0000395197009780343114*V032*V04 + 0.0000179623617123617124*V02*V042 - 
      8.2671957671957672e-6*V013*V05 + 0.0000417743907327240661*V02*V03*V05 + 0.0000256408329324995992*V01*V04*V05 + 
      6.68891293891293891e-6*V022*V06 + 0.0000185636123136123136*V01*V03*V06 - 3.70998324867372486e-7*V062 + 
      6.95196007696007696e-6*V01*V02*V07 - 7.19525459108792442e-7*V05*V07 + 1.12734487734487734e-6*V012*V08 - 
      4.17213958880625547e-7*V04*V08 - 2.37272372689039356e-7*V03*V09 - 6.02214143880810547e-8*V02*V10 - 
      1.80664243164243164e-8*V01*V11 + 6.02214143880810547e-11*V14) + 
   delta4*eps5*(0.0000263047138047138047*V032*V04 + 9.11896745230078563e-6*V02*V042 + 
      0.0000267431257014590348*V02*V03*V05 + 0.0000157828282828282828*V01*V04*V05 + 3.20666987333654e-6*V022*V06 + 
      0.0000109352453102453102*V01*V03*V06 - 3.36345202416630988e-7*V062 + 3.82044652877986211e-6*V01*V02*V07 - 
      7.00254606504606505e-7*V05*V07 + 5.63672438672438672e-7*V012*V08 - 3.67591513424846758e-7*V04*V08 - 
      2.18001520084853418e-7*V03*V09 - 4.81771315104648438e-8*V02*V10 - 1.44531394531394531e-8*V01*V11 + 
      6.02214143880810547e-11*V14) + 7.64716373181981648e-13*delta14*V14 + 
   2.67650730613693577e-12*delta12*eps*V14 + 
   delta12*eps2*(-3.28063324095070127e-10*V072 - 4.37417765460093502e-10*V06*V08 - 
      3.82740544777581815e-10*V05*V09 - 1.3917837991912066e-10*V04*V10 - 6.95891899595603299e-11*V03*V11 - 
      1.07060292245477431e-11*V02*V12 - 2.67650730613693577e-12*V01*V13 + 3.93604015608372907e-14*V16) + 
   delta10*eps3*(-1.96837994457042076e-9*V072 - 2.62450659276056101e-9*V06*V08 - 
      2.29644326866549089e-9*V05*V09 - 8.35070279514723959e-10*V04*V10 - 4.1753513975736198e-10*V03*V11 - 
      6.42361753472864584e-11*V02*V12 - 1.60590438368216146e-11*V01*V13 + 1.18081204682511872e-13*V16) + 
   delta8*eps4*(5.93542260208926876e-8*V043 + 5.93542260208926876e-7*V03*V04*V05 + 
      1.51757964257964258e-7*V02*V052 + 2.04408686551543694e-7*V032*V06 + 1.2498524403286308e-7*V02*V04*V06 + 
      1.22645211930926217e-7*V01*V05*V06 + 1.44531394531394531e-7*V02*V03*V07 + 8.47917514584181251e-8*V01*V04*V07 - 
      6.52972193150764579e-9*V072 + 1.09201498090386979e-8*V022*V08 + 4.23958757292090625e-8*V01*V03*V08 - 
      9.08483051340194197e-9*V06*V08 + 1.20442828776162109e-8*V01*V02*V09 - 7.72841484647040203e-9*V05*V09 + 
      1.20442828776162109e-9*V012*V10 - 2.9709231098119987e-9*V04*V10 - 1.46538775010997233e-9*V03*V11 - 
      2.40885657552324219e-10*V02*V12 - 6.02214143880810547e-11*V01*V13 + 2.9520301170627968e-13*V16) + 
   eps8*(0.0000427138447971781305*V012*V023 + 0.0000454695767195767196*V013*V02*V03 - 
      0.0000265865500240500241*V022*V032 - 0.0000157201980118646785*V01*V033 + 
      4.1335978835978836e-6*V014*V04 - 0.0000100208433541766875*V023*V04 - 
      0.000068329625621292288*V01*V02*V03*V04 - 0.0000103840989257655924*V012*V042 + 
      8.50711788211788212e-7*V043 - 0.0000202922077922077922*V01*V022*V05 - 
      0.0000166283369408369408*V012*V03*V05 + 4.77122221913888581e-6*V03*V04*V05 + 
      1.40881976819476819e-6*V02*V052 - 8.83086820586820587e-6*V012*V02*V06 + 
      1.726031766954386e-6*V032*V06 + 2.18586528110337634e-6*V02*V04*V06 + 1.33467860402384212e-6*V01*V05*V06 - 
      9.39454064454064454e-7*V013*V07 + 1.49830878997545664e-6*V02*V03*V07 + 9.8088639755306422e-7*V01*V04*V07 - 
      1.13969026729443396e-8*V072 + 2.66580127691238802e-7*V022*V08 + 5.46810442643775977e-7*V01*V03*V08 - 
      1.96493872089110184e-8*V06*V08 + 1.92708526041859375e-7*V01*V02*V09 - 1.41821430883930884e-8*V05*V09 + 
      2.70996364746364746e-8*V012*V10 - 7.34701255534588868e-9*V04*V10 - 3.22184566976233643e-9*V03*V11 - 
      8.43099801433134766e-10*V02*V12 - 2.10774950358283692e-10*V01*V13 + 4.4280451755941952e-13*V16) + 
   delta6*eps5*(3.56125356125356125e-7*V043 + 3.07900047483380817e-6*V03*V04*V05 + 
      7.79024216524216524e-7*V02*V052 + 1.07882362346648061e-6*V032*V06 + 7.57069209450161831e-7*V02*V04*V06 + 
      6.47294174079888366e-7*V01*V05*V06 + 7.41927825261158594e-7*V02*V03*V07 + 4.39857210690544024e-7*V01*V04*V07 - 
      1.45735822819156152e-8*V072 + 6.83044664526146008e-8*V022*V08 + 2.31410821688599466e-7*V01*V03*V08 - 
      2.17026506709046392e-8*V06*V08 + 6.18273187717632162e-8*V01*V02*V09 - 1.76649482205037761e-8*V05*V09 + 
      7.22656972656972657e-9*V012*V10 - 7.38716016493794272e-9*V04*V10 - 3.57313725369280925e-9*V03*V11 - 
      6.42361753472864584e-10*V02*V12 - 1.60590438368216146e-10*V01*V13 + 5.9040602341255936e-13*V16) + 
   delta2*eps7*(-0.0000311898749398749399*V022*V032 - 
      0.0000202922077922077922*V01*V033 - 6.91438191438191438e-6*V023*V04 - 
      0.0000756072631072631073*V01*V02*V03*V04 - 0.0000108976671476671477*V012*V042 + 
      1.41486599819933153e-6*V043 - 0.0000187139249639249639*V01*V022*V05 - 
      0.0000174362674362674363*V012*V03*V05 + 8.83134997718331052e-6*V03*V04*V05 + 
      2.36067944401277735e-6*V02*V052 - 7.89141414141414141e-6*V012*V02*V06 + 
      3.2333737690880548e-6*V032*V06 + 3.3093559879274165e-6*V02*V04*V06 + 2.16549323692180835e-6*V01*V05*V06 - 
      7.51563251563251563e-7*V013*V07 + 2.48834884251550918e-6*V02*V03*V07 + 1.55419426252759586e-6*V01*V04*V07 - 
      2.27636946386946387e-8*V072 + 3.52656602656602657e-7*V022*V08 + 8.77305564805564806e-7*V01*V03*V08 - 
      3.81287583668536049e-8*V06*V08 + 2.67383079883079883e-7*V01*V02*V09 - 2.83040647623980957e-8*V05*V09 + 
      3.61328486328486328e-8*V012*V10 - 1.39713681380348047e-8*V04*V10 - 6.3834699251365918e-9*V03*V11 - 
      1.44531394531394531e-9*V02*V12 - 3.61328486328486328e-10*V01*V13 + 8.8560903511883904e-13*V16) + 
   delta4*eps6*(-0.0000102087341670675004*V022*V032 - 7.13985088985088985e-6*V01*V033 - 
      9.01875901875901876e-7*V023*V04 - 0.0000239999198332531666*V01*V02*V03*V04 - 
      3.34445646945646946e-6*V012*V042 + 9.90714532381199048e-7*V043 - 
      6.12524050024050024e-6*V01*V022*V05 - 5.59914622414622415e-6*V012*V03*V05 + 
      7.18272853689520356e-6*V03*V04*V05 + 1.84751269820714265e-6*V02*V052 - 
      2.31732002565335899e-6*V012*V02*V06 + 2.5855634114562686e-6*V032*V06 + 
      2.17219215235088251e-6*V02*V04*V06 + 1.60770529074100503e-6*V01*V05*V06 - 1.87890812890812891e-7*V013*V07 + 
      1.8291250930139819e-6*V02*V03*V07 + 1.10662871079537746e-6*V01*V04*V07 - 2.25830303955303955e-8*V072 + 
      2.09088750755417422e-7*V022*V08 + 6.12813112813112813e-7*V01*V03*V08 - 3.60296119224690653e-8*V06*V08 + 
      1.69824388574388574e-7*V01*V02*V09 - 2.79427362760696094e-8*V05*V09 + 2.16797091797091797e-8*V012*V10 - 
      1.27669398502731836e-8*V04*V10 - 6.02214143880810547e-9*V03*V11 - 1.20442828776162109e-9*V02*V12 - 
      3.01107071940405274e-10*V01*V13 + 8.8560903511883904e-13*V16) + 2.81145725434552076e-15*delta16*V16 + 
   1.12458290173820831e-14*delta14*eps*V16 + 
   delta14*eps2*(-3.57367455441252861e-12*V082 - 8.04076774742818938e-12*V07*V09 - 
      4.38587331677901239e-12*V06*V10 - 3.07011132174530867e-12*V05*V11 - 9.44649637460094976e-13*V04*V12 - 
      3.93604015608372907e-13*V03*V13 - 5.24805354144497209e-14*V02*V14 - 1.12458290173820831e-14*V01*V15 + 
      1.47971434439237935e-16*V18) + delta12*eps3*
    (-2.50157218808877003e-11*V082 - 5.62853742319973257e-11*V07*V09 - 3.07011132174530867e-11*V06*V10 - 
      2.14907792522171607e-11*V05*V11 - 6.61254746222066484e-12*V04*V12 - 2.75522810925861035e-12*V03*V13 - 
      3.67363747901148046e-13*V02*V14 - 7.87208031216745814e-14*V01*V15 + 5.17900020537332772e-16*V18) + 
   delta10*eps4*(1.31523569023569024e-8*V04*V052 + 5.84549195660306771e-9*V042*V06 + 
      1.83715461493239271e-8*V03*V05*V06 + 2.06932250583044234e-9*V02*V062 + 1.25260541927208594e-8*V03*V04*V07 + 
      6.35938135938135938e-9*V02*V05*V07 + 2.62450659276056101e-9*V01*V06*V07 + 3.28063324095070127e-9*V032*V08 + 
      2.11061718998226935e-9*V02*V04*V08 + 1.96837994457042076e-9*V01*V05*V08 - 1.03457878350242703e-10*V082 + 
      1.76649482205037761e-9*V02*V03*V09 + 1.04383784939340495e-9*V01*V04*V09 - 2.25945573702732122e-10*V07*V09 + 
      1.12413306857751302e-10*V022*V10 + 4.1753513975736198e-10*V01*V03*V10 - 1.28213696627173129e-10*V06*V10 + 
      9.63542630209296876e-11*V01*V02*V11 - 8.8009857890032182e-11*V05*V11 + 8.0295219184108073e-12*V012*V12 - 
      2.84182099269245239e-11*V04*V12 - 1.17293996651295126e-11*V03*V13 - 1.65313686555516621e-12*V02*V14 - 
      3.54243614047535616e-13*V01*V15 + 1.55370006161199832e-15*V18) + 
   delta8*eps5*(8.54903198653198653e-8*V04*V052 + 4.25885842552509219e-8*V042*V06 + 
      1.20563271604938272e-7*V03*V05*V06 + 1.51413841890032366e-8*V02*V062 + 8.1419352252685586e-8*V03*V04*V07 + 
      4.10710046126712793e-8*V02*V05*V07 + 1.72233245149911817e-8*V01*V06*V07 + 2.18708882730046751e-8*V032*V08 + 
      1.55696253579851463e-8*V02*V04*V08 + 1.31225329638028051e-8*V01*V05*V08 - 3.06889302360175895e-10*V082 + 
      1.14086123924086887e-8*V02*V03*V09 + 6.78494602105713217e-9*V01*V04*V09 - 6.39241035920541056e-10*V07*V09 + 
      8.56482337963819445e-10*V022*V10 + 2.87055408583186361e-9*V01*V03*V10 - 3.8595685187655309e-10*V06*V10 + 
      6.22287948676837566e-10*V01*V02*V11 - 2.57121823196169601e-10*V05*V11 + 6.02214143880810547e-11*V012*V12 - 
      8.91513095352964634e-11*V04*V12 - 3.63099704398724007e-11*V03*V13 - 5.5104562185172207e-12*V02*V14 - 
      1.18081204682511872e-12*V01*V15 + 3.88425015402999579e-15*V18) + 
   eps9*(1.06888995777884667e-6*V025 + 0.0000263923961840628507*V01*V023*V03 + 
      0.0000299748476831810165*V012*V02*V032 - 1.21518211175949271e-6*V034 + 
      0.0000238245550745550746*V012*V022*V04 + 0.0000102212602212602213*V013*V03*V04 - 
      0.0000101287830702513242*V02*V032*V04 - 3.09484386865339246e-6*V022*V042 - 
      6.45033978367311701e-6*V01*V03*V042 + 6.32565736732403399e-6*V013*V02*V05 - 
      5.97243869813314258e-6*V022*V03*V05 - 5.42102848650467698e-6*V01*V032*V05 - 
      7.74114737408388202e-6*V01*V02*V04*V05 - 9.78856075582266058e-7*V012*V052 + 
      2.90447881593714927e-7*V04*V052 + 4.69727032227032227e-7*V014*V06 - 
      8.74346112441350537e-7*V023*V06 - 5.52347371543800115e-6*V01*V02*V03*V06 - 
      1.67601358077548554e-6*V012*V04*V06 + 2.3201418290704005e-7*V042*V06 + 
      4.20311060192012573e-7*V03*V05*V06 + 1.000249016122032e-7*V02*V062 - 
      1.21213662880329547e-6*V01*V022*V07 - 1.0095517908017908e-6*V012*V03*V07 + 
      3.08183088131004798e-7*V03*V04*V07 + 1.83444465128492906e-7*V02*V05*V07 + 8.64564434132886514e-8*V01*V06*V07 - 
      4.09505617838951172e-7*V012*V02*V08 + 8.67546827988296242e-8*V032*V08 + 
      1.14248626153388058e-7*V02*V04*V08 + 6.72587168122882409e-8*V01*V05*V08 - 5.58025064485634825e-10*V082 - 
      3.61328486328486328e-8*V013*V09 + 6.05727059720115276e-8*V02*V03*V09 + 3.94450264241930909e-8*V01*V04*V09 - 
      1.01977880393934316e-9*V07*V09 + 9.15365498698832032e-9*V022*V10 + 1.79760921948421948e-8*V01*V03*V10 - 
      7.27717595714794594e-10*V06*V10 + 5.32959517334517335e-9*V01*V02*V11 - 4.32620013655552871e-10*V05*V11 + 
      6.32324851074851075e-10*V012*V12 - 1.92177160620788072e-10*V04*V12 - 7.12915273270665428e-11*V03*V13 - 
      1.65313686555516621e-11*V02*V14 - 3.54243614047535616e-12*V01*V15 + 5.82637523104499369e-15*V18) + 
   delta6*eps6*(-3.02827683780064732e-7*V034 - 1.85757254209635162e-6*V02*V032*V04 - 
      1.58222876476844731e-7*V022*V042 - 1.08321462488129155e-6*V01*V03*V042 - 
      9.25161515439293217e-7*V022*V03*V05 - 1.03112826327112041e-6*V01*V032*V05 - 
      1.11454352525781097e-6*V01*V02*V04*V05 - 1.39369559012416155e-7*V012*V052 + 
      2.68161943509165731e-7*V04*V052 - 3.51463645114438765e-8*V023*V06 - 
      7.62712816284244856e-7*V01*V02*V03*V06 - 2.12598798908322718e-7*V012*V04*V06 + 
      1.55031715051556321e-7*V042*V06 + 3.8440189109831967e-7*V03*V05*V06 + 5.61607704464847322e-8*V02*V062 - 
      1.32165930777041888e-7*V01*V022*V07 - 1.24296999296999297e-7*V012*V03*V07 + 
      2.6128064322508767e-7*V03*V04*V07 + 1.32968882968882969e-7*V02*V05*V07 + 5.73479926158497587e-8*V01*V06*V07 - 
      3.77387530165307943e-8*V012*V02*V08 + 7.26576144069530313e-8*V032*V08 + 
      5.89825738635262445e-8*V02*V04*V08 + 4.44778160551970076e-8*V01*V05*V08 - 6.7521831725198257e-10*V082 - 
      2.40885657552324219e-9*V013*V09 + 3.86086178910252984e-8*V02*V03*V09 + 2.32454659537992871e-8*V01*V04*V09 - 
      1.33786004905285951e-9*V07*V09 + 3.45269442491664714e-9*V022*V10 + 1.03580832747499414e-8*V01*V03*V10 - 
      8.61655419311815204e-10*V06*V10 + 2.28841374674708008e-9*V01*V02*V11 - 5.54981662007805799e-10*V05*V11 + 
      2.40885657552324219e-10*V012*V12 - 2.07822920241220895e-10*V04*V12 - 8.32472493011708698e-11*V03*V13 - 
      1.37761405462930517e-11*V02*V14 - 2.9520301170627968e-12*V01*V15 + 7.76850030805999158e-15*V18) + 
   delta2*eps8*(4.1753513975736198e-8*V025 + 0.0000140291806958473625*V01*V023*V03 + 
      0.0000188517115600448934*V012*V02*V032 - 2.104308279903518e-6*V034 + 
      0.0000125886844636844637*V012*V022*V04 + 5.82461519961519962e-6*V013*V03*V04 - 
      0.0000153405163325798246*V02*V032*V04 - 3.46221514376276281e-6*V022*V042 - 
      9.37767864851198185e-6*V01*V03*V042 + 2.94362273528940196e-6*V013*V02*V05 - 
      7.97973888251666029e-6*V022*V03*V05 - 8.09444633849395754e-6*V01*V032*V05 - 
      9.9663114296050804e-6*V01*V02*V04*V05 - 1.24727152256914162e-6*V012*V052 + 
      5.53495019640852974e-7*V04*V052 + 1.87890812890812891e-7*V014*V06 - 
      8.40346822489679633e-7*V023*V06 - 7.21314895422038279e-6*V01*V02*V03*V06 - 
      2.10547829595448643e-6*V012*V04*V06 + 4.143130073189597e-7*V042*V06 + 
      8.11973933253695158e-7*V03*V05*V06 + 1.64565051717829496e-7*V02*V062 - 
      1.3248711165377832e-6*V01*V022*V07 - 1.25380984755984756e-6*V012*V03*V07 + 
      5.84147719564386231e-7*V03*V04*V07 + 3.1668434446212224e-7*V02*V05*V07 + 1.46458479791813125e-7*V01*V06*V07 - 
      4.40820753320753321e-7*V012*V02*V08 + 1.6699971747094763e-7*V032*V08 + 
      1.84426647720298514e-7*V02*V04*V08 + 1.14231420034991464e-7*V01*V05*V08 - 1.09940630202554417e-9*V082 - 
      3.61328486328486328e-8*V013*V09 + 1.03781570795459684e-7*V02*V03*V09 + 6.52800131966798633e-8*V01*V04*V09 - 
      2.03867199884356747e-9*V07*V09 + 1.30479731174175619e-8*V022*V10 + 3.01107071940405274e-8*V01*V03*V10 - 
      1.42836085807024182e-9*V06*V10 + 7.82878387045053712e-9*V01*V02*V11 - 8.64354418275986903e-10*V05*V11 + 
      9.03321215821215821e-10*V012*V12 - 3.70184576679674719e-10*V04*V12 - 1.41697445619014246e-10*V03*V13 - 
      2.89298951472154087e-11*V02*V14 - 6.19926324583187328e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   delta4*eps7*(-1.3248711165377832e-6*V034 - 8.6670659587326254e-6*V02*V032*V04 - 
      1.31581381581381581e-6*V022*V042 - 5.14897910731244065e-6*V01*V03*V042 - 
      4.27957459207459207e-6*V022*V03*V05 - 4.63174942341609008e-6*V01*V032*V05 - 
      5.20023957523957524e-6*V01*V02*V04*V05 - 6.59063159063159063e-7*V012*V052 + 
      5.00520248784137673e-7*V04*V052 - 3.03928875357446786e-7*V023*V06 - 
      3.68334817739579644e-6*V01*V02*V03*V06 - 1.04922909982433792e-6*V012*V04*V06 + 
      3.34278174059920092e-7*V042*V06 + 7.29246916002868384e-7*V03*V05*V06 + 1.25604664295140486e-7*V02*V062 - 
      6.11367798867798868e-7*V01*V022*V07 - 6.07995399662066329e-7*V012*V03*V07 + 
      5.08188442216219994e-7*V03*V04*V07 + 2.63408466533466533e-7*V02*V05*V07 + 1.17724262069500165e-7*V01*V06*V07 - 
      1.95117382617382617e-7*V012*V02*V08 + 1.4478948630734345e-7*V032*V08 + 
      1.36065984280269995e-7*V02*V04*V08 + 9.21731762505572029e-8*V01*V05*V08 - 1.06818506921603716e-9*V082 - 
      1.44531394531394531e-8*V013*V09 + 8.19011235677902345e-8*V02*V03*V09 + 5.02246595996595997e-8*V01*V04*V09 - 
      2.03276793860944188e-9*V07*V09 + 8.67188367188367188e-9*V022*V10 + 2.30045802962469629e-8*V01*V03*V10 - 
      1.37834503351543501e-9*V06*V10 + 5.41992729492729493e-9*V01*V02*V11 - 8.5845035804186131e-10*V05*V11 + 
      6.02214143880810547e-10*V012*V12 - 3.45977929719759785e-10*V04*V12 - 1.35793385384888653e-10*V03*V13 - 
      2.47970529833274931e-11*V02*V14 - 5.31365421071303424e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   8.22063524662432972e-18*delta18*V18 + 3.69928586098094837e-17*delta16*eps*V18 + 
   delta16*eps2*(-4.99609107113593639e-14*V092 - 7.26704155801590747e-14*V08*V10 - 
      6.54033740221431672e-14*V07*V11 - 3.01861726256045387e-14*V06*V12 - 1.76086006982693143e-14*V05*V13 - 
      4.69562685287181713e-15*V04*V14 - 1.67700959031136326e-15*V03*V15 - 1.97295245918983913e-16*V02*V16 - 
      3.69928586098094837e-17*V01*V17 + 4.40391173926303378e-19*V20) + 
   delta14*eps3*(-3.99687285690874911e-13*V092 - 5.81363324641272598e-13*V08*V10 - 
      5.23226992177145338e-13*V07*V11 - 2.4148938100483631e-13*V06*V12 - 1.40868805586154514e-13*V05*V13 - 
      3.75650148229745371e-14*V04*V14 - 1.34160767224909061e-14*V03*V15 - 1.57836196735187131e-15*V02*V16 - 
      2.9594286887847587e-16*V01*V17 + 1.76156469570521351e-18*V20) + 
   delta12*eps4*(4.14465028435616671e-10*V052*V06 + 1.9311337588648513e-10*V04*V062 + 
      5.61121884651296416e-10*V04*V05*V07 + 3.94728598510111115e-10*V03*V06*V07 + 6.75424490783967908e-11*V02*V072 + 
      9.9293173004138872e-11*V042*V08 + 3.00188662570652404e-10*V03*V05*V08 + 7.05638284744001105e-11*V02*V06*V08 + 
      4.28840946529503434e-11*V01*V07*V08 + 1.55867190180915671e-10*V03*V04*V09 + 7.8799523924796256e-11*V02*V05*V09 + 
      3.28940498758425929e-11*V01*V06*V09 - 1.87500359022631024e-12*V092 + 3.28940498758425929e-11*V032*V10 + 
      2.19068749258602978e-11*V02*V04*V10 + 1.97364299255055558e-11*V01*V05*V10 - 2.808497825656736e-12*V08*V10 + 
      1.43271861681447738e-11*V02*V03*V11 + 8.50184673714085479e-12*V01*V04*V11 - 2.47282462663132475e-12*V07*V11 + 
      7.87208031216745814e-13*V022*V12 + 2.83394891238028493e-12*V01*V03*V12 - 1.183475532645025e-12*V06*V12 + 
      5.5104562185172207e-13*V01*V02*V13 - 6.80520626986055263e-13*V05*V13 + 3.93604015608372907e-14*V012*V14 - 
      1.89344247508448862e-13*V04*V14 - 6.71543693296741495e-14*V03*V15 - 8.28640032859732435e-15*V02*V16 - 
      1.55370006161199832e-15*V01*V17 + 6.16547643496824729e-18*V20) + 
   delta10*eps5*(3.26045822369351781e-9*V052*V06 + 1.65543101467471215e-9*V04*V062 + 
      4.38766140359277614e-9*V04*V05*V07 + 3.10519830827954077e-9*V03*V06*V07 + 5.25866210681803586e-10*V02*V072 + 
      8.54383116547241456e-10*V042*V08 + 2.38274750915455345e-9*V03*V05*V08 + 6.08564288665958964e-10*V02*V06*V08 + 
      3.40392501307793351e-10*V01*V07*V08 + 1.21879483433132671e-9*V03*V04*V09 + 6.1351057912877085e-10*V02*V05*V09 + 
      2.58766525689961731e-10*V01*V06*V09 - 6.38324106265132578e-12*V092 + 2.64979846222065332e-10*V032*V10 + 
      1.91044143347286827e-10*V02*V04*V10 + 1.58987907733239199e-10*V01*V05*V10 - 1.00156931590772184e-11*V08*V10 + 
      1.11547378023412882e-10*V02*V03*V11 + 6.6479718236254184e-11*V01*V04*V11 - 8.52071309503185762e-12*V07*V11 + 
      7.08487228095071232e-12*V022*V12 + 2.34981597318198625e-11*V01*V03*V12 - 4.3121835424282719e-12*V06*V12 + 
      4.29028377013126468e-12*V01*V02*V13 - 2.42687949623794137e-12*V05*V13 + 3.54243614047535616e-13*V012*V14 - 
      7.18016588472958155e-13*V04*V14 - 2.5221731000168106e-13*V03*V15 - 3.31456013143892974e-14*V02*V16 - 
      6.21480024644799327e-15*V01*V17 + 1.84964293049047419e-17*V20) + 
   delta8*eps6*(-8.45508658008658009e-8*V032*V042 - 1.14340392118169896e-8*V02*V043 - 
      5.74110817166372722e-8*V033*V05 - 1.70707635985413763e-7*V02*V03*V04*V05 - 
      5.07305194805194805e-8*V01*V042*V05 - 2.09931850556850557e-8*V022*V052 - 
      4.97910654160654161e-8*V01*V03*V052 - 5.99346457481378116e-8*V02*V032*V06 - 
      1.17185137026406868e-8*V022*V04*V06 - 6.97283683394794506e-8*V01*V03*V04*V06 - 
      3.5960787448882687e-8*V01*V02*V05*V06 + 1.29533113516637482e-8*V052*V06 - 
      3.43835599291948498e-9*V012*V062 + 7.392378229602008e-9*V04*V062 - 
      1.99935095768429102e-8*V022*V03*V07 - 2.28153129938844225e-8*V01*V032*V07 - 
      2.43868051407733947e-8*V01*V02*V04*V07 - 6.24582097796383511e-9*V012*V05*V07 + 
      1.75019961580419097e-8*V04*V05*V07 + 1.2518744403859561e-8*V03*V06*V07 + 2.14039052230578841e-9*V02*V072 - 
      6.57656080936504217e-10*V023*V08 - 1.26407616486981566e-8*V01*V02*V03*V08 - 
      3.52151889850302549e-9*V012*V04*V08 + 3.86929241225589394e-9*V042*V08 + 
      9.72664871847229976e-9*V03*V05*V08 + 2.79046504017974087e-9*V02*V06*V08 + 1.42857640312640831e-9*V01*V07*V08 - 
      1.66612579807024251e-9*V01*V022*V09 - 1.58583057888613444e-9*V012*V03*V09 + 
      5.00664307853850338e-9*V03*V04*V09 + 2.53392425148280268e-9*V02*V05*V09 + 1.08879305089038983e-9*V01*V06*V09 - 
      1.6748072821287926e-11*V092 - 3.81402291124513347e-10*V012*V02*V10 + 
      1.12917963434906323e-9*V032*V10 + 9.01690570613695419e-10*V02*V04*V10 + 6.8620642935438298e-10*V01*V05*V10 - 
      2.760150625644289e-11*V08*V10 - 2.00738047960270182e-11*V013*V11 + 4.80787305065627506e-10*V02*V03*V11 + 
      2.88905347456545714e-10*V01*V04*V11 - 2.26228347113945505e-11*V07*V11 + 3.54243614047535616e-11*V022*V12 + 
      1.07453896261085804e-10*V01*V03*V12 - 1.21478628817236775e-11*V06*V12 + 1.97786017843207386e-11*V01*V02*V13 - 
      6.6713291145516521e-12*V05*V13 + 1.77121807023767808e-12*V012*V14 - 2.11096048371016838e-12*V04*V14 - 
      7.32828529060325873e-13*V03*V15 - 1.03580004107466554e-13*V02*V16 - 1.9421250770149979e-14*V01*V17 + 
      4.62410732622618547e-17*V20) + eps10*(-4.32775172358505692e-6*V012*V024 - 
      9.24422799422799423e-6*V013*V022*V03 - 1.23068482443482443e-6*V014*V032 + 
      4.22450354245989167e-6*V023*V032 + 7.39166243258505163e-6*V01*V02*V033 - 
      1.69101731601731602e-6*V014*V02*V04 + 1.21747740795359843e-6*V024*V04 + 
      0.0000161214859875574161*V01*V022*V03*V04 + 6.33712696584720394e-6*V012*V032*V04 + 
      4.84675707889993604e-6*V012*V02*V042 - 1.07324812418438411e-6*V032*V042 - 
      4.62417873132158846e-7*V02*V043 - 9.39454064454064454e-8*V015*V05 + 
      3.19858299769014055e-6*V01*V023*V05 + 7.76295326146516623e-6*V012*V02*V03*V05 - 
      6.14896486982300474e-7*V033*V05 + 1.39724005051386004e-6*V013*V04*V05 - 
      2.56161679617780808e-6*V02*V03*V04*V05 - 8.20972733175114127e-7*V01*V042*V05 - 
      3.79289523169731503e-7*V022*V052 - 6.95468437903953777e-7*V01*V03*V052 + 
      2.05559775872275872e-6*V012*V022*V06 + 9.52221004304337638e-7*V013*V03*V06 - 
      9.2266376058538757e-7*V02*V032*V06 - 5.93101783577974054e-7*V022*V04*V06 - 
      1.16940150577303355e-6*V01*V03*V04*V06 - 7.07132752333645191e-7*V01*V02*V05*V06 + 
      2.89604486589270086e-8*V052*V06 - 7.63370950312914599e-8*V012*V062 + 
      2.35668492554580323e-8*V04*V062 + 4.33594183594183594e-7*V013*V02*V07 - 
      4.0140583760375427e-7*V022*V03*V07 - 3.62902846161774733e-7*V01*V032*V07 - 
      5.19422603685996543e-7*V01*V02*V04*V07 - 1.32534428479368956e-7*V012*V05*V07 + 
      4.25063111758883818e-8*V04*V05*V07 + 3.06977183828184645e-8*V03*V06*V07 + 6.76143520976766775e-9*V02*V072 + 
      2.70996364746364746e-8*V014*V08 - 4.80241882358284475e-8*V023*V08 - 
      2.87815345479035955e-7*V01*V02*V03*V08 - 8.72350202707345564e-8*V012*V04*V08 + 
      1.34766641195601669e-8*V042*V08 + 2.39151691290706619e-8*V03*V05*V08 + 1.16898143469883277e-8*V02*V06*V08 + 
      4.92813313471090471e-9*V01*V07*V08 - 5.07365416219582886e-8*V01*V022*V09 - 
      4.2305543607626941e-8*V012*V03*V09 + 1.39815526419386714e-8*V03*V04*V09 + 8.39144081076270619e-9*V02*V05*V09 + 
      3.92546204816425405e-9*V01*V06*V09 - 2.56298084717075669e-11*V092 - 1.40014788452288452e-8*V012*V02*V10 + 
      3.21391736030508206e-9*V032*V10 + 4.35416007894999492e-9*V02*V04*V10 + 2.49794462727031588e-9*V01*V05*V10 - 
      4.62118489039601052e-11*V08*V10 - 1.05387475179141846e-9*V013*V11 + 1.88841366588507111e-9*V02*V03*V11 + 
      1.22273087448741044e-9*V01*V04*V11 - 3.49496505466431814e-11*V07*V11 + 2.47970529833274931e-10*V022*V12 + 
      4.71144006683222369e-10*V01*V03*V12 - 2.1239079842236017e-11*V06*V12 + 1.20885633293721529e-10*V01*V02*V13 - 
      1.07535465514320433e-11*V05*V13 + 1.23985264916637466e-11*V012*V14 - 4.17634576561305147e-12*V04*V14 - 
      1.34395055329437854e-12*V03*V15 - 2.79666011090159697e-13*V02*V16 - 5.24373770794049432e-14*V01*V17 + 
      6.9361609893392782e-17*V20) + delta6*eps7*
    (-5.30269627491849714e-7*V032*V042 - 1.06760523427190094e-7*V02*V043 - 
      3.44466490299823633e-7*V033*V05 - 1.06134220717554051e-6*V02*V03*V04*V05 - 
      3.18161776495109828e-7*V01*V042*V05 - 1.30511849261849262e-7*V022*V052 - 
      3.03130511463844797e-7*V01*V03*V052 - 3.78534604725080916e-7*V02*V032*V06 - 
      1.11853534472582092e-7*V022*V04*V06 - 4.46345064400619956e-7*V01*V03*V04*V06 - 
      2.27120762835048549e-7*V01*V02*V05*V06 + 3.26639377224889207e-8*V052*V06 - 
      2.2585898081929828e-8*V012*V062 + 2.10193091164924343e-8*V04*V062 - 
      1.24296999296999297e-7*V022*V03*V07 - 1.41067229360880155e-7*V01*V032*V07 - 
      1.51620315310791501e-7*V01*V02*V04*V07 - 4.0124668100858577e-8*V012*V05*V07 + 4.4787492448848658e-8*V04*V05*V07 + 
      3.24298782831501475e-8*V03*V06*V07 + 5.68358575623981786e-9*V02*V072 - 6.5918551368286818e-9*V023*V08 - 
      8.25205438300676396e-8*V01*V02*V03*V08 - 2.34003210193686384e-8*V012*V04*V08 + 
      1.12529063924436888e-8*V042*V08 + 2.54356286410311724e-8*V03*V05*V08 + 8.30444495178907462e-9*V02*V06*V08 + 
      3.92657491666076582e-9*V01*V07*V08 - 1.03580832747499414e-8*V01*V022*V09 - 
      1.05989689323022656e-8*V012*V03*V09 + 1.3470310226165346e-8*V03*V04*V09 + 6.88846387716213424e-9*V02*V05*V09 + 
      3.03283139855268707e-9*V01*V06*V09 - 3.40039836055713167e-11*V092 - 2.64974223307556641e-9*V012*V02*V10 + 
      3.11981788600213748e-9*V032*V10 + 2.79278917817666651e-9*V02*V04*V10 + 1.94147992156084282e-9*V01*V05*V10 - 
      5.8329550274963918e-11*V08*V10 - 1.60590438368216146e-10*V013*V11 + 1.39296461123803172e-9*V02*V03*V11 + 
      8.47035841589218496e-10*V01*V04*V11 - 4.62613453487800303e-11*V07*V11 + 1.18081204682511872e-10*V022*V12 + 
      3.24723312876907648e-10*V01*V03*V12 - 2.6147736236888857e-11*V06*V12 + 6.25830384817312922e-11*V01*V02*V13 - 
      1.39998733551651795e-11*V05*V13 + 5.9040602341255936e-12*V012*V14 - 4.73567778779337087e-12*V04*V14 - 
      1.62102706428185158e-12*V03*V15 - 2.48592009857919731e-13*V02*V16 - 4.66110018483599495e-14*V01*V17 + 
      9.24821465245237093e-17*V20) + delta2*eps9*
    (4.15642466733736575e-6*V023*V032 + 8.35529109338633148e-6*V01*V02*V033 + 
      6.79829796893288957e-7*V024*V04 + 0.0000154207702570797809*V01*V022*V03*V04 + 
      6.74263732299446585e-6*V012*V032*V04 + 4.56072256667494763e-6*V012*V02*V042 - 
      1.91435273280511376e-6*V032*V042 - 6.72419695237155555e-7*V02*V043 + 
      2.49385480040241945e-6*V01*V023*V05 + 7.25582012784393737e-6*V012*V02*V03*V05 - 
      1.13434203215949248e-6*V033*V05 + 1.24703063691158929e-6*V013*V04*V05 - 
      4.15228372817658532e-6*V02*V03*V04*V05 - 1.29452411198442944e-6*V01*V042*V05 - 
      5.49420037267259489e-7*V022*V052 - 1.13306877939814448e-6*V01*V03*V052 + 
      1.63031413031413031e-6*V012*V022*V06 + 8.24792491459158126e-7*V013*V03*V06 - 
      1.51755096571564826e-6*V02*V032*V06 - 7.77042071684928828e-7*V022*V04*V06 - 
      1.86239140232195788e-6*V01*V03*V04*V06 - 1.01627938309485929e-6*V01*V02*V05*V06 + 
      5.68838491377298567e-8*V052*V06 - 1.07641476689095737e-7*V012*V062 + 
      4.41557917412842716e-8*V04*V062 + 3.20377924544591211e-7*V013*V02*V07 - 
      5.77443068762513207e-7*V022*V03*V07 - 5.83046527987004177e-7*V01*V032*V07 - 
      7.28552935894205735e-7*V01*V02*V04*V07 - 1.86531529537481918e-7*V012*V05*V07 + 
      8.20730498018079717e-8*V04*V05*V07 + 6.00686679154524626e-8*V03*V06*V07 + 1.19181468478999992e-8*V02*V072 + 
      1.80664243164243164e-8*V014*V08 - 5.42489795135297781e-8*V023*V08 - 
      4.0979812185169328e-7*V01*V02*V03*V08 - 1.20546065486541677e-7*V012*V04*V08 + 
      2.49040458005988663e-8*V042*V08 + 4.6958392905278604e-8*V03*V05*V08 + 2.00429912245193913e-8*V02*V06*V08 + 
      8.62016691568998603e-9*V01*V07*V08 - 6.16667283333950001e-8*V01*V022*V09 - 
      5.79330006413339747e-8*V012*V03*V09 + 2.68752821857397021e-8*V03*V04*V09 + 1.4780224390110011e-8*V02*V05*V09 + 
      6.83399189285918978e-9*V01*V06*V09 - 5.12537905681840888e-11*V092 - 1.68619960286626953e-8*V012*V02*V10 + 
      6.27264228017029137e-9*V032*V10 + 7.31125081907061366e-9*V02*V04*V10 + 4.36078106078397862e-9*V01*V05*V10 - 
      9.16586854918693502e-11*V08*V10 - 1.20442828776162109e-9*V013*V11 + 3.30686413713374498e-9*V02*V03*V11 + 
      2.08501887168145338e-9*V01*V04*V11 - 6.98876483428242728e-11*V07*V11 + 3.71955794749912397e-10*V022*V12 + 
      8.121034852039754e-10*V01*V03*V12 - 4.19521212350405431e-11*V06*V12 + 1.85092288339837359e-10*V01*V02*V13 - 
      2.14954403524019967e-11*V05*V13 + 1.85977897374956198e-11*V012*V14 - 8.11342172173785521e-12*V04*V14 - 
      2.6762483561266671e-12*V03*V15 - 4.97184019715839461e-13*V02*V16 - 9.3222003696719899e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + delta4*eps8*
    (1.12355953129762654e-6*V023*V032 + 2.5791971476495286e-6*V01*V02*V033 + 
      3.77616945077262538e-8*V024*V04 + 4.13625909657655689e-6*V01*V022*V03*V04 + 
      1.98785727059536583e-6*V012*V032*V04 + 1.22404326273373892e-6*V012*V02*V042 - 
      1.42409880133094419e-6*V032*V042 - 3.91505723846993688e-7*V02*V043 + 
      6.74135718778575921e-7*V01*V023*V05 + 2.06180916746392937e-6*V012*V02*V03*V05 - 
      8.81354738001563398e-7*V033*V05 + 3.3207808505427553e-7*V013*V04*V05 - 
      2.91372423688891943e-6*V02*V03*V04*V05 - 8.88464306123036282e-7*V01*V042*V05 - 
      3.66935769134843209e-7*V022*V052 - 8.12937475883904455e-7*V01*V03*V052 + 
      4.23557281196170085e-7*V012*V022*V06 + 2.13183806933806934e-7*V013*V03*V06 - 
      1.05803289707059548e-6*V02*V032*V06 - 4.22574620656631239e-7*V022*V04*V06 - 
      1.26838342984176318e-6*V01*V03*V04*V06 - 6.5878786116881355e-7*V01*V02*V05*V06 + 
      5.45632582627067921e-8*V052*V06 - 6.76716636538065109e-8*V012*V062 + 
      3.90218908615850726e-8*V04*V062 + 7.34701255534588868e-8*V013*V02*V07 - 
      3.63268954125435607e-7*V022*V03*V07 - 3.97088535729408745e-7*V01*V032*V07 - 
      4.49314840435872182e-7*V01*V02*V04*V07 - 1.17990956904647381e-7*V012*V05*V07 + 
      7.65859343014163276e-8*V04*V05*V07 + 5.59869380444485487e-8*V03*V06*V07 + 1.02824269600355035e-8*V02*V072 + 
      3.61328486328486328e-9*V014*V08 - 2.64209506934374659e-8*V023*V08 - 
      2.52155665102093674e-7*V01*V02*V03*V08 - 7.26442318704223466e-8*V012*V04*V08 + 
      2.14728983840795232e-8*V042*V08 + 4.39814532769423059e-8*V03*V05*V08 + 1.64109258267755e-8*V02*V06*V08 + 
      7.31276900598796024e-9*V01*V07*V08 - 3.37239920573253907e-8*V01*V022*V09 - 
      3.40250991292657959e-8*V012*V03*V09 + 2.42509274116708757e-8*V03*V04*V09 + 1.27037664057680398e-8*V02*V05*V09 + 
      5.74203595255766124e-9*V01*V06*V09 - 5.12110638164897588e-11*V092 - 9.03321215821215821e-9*V012*V02*V10 + 
      5.67822993017028965e-9*V032*V10 + 5.76472441260022959e-9*V02*V04*V10 + 3.68295277404754529e-9*V01*V05*V10 - 
      9.01908088622321099e-11*V08*V10 - 6.02214143880810547e-10*V013*V11 + 2.72767582816602424e-9*V02*V03*V11 + 
      1.68501879081944441e-9*V01*V04*V11 - 6.98021948394356129e-11*V07*V11 + 2.65682710535651712e-10*V022*V12 + 
      6.5535068598794089e-10*V01*V03*V12 - 4.09621923386420413e-11*V06*V12 + 1.35793385384888653e-10*V01*V02*V13 - 
      2.14099868490133368e-11*V05*V13 + 1.32841355267825856e-11*V012*V14 - 7.69703010522583966e-12*V04*V14 - 
      2.59079485273800719e-12*V03*V15 - 4.35036017251359529e-13*V02*V16 - 8.15692532346299116e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + 1.95729410633912612e-20*delta20*V20 + 
   9.78647053169563062e-20*delta18*eps*V20;
}
#endif


#ifdef p12 /* Uses: V00 - V22. */
double Vp(void)
{

   V012 = V01 * V01;
   V013 = V01 * V012;
   V014 = V01 * V013;
   V015 = V01 * V014;
   V022 = V02 * V02;
   V023 = V02 * V022;
   V024 = V02 * V023;
   V025 = V02 * V024;
   V026 = V02 * V025;
   V032 = V03 * V03;
   V033 = V03 * V032;
   V034 = V03 * V033;
   V042 = V04 * V04;
   V043 = V04 * V042;
   V044 = V04 * V043;
   V052 = V05 * V05;
   V053 = V05 * V052;
   V062 = V06 * V06;
   V063 = V06 * V062;
   V072 = V07 * V07;
   V082 = V08 * V08;
   V092 = V09 * V09;
   V102 = V10 * V10;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;
   delta8 = delta2 * delta6;
   delta10 = delta2 * delta8;
   delta12 = delta2 * delta10;
   delta14 = delta2 * delta12;
   delta16 = delta2 * delta14;
   delta18 = delta2 * delta16;
   delta20 = delta2 * delta18;
   delta22 = delta2 * delta20;

   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 + 
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) + 
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 + 
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) + 
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 
      0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 + 
   0.000297619047619047619*delta4*eps*V06 + 
   eps4*(0.00416666666666666667*V012*V02 - 0.000570436507936507937*V032 - 
      0.000595238095238095238*V02*V04 - 0.000446428571428571429*V01*V05 + 4.1335978835978836e-6*V08) + 
   delta2*eps3*(-0.000992063492063492063*V032 - 0.000793650793650793651*V02*V04 - 
      0.000595238095238095238*V01*V05 + 8.2671957671957672e-6*V08) + 
   delta4*eps2*(-0.000496031746031746032*V032 - 0.000396825396825396825*V02*V04 - 
      0.000297619047619047619*V01*V05 + 8.2671957671957672e-6*V08) + 2.75573192239858907e-6*delta8*V08 + 
   5.51146384479717813e-6*delta6*eps*V08 + eps5*
    (0.0001763668430335097*V023 + 0.00143849206349206349*V01*V02*V03 + 0.000446428571428571429*V012*V04 - 
      0.0000388558201058201058*V042 - 0.0000785383597883597884*V03*V05 - 0.0000330687830687830688*V02*V06 - 
      0.0000165343915343915344*V01*V07 + 9.39454064454064454e-8*V10) + 
   delta6*eps2*(-0.0000154320987654320988*V042 - 0.0000385802469135802469*V03*V05 - 
      0.0000110229276895943563*V02*V06 - 5.51146384479717813e-6*V01*V07 + 1.25260541927208594e-7*V10) + 
   delta2*eps4*(0.0000661375661375661376*V023 + 0.00119047619047619048*V01*V02*V03 + 
      0.000297619047619047619*V012*V04 - 0.0000644841269841269841*V042 - 0.00014880952380952381*V03*V05 - 
      0.0000496031746031746032*V02*V06 - 0.0000248015873015873016*V01*V07 + 1.87890812890812891e-7*V10) + 
   delta4*eps3*(-0.0000462962962962962963*V042 - 0.000115740740740740741*V03*V05 - 
      0.0000330687830687830688*V02*V06 - 0.0000165343915343915344*V01*V07 + 1.87890812890812891e-7*V10) + 
   2.50521083854417188e-8*delta10*V10 + 6.26302709636042969e-8*delta8*eps*V10 + 
   delta8*eps2*(-7.89141414141414141e-7*V052 - 9.01875901875901876e-7*V04*V06 - 
      7.51563251563251563e-7*V03*V07 - 1.67014055902944792e-7*V02*V08 - 6.26302709636042969e-8*V01*V09 + 
      1.20442828776162109e-9*V12) + eps6*(-0.000421626984126984127*V012*V022 - 
      0.00014880952380952381*V013*V03 + 0.000144675925925925926*V02*V032 + 
      0.0000793650793650793651*V022*V04 + 0.000188492063492063492*V01*V03*V04 + 0.000111607142857142857*V01*V02*V05 - 
      3.33506192881192881e-6*V052 + 0.0000248015873015873016*V012*V06 - 5.11063011063011063e-6*V04*V06 - 
      3.56992544492544493e-6*V03*V07 - 1.25260541927208594e-6*V02*V08 - 4.69727032227032227e-7*V01*V09 + 
      1.80664243164243164e-9*V12) + delta6*eps3*
    (-3.15656565656565657e-6*V052 - 3.6075036075036075e-6*V04*V06 - 3.00625300625300625e-6*V03*V07 - 
      6.68056223611779167e-7*V02*V08 - 2.50521083854417188e-7*V01*V09 + 2.40885657552324219e-9*V12) + 
   delta2*eps5*(0.00020667989417989418*V02*V032 + 0.0000727513227513227513*V022*V04 + 
      0.000243055555555555556*V01*V03*V04 + 0.000124007936507936508*V01*V02*V05 - 6.57617845117845118e-6*V052 + 
      0.0000248015873015873016*V012*V06 - 9.16907166907166907e-6*V04*V06 - 6.95196007696007696e-6*V03*V07 - 
      2.0041686708353375e-6*V02*V08 - 7.51563251563251563e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   delta4*eps4*(0.000082671957671957672*V02*V032 + 0.0000198412698412698413*V022*V04 + 
      0.0000925925925925925926*V01*V03*V04 + 0.0000496031746031746032*V01*V02*V05 - 6.1377665544332211e-6*V052 + 
      8.2671957671957672e-6*V012*V06 - 7.56573673240339907e-6*V04*V06 - 6.0751362834696168e-6*V03*V07 - 
      1.50312650312650313e-6*V02*V08 - 5.63672438672438672e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   1.60590438368216146e-10*delta12*V12 + 4.81771315104648438e-10*delta10*eps*V12 + 
   delta10*eps2*(-1.3627245770102913e-8*V062 - 3.17969067969067969e-8*V05*V07 - 
      1.41319585764030208e-8*V04*V08 - 8.83247411025188803e-9*V03*V09 - 1.60590438368216146e-9*V02*V10 - 
      4.81771315104648438e-10*V01*V11 + 8.0295219184108073e-12*V14) + 
   delta8*eps3*(-6.81362288505145648e-8*V062 - 1.58984533984533985e-7*V05*V07 - 
      7.06597928820151042e-8*V04*V08 - 4.41623705512594401e-8*V03*V09 - 8.0295219184108073e-9*V02*V10 - 
      2.40885657552324219e-9*V01*V11 + 2.00738047960270182e-11*V14) + 
   eps7*(-0.0000132275132275132275*V024 - 0.000203373015873015873*V01*V022*V03 - 
      0.0000777116402116402116*V012*V032 - 0.000124007936507936508*V012*V02*V04 + 
      0.0000224842672759339426*V032*V04 + 0.000013452982202982203*V02*V042 - 
      0.0000165343915343915344*V013*V05 + 0.0000264299743466410133*V02*V03*V05 + 0.0000173485850569183903*V01*V04*V05 + 
      5.71188071188071188e-6*V022*V06 + 0.0000124383718133718134*V01*V03*V06 - 1.95667978406073644e-7*V062 + 
      5.44883357383357383e-6*V01*V02*V07 - 3.61569371986038653e-7*V05*V07 + 9.39454064454064454e-7*V012*V08 - 
      2.24023661523661524e-7*V04*V08 - 1.20442828776162109e-7*V03*V09 - 3.61328486328486328e-8*V02*V10 - 
      1.08398545898545899e-8*V01*V11 + 3.01107071940405274e-11*V14) + 
   delta6*eps4*(6.76406926406926407e-6*V032*V04 + 1.90396023729357063e-6*V02*V042 + 
      7.01459034792368126e-6*V02*V03*V05 + 4.05844155844155844e-6*V01*V04*V05 + 6.51354818021484688e-7*V022*V06 + 
      2.70562770562770563e-6*V01*V03*V06 - 1.88303759732331161e-7*V062 + 1.00208433541766875e-6*V01*V02*V07 - 
      4.20586358086358086e-7*V05*V07 + 1.25260541927208594e-7*V012*V08 - 1.99453324453324453e-7*V04*V08 - 
      1.22048733159844271e-7*V03*V09 - 2.40885657552324219e-8*V02*V10 - 7.22656972656972657e-9*V01*V11 + 
      4.01476095920540365e-11*V14) + delta2*eps6*
    (-1.65343915343915344e-6*V024 - 0.000133928571428571429*V01*V022*V03 - 
      0.0000562169312169312169*V012*V032 - 0.0000744047619047619048*V012*V02*V04 + 
      0.0000395197009780343114*V032*V04 + 0.0000179623617123617124*V02*V042 - 
      8.2671957671957672e-6*V013*V05 + 0.0000417743907327240661*V02*V03*V05 + 0.0000256408329324995992*V01*V04*V05 + 
      6.68891293891293891e-6*V022*V06 + 0.0000185636123136123136*V01*V03*V06 - 3.70998324867372486e-7*V062 + 
      6.95196007696007696e-6*V01*V02*V07 - 7.19525459108792442e-7*V05*V07 + 1.12734487734487734e-6*V012*V08 - 
      4.17213958880625547e-7*V04*V08 - 2.37272372689039356e-7*V03*V09 - 6.02214143880810547e-8*V02*V10 - 
      1.80664243164243164e-8*V01*V11 + 6.02214143880810547e-11*V14) + 
   delta4*eps5*(0.0000263047138047138047*V032*V04 + 9.11896745230078563e-6*V02*V042 + 
      0.0000267431257014590348*V02*V03*V05 + 0.0000157828282828282828*V01*V04*V05 + 3.20666987333654e-6*V022*V06 + 
      0.0000109352453102453102*V01*V03*V06 - 3.36345202416630988e-7*V062 + 3.82044652877986211e-6*V01*V02*V07 - 
      7.00254606504606505e-7*V05*V07 + 5.63672438672438672e-7*V012*V08 - 3.67591513424846758e-7*V04*V08 - 
      2.18001520084853418e-7*V03*V09 - 4.81771315104648438e-8*V02*V10 - 1.44531394531394531e-8*V01*V11 + 
      6.02214143880810547e-11*V14) + 7.64716373181981648e-13*delta14*V14 + 
   2.67650730613693577e-12*delta12*eps*V14 + 
   delta12*eps2*(-3.28063324095070127e-10*V072 - 4.37417765460093502e-10*V06*V08 - 
      3.82740544777581815e-10*V05*V09 - 1.3917837991912066e-10*V04*V10 - 6.95891899595603299e-11*V03*V11 - 
      1.07060292245477431e-11*V02*V12 - 2.67650730613693577e-12*V01*V13 + 3.93604015608372907e-14*V16) + 
   delta10*eps3*(-1.96837994457042076e-9*V072 - 2.62450659276056101e-9*V06*V08 - 
      2.29644326866549089e-9*V05*V09 - 8.35070279514723959e-10*V04*V10 - 4.1753513975736198e-10*V03*V11 - 
      6.42361753472864584e-11*V02*V12 - 1.60590438368216146e-11*V01*V13 + 1.18081204682511872e-13*V16) + 
   delta8*eps4*(5.93542260208926876e-8*V043 + 5.93542260208926876e-7*V03*V04*V05 + 
      1.51757964257964258e-7*V02*V052 + 2.04408686551543694e-7*V032*V06 + 1.2498524403286308e-7*V02*V04*V06 + 
      1.22645211930926217e-7*V01*V05*V06 + 1.44531394531394531e-7*V02*V03*V07 + 8.47917514584181251e-8*V01*V04*V07 - 
      6.52972193150764579e-9*V072 + 1.09201498090386979e-8*V022*V08 + 4.23958757292090625e-8*V01*V03*V08 - 
      9.08483051340194197e-9*V06*V08 + 1.20442828776162109e-8*V01*V02*V09 - 7.72841484647040203e-9*V05*V09 + 
      1.20442828776162109e-9*V012*V10 - 2.9709231098119987e-9*V04*V10 - 1.46538775010997233e-9*V03*V11 - 
      2.40885657552324219e-10*V02*V12 - 6.02214143880810547e-11*V01*V13 + 2.9520301170627968e-13*V16) + 
   eps8*(0.0000427138447971781305*V012*V023 + 0.0000454695767195767196*V013*V02*V03 - 
      0.0000265865500240500241*V022*V032 - 0.0000157201980118646785*V01*V033 + 
      4.1335978835978836e-6*V014*V04 - 0.0000100208433541766875*V023*V04 - 
      0.000068329625621292288*V01*V02*V03*V04 - 0.0000103840989257655924*V012*V042 + 
      8.50711788211788212e-7*V043 - 0.0000202922077922077922*V01*V022*V05 - 
      0.0000166283369408369408*V012*V03*V05 + 4.77122221913888581e-6*V03*V04*V05 + 
      1.40881976819476819e-6*V02*V052 - 8.83086820586820587e-6*V012*V02*V06 + 
      1.726031766954386e-6*V032*V06 + 2.18586528110337634e-6*V02*V04*V06 + 1.33467860402384212e-6*V01*V05*V06 - 
      9.39454064454064454e-7*V013*V07 + 1.49830878997545664e-6*V02*V03*V07 + 9.8088639755306422e-7*V01*V04*V07 - 
      1.13969026729443396e-8*V072 + 2.66580127691238802e-7*V022*V08 + 5.46810442643775977e-7*V01*V03*V08 - 
      1.96493872089110184e-8*V06*V08 + 1.92708526041859375e-7*V01*V02*V09 - 1.41821430883930884e-8*V05*V09 + 
      2.70996364746364746e-8*V012*V10 - 7.34701255534588868e-9*V04*V10 - 3.22184566976233643e-9*V03*V11 - 
      8.43099801433134766e-10*V02*V12 - 2.10774950358283692e-10*V01*V13 + 4.4280451755941952e-13*V16) + 
   delta6*eps5*(3.56125356125356125e-7*V043 + 3.07900047483380817e-6*V03*V04*V05 + 
      7.79024216524216524e-7*V02*V052 + 1.07882362346648061e-6*V032*V06 + 7.57069209450161831e-7*V02*V04*V06 + 
      6.47294174079888366e-7*V01*V05*V06 + 7.41927825261158594e-7*V02*V03*V07 + 4.39857210690544024e-7*V01*V04*V07 - 
      1.45735822819156152e-8*V072 + 6.83044664526146008e-8*V022*V08 + 2.31410821688599466e-7*V01*V03*V08 - 
      2.17026506709046392e-8*V06*V08 + 6.18273187717632162e-8*V01*V02*V09 - 1.76649482205037761e-8*V05*V09 + 
      7.22656972656972657e-9*V012*V10 - 7.38716016493794272e-9*V04*V10 - 3.57313725369280925e-9*V03*V11 - 
      6.42361753472864584e-10*V02*V12 - 1.60590438368216146e-10*V01*V13 + 5.9040602341255936e-13*V16) + 
   delta2*eps7*(-0.0000311898749398749399*V022*V032 - 
      0.0000202922077922077922*V01*V033 - 6.91438191438191438e-6*V023*V04 - 
      0.0000756072631072631073*V01*V02*V03*V04 - 0.0000108976671476671477*V012*V042 + 
      1.41486599819933153e-6*V043 - 0.0000187139249639249639*V01*V022*V05 - 
      0.0000174362674362674363*V012*V03*V05 + 8.83134997718331052e-6*V03*V04*V05 + 
      2.36067944401277735e-6*V02*V052 - 7.89141414141414141e-6*V012*V02*V06 + 
      3.2333737690880548e-6*V032*V06 + 3.3093559879274165e-6*V02*V04*V06 + 2.16549323692180835e-6*V01*V05*V06 - 
      7.51563251563251563e-7*V013*V07 + 2.48834884251550918e-6*V02*V03*V07 + 1.55419426252759586e-6*V01*V04*V07 - 
      2.27636946386946387e-8*V072 + 3.52656602656602657e-7*V022*V08 + 8.77305564805564806e-7*V01*V03*V08 - 
      3.81287583668536049e-8*V06*V08 + 2.67383079883079883e-7*V01*V02*V09 - 2.83040647623980957e-8*V05*V09 + 
      3.61328486328486328e-8*V012*V10 - 1.39713681380348047e-8*V04*V10 - 6.3834699251365918e-9*V03*V11 - 
      1.44531394531394531e-9*V02*V12 - 3.61328486328486328e-10*V01*V13 + 8.8560903511883904e-13*V16) + 
   delta4*eps6*(-0.0000102087341670675004*V022*V032 - 7.13985088985088985e-6*V01*V033 - 
      9.01875901875901876e-7*V023*V04 - 0.0000239999198332531666*V01*V02*V03*V04 - 
      3.34445646945646946e-6*V012*V042 + 9.90714532381199048e-7*V043 - 
      6.12524050024050024e-6*V01*V022*V05 - 5.59914622414622415e-6*V012*V03*V05 + 
      7.18272853689520356e-6*V03*V04*V05 + 1.84751269820714265e-6*V02*V052 - 
      2.31732002565335899e-6*V012*V02*V06 + 2.5855634114562686e-6*V032*V06 + 
      2.17219215235088251e-6*V02*V04*V06 + 1.60770529074100503e-6*V01*V05*V06 - 1.87890812890812891e-7*V013*V07 + 
      1.8291250930139819e-6*V02*V03*V07 + 1.10662871079537746e-6*V01*V04*V07 - 2.25830303955303955e-8*V072 + 
      2.09088750755417422e-7*V022*V08 + 6.12813112813112813e-7*V01*V03*V08 - 3.60296119224690653e-8*V06*V08 + 
      1.69824388574388574e-7*V01*V02*V09 - 2.79427362760696094e-8*V05*V09 + 2.16797091797091797e-8*V012*V10 - 
      1.27669398502731836e-8*V04*V10 - 6.02214143880810547e-9*V03*V11 - 1.20442828776162109e-9*V02*V12 - 
      3.01107071940405274e-10*V01*V13 + 8.8560903511883904e-13*V16) + 2.81145725434552076e-15*delta16*V16 + 
   1.12458290173820831e-14*delta14*eps*V16 + 
   delta14*eps2*(-3.57367455441252861e-12*V082 - 8.04076774742818938e-12*V07*V09 - 
      4.38587331677901239e-12*V06*V10 - 3.07011132174530867e-12*V05*V11 - 9.44649637460094976e-13*V04*V12 - 
      3.93604015608372907e-13*V03*V13 - 5.24805354144497209e-14*V02*V14 - 1.12458290173820831e-14*V01*V15 + 
      1.47971434439237935e-16*V18) + delta12*eps3*
    (-2.50157218808877003e-11*V082 - 5.62853742319973257e-11*V07*V09 - 3.07011132174530867e-11*V06*V10 - 
      2.14907792522171607e-11*V05*V11 - 6.61254746222066484e-12*V04*V12 - 2.75522810925861035e-12*V03*V13 - 
      3.67363747901148046e-13*V02*V14 - 7.87208031216745814e-14*V01*V15 + 5.17900020537332772e-16*V18) + 
   delta10*eps4*(1.31523569023569024e-8*V04*V052 + 5.84549195660306771e-9*V042*V06 + 
      1.83715461493239271e-8*V03*V05*V06 + 2.06932250583044234e-9*V02*V062 + 1.25260541927208594e-8*V03*V04*V07 + 
      6.35938135938135938e-9*V02*V05*V07 + 2.62450659276056101e-9*V01*V06*V07 + 3.28063324095070127e-9*V032*V08 + 
      2.11061718998226935e-9*V02*V04*V08 + 1.96837994457042076e-9*V01*V05*V08 - 1.03457878350242703e-10*V082 + 
      1.76649482205037761e-9*V02*V03*V09 + 1.04383784939340495e-9*V01*V04*V09 - 2.25945573702732122e-10*V07*V09 + 
      1.12413306857751302e-10*V022*V10 + 4.1753513975736198e-10*V01*V03*V10 - 1.28213696627173129e-10*V06*V10 + 
      9.63542630209296876e-11*V01*V02*V11 - 8.8009857890032182e-11*V05*V11 + 8.0295219184108073e-12*V012*V12 - 
      2.84182099269245239e-11*V04*V12 - 1.17293996651295126e-11*V03*V13 - 1.65313686555516621e-12*V02*V14 - 
      3.54243614047535616e-13*V01*V15 + 1.55370006161199832e-15*V18) + 
   delta8*eps5*(8.54903198653198653e-8*V04*V052 + 4.25885842552509219e-8*V042*V06 + 
      1.20563271604938272e-7*V03*V05*V06 + 1.51413841890032366e-8*V02*V062 + 8.1419352252685586e-8*V03*V04*V07 + 
      4.10710046126712793e-8*V02*V05*V07 + 1.72233245149911817e-8*V01*V06*V07 + 2.18708882730046751e-8*V032*V08 + 
      1.55696253579851463e-8*V02*V04*V08 + 1.31225329638028051e-8*V01*V05*V08 - 3.06889302360175895e-10*V082 + 
      1.14086123924086887e-8*V02*V03*V09 + 6.78494602105713217e-9*V01*V04*V09 - 6.39241035920541056e-10*V07*V09 + 
      8.56482337963819445e-10*V022*V10 + 2.87055408583186361e-9*V01*V03*V10 - 3.8595685187655309e-10*V06*V10 + 
      6.22287948676837566e-10*V01*V02*V11 - 2.57121823196169601e-10*V05*V11 + 6.02214143880810547e-11*V012*V12 - 
      8.91513095352964634e-11*V04*V12 - 3.63099704398724007e-11*V03*V13 - 5.5104562185172207e-12*V02*V14 - 
      1.18081204682511872e-12*V01*V15 + 3.88425015402999579e-15*V18) + 
   eps9*(1.06888995777884667e-6*V025 + 0.0000263923961840628507*V01*V023*V03 + 
      0.0000299748476831810165*V012*V02*V032 - 1.21518211175949271e-6*V034 + 
      0.0000238245550745550746*V012*V022*V04 + 0.0000102212602212602213*V013*V03*V04 - 
      0.0000101287830702513242*V02*V032*V04 - 3.09484386865339246e-6*V022*V042 - 
      6.45033978367311701e-6*V01*V03*V042 + 6.32565736732403399e-6*V013*V02*V05 - 
      5.97243869813314258e-6*V022*V03*V05 - 5.42102848650467698e-6*V01*V032*V05 - 
      7.74114737408388202e-6*V01*V02*V04*V05 - 9.78856075582266058e-7*V012*V052 + 
      2.90447881593714927e-7*V04*V052 + 4.69727032227032227e-7*V014*V06 - 
      8.74346112441350537e-7*V023*V06 - 5.52347371543800115e-6*V01*V02*V03*V06 - 
      1.67601358077548554e-6*V012*V04*V06 + 2.3201418290704005e-7*V042*V06 + 
      4.20311060192012573e-7*V03*V05*V06 + 1.000249016122032e-7*V02*V062 - 
      1.21213662880329547e-6*V01*V022*V07 - 1.0095517908017908e-6*V012*V03*V07 + 
      3.08183088131004798e-7*V03*V04*V07 + 1.83444465128492906e-7*V02*V05*V07 + 8.64564434132886514e-8*V01*V06*V07 - 
      4.09505617838951172e-7*V012*V02*V08 + 8.67546827988296242e-8*V032*V08 + 
      1.14248626153388058e-7*V02*V04*V08 + 6.72587168122882409e-8*V01*V05*V08 - 5.58025064485634825e-10*V082 - 
      3.61328486328486328e-8*V013*V09 + 6.05727059720115276e-8*V02*V03*V09 + 3.94450264241930909e-8*V01*V04*V09 - 
      1.01977880393934316e-9*V07*V09 + 9.15365498698832032e-9*V022*V10 + 1.79760921948421948e-8*V01*V03*V10 - 
      7.27717595714794594e-10*V06*V10 + 5.32959517334517335e-9*V01*V02*V11 - 4.32620013655552871e-10*V05*V11 + 
      6.32324851074851075e-10*V012*V12 - 1.92177160620788072e-10*V04*V12 - 7.12915273270665428e-11*V03*V13 - 
      1.65313686555516621e-11*V02*V14 - 3.54243614047535616e-12*V01*V15 + 5.82637523104499369e-15*V18) + 
   delta6*eps6*(-3.02827683780064732e-7*V034 - 1.85757254209635162e-6*V02*V032*V04 - 
      1.58222876476844731e-7*V022*V042 - 1.08321462488129155e-6*V01*V03*V042 - 
      9.25161515439293217e-7*V022*V03*V05 - 1.03112826327112041e-6*V01*V032*V05 - 
      1.11454352525781097e-6*V01*V02*V04*V05 - 1.39369559012416155e-7*V012*V052 + 
      2.68161943509165731e-7*V04*V052 - 3.51463645114438765e-8*V023*V06 - 
      7.62712816284244856e-7*V01*V02*V03*V06 - 2.12598798908322718e-7*V012*V04*V06 + 
      1.55031715051556321e-7*V042*V06 + 3.8440189109831967e-7*V03*V05*V06 + 5.61607704464847322e-8*V02*V062 - 
      1.32165930777041888e-7*V01*V022*V07 - 1.24296999296999297e-7*V012*V03*V07 + 
      2.6128064322508767e-7*V03*V04*V07 + 1.32968882968882969e-7*V02*V05*V07 + 5.73479926158497587e-8*V01*V06*V07 - 
      3.77387530165307943e-8*V012*V02*V08 + 7.26576144069530313e-8*V032*V08 + 
      5.89825738635262445e-8*V02*V04*V08 + 4.44778160551970076e-8*V01*V05*V08 - 6.7521831725198257e-10*V082 - 
      2.40885657552324219e-9*V013*V09 + 3.86086178910252984e-8*V02*V03*V09 + 2.32454659537992871e-8*V01*V04*V09 - 
      1.33786004905285951e-9*V07*V09 + 3.45269442491664714e-9*V022*V10 + 1.03580832747499414e-8*V01*V03*V10 - 
      8.61655419311815204e-10*V06*V10 + 2.28841374674708008e-9*V01*V02*V11 - 5.54981662007805799e-10*V05*V11 + 
      2.40885657552324219e-10*V012*V12 - 2.07822920241220895e-10*V04*V12 - 8.32472493011708698e-11*V03*V13 - 
      1.37761405462930517e-11*V02*V14 - 2.9520301170627968e-12*V01*V15 + 7.76850030805999158e-15*V18) + 
   delta2*eps8*(4.1753513975736198e-8*V025 + 0.0000140291806958473625*V01*V023*V03 + 
      0.0000188517115600448934*V012*V02*V032 - 2.104308279903518e-6*V034 + 
      0.0000125886844636844637*V012*V022*V04 + 5.82461519961519962e-6*V013*V03*V04 - 
      0.0000153405163325798246*V02*V032*V04 - 3.46221514376276281e-6*V022*V042 - 
      9.37767864851198185e-6*V01*V03*V042 + 2.94362273528940196e-6*V013*V02*V05 - 
      7.97973888251666029e-6*V022*V03*V05 - 8.09444633849395754e-6*V01*V032*V05 - 
      9.9663114296050804e-6*V01*V02*V04*V05 - 1.24727152256914162e-6*V012*V052 + 
      5.53495019640852974e-7*V04*V052 + 1.87890812890812891e-7*V014*V06 - 
      8.40346822489679633e-7*V023*V06 - 7.21314895422038279e-6*V01*V02*V03*V06 - 
      2.10547829595448643e-6*V012*V04*V06 + 4.143130073189597e-7*V042*V06 + 
      8.11973933253695158e-7*V03*V05*V06 + 1.64565051717829496e-7*V02*V062 - 
      1.3248711165377832e-6*V01*V022*V07 - 1.25380984755984756e-6*V012*V03*V07 + 
      5.84147719564386231e-7*V03*V04*V07 + 3.1668434446212224e-7*V02*V05*V07 + 1.46458479791813125e-7*V01*V06*V07 - 
      4.40820753320753321e-7*V012*V02*V08 + 1.6699971747094763e-7*V032*V08 + 
      1.84426647720298514e-7*V02*V04*V08 + 1.14231420034991464e-7*V01*V05*V08 - 1.09940630202554417e-9*V082 - 
      3.61328486328486328e-8*V013*V09 + 1.03781570795459684e-7*V02*V03*V09 + 6.52800131966798633e-8*V01*V04*V09 - 
      2.03867199884356747e-9*V07*V09 + 1.30479731174175619e-8*V022*V10 + 3.01107071940405274e-8*V01*V03*V10 - 
      1.42836085807024182e-9*V06*V10 + 7.82878387045053712e-9*V01*V02*V11 - 8.64354418275986903e-10*V05*V11 + 
      9.03321215821215821e-10*V012*V12 - 3.70184576679674719e-10*V04*V12 - 1.41697445619014246e-10*V03*V13 - 
      2.89298951472154087e-11*V02*V14 - 6.19926324583187328e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   delta4*eps7*(-1.3248711165377832e-6*V034 - 8.6670659587326254e-6*V02*V032*V04 - 
      1.31581381581381581e-6*V022*V042 - 5.14897910731244065e-6*V01*V03*V042 - 
      4.27957459207459207e-6*V022*V03*V05 - 4.63174942341609008e-6*V01*V032*V05 - 
      5.20023957523957524e-6*V01*V02*V04*V05 - 6.59063159063159063e-7*V012*V052 + 
      5.00520248784137673e-7*V04*V052 - 3.03928875357446786e-7*V023*V06 - 
      3.68334817739579644e-6*V01*V02*V03*V06 - 1.04922909982433792e-6*V012*V04*V06 + 
      3.34278174059920092e-7*V042*V06 + 7.29246916002868384e-7*V03*V05*V06 + 1.25604664295140486e-7*V02*V062 - 
      6.11367798867798868e-7*V01*V022*V07 - 6.07995399662066329e-7*V012*V03*V07 + 
      5.08188442216219994e-7*V03*V04*V07 + 2.63408466533466533e-7*V02*V05*V07 + 1.17724262069500165e-7*V01*V06*V07 - 
      1.95117382617382617e-7*V012*V02*V08 + 1.4478948630734345e-7*V032*V08 + 
      1.36065984280269995e-7*V02*V04*V08 + 9.21731762505572029e-8*V01*V05*V08 - 1.06818506921603716e-9*V082 - 
      1.44531394531394531e-8*V013*V09 + 8.19011235677902345e-8*V02*V03*V09 + 5.02246595996595997e-8*V01*V04*V09 - 
      2.03276793860944188e-9*V07*V09 + 8.67188367188367188e-9*V022*V10 + 2.30045802962469629e-8*V01*V03*V10 - 
      1.37834503351543501e-9*V06*V10 + 5.41992729492729493e-9*V01*V02*V11 - 8.5845035804186131e-10*V05*V11 + 
      6.02214143880810547e-10*V012*V12 - 3.45977929719759785e-10*V04*V12 - 1.35793385384888653e-10*V03*V13 - 
      2.47970529833274931e-11*V02*V14 - 5.31365421071303424e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   8.22063524662432972e-18*delta18*V18 + 3.69928586098094837e-17*delta16*eps*V18 + 
   delta16*eps2*(-4.99609107113593639e-14*V092 - 7.26704155801590747e-14*V08*V10 - 
      6.54033740221431672e-14*V07*V11 - 3.01861726256045387e-14*V06*V12 - 1.76086006982693143e-14*V05*V13 - 
      4.69562685287181713e-15*V04*V14 - 1.67700959031136326e-15*V03*V15 - 1.97295245918983913e-16*V02*V16 - 
      3.69928586098094837e-17*V01*V17 + 4.40391173926303378e-19*V20) + 
   delta14*eps3*(-3.99687285690874911e-13*V092 - 5.81363324641272598e-13*V08*V10 - 
      5.23226992177145338e-13*V07*V11 - 2.4148938100483631e-13*V06*V12 - 1.40868805586154514e-13*V05*V13 - 
      3.75650148229745371e-14*V04*V14 - 1.34160767224909061e-14*V03*V15 - 1.57836196735187131e-15*V02*V16 - 
      2.9594286887847587e-16*V01*V17 + 1.76156469570521351e-18*V20) + 
   delta12*eps4*(4.14465028435616671e-10*V052*V06 + 1.9311337588648513e-10*V04*V062 + 
      5.61121884651296416e-10*V04*V05*V07 + 3.94728598510111115e-10*V03*V06*V07 + 6.75424490783967908e-11*V02*V072 + 
      9.9293173004138872e-11*V042*V08 + 3.00188662570652404e-10*V03*V05*V08 + 7.05638284744001105e-11*V02*V06*V08 + 
      4.28840946529503434e-11*V01*V07*V08 + 1.55867190180915671e-10*V03*V04*V09 + 7.8799523924796256e-11*V02*V05*V09 + 
      3.28940498758425929e-11*V01*V06*V09 - 1.87500359022631024e-12*V092 + 3.28940498758425929e-11*V032*V10 + 
      2.19068749258602978e-11*V02*V04*V10 + 1.97364299255055558e-11*V01*V05*V10 - 2.808497825656736e-12*V08*V10 + 
      1.43271861681447738e-11*V02*V03*V11 + 8.50184673714085479e-12*V01*V04*V11 - 2.47282462663132475e-12*V07*V11 + 
      7.87208031216745814e-13*V022*V12 + 2.83394891238028493e-12*V01*V03*V12 - 1.183475532645025e-12*V06*V12 + 
      5.5104562185172207e-13*V01*V02*V13 - 6.80520626986055263e-13*V05*V13 + 3.93604015608372907e-14*V012*V14 - 
      1.89344247508448862e-13*V04*V14 - 6.71543693296741495e-14*V03*V15 - 8.28640032859732435e-15*V02*V16 - 
      1.55370006161199832e-15*V01*V17 + 6.16547643496824729e-18*V20) + 
   delta10*eps5*(3.26045822369351781e-9*V052*V06 + 1.65543101467471215e-9*V04*V062 + 
      4.38766140359277614e-9*V04*V05*V07 + 3.10519830827954077e-9*V03*V06*V07 + 5.25866210681803586e-10*V02*V072 + 
      8.54383116547241456e-10*V042*V08 + 2.38274750915455345e-9*V03*V05*V08 + 6.08564288665958964e-10*V02*V06*V08 + 
      3.40392501307793351e-10*V01*V07*V08 + 1.21879483433132671e-9*V03*V04*V09 + 6.1351057912877085e-10*V02*V05*V09 + 
      2.58766525689961731e-10*V01*V06*V09 - 6.38324106265132578e-12*V092 + 2.64979846222065332e-10*V032*V10 + 
      1.91044143347286827e-10*V02*V04*V10 + 1.58987907733239199e-10*V01*V05*V10 - 1.00156931590772184e-11*V08*V10 + 
      1.11547378023412882e-10*V02*V03*V11 + 6.6479718236254184e-11*V01*V04*V11 - 8.52071309503185762e-12*V07*V11 + 
      7.08487228095071232e-12*V022*V12 + 2.34981597318198625e-11*V01*V03*V12 - 4.3121835424282719e-12*V06*V12 + 
      4.29028377013126468e-12*V01*V02*V13 - 2.42687949623794137e-12*V05*V13 + 3.54243614047535616e-13*V012*V14 - 
      7.18016588472958155e-13*V04*V14 - 2.5221731000168106e-13*V03*V15 - 3.31456013143892974e-14*V02*V16 - 
      6.21480024644799327e-15*V01*V17 + 1.84964293049047419e-17*V20) + 
   delta8*eps6*(-8.45508658008658009e-8*V032*V042 - 1.14340392118169896e-8*V02*V043 - 
      5.74110817166372722e-8*V033*V05 - 1.70707635985413763e-7*V02*V03*V04*V05 - 
      5.07305194805194805e-8*V01*V042*V05 - 2.09931850556850557e-8*V022*V052 - 
      4.97910654160654161e-8*V01*V03*V052 - 5.99346457481378116e-8*V02*V032*V06 - 
      1.17185137026406868e-8*V022*V04*V06 - 6.97283683394794506e-8*V01*V03*V04*V06 - 
      3.5960787448882687e-8*V01*V02*V05*V06 + 1.29533113516637482e-8*V052*V06 - 
      3.43835599291948498e-9*V012*V062 + 7.392378229602008e-9*V04*V062 - 
      1.99935095768429102e-8*V022*V03*V07 - 2.28153129938844225e-8*V01*V032*V07 - 
      2.43868051407733947e-8*V01*V02*V04*V07 - 6.24582097796383511e-9*V012*V05*V07 + 
      1.75019961580419097e-8*V04*V05*V07 + 1.2518744403859561e-8*V03*V06*V07 + 2.14039052230578841e-9*V02*V072 - 
      6.57656080936504217e-10*V023*V08 - 1.26407616486981566e-8*V01*V02*V03*V08 - 
      3.52151889850302549e-9*V012*V04*V08 + 3.86929241225589394e-9*V042*V08 + 
      9.72664871847229976e-9*V03*V05*V08 + 2.79046504017974087e-9*V02*V06*V08 + 1.42857640312640831e-9*V01*V07*V08 - 
      1.66612579807024251e-9*V01*V022*V09 - 1.58583057888613444e-9*V012*V03*V09 + 
      5.00664307853850338e-9*V03*V04*V09 + 2.53392425148280268e-9*V02*V05*V09 + 1.08879305089038983e-9*V01*V06*V09 - 
      1.6748072821287926e-11*V092 - 3.81402291124513347e-10*V012*V02*V10 + 
      1.12917963434906323e-9*V032*V10 + 9.01690570613695419e-10*V02*V04*V10 + 6.8620642935438298e-10*V01*V05*V10 - 
      2.760150625644289e-11*V08*V10 - 2.00738047960270182e-11*V013*V11 + 4.80787305065627506e-10*V02*V03*V11 + 
      2.88905347456545714e-10*V01*V04*V11 - 2.26228347113945505e-11*V07*V11 + 3.54243614047535616e-11*V022*V12 + 
      1.07453896261085804e-10*V01*V03*V12 - 1.21478628817236775e-11*V06*V12 + 1.97786017843207386e-11*V01*V02*V13 - 
      6.6713291145516521e-12*V05*V13 + 1.77121807023767808e-12*V012*V14 - 2.11096048371016838e-12*V04*V14 - 
      7.32828529060325873e-13*V03*V15 - 1.03580004107466554e-13*V02*V16 - 1.9421250770149979e-14*V01*V17 + 
      4.62410732622618547e-17*V20) + eps10*(-4.32775172358505692e-6*V012*V024 - 
      9.24422799422799423e-6*V013*V022*V03 - 1.23068482443482443e-6*V014*V032 + 
      4.22450354245989167e-6*V023*V032 + 7.39166243258505163e-6*V01*V02*V033 - 
      1.69101731601731602e-6*V014*V02*V04 + 1.21747740795359843e-6*V024*V04 + 
      0.0000161214859875574161*V01*V022*V03*V04 + 6.33712696584720394e-6*V012*V032*V04 + 
      4.84675707889993604e-6*V012*V02*V042 - 1.07324812418438411e-6*V032*V042 - 
      4.62417873132158846e-7*V02*V043 - 9.39454064454064454e-8*V015*V05 + 
      3.19858299769014055e-6*V01*V023*V05 + 7.76295326146516623e-6*V012*V02*V03*V05 - 
      6.14896486982300474e-7*V033*V05 + 1.39724005051386004e-6*V013*V04*V05 - 
      2.56161679617780808e-6*V02*V03*V04*V05 - 8.20972733175114127e-7*V01*V042*V05 - 
      3.79289523169731503e-7*V022*V052 - 6.95468437903953777e-7*V01*V03*V052 + 
      2.05559775872275872e-6*V012*V022*V06 + 9.52221004304337638e-7*V013*V03*V06 - 
      9.2266376058538757e-7*V02*V032*V06 - 5.93101783577974054e-7*V022*V04*V06 - 
      1.16940150577303355e-6*V01*V03*V04*V06 - 7.07132752333645191e-7*V01*V02*V05*V06 + 
      2.89604486589270086e-8*V052*V06 - 7.63370950312914599e-8*V012*V062 + 
      2.35668492554580323e-8*V04*V062 + 4.33594183594183594e-7*V013*V02*V07 - 
      4.0140583760375427e-7*V022*V03*V07 - 3.62902846161774733e-7*V01*V032*V07 - 
      5.19422603685996543e-7*V01*V02*V04*V07 - 1.32534428479368956e-7*V012*V05*V07 + 
      4.25063111758883818e-8*V04*V05*V07 + 3.06977183828184645e-8*V03*V06*V07 + 6.76143520976766775e-9*V02*V072 + 
      2.70996364746364746e-8*V014*V08 - 4.80241882358284475e-8*V023*V08 - 
      2.87815345479035955e-7*V01*V02*V03*V08 - 8.72350202707345564e-8*V012*V04*V08 + 
      1.34766641195601669e-8*V042*V08 + 2.39151691290706619e-8*V03*V05*V08 + 1.16898143469883277e-8*V02*V06*V08 + 
      4.92813313471090471e-9*V01*V07*V08 - 5.07365416219582886e-8*V01*V022*V09 - 
      4.2305543607626941e-8*V012*V03*V09 + 1.39815526419386714e-8*V03*V04*V09 + 8.39144081076270619e-9*V02*V05*V09 + 
      3.92546204816425405e-9*V01*V06*V09 - 2.56298084717075669e-11*V092 - 1.40014788452288452e-8*V012*V02*V10 + 
      3.21391736030508206e-9*V032*V10 + 4.35416007894999492e-9*V02*V04*V10 + 2.49794462727031588e-9*V01*V05*V10 - 
      4.62118489039601052e-11*V08*V10 - 1.05387475179141846e-9*V013*V11 + 1.88841366588507111e-9*V02*V03*V11 + 
      1.22273087448741044e-9*V01*V04*V11 - 3.49496505466431814e-11*V07*V11 + 2.47970529833274931e-10*V022*V12 + 
      4.71144006683222369e-10*V01*V03*V12 - 2.1239079842236017e-11*V06*V12 + 1.20885633293721529e-10*V01*V02*V13 - 
      1.07535465514320433e-11*V05*V13 + 1.23985264916637466e-11*V012*V14 - 4.17634576561305147e-12*V04*V14 - 
      1.34395055329437854e-12*V03*V15 - 2.79666011090159697e-13*V02*V16 - 5.24373770794049432e-14*V01*V17 + 
      6.9361609893392782e-17*V20) + delta6*eps7*
    (-5.30269627491849714e-7*V032*V042 - 1.06760523427190094e-7*V02*V043 - 
      3.44466490299823633e-7*V033*V05 - 1.06134220717554051e-6*V02*V03*V04*V05 - 
      3.18161776495109828e-7*V01*V042*V05 - 1.30511849261849262e-7*V022*V052 - 
      3.03130511463844797e-7*V01*V03*V052 - 3.78534604725080916e-7*V02*V032*V06 - 
      1.11853534472582092e-7*V022*V04*V06 - 4.46345064400619956e-7*V01*V03*V04*V06 - 
      2.27120762835048549e-7*V01*V02*V05*V06 + 3.26639377224889207e-8*V052*V06 - 
      2.2585898081929828e-8*V012*V062 + 2.10193091164924343e-8*V04*V062 - 
      1.24296999296999297e-7*V022*V03*V07 - 1.41067229360880155e-7*V01*V032*V07 - 
      1.51620315310791501e-7*V01*V02*V04*V07 - 4.0124668100858577e-8*V012*V05*V07 + 4.4787492448848658e-8*V04*V05*V07 + 
      3.24298782831501475e-8*V03*V06*V07 + 5.68358575623981786e-9*V02*V072 - 6.5918551368286818e-9*V023*V08 - 
      8.25205438300676396e-8*V01*V02*V03*V08 - 2.34003210193686384e-8*V012*V04*V08 + 
      1.12529063924436888e-8*V042*V08 + 2.54356286410311724e-8*V03*V05*V08 + 8.30444495178907462e-9*V02*V06*V08 + 
      3.92657491666076582e-9*V01*V07*V08 - 1.03580832747499414e-8*V01*V022*V09 - 
      1.05989689323022656e-8*V012*V03*V09 + 1.3470310226165346e-8*V03*V04*V09 + 6.88846387716213424e-9*V02*V05*V09 + 
      3.03283139855268707e-9*V01*V06*V09 - 3.40039836055713167e-11*V092 - 2.64974223307556641e-9*V012*V02*V10 + 
      3.11981788600213748e-9*V032*V10 + 2.79278917817666651e-9*V02*V04*V10 + 1.94147992156084282e-9*V01*V05*V10 - 
      5.8329550274963918e-11*V08*V10 - 1.60590438368216146e-10*V013*V11 + 1.39296461123803172e-9*V02*V03*V11 + 
      8.47035841589218496e-10*V01*V04*V11 - 4.62613453487800303e-11*V07*V11 + 1.18081204682511872e-10*V022*V12 + 
      3.24723312876907648e-10*V01*V03*V12 - 2.6147736236888857e-11*V06*V12 + 6.25830384817312922e-11*V01*V02*V13 - 
      1.39998733551651795e-11*V05*V13 + 5.9040602341255936e-12*V012*V14 - 4.73567778779337087e-12*V04*V14 - 
      1.62102706428185158e-12*V03*V15 - 2.48592009857919731e-13*V02*V16 - 4.66110018483599495e-14*V01*V17 + 
      9.24821465245237093e-17*V20) + delta2*eps9*
    (4.15642466733736575e-6*V023*V032 + 8.35529109338633148e-6*V01*V02*V033 + 
      6.79829796893288957e-7*V024*V04 + 0.0000154207702570797809*V01*V022*V03*V04 + 
      6.74263732299446585e-6*V012*V032*V04 + 4.56072256667494763e-6*V012*V02*V042 - 
      1.91435273280511376e-6*V032*V042 - 6.72419695237155555e-7*V02*V043 + 
      2.49385480040241945e-6*V01*V023*V05 + 7.25582012784393737e-6*V012*V02*V03*V05 - 
      1.13434203215949248e-6*V033*V05 + 1.24703063691158929e-6*V013*V04*V05 - 
      4.15228372817658532e-6*V02*V03*V04*V05 - 1.29452411198442944e-6*V01*V042*V05 - 
      5.49420037267259489e-7*V022*V052 - 1.13306877939814448e-6*V01*V03*V052 + 
      1.63031413031413031e-6*V012*V022*V06 + 8.24792491459158126e-7*V013*V03*V06 - 
      1.51755096571564826e-6*V02*V032*V06 - 7.77042071684928828e-7*V022*V04*V06 - 
      1.86239140232195788e-6*V01*V03*V04*V06 - 1.01627938309485929e-6*V01*V02*V05*V06 + 
      5.68838491377298567e-8*V052*V06 - 1.07641476689095737e-7*V012*V062 + 
      4.41557917412842716e-8*V04*V062 + 3.20377924544591211e-7*V013*V02*V07 - 
      5.77443068762513207e-7*V022*V03*V07 - 5.83046527987004177e-7*V01*V032*V07 - 
      7.28552935894205735e-7*V01*V02*V04*V07 - 1.86531529537481918e-7*V012*V05*V07 + 
      8.20730498018079717e-8*V04*V05*V07 + 6.00686679154524626e-8*V03*V06*V07 + 1.19181468478999992e-8*V02*V072 + 
      1.80664243164243164e-8*V014*V08 - 5.42489795135297781e-8*V023*V08 - 
      4.0979812185169328e-7*V01*V02*V03*V08 - 1.20546065486541677e-7*V012*V04*V08 + 
      2.49040458005988663e-8*V042*V08 + 4.6958392905278604e-8*V03*V05*V08 + 2.00429912245193913e-8*V02*V06*V08 + 
      8.62016691568998603e-9*V01*V07*V08 - 6.16667283333950001e-8*V01*V022*V09 - 
      5.79330006413339747e-8*V012*V03*V09 + 2.68752821857397021e-8*V03*V04*V09 + 1.4780224390110011e-8*V02*V05*V09 + 
      6.83399189285918978e-9*V01*V06*V09 - 5.12537905681840888e-11*V092 - 1.68619960286626953e-8*V012*V02*V10 + 
      6.27264228017029137e-9*V032*V10 + 7.31125081907061366e-9*V02*V04*V10 + 4.36078106078397862e-9*V01*V05*V10 - 
      9.16586854918693502e-11*V08*V10 - 1.20442828776162109e-9*V013*V11 + 3.30686413713374498e-9*V02*V03*V11 + 
      2.08501887168145338e-9*V01*V04*V11 - 6.98876483428242728e-11*V07*V11 + 3.71955794749912397e-10*V022*V12 + 
      8.121034852039754e-10*V01*V03*V12 - 4.19521212350405431e-11*V06*V12 + 1.85092288339837359e-10*V01*V02*V13 - 
      2.14954403524019967e-11*V05*V13 + 1.85977897374956198e-11*V012*V14 - 8.11342172173785521e-12*V04*V14 - 
      2.6762483561266671e-12*V03*V15 - 4.97184019715839461e-13*V02*V16 - 9.3222003696719899e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + delta4*eps8*
    (1.12355953129762654e-6*V023*V032 + 2.5791971476495286e-6*V01*V02*V033 + 
      3.77616945077262538e-8*V024*V04 + 4.13625909657655689e-6*V01*V022*V03*V04 + 
      1.98785727059536583e-6*V012*V032*V04 + 1.22404326273373892e-6*V012*V02*V042 - 
      1.42409880133094419e-6*V032*V042 - 3.91505723846993688e-7*V02*V043 + 
      6.74135718778575921e-7*V01*V023*V05 + 2.06180916746392937e-6*V012*V02*V03*V05 - 
      8.81354738001563398e-7*V033*V05 + 3.3207808505427553e-7*V013*V04*V05 - 
      2.91372423688891943e-6*V02*V03*V04*V05 - 8.88464306123036282e-7*V01*V042*V05 - 
      3.66935769134843209e-7*V022*V052 - 8.12937475883904455e-7*V01*V03*V052 + 
      4.23557281196170085e-7*V012*V022*V06 + 2.13183806933806934e-7*V013*V03*V06 - 
      1.05803289707059548e-6*V02*V032*V06 - 4.22574620656631239e-7*V022*V04*V06 - 
      1.26838342984176318e-6*V01*V03*V04*V06 - 6.5878786116881355e-7*V01*V02*V05*V06 + 
      5.45632582627067921e-8*V052*V06 - 6.76716636538065109e-8*V012*V062 + 
      3.90218908615850726e-8*V04*V062 + 7.34701255534588868e-8*V013*V02*V07 - 
      3.63268954125435607e-7*V022*V03*V07 - 3.97088535729408745e-7*V01*V032*V07 - 
      4.49314840435872182e-7*V01*V02*V04*V07 - 1.17990956904647381e-7*V012*V05*V07 + 
      7.65859343014163276e-8*V04*V05*V07 + 5.59869380444485487e-8*V03*V06*V07 + 1.02824269600355035e-8*V02*V072 + 
      3.61328486328486328e-9*V014*V08 - 2.64209506934374659e-8*V023*V08 - 
      2.52155665102093674e-7*V01*V02*V03*V08 - 7.26442318704223466e-8*V012*V04*V08 + 
      2.14728983840795232e-8*V042*V08 + 4.39814532769423059e-8*V03*V05*V08 + 1.64109258267755e-8*V02*V06*V08 + 
      7.31276900598796024e-9*V01*V07*V08 - 3.37239920573253907e-8*V01*V022*V09 - 
      3.40250991292657959e-8*V012*V03*V09 + 2.42509274116708757e-8*V03*V04*V09 + 1.27037664057680398e-8*V02*V05*V09 + 
      5.74203595255766124e-9*V01*V06*V09 - 5.12110638164897588e-11*V092 - 9.03321215821215821e-9*V012*V02*V10 + 
      5.67822993017028965e-9*V032*V10 + 5.76472441260022959e-9*V02*V04*V10 + 3.68295277404754529e-9*V01*V05*V10 - 
      9.01908088622321099e-11*V08*V10 - 6.02214143880810547e-10*V013*V11 + 2.72767582816602424e-9*V02*V03*V11 + 
      1.68501879081944441e-9*V01*V04*V11 - 6.98021948394356129e-11*V07*V11 + 2.65682710535651712e-10*V022*V12 + 
      6.5535068598794089e-10*V01*V03*V12 - 4.09621923386420413e-11*V06*V12 + 1.35793385384888653e-10*V01*V02*V13 - 
      2.14099868490133368e-11*V05*V13 + 1.32841355267825856e-11*V012*V14 - 7.69703010522583966e-12*V04*V14 - 
      2.59079485273800719e-12*V03*V15 - 4.35036017251359529e-13*V02*V16 - 8.15692532346299116e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + 1.95729410633912612e-20*delta20*V20 + 
   9.78647053169563062e-20*delta18*eps*V20 + 
   delta18*eps2*(-3.73576270568999572e-16*V102 - 8.21867795251799059e-16*V09*V11 - 
      5.0576479707803019e-16*V08*V12 - 3.79323597808522643e-16*V07*V13 - 1.51729439123409057e-16*V06*V14 - 
      7.58647195617045285e-17*V05*V15 - 1.78505222498128302e-17*V04*V16 - 5.57828820306650945e-18*V03*V17 - 
      5.87188231901737837e-19*V02*V18 - 9.78647053169563062e-20*V01*V19 + 1.06374679692343811e-21*V22) + 
   delta16*eps3*(-3.36218643512099615e-15*V102 - 7.39681015726619153e-15*V09*V11 - 
      4.55188317370227171e-15*V08*V12 - 3.41391238027670378e-15*V07*V13 - 1.36556495211068151e-15*V06*V14 - 
      6.82782476055340757e-16*V05*V15 - 1.60654700248315472e-16*V04*V16 - 5.02045938275985851e-17*V03*V17 - 
      5.28469408711564053e-18*V02*V18 - 8.80782347852606755e-19*V01*V19 + 4.7868605861554715e-21*V22) + 
   delta14*eps4*(2.13459363566774952e-12*V063 + 1.7930586539609096e-11*V05*V06*V07 + 
      6.04327175964602865e-12*V04*V072 + 6.86735427232503256e-12*V052*V08 + 
      6.60875939349902034e-12*V04*V06*V08 + 6.54033740221431672e-12*V03*V07*V08 + 6.07011706610740506e-13*V02*V082 + 
      7.05048371958703343e-12*V04*V05*V09 + 4.98071848322474889e-12*V03*V06*V09 + 1.69279320998488198e-12*V02*V07*V09 + 
      5.4502811685119306e-13*V01*V08*V09 + 1.03773353448467159e-12*V042*V10 + 3.05215745436668114e-12*V03*V05*V10 + 
      7.38870695966594755e-13*V02*V06*V10 + 4.36022493480954448e-13*V01*V07*V10 - 1.85215182566314525e-14*V102 + 
      1.28190613083400608e-12*V03*V04*V11 + 6.463392256305913e-13*V02*V05*V11 + 2.71675553630440848e-13*V01*V06*V11 - 
      3.9838959969837207e-14*V09*V11 + 2.2639629469203404e-13*V032*V12 + 1.54600554702115794e-13*V02*V04*V12 + 
      1.35837776815220424e-13*V01*V05*V12 - 2.52150370543244262e-14*V08*V12 + 8.28640032859732435e-14*V02*V03*V13 + 
      4.93040819551540799e-14*V01*V04*V13 - 1.8596838492559939e-14*V07*V13 + 4.00509349215537344e-15*V022*V14 + 
      1.40868805586154514e-14*V01*V03*V14 - 7.6902868355706801e-15*V06*V14 + 2.36754295102780696e-15*V01*V02*V15 - 
      3.80321817802755597e-15*V05*V15 + 1.47971434439237935e-16*V012*V16 - 9.29401533454070648e-16*V04*V16 - 
      2.88896610095655016e-16*V03*V17 - 3.17081645226938432e-17*V02*V18 - 5.28469408711564053e-18*V01*V19 + 
      1.9147442344621886e-20*V22) + delta12*eps5*
    (2.10613238719217953e-11*V063 + 1.64612745870577951e-10*V05*V06*V07 + 5.52527703739065477e-11*V04*V072 + 
      6.34085711144678006e-11*V052*V08 + 6.53389768538752109e-11*V04*V06*V08 + 6.03891153471121911e-11*V03*V07*V08 + 
      6.02167012238729901e-12*V02*V082 + 6.44615654362243056e-11*V04*V05*V09 + 4.57257627418272085e-11*V03*V06*V09 + 
      1.54291047785080388e-11*V02*V07*V09 + 5.03242627892601592e-12*V01*V08*V09 + 1.03162921957593822e-11*V042*V10 + 
      2.84232162937897181e-11*V03*V05*V10 + 7.35516676785972028e-12*V02*V06*V10 + 4.0604594705413883e-12*V01*V07*V10 - 
      7.67994164653953858e-14*V102 + 1.17202846247680556e-11*V03*V04*V11 + 5.89111273361216028e-12*V02*V05*V11 + 
      2.49413251319057501e-12*V01*V06*V11 - 1.5942072417897397e-13*V09*V11 + 2.13818722764698816e-12*V032*V12 + 
      1.55808001607139976e-12*V02*V04*V12 + 1.2829123365881929e-12*V01*V05*V12 - 1.05441977990826965e-13*V08*V12 + 
      7.55270863283610293e-13*V02*V03*V13 + 4.50780177875694445e-13*V01*V04*V13 - 7.57798708621947274e-14*V07*V13 + 
      4.16161438725110068e-14*V022*V14 + 1.36760132089891674e-13*V01*V03*V14 - 3.29532384496182881e-14*V06*V14 + 
      2.15791675223888655e-14*V01*V02*V15 - 1.60364042073524112e-14*V05*V15 + 1.55370006161199832e-15*V012*V16 - 
      4.13580159257670028e-15*V04*V16 - 1.27625362203842719e-15*V03*V17 - 1.47971434439237935e-16*V02*V18 - 
      2.46619057398729892e-17*V01*V19 + 6.7016048206176601e-20*V22) + 
   delta10*eps6*(-2.95801289810004407e-10*V044 - 7.84358338143741194e-9*V03*V042*V05 - 
      4.09348176232707823e-9*V032*V052 - 3.92005983305002913e-9*V02*V04*V052 - 
      8.01299054975525564e-10*V01*V053 - 5.49887301462931715e-9*V032*V04*V06 - 
      1.23515189263710895e-9*V02*V042*V06 - 5.57736890117064409e-9*V02*V03*V05*V06 - 
      3.29932380877759029e-9*V01*V04*V05*V06 - 2.13153443195460002e-10*V022*V062 - 
      1.13590745155871206e-9*V01*V03*V062 + 1.11077632135397347e-10*V063 - 
      1.27190326186591359e-9*V033*V07 - 3.73339031719050393e-9*V02*V03*V04*V07 - 
      1.12051191163391599e-9*V01*V042*V07 - 9.11823062558356676e-10*V022*V05*V07 - 
      2.2213661141454481e-9*V01*V03*V05*V07 - 7.96766985881520584e-10*V01*V02*V06*V07 + 7.90818238274194341e-10*V05*V06*V07 - 
      7.07587561773680666e-11*V012*V072 + 2.66182291692605467e-10*V04*V072 - 
      1.0063142665720734e-9*V02*V032*V08 - 2.14750350915928258e-10*V022*V04*V08 - 
      1.16958121224642648e-9*V01*V03*V04*V08 - 6.03788559943244039e-10*V01*V02*V05*V08 + 
      3.07308867141893107e-10*V052*V08 - 1.15543395934255982e-10*V012*V06*V08 + 
      3.48020435329644263e-10*V04*V06*V08 + 2.95653173692384828e-10*V03*V07*V08 + 3.2678175994266238e-11*V02*V082 - 
      2.53284184043987966e-10*V022*V03*V09 - 2.92166637871586518e-10*V01*V032*V09 - 
      3.11115859765875328e-10*V01*V02*V04*V09 - 8.04807753628948774e-11*V012*V05*V09 + 
      3.13793240103475455e-10*V04*V05*V09 + 2.24240350892254344e-10*V03*V06*V09 + 7.61580611867156797e-11*V02*V07*V09 + 
      2.53822800065346792e-11*V01*V08*V09 - 7.30978886129835398e-12*V023*V10 - 
      1.29608179425328507e-10*V01*V02*V03*V10 - 3.60822424022704135e-11*V012*V04*V10 + 
      5.60804732543481649e-11*V042*V10 + 1.42000663750085985e-10*V03*V05*V10 + 4.03355333137918687e-11*V02*V06*V10 + 
      2.06774049390104097e-11*V01*V07*V10 - 2.53132042505487258e-13*V102 - 
      1.3815500947853889e-11*V01*V022*V11 - 1.32250949244413297e-11*V012*V03*V11 + 
      5.88245344526877608e-11*V03*V04*V11 + 2.96754985434489887e-11*V02*V05*V11 + 1.27296865619387611e-11*V01*V06*V11 - 
      5.05754031960445325e-13*V09*V11 - 2.63714690457609848e-12*V012*V02*V12 + 
      1.11352203701387527e-11*V032*V12 + 8.81730210584071817e-12*V02*V04*V12 + 6.74017282442450755e-12*V01*V05*V12 - 
      3.50568990092294541e-13*V08*V12 - 1.18081204682511872e-13*V013*V13 + 3.95761932360611793e-12*V02*V03*V13 + 
      2.37602171422117529e-12*V01*V04*V13 - 2.44874227567633878e-13*V07*V13 + 2.48384849849704798e-13*V022*V14 + 
      7.57584150042010379e-13*V01*V03*V14 - 1.12391703028323173e-13*V06*V14 + 1.1963490474412387e-13*V01*V02*V15 - 
      5.36951342721384656e-14*V05*V15 + 9.3222003696719899e-15*V012*V16 - 1.46935634398163269e-14*V04*V16 - 
      4.49463232109185227e-15*V03*V17 - 5.54892879147142256e-16*V02*V18 - 9.24821465245237093e-17*V01*V19 + 
      2.01048144618529803e-19*V22) + delta8*eps7*
    (-3.12288574815807931e-9*V044 - 6.13302756208529629e-8*V03*V042*V05 - 
      3.11053445414828857e-8*V032*V052 - 3.05407589414942356e-8*V02*V04*V052 - 
      6.13408242084712673e-9*V01*V053 - 4.34778369389713928e-8*V032*V04*V06 - 
      1.31957658023639972e-8*V02*V042*V06 - 4.3769553743682284e-8*V02*V03*V05*V06 - 
      2.60867021633828357e-8*V01*V04*V05*V06 - 2.31124277965236571e-9*V022*V062 - 
      9.11367606483152702e-9*V01*V03*V062 + 3.89361294085025683e-10*V063 - 
      9.73663876324940751e-9*V033*V07 - 2.90864370871373672e-8*V02*V03*V04*V07 - 
      8.76146794583613756e-9*V01*V042*V07 - 7.13092395077689195e-9*V022*V05*V07 - 
      1.71856509877829517e-8*V01*V03*V05*V07 - 6.252793391954612e-9*V01*V02*V06*V07 + 2.5282819527162001e-9*V05*V06*V07 - 
      5.70894510067401446e-10*V012*V072 + 8.58885837973415987e-10*V04*V072 - 
      8.03345795856689103e-9*V02*V032*V08 - 2.36162409365023744e-9*V022*V04*V08 - 
      9.43862429428878231e-9*V01*V03*V04*V08 - 4.82007477514013462e-9*V01*V02*V05*V08 + 
      9.90550771013638422e-10*V052*V08 - 9.52465488627175524e-10*V012*V06*V08 + 
      1.24013655702525207e-9*V04*V06*V08 + 9.70630955157051171e-10*V03*V07*V08 + 1.20233202577373189e-10*V02*V082 - 
      1.98081220854913665e-9*V022*V03*V09 - 2.30511380283789247e-9*V01*V032*V09 - 
      2.42386975726144727e-9*V01*V02*V04*V09 - 6.55688060858462352e-10*V012*V05*V09 + 
      1.03082561137740446e-9*V04*V05*V09 + 7.43326732405203706e-10*V03*V06*V09 + 2.56405271524897592e-10*V02*V07*V09 + 
      8.76982300491031469e-11*V01*V08*V09 - 8.45686342107132646e-11*V023*V10 - 1.06762277776516805e-9*V01*V02*V03*V10 - 
      3.02034852834339296e-10*V012*V04*V10 + 2.06123073726194409e-10*V042*V10 + 
      4.7748951503009169e-10*V03*V05*V10 + 1.50591515305042041e-10*V02*V06*V10 + 7.19068418752763738e-11*V01*V07*V10 - 
      6.67076525370678137e-13*V102 - 1.08044302284498363e-10*V01*V022*V11 - 
      1.12177144448386278e-10*V012*V03*V11 + 2.03127638655029436e-10*V03*V04*V11 + 
      1.03144968090215195e-10*V02*V05*V11 + 4.50206788567242398e-11*V01*V06*V11 - 1.29003346187058122e-12*V09*V11 - 
      2.30258349130898151e-11*V012*V02*V12 + 3.95028240664850572e-11*V032*V12 + 
      3.43243417611322668e-11*V02*V04*V12 + 2.42921004633035937e-11*V01*V05*V12 - 9.30432048801058198e-13*V08*V12 - 
      1.18081204682511872e-12*V013*V13 + 1.45685275777151709e-11*V02*V03*V13 + 8.81931944973023978e-12*V01*V04*V13 - 
      6.32855328667315743e-13*V07*V13 + 1.03165684091036688e-12*V022*V14 + 2.90075801502960086e-12*V01*V03*V14 - 
      3.05117097813708622e-13*V06*V14 + 4.73878518791659487e-13*V01*V02*V15 - 1.4295890209760875e-13*V05*V15 + 
      3.88425015402999579e-14*V012*V16 - 4.15429802188160502e-14*V04*V16 - 1.25775719273352245e-14*V03*V17 - 
      1.66467863744142677e-15*V02*V18 - 2.77446439573571128e-16*V01*V19 + 5.02620361546324507e-19*V22) + 
   eps11*(-9.01835117002665504e-8*V026 - 3.25916459348999032e-6*V01*V024*V03 - 
      7.35068548808628174e-6*V012*V022*V032 - 1.0854789500622834e-6*V013*V033 + 
      6.78100295225791258e-7*V02*V034 - 3.88445328921519398e-6*V012*V023*V04 - 
      4.99063464093225998e-6*V013*V02*V03*V04 + 2.84278006510562727e-6*V022*V032*V04 + 
      1.64707575731881287e-6*V01*V033*V04 - 2.84933320647606362e-7*V014*V042 + 
      5.87400058299529199e-7*V023*V042 + 3.58815504059799695e-6*V01*V02*V03*V042 + 
      3.5912954439740154e-7*V012*V043 - 2.81868399275952575e-8*V044 - 
      1.54110614180058625e-6*V013*V022*V05 - 4.60814262897596231e-7*V014*V03*V05 + 
      1.12000694579646299e-6*V023*V03*V05 + 3.00648528885136028e-6*V01*V02*V032*V05 + 
      2.15679602202006303e-6*V01*V022*V04*V05 + 1.75801937489685506e-6*V012*V03*V04*V05 - 
      3.02837308803974984e-7*V03*V042*V05 + 5.39000298734921751e-7*V012*V02*V052 - 
      1.30260107162109282e-7*V032*V052 - 1.81474604951678073e-7*V02*V04*V052 - 
      3.30907815972154207e-8*V01*V053 - 2.28841374674708008e-7*V014*V02*V06 + 
      1.2426335177657929e-7*V024*V06 + 1.53341242595954898e-6*V01*V022*V03*V06 + 
      6.11779025097477478e-7*V012*V032*V06 + 9.21724593289573448e-7*V012*V02*V04*V06 - 
      2.1732776138249265e-7*V032*V04*V06 - 1.45683102372722665e-7*V02*V042*V06 + 
      1.38048989425477521e-7*V013*V05*V06 - 2.61595716210939036e-7*V02*V03*V05*V06 - 
      1.66642922459441776e-7*V01*V04*V05*V06 - 3.13513920345541883e-8*V022*V062 - 
      5.92808427693683879e-8*V01*V03*V062 + 8.84509142307875836e-10*V063 - 
      1.08398545898545899e-8*V015*V07 + 2.24590985483015906e-7*V01*V023*V07 + 
      5.54011203192750812e-7*V012*V02*V03*V07 - 4.56228874516762589e-8*V033*V07 + 
      1.01933346911025482e-7*V013*V04*V07 - 1.91754429908024679e-7*V02*V03*V04*V07 - 
      6.13420781184067054e-8*V01*V042*V07 - 5.72043116871378037e-8*V022*V05*V07 - 
      1.03916952302356811e-7*V01*V03*V05*V07 - 5.3133259730785894e-8*V01*V02*V06*V07 + 4.73703555517935601e-9*V05*V06*V07 - 
      5.00584884186415077e-9*V012*V072 + 1.741265174578467e-9*V04*V072 + 
      1.12062015273820829e-7*V012*V022*V08 + 5.3898165877332544e-8*V013*V03*V08 - 
      5.36809105180029939e-8*V02*V032*V08 - 3.57374452845974788e-8*V022*V04*V08 - 
      6.77966188714758976e-8*V01*V03*V04*V08 - 4.12668507250089883e-8*V01*V02*V05*V08 + 
      1.84415328275492498e-9*V052*V08 - 8.89450891456902195e-9*V012*V06*V08 + 
      3.03796541544199087e-9*V04*V06*V08 + 1.95419862124377447e-9*V03*V07*V08 + 3.79246470634262349e-10*V02*V082 + 
      1.95719596761263428e-8*V013*V02*V09 - 1.87589213813852975e-8*V022*V03*V09 - 
      1.67786011778556713e-8*V01*V032*V09 - 2.41704845909809145e-8*V01*V02*V04*V09 - 
      6.17402338833098637e-9*V012*V05*V09 + 2.15772698503969466e-9*V04*V05*V09 + 1.55508035764887683e-9*V03*V06*V09 + 
      6.91653165373944804e-10*V02*V07*V09 + 2.50103168132130448e-10*V01*V08*V09 + 1.05387475179141846e-9*V014*V10 - 
      1.89829593813409562e-9*V023*V10 - 1.09471819705392301e-8*V01*V02*V03*V10 - 
      3.31517199332033599e-9*V012*V04*V10 + 5.66213951638936691e-10*V042*V10 + 
      9.90709445715168765e-10*V03*V05*V10 + 4.93857621869645393e-10*V02*V06*V10 + 2.04600194881280817e-10*V01*V07*V10 - 
      1.0592820988240287e-12*V102 - 1.62155014330259428e-9*V01*V022*V11 - 
      1.34701134241575418e-9*V012*V03*V11 + 4.83293552740012793e-10*V03*V04*V11 + 2.92311187466604348e-10*V02*V05*V11 + 
      1.35732624614622041e-10*V01*V06*V11 - 1.95010166215273807e-12*V09*V11 - 3.7815505799574427e-10*V012*V02*V12 + 
      9.37949305944393234e-11*V032*V12 + 1.29817854947928907e-10*V02*V04*V12 + 7.30666296474582508e-11*V01*V05*V12 - 
      1.49261560383255041e-12*V08*V12 - 2.47970529833274931e-11*V013*V13 + 4.77180131422584983e-11*V02*V03*V13 + 
      3.07298566685929087e-11*V01*V04*V13 - 9.64334462347839848e-13*V07*V13 + 5.53945861966731133e-12*V022*V14 + 
      1.02559741067008009e-11*V01*V03*V14 - 5.09835577360394305e-13*V06*V14 + 2.32278159210993748e-12*V01*V02*V15 - 
      2.25009062494166185e-13*V05*V15 + 2.09749508317619773e-13*V012*V16 - 7.75740245047704874e-14*V04*V16 - 
      2.20569919460989047e-14*V03*V17 - 4.16169659360356692e-15*V02*V18 - 6.9361609893392782e-16*V01*V19 + 
      7.53930542319486761e-19*V22) + delta6*eps8*
    (1.16714836456899949e-7*V02*V034 + 3.3167660895835499e-7*V022*V032*V04 + 
      2.55740273101384212e-7*V01*V033*V04 + 1.0639753805538638e-8*V023*V042 + 
      4.0211845767401323e-7*V01*V02*V03*V042 + 3.92643621810288477e-8*V012*V043 - 
      1.44647796358943781e-8*V044 + 1.06435773874045479e-7*V023*V03*V05 + 
      3.97805457329266853e-7*V01*V02*V032*V05 + 1.99005965375012994e-7*V01*V022*V04*V05 + 
      2.09450079241745908e-7*V012*V03*V04*V05 - 2.23205463736282545e-7*V03*V042*V05 + 
      5.46638381459810031e-8*V012*V02*V052 - 1.08785983451243074e-7*V032*V052 - 
      1.12518714013131224e-7*V02*V04*V052 - 2.20587498467400428e-8*V01*V053 + 
      1.74482785814355479e-9*V024*V06 + 1.40126628221866317e-7*V01*V022*V03*V06 + 
      6.90710946167295374e-8*V012*V032*V06 + 8.25320145756653693e-8*V012*V02*V04*V06 - 
      1.60306931018687944e-7*V032*V04*V06 - 6.23141806988030663e-8*V02*V042*V06 + 
      1.17976618472650219e-8*V013*V05*V06 - 1.63158892000544402e-7*V02*V03*V05*V06 - 
      9.83588207974490265e-8*V01*V04*V05*V06 - 1.11381689475890119e-8*V022*V062 - 
      3.48030855806882884e-8*V01*V03*V062 + 9.53886585144753617e-10*V063 + 
      1.52051105534350684e-8*V01*V023*V07 + 4.88653762463286273e-8*V012*V02*V03*V07 - 
      3.50760218509401516e-8*V033*V07 + 8.00084505441648299e-9*V013*V04*V07 - 
      1.0966831245289851e-7*V02*V03*V04*V07 - 3.33776917471737993e-8*V01*V042*V07 - 
      2.72838431539411932e-8*V022*V05*V07 - 6.36466502471469273e-8*V01*V03*V05*V07 - 
      2.43659066418494264e-8*V01*V02*V06*V07 + 5.73454430680343706e-9*V05*V06*V07 - 
      2.24285876770250149e-9*V012*V072 + 1.97943651812315506e-9*V04*V072 + 
      7.29348240922314996e-9*V012*V022*V08 + 3.81402291124513347e-9*V013*V03*V08 - 
      3.10448607244177324e-8*V02*V032*V08 - 1.1607382420290917e-8*V022*V04*V08 - 
      3.68885683428167088e-8*V01*V03*V04*V08 - 1.90217012623058375e-8*V01*V02*V05*V08 + 
      2.25567676854889474e-9*V052*V08 - 3.85231495904931946e-9*V012*V06*V08 + 
      3.10327793500338834e-9*V04*V06*V08 + 2.26552478541084656e-9*V03*V07*V08 + 3.14616699492002765e-10*V02*V082 + 
      1.00369023980135091e-9*V013*V02*V09 - 7.92456084758190786e-9*V022*V03*V09 - 
      9.03546132401563463e-9*V01*V032*V09 - 9.76593414783968783e-9*V01*V02*V04*V09 - 
      2.6475492964171769e-9*V012*V05*V09 + 2.41967965015243137e-9*V04*V05*V09 + 1.75967541052281089e-9*V03*V06*V09 + 
      6.25456165059616089e-10*V02*V07*V09 + 2.19248139960954814e-10*V01*V08*V09 + 4.01476095920540365e-11*V014*V10 - 
      4.41323816738797546e-10*V023*V10 - 4.45295468686769652e-9*V01*V02*V03*V10 - 
      1.27550192715147586e-9*V012*V04*V10 + 5.34938290003461784e-10*V042*V10 + 
      1.1361175216718043e-9*V03*V05*V10 + 4.00148693505997441e-10*V02*V06*V10 + 1.80018298529104411e-10*V01*V07*V10 - 
      1.37352914624220985e-12*V102 - 4.69963194636397251e-10*V01*V022*V11 - 
      4.90627405455836828e-10*V012*V03*V11 + 5.02893349542243018e-10*V03*V04*V11 + 
      2.59112630875115109e-10*V02*V05*V11 + 1.15332635287803027e-10*V01*V06*V11 - 2.59545595292284319e-12*V09*V11 - 
      1.05092272167435566e-10*V012*V02*V12 + 9.92078181483731716e-11*V032*V12 + 
      9.54439427562594958e-11*V02*V04*V12 + 6.26440027127202582e-11*V01*V05*V12 - 1.92513302396022541e-12*V08*V12 - 
      5.9040602341255936e-12*V013*V13 + 3.87855325380408513e-11*V02*V03*V13 + 2.3732250541102737e-11*V01*V04*V13 - 
      1.28109968651631223e-12*V07*V13 + 3.08841045580429443e-12*V022*V14 + 7.94458631504268473e-12*V01*V03*V14 - 
      6.42639939769610351e-13*V06*V14 + 1.37243505442393185e-12*V01*V02*V15 - 2.95332486711414013e-13*V05*V15 + 
      1.16527504620899874e-13*V012*V16 - 9.08914536043019015e-14*V04*V16 - 2.71897510782099705e-14*V03*V17 - 
      3.88425015402999579e-15*V02*V18 - 6.47375025671665965e-16*V01*V19 + 1.00524072309264901e-18*V22) + 
   delta2*eps10*(-1.05683802773749864e-9*V026 - 1.43624287969526065e-6*V01*V024*V03 - 
      4.03239837763647287e-6*V012*V022*V032 - 6.39695952195952196e-7*V013*V033 + 
      1.03731386283469617e-6*V02*V034 - 1.80719302743112267e-6*V012*V023*V04 - 
      2.58256954685526114e-6*V013*V02*V03*V04 + 3.76126895224117446e-6*V022*V032*V04 + 
      2.41349362443112443e-6*V01*V033*V04 - 1.39266322302036588e-7*V014*V042 + 
      5.67501373552960855e-7*V023*V042 + 4.64213503648027458e-6*V01*V02*V03*V042 + 
      4.56605646337789195e-7*V012*V043 - 4.8511255774108832e-8*V044 - 
      6.58099616432949766e-7*V013*V022*V05 - 2.11015836015836016e-7*V014*V03*V05 + 
      1.29053917496377814e-6*V023*V03*V05 + 3.9946842867229772e-6*V01*V02*V032*V05 + 
      2.44500548319992764e-6*V01*V022*V04*V05 + 2.24826843130414559e-6*V012*V03*V04*V05 - 
      5.60125414233724224e-7*V03*V042*V05 + 6.19076139909473243e-7*V012*V02*V052 - 
      2.49438911785360782e-7*V032*V052 - 3.07119530720429413e-7*V02*V04*V052 - 
      5.691691187504096e-8*V01*V053 - 8.67188367188367188e-8*V014*V02*V06 + 
      1.01721424886107426e-7*V024*V06 + 1.76647646885742124e-6*V01*V022*V03*V06 + 
      7.76630845455250217e-7*V012*V032*V06 + 1.04599434956577814e-6*V012*V02*V04*V06 - 
      4.0652457348302353e-7*V032*V04*V06 - 2.31405524903132279e-7*V02*V042*V06 + 
      1.52463415112224636e-7*V013*V05*V06 - 4.49494829929295382e-7*V02*V03*V05*V06 - 
      2.8006164438601997e-7*V01*V04*V05*V06 - 4.55565553349458578e-8*V022*V062 - 
      1.00457618621134027e-7*V01*V03*V062 + 1.71256554412201539e-9*V063 - 
      3.61328486328486328e-9*V015*V07 + 2.13711461231302501e-7*V01*V023*V07 + 
      6.20745133393942918e-7*V012*V02*V03*V07 - 8.67051308647217844e-8*V033*V07 + 
      1.10772990237275952e-7*V013*V04*V07 - 3.23151314667712894e-7*V02*V03*V04*V07 - 
      1.01333081107021933e-7*V01*V042*V07 - 8.70315157488360103e-8*V022*V05*V07 - 
      1.77061130153304523e-7*V01*V03*V05*V07 - 8.07420722001137501e-8*V01*V02*V06*V07 + 9.36414228087805413e-9*V05*V06*V07 - 
      7.52927932914510879e-9*V012*V072 + 3.39053821003755583e-9*V04*V072 + 
      1.08217881655381655e-7*V012*V022*V08 + 5.69694580111246778e-8*V013*V03*V08 - 
      9.20055009399080361e-8*V02*V032*V08 - 5.09313924784279593e-8*V022*V04*V08 - 
      1.13208170487071631e-7*V01*V03*V04*V08 - 6.28664755448281359e-8*V01*V02*V05*V08 + 
      3.65860240983193125e-9*V052*V08 - 1.33508092355693896e-8*V012*V06*V08 + 
      5.81472070492569043e-9*V04*V06*V08 + 3.86604911270109038e-9*V03*V07*V08 + 6.69355072471856466e-10*V02*V082 + 
      1.80664243164243164e-8*V013*V02*V09 - 2.83619245526925265e-8*V022*V03*V09 - 
      2.81638855036964281e-8*V01*V032*V09 - 3.58774136840050706e-8*V01*V02*V04*V09 - 
      9.23462495591347132e-9*V012*V05*V09 + 4.20004124525269606e-9*V04*V05*V09 + 3.06443310291299597e-9*V03*V06*V09 + 
      1.23744774342815094e-9*V02*V07*V09 + 4.45845885430025007e-10*V01*V08*V09 + 9.03321215821215821e-10*V014*V10 - 
      2.36809044533523214e-9*V023*V10 - 1.64647371186236732e-8*V01*V02*V03*V10 - 
      4.8689519595069315e-9*V012*V04*V10 + 1.06738757717012689e-9*V042*V10 + 
      1.95993066468536445e-9*V03*V05*V10 + 8.68331150576541423e-10*V02*V06*V10 + 3.64912169506311622e-10*V01*V07*V10 - 
      2.10980781986575818e-12*V102 - 2.1210336391096195e-9*V01*V022*V11 - 
      1.96605205796382267e-9*V012*V03*V11 + 9.3749562552640253e-10*V03*V04*V11 + 5.22594784223503694e-10*V02*V05*V11 + 
      2.40847369943663066e-10*V01*V06*V11 - 3.90006460108568935e-12*V09*V11 - 4.91513014490955667e-10*V012*V02*V12 + 
      1.84496333387633329e-10*V032*V12 + 2.23917921136611244e-10*V02*V04*V12 + 1.29959796546414746e-10*V01*V05*V12 - 
      2.97043406422117702e-12*V08*V12 - 3.09963162291593664e-11*V013*V13 + 8.4929129617865858e-11*V02*V03*V13 + 
      5.3556817973796388e-11*V01*V04*V13 - 1.92853020147589291e-12*V07*V13 + 8.62458904200820265e-12*V022*V14 + 
      1.80431188155001364e-11*V01*V03*V14 - 1.01084835794234905e-12*V06*V14 + 3.67061639555834602e-12*V01*V02*V15 - 
      4.49879401768545584e-13*V05*V15 + 3.26277012938519646e-13*V012*V16 - 1.51596734582999264e-13*V04*V16 - 
      4.39752606724110238e-14*V03*V17 - 7.49105386848642045e-15*V02*V18 - 1.24850897808107008e-15*V01*V19 + 
      1.50786108463897352e-18*V22) + delta4*eps9*
    (5.77265272205748396e-7*V02*V034 + 1.82975598402185704e-6*V022*V032*V04 + 
      1.29435893324782214e-6*V01*V033*V04 + 1.71045640622360199e-7*V023*V042 + 
      2.22836898184120406e-6*V01*V02*V03*V042 + 2.17760634427301094e-7*V012*V043 - 
      3.60906857706966639e-8*V044 + 5.88336453498490536e-7*V023*V03*V05 + 
      2.02834900255535176e-6*V01*V02*V032*V05 + 1.09785359041311422e-6*V01*V022*V04*V05 + 
      1.10349719724719725e-6*V012*V03*V04*V05 - 4.68083420578654783e-7*V03*V042*V05 + 
      2.91282378335949765e-7*V012*V02*V052 - 2.17885800504264557e-7*V032*V052 - 
      2.43074095879106772e-7*V02*V04*V052 - 4.63433304017454344e-8*V01*V053 + 
      2.92978136893480809e-8*V024*V06 + 7.90223105451280054e-7*V01*V022*V03*V06 + 
      3.71694599125154681e-7*V012*V032*V06 + 4.64519313725662932e-7*V012*V02*V04*V06 - 
      3.39387086707542668e-7*V032*V04*V06 - 1.61809756133596781e-7*V02*V042*V06 + 
      6.75684269434269434e-8*V013*V05*V06 - 3.55806643708089008e-7*V02*V03*V05*V06 - 
      2.17671871098866897e-7*V01*V04*V05*V06 - 3.00604608299908642e-8*V022*V062 - 
      7.77819282174149121e-8*V01*V03*V062 + 1.60833310225194172e-9*V063 + 
      8.40480647854986479e-8*V01*V023*V07 + 2.70296649264903233e-7*V012*V02*V03*V07 - 
      7.32294648124869102e-8*V033*V07 + 4.66974053283577093e-8*V013*V04*V07 - 
      2.46677484412856339e-7*V02*V03*V04*V07 - 7.61219370190736515e-8*V01*V042*V07 - 
      6.29359832025273202e-8*V022*V05*V07 - 1.38998120525801042e-7*V01*V03*V05*V07 - 
      5.7467395205441813e-8*V01*V02*V06*V07 + 9.13001277706507386e-9*V05*V06*V07 - 
      5.30907153538845104e-9*V012*V072 + 3.22444623072974743e-9*V04*V072 + 
      4.26367613867613868e-8*V012*V022*V08 + 2.3125023125023125e-8*V013*V03*V08 - 
      7.06136849830438377e-8*V02*V032*V08 - 3.23479074354424494e-8*V022*V04*V08 - 
      8.51545756400059232e-8*V01*V03*V04*V08 - 4.4997879418105842e-8*V01*V02*V05*V08 + 
      3.58588104686483122e-9*V052*V08 - 9.33831149945373413e-9*V012*V06*V08 + 
      5.35219682347953734e-9*V04*V06*V08 + 3.70330815615235731e-9*V03*V07*V08 + 5.74573573165675699e-10*V02*V082 + 
      6.62435558268891602e-9*V013*V02*V09 - 1.95347640966513516e-8*V022*V03*V09 - 
      2.10785071604399335e-8*V01*V032*V09 - 2.43510434044981197e-8*V01*V02*V04*V09 - 
      6.44571558874780163e-9*V012*V05*V09 + 3.98584660105880436e-9*V04*V05*V09 + 2.91333022299243766e-9*V03*V06*V09 + 
      1.09040704931153581e-9*V02*V07*V09 + 3.89198166147944597e-10*V01*V08*V09 + 3.01107071940405274e-10*V014*V10 - 
      1.34500115047889713e-9*V023*V10 - 1.12181361634267797e-8*V01*V02*V03*V10 - 
      3.25870387436680621e-9*V012*V04*V10 + 9.5573417761393829e-10*V042*V10 + 
      1.87501133817503019e-9*V03*V05*V10 + 7.39981468201118634e-10*V02*V06*V10 + 3.1894243886195272e-10*V01*V07*V10 - 
      2.09271123396052009e-12*V102 - 1.28944675513302964e-9*V01*V022*V11 - 
      1.29121797320326732e-9*V012*V03*V11 + 8.658560693855349e-10*V03*V04*V11 + 4.59043272703367589e-10*V02*V05*V11 + 
      2.08292359616979377e-10*V01*V06*V11 - 3.89895481532739506e-12*V09*V11 - 2.9520301170627968e-10*V012*V02*V12 + 
      1.71398086975365036e-10*V032*V12 + 1.84287767650791223e-10*V02*V04*V12 + 1.129495553361591e-10*V01*V05*V12 - 
      2.94167211665205015e-12*V08*V12 - 1.77121807023767808e-11*V013*V13 + 7.22146841136743384e-11*V02*V03*V13 + 
      4.47838505759042395e-11*V01*V04*V13 - 1.92742041571759863e-12*V07*V13 + 6.47582185679880898e-12*V022*V14 + 
      1.51042951489610416e-11*V01*V03*V14 - 9.94035103704190637e-13*V06*V14 + 2.80831286136368696e-12*V01*V02*V15 - 
      4.48769616010251299e-13*V05*V15 + 2.44707759703889735e-13*V012*V16 - 1.45326445048636557e-13*V04*V16 - 
      4.28654749141167393e-14*V03*V17 - 6.65871454976570707e-15*V02*V18 - 1.10978575829428451e-15*V01*V19 + 
      1.50786108463897352e-18*V22) + 3.86817017063068404e-23*delta22*V22 + 
   2.12749359384687622e-22*delta20*eps*V22;
}
#endif


#ifdef p13 /* Uses: V00 - V24. */
double Vp(void)
{

   V012 = V01 * V01;
   V013 = V01 * V012;
   V014 = V01 * V013;
   V015 = V01 * V014;
   V016 = V01 * V015;
   V022 = V02 * V02;
   V023 = V02 * V022;
   V024 = V02 * V023;
   V025 = V02 * V024;
   V026 = V02 * V025;
   V032 = V03 * V03;
   V033 = V03 * V032;
   V034 = V03 * V033;
   V042 = V04 * V04;
   V043 = V04 * V042;
   V044 = V04 * V043;
   V052 = V05 * V05;
   V053 = V05 * V052;
   V062 = V06 * V06;
   V063 = V06 * V062;
   V072 = V07 * V07;
   V074 = V07 * V073;
   V082 = V08 * V08;
   V092 = V09 * V09;
   V102 = V10 * V10;
   V112 = V11 * V11;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;
   delta8 = delta2 * delta6;
   delta10 = delta2 * delta8;
   delta12 = delta2 * delta10;
   delta14 = delta2 * delta12;
   delta16 = delta2 * delta14;
   delta18 = delta2 * delta16;
   delta20 = delta2 * delta18;
   delta22 = delta2 * delta20;
   delta24 = delta2 * delta22;

   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 + 
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) + 
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 + 
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) + 
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 
      0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 + 
   0.000297619047619047619*delta4*eps*V06 + 
   eps4*(0.00416666666666666667*V012*V02 - 0.000570436507936507937*V032 - 
      0.000595238095238095238*V02*V04 - 0.000446428571428571429*V01*V05 + 4.1335978835978836e-6*V08) + 
   delta2*eps3*(-0.000992063492063492063*V032 - 0.000793650793650793651*V02*V04 - 
      0.000595238095238095238*V01*V05 + 8.2671957671957672e-6*V08) + 
   delta4*eps2*(-0.000496031746031746032*V032 - 0.000396825396825396825*V02*V04 - 
      0.000297619047619047619*V01*V05 + 8.2671957671957672e-6*V08) + 2.75573192239858907e-6*delta8*V08 + 
   5.51146384479717813e-6*delta6*eps*V08 + eps5*
    (0.0001763668430335097*V023 + 0.00143849206349206349*V01*V02*V03 + 0.000446428571428571429*V012*V04 - 
      0.0000388558201058201058*V042 - 0.0000785383597883597884*V03*V05 - 0.0000330687830687830688*V02*V06 - 
      0.0000165343915343915344*V01*V07 + 9.39454064454064454e-8*V10) + 
   delta6*eps2*(-0.0000154320987654320988*V042 - 0.0000385802469135802469*V03*V05 - 
      0.0000110229276895943563*V02*V06 - 5.51146384479717813e-6*V01*V07 + 1.25260541927208594e-7*V10) + 
   delta2*eps4*(0.0000661375661375661376*V023 + 0.00119047619047619048*V01*V02*V03 + 
      0.000297619047619047619*V012*V04 - 0.0000644841269841269841*V042 - 0.00014880952380952381*V03*V05 - 
      0.0000496031746031746032*V02*V06 - 0.0000248015873015873016*V01*V07 + 1.87890812890812891e-7*V10) + 
   delta4*eps3*(-0.0000462962962962962963*V042 - 0.000115740740740740741*V03*V05 - 
      0.0000330687830687830688*V02*V06 - 0.0000165343915343915344*V01*V07 + 1.87890812890812891e-7*V10) + 
   2.50521083854417188e-8*delta10*V10 + 6.26302709636042969e-8*delta8*eps*V10 + 
   delta8*eps2*(-7.89141414141414141e-7*V052 - 9.01875901875901876e-7*V04*V06 - 
      7.51563251563251563e-7*V03*V07 - 1.67014055902944792e-7*V02*V08 - 6.26302709636042969e-8*V01*V09 + 
      1.20442828776162109e-9*V12) + eps6*(-0.000421626984126984127*V012*V022 - 
      0.00014880952380952381*V013*V03 + 0.000144675925925925926*V02*V032 + 
      0.0000793650793650793651*V022*V04 + 0.000188492063492063492*V01*V03*V04 + 0.000111607142857142857*V01*V02*V05 - 
      3.33506192881192881e-6*V052 + 0.0000248015873015873016*V012*V06 - 5.11063011063011063e-6*V04*V06 - 
      3.56992544492544493e-6*V03*V07 - 1.25260541927208594e-6*V02*V08 - 4.69727032227032227e-7*V01*V09 + 
      1.80664243164243164e-9*V12) + delta6*eps3*
    (-3.15656565656565657e-6*V052 - 3.6075036075036075e-6*V04*V06 - 3.00625300625300625e-6*V03*V07 - 
      6.68056223611779167e-7*V02*V08 - 2.50521083854417188e-7*V01*V09 + 2.40885657552324219e-9*V12) + 
   delta2*eps5*(0.00020667989417989418*V02*V032 + 0.0000727513227513227513*V022*V04 + 
      0.000243055555555555556*V01*V03*V04 + 0.000124007936507936508*V01*V02*V05 - 6.57617845117845118e-6*V052 + 
      0.0000248015873015873016*V012*V06 - 9.16907166907166907e-6*V04*V06 - 6.95196007696007696e-6*V03*V07 - 
      2.0041686708353375e-6*V02*V08 - 7.51563251563251563e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   delta4*eps4*(0.000082671957671957672*V02*V032 + 0.0000198412698412698413*V022*V04 + 
      0.0000925925925925925926*V01*V03*V04 + 0.0000496031746031746032*V01*V02*V05 - 6.1377665544332211e-6*V052 + 
      8.2671957671957672e-6*V012*V06 - 7.56573673240339907e-6*V04*V06 - 6.0751362834696168e-6*V03*V07 - 
      1.50312650312650313e-6*V02*V08 - 5.63672438672438672e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   1.60590438368216146e-10*delta12*V12 + 4.81771315104648438e-10*delta10*eps*V12 + 
   delta10*eps2*(-1.3627245770102913e-8*V062 - 3.17969067969067969e-8*V05*V07 - 
      1.41319585764030208e-8*V04*V08 - 8.83247411025188803e-9*V03*V09 - 1.60590438368216146e-9*V02*V10 - 
      4.81771315104648438e-10*V01*V11 + 8.0295219184108073e-12*V14) + 
   delta8*eps3*(-6.81362288505145648e-8*V062 - 1.58984533984533985e-7*V05*V07 - 
      7.06597928820151042e-8*V04*V08 - 4.41623705512594401e-8*V03*V09 - 8.0295219184108073e-9*V02*V10 - 
      2.40885657552324219e-9*V01*V11 + 2.00738047960270182e-11*V14) + 
   eps7*(-0.0000132275132275132275*V024 - 0.000203373015873015873*V01*V022*V03 - 
      0.0000777116402116402116*V012*V032 - 0.000124007936507936508*V012*V02*V04 + 
      0.0000224842672759339426*V032*V04 + 0.000013452982202982203*V02*V042 - 
      0.0000165343915343915344*V013*V05 + 0.0000264299743466410133*V02*V03*V05 + 0.0000173485850569183903*V01*V04*V05 + 
      5.71188071188071188e-6*V022*V06 + 0.0000124383718133718134*V01*V03*V06 - 1.95667978406073644e-7*V062 + 
      5.44883357383357383e-6*V01*V02*V07 - 3.61569371986038653e-7*V05*V07 + 9.39454064454064454e-7*V012*V08 - 
      2.24023661523661524e-7*V04*V08 - 1.20442828776162109e-7*V03*V09 - 3.61328486328486328e-8*V02*V10 - 
      1.08398545898545899e-8*V01*V11 + 3.01107071940405274e-11*V14) + 
   delta6*eps4*(6.76406926406926407e-6*V032*V04 + 1.90396023729357063e-6*V02*V042 + 
      7.01459034792368126e-6*V02*V03*V05 + 4.05844155844155844e-6*V01*V04*V05 + 6.51354818021484688e-7*V022*V06 + 
      2.70562770562770563e-6*V01*V03*V06 - 1.88303759732331161e-7*V062 + 1.00208433541766875e-6*V01*V02*V07 - 
      4.20586358086358086e-7*V05*V07 + 1.25260541927208594e-7*V012*V08 - 1.99453324453324453e-7*V04*V08 - 
      1.22048733159844271e-7*V03*V09 - 2.40885657552324219e-8*V02*V10 - 7.22656972656972657e-9*V01*V11 + 
      4.01476095920540365e-11*V14) + delta2*eps6*
    (-1.65343915343915344e-6*V024 - 0.000133928571428571429*V01*V022*V03 - 
      0.0000562169312169312169*V012*V032 - 0.0000744047619047619048*V012*V02*V04 + 
      0.0000395197009780343114*V032*V04 + 0.0000179623617123617124*V02*V042 - 
      8.2671957671957672e-6*V013*V05 + 0.0000417743907327240661*V02*V03*V05 + 0.0000256408329324995992*V01*V04*V05 + 
      6.68891293891293891e-6*V022*V06 + 0.0000185636123136123136*V01*V03*V06 - 3.70998324867372486e-7*V062 + 
      6.95196007696007696e-6*V01*V02*V07 - 7.19525459108792442e-7*V05*V07 + 1.12734487734487734e-6*V012*V08 - 
      4.17213958880625547e-7*V04*V08 - 2.37272372689039356e-7*V03*V09 - 6.02214143880810547e-8*V02*V10 - 
      1.80664243164243164e-8*V01*V11 + 6.02214143880810547e-11*V14) + 
   delta4*eps5*(0.0000263047138047138047*V032*V04 + 9.11896745230078563e-6*V02*V042 + 
      0.0000267431257014590348*V02*V03*V05 + 0.0000157828282828282828*V01*V04*V05 + 3.20666987333654e-6*V022*V06 + 
      0.0000109352453102453102*V01*V03*V06 - 3.36345202416630988e-7*V062 + 3.82044652877986211e-6*V01*V02*V07 - 
      7.00254606504606505e-7*V05*V07 + 5.63672438672438672e-7*V012*V08 - 3.67591513424846758e-7*V04*V08 - 
      2.18001520084853418e-7*V03*V09 - 4.81771315104648438e-8*V02*V10 - 1.44531394531394531e-8*V01*V11 + 
      6.02214143880810547e-11*V14) + 7.64716373181981648e-13*delta14*V14 + 
   2.67650730613693577e-12*delta12*eps*V14 + 
   delta12*eps2*(-3.28063324095070127e-10*V072 - 4.37417765460093502e-10*V06*V08 - 
      3.82740544777581815e-10*V05*V09 - 1.3917837991912066e-10*V04*V10 - 6.95891899595603299e-11*V03*V11 - 
      1.07060292245477431e-11*V02*V12 - 2.67650730613693577e-12*V01*V13 + 3.93604015608372907e-14*V16) + 
   delta10*eps3*(-1.96837994457042076e-9*V072 - 2.62450659276056101e-9*V06*V08 - 
      2.29644326866549089e-9*V05*V09 - 8.35070279514723959e-10*V04*V10 - 4.1753513975736198e-10*V03*V11 - 
      6.42361753472864584e-11*V02*V12 - 1.60590438368216146e-11*V01*V13 + 1.18081204682511872e-13*V16) + 
   delta8*eps4*(5.93542260208926876e-8*V043 + 5.93542260208926876e-7*V03*V04*V05 + 
      1.51757964257964258e-7*V02*V052 + 2.04408686551543694e-7*V032*V06 + 1.2498524403286308e-7*V02*V04*V06 + 
      1.22645211930926217e-7*V01*V05*V06 + 1.44531394531394531e-7*V02*V03*V07 + 8.47917514584181251e-8*V01*V04*V07 - 
      6.52972193150764579e-9*V072 + 1.09201498090386979e-8*V022*V08 + 4.23958757292090625e-8*V01*V03*V08 - 
      9.08483051340194197e-9*V06*V08 + 1.20442828776162109e-8*V01*V02*V09 - 7.72841484647040203e-9*V05*V09 + 
      1.20442828776162109e-9*V012*V10 - 2.9709231098119987e-9*V04*V10 - 1.46538775010997233e-9*V03*V11 - 
      2.40885657552324219e-10*V02*V12 - 6.02214143880810547e-11*V01*V13 + 2.9520301170627968e-13*V16) + 
   eps8*(0.0000427138447971781305*V012*V023 + 0.0000454695767195767196*V013*V02*V03 - 
      0.0000265865500240500241*V022*V032 - 0.0000157201980118646785*V01*V033 + 
      4.1335978835978836e-6*V014*V04 - 0.0000100208433541766875*V023*V04 - 
      0.000068329625621292288*V01*V02*V03*V04 - 0.0000103840989257655924*V012*V042 + 
      8.50711788211788212e-7*V043 - 0.0000202922077922077922*V01*V022*V05 - 
      0.0000166283369408369408*V012*V03*V05 + 4.77122221913888581e-6*V03*V04*V05 + 
      1.40881976819476819e-6*V02*V052 - 8.83086820586820587e-6*V012*V02*V06 + 
      1.726031766954386e-6*V032*V06 + 2.18586528110337634e-6*V02*V04*V06 + 1.33467860402384212e-6*V01*V05*V06 - 
      9.39454064454064454e-7*V013*V07 + 1.49830878997545664e-6*V02*V03*V07 + 9.8088639755306422e-7*V01*V04*V07 - 
      1.13969026729443396e-8*V072 + 2.66580127691238802e-7*V022*V08 + 5.46810442643775977e-7*V01*V03*V08 - 
      1.96493872089110184e-8*V06*V08 + 1.92708526041859375e-7*V01*V02*V09 - 1.41821430883930884e-8*V05*V09 + 
      2.70996364746364746e-8*V012*V10 - 7.34701255534588868e-9*V04*V10 - 3.22184566976233643e-9*V03*V11 - 
      8.43099801433134766e-10*V02*V12 - 2.10774950358283692e-10*V01*V13 + 4.4280451755941952e-13*V16) + 
   delta6*eps5*(3.56125356125356125e-7*V043 + 3.07900047483380817e-6*V03*V04*V05 + 
      7.79024216524216524e-7*V02*V052 + 1.07882362346648061e-6*V032*V06 + 7.57069209450161831e-7*V02*V04*V06 + 
      6.47294174079888366e-7*V01*V05*V06 + 7.41927825261158594e-7*V02*V03*V07 + 4.39857210690544024e-7*V01*V04*V07 - 
      1.45735822819156152e-8*V072 + 6.83044664526146008e-8*V022*V08 + 2.31410821688599466e-7*V01*V03*V08 - 
      2.17026506709046392e-8*V06*V08 + 6.18273187717632162e-8*V01*V02*V09 - 1.76649482205037761e-8*V05*V09 + 
      7.22656972656972657e-9*V012*V10 - 7.38716016493794272e-9*V04*V10 - 3.57313725369280925e-9*V03*V11 - 
      6.42361753472864584e-10*V02*V12 - 1.60590438368216146e-10*V01*V13 + 5.9040602341255936e-13*V16) + 
   delta2*eps7*(-0.0000311898749398749399*V022*V032 - 
      0.0000202922077922077922*V01*V033 - 6.91438191438191438e-6*V023*V04 - 
      0.0000756072631072631073*V01*V02*V03*V04 - 0.0000108976671476671477*V012*V042 + 
      1.41486599819933153e-6*V043 - 0.0000187139249639249639*V01*V022*V05 - 
      0.0000174362674362674363*V012*V03*V05 + 8.83134997718331052e-6*V03*V04*V05 + 
      2.36067944401277735e-6*V02*V052 - 7.89141414141414141e-6*V012*V02*V06 + 
      3.2333737690880548e-6*V032*V06 + 3.3093559879274165e-6*V02*V04*V06 + 2.16549323692180835e-6*V01*V05*V06 - 
      7.51563251563251563e-7*V013*V07 + 2.48834884251550918e-6*V02*V03*V07 + 1.55419426252759586e-6*V01*V04*V07 - 
      2.27636946386946387e-8*V072 + 3.52656602656602657e-7*V022*V08 + 8.77305564805564806e-7*V01*V03*V08 - 
      3.81287583668536049e-8*V06*V08 + 2.67383079883079883e-7*V01*V02*V09 - 2.83040647623980957e-8*V05*V09 + 
      3.61328486328486328e-8*V012*V10 - 1.39713681380348047e-8*V04*V10 - 6.3834699251365918e-9*V03*V11 - 
      1.44531394531394531e-9*V02*V12 - 3.61328486328486328e-10*V01*V13 + 8.8560903511883904e-13*V16) + 
   delta4*eps6*(-0.0000102087341670675004*V022*V032 - 7.13985088985088985e-6*V01*V033 - 
      9.01875901875901876e-7*V023*V04 - 0.0000239999198332531666*V01*V02*V03*V04 - 
      3.34445646945646946e-6*V012*V042 + 9.90714532381199048e-7*V043 - 
      6.12524050024050024e-6*V01*V022*V05 - 5.59914622414622415e-6*V012*V03*V05 + 
      7.18272853689520356e-6*V03*V04*V05 + 1.84751269820714265e-6*V02*V052 - 
      2.31732002565335899e-6*V012*V02*V06 + 2.5855634114562686e-6*V032*V06 + 
      2.17219215235088251e-6*V02*V04*V06 + 1.60770529074100503e-6*V01*V05*V06 - 1.87890812890812891e-7*V013*V07 + 
      1.8291250930139819e-6*V02*V03*V07 + 1.10662871079537746e-6*V01*V04*V07 - 2.25830303955303955e-8*V072 + 
      2.09088750755417422e-7*V022*V08 + 6.12813112813112813e-7*V01*V03*V08 - 3.60296119224690653e-8*V06*V08 + 
      1.69824388574388574e-7*V01*V02*V09 - 2.79427362760696094e-8*V05*V09 + 2.16797091797091797e-8*V012*V10 - 
      1.27669398502731836e-8*V04*V10 - 6.02214143880810547e-9*V03*V11 - 1.20442828776162109e-9*V02*V12 - 
      3.01107071940405274e-10*V01*V13 + 8.8560903511883904e-13*V16) + 2.81145725434552076e-15*delta16*V16 + 
   1.12458290173820831e-14*delta14*eps*V16 + 
   delta14*eps2*(-3.57367455441252861e-12*V082 - 8.04076774742818938e-12*V07*V09 - 
      4.38587331677901239e-12*V06*V10 - 3.07011132174530867e-12*V05*V11 - 9.44649637460094976e-13*V04*V12 - 
      3.93604015608372907e-13*V03*V13 - 5.24805354144497209e-14*V02*V14 - 1.12458290173820831e-14*V01*V15 + 
      1.47971434439237935e-16*V18) + delta12*eps3*
    (-2.50157218808877003e-11*V082 - 5.62853742319973257e-11*V07*V09 - 3.07011132174530867e-11*V06*V10 - 
      2.14907792522171607e-11*V05*V11 - 6.61254746222066484e-12*V04*V12 - 2.75522810925861035e-12*V03*V13 - 
      3.67363747901148046e-13*V02*V14 - 7.87208031216745814e-14*V01*V15 + 5.17900020537332772e-16*V18) + 
   delta10*eps4*(1.31523569023569024e-8*V04*V052 + 5.84549195660306771e-9*V042*V06 + 
      1.83715461493239271e-8*V03*V05*V06 + 2.06932250583044234e-9*V02*V062 + 1.25260541927208594e-8*V03*V04*V07 + 
      6.35938135938135938e-9*V02*V05*V07 + 2.62450659276056101e-9*V01*V06*V07 + 3.28063324095070127e-9*V032*V08 + 
      2.11061718998226935e-9*V02*V04*V08 + 1.96837994457042076e-9*V01*V05*V08 - 1.03457878350242703e-10*V082 + 
      1.76649482205037761e-9*V02*V03*V09 + 1.04383784939340495e-9*V01*V04*V09 - 2.25945573702732122e-10*V07*V09 + 
      1.12413306857751302e-10*V022*V10 + 4.1753513975736198e-10*V01*V03*V10 - 1.28213696627173129e-10*V06*V10 + 
      9.63542630209296876e-11*V01*V02*V11 - 8.8009857890032182e-11*V05*V11 + 8.0295219184108073e-12*V012*V12 - 
      2.84182099269245239e-11*V04*V12 - 1.17293996651295126e-11*V03*V13 - 1.65313686555516621e-12*V02*V14 - 
      3.54243614047535616e-13*V01*V15 + 1.55370006161199832e-15*V18) + 
   delta8*eps5*(8.54903198653198653e-8*V04*V052 + 4.25885842552509219e-8*V042*V06 + 
      1.20563271604938272e-7*V03*V05*V06 + 1.51413841890032366e-8*V02*V062 + 8.1419352252685586e-8*V03*V04*V07 + 
      4.10710046126712793e-8*V02*V05*V07 + 1.72233245149911817e-8*V01*V06*V07 + 2.18708882730046751e-8*V032*V08 + 
      1.55696253579851463e-8*V02*V04*V08 + 1.31225329638028051e-8*V01*V05*V08 - 3.06889302360175895e-10*V082 + 
      1.14086123924086887e-8*V02*V03*V09 + 6.78494602105713217e-9*V01*V04*V09 - 6.39241035920541056e-10*V07*V09 + 
      8.56482337963819445e-10*V022*V10 + 2.87055408583186361e-9*V01*V03*V10 - 3.8595685187655309e-10*V06*V10 + 
      6.22287948676837566e-10*V01*V02*V11 - 2.57121823196169601e-10*V05*V11 + 6.02214143880810547e-11*V012*V12 - 
      8.91513095352964634e-11*V04*V12 - 3.63099704398724007e-11*V03*V13 - 5.5104562185172207e-12*V02*V14 - 
      1.18081204682511872e-12*V01*V15 + 3.88425015402999579e-15*V18) + 
   eps9*(1.06888995777884667e-6*V025 + 0.0000263923961840628507*V01*V023*V03 + 
      0.0000299748476831810165*V012*V02*V032 - 1.21518211175949271e-6*V034 + 
      0.0000238245550745550746*V012*V022*V04 + 0.0000102212602212602213*V013*V03*V04 - 
      0.0000101287830702513242*V02*V032*V04 - 3.09484386865339246e-6*V022*V042 - 
      6.45033978367311701e-6*V01*V03*V042 + 6.32565736732403399e-6*V013*V02*V05 - 
      5.97243869813314258e-6*V022*V03*V05 - 5.42102848650467698e-6*V01*V032*V05 - 
      7.74114737408388202e-6*V01*V02*V04*V05 - 9.78856075582266058e-7*V012*V052 + 
      2.90447881593714927e-7*V04*V052 + 4.69727032227032227e-7*V014*V06 - 
      8.74346112441350537e-7*V023*V06 - 5.52347371543800115e-6*V01*V02*V03*V06 - 
      1.67601358077548554e-6*V012*V04*V06 + 2.3201418290704005e-7*V042*V06 + 
      4.20311060192012573e-7*V03*V05*V06 + 1.000249016122032e-7*V02*V062 - 
      1.21213662880329547e-6*V01*V022*V07 - 1.0095517908017908e-6*V012*V03*V07 + 
      3.08183088131004798e-7*V03*V04*V07 + 1.83444465128492906e-7*V02*V05*V07 + 8.64564434132886514e-8*V01*V06*V07 - 
      4.09505617838951172e-7*V012*V02*V08 + 8.67546827988296242e-8*V032*V08 + 
      1.14248626153388058e-7*V02*V04*V08 + 6.72587168122882409e-8*V01*V05*V08 - 5.58025064485634825e-10*V082 - 
      3.61328486328486328e-8*V013*V09 + 6.05727059720115276e-8*V02*V03*V09 + 3.94450264241930909e-8*V01*V04*V09 - 
      1.01977880393934316e-9*V07*V09 + 9.15365498698832032e-9*V022*V10 + 1.79760921948421948e-8*V01*V03*V10 - 
      7.27717595714794594e-10*V06*V10 + 5.32959517334517335e-9*V01*V02*V11 - 4.32620013655552871e-10*V05*V11 + 
      6.32324851074851075e-10*V012*V12 - 1.92177160620788072e-10*V04*V12 - 7.12915273270665428e-11*V03*V13 - 
      1.65313686555516621e-11*V02*V14 - 3.54243614047535616e-12*V01*V15 + 5.82637523104499369e-15*V18) + 
   delta6*eps6*(-3.02827683780064732e-7*V034 - 1.85757254209635162e-6*V02*V032*V04 - 
      1.58222876476844731e-7*V022*V042 - 1.08321462488129155e-6*V01*V03*V042 - 
      9.25161515439293217e-7*V022*V03*V05 - 1.03112826327112041e-6*V01*V032*V05 - 
      1.11454352525781097e-6*V01*V02*V04*V05 - 1.39369559012416155e-7*V012*V052 + 
      2.68161943509165731e-7*V04*V052 - 3.51463645114438765e-8*V023*V06 - 
      7.62712816284244856e-7*V01*V02*V03*V06 - 2.12598798908322718e-7*V012*V04*V06 + 
      1.55031715051556321e-7*V042*V06 + 3.8440189109831967e-7*V03*V05*V06 + 5.61607704464847322e-8*V02*V062 - 
      1.32165930777041888e-7*V01*V022*V07 - 1.24296999296999297e-7*V012*V03*V07 + 
      2.6128064322508767e-7*V03*V04*V07 + 1.32968882968882969e-7*V02*V05*V07 + 5.73479926158497587e-8*V01*V06*V07 - 
      3.77387530165307943e-8*V012*V02*V08 + 7.26576144069530313e-8*V032*V08 + 
      5.89825738635262445e-8*V02*V04*V08 + 4.44778160551970076e-8*V01*V05*V08 - 6.7521831725198257e-10*V082 - 
      2.40885657552324219e-9*V013*V09 + 3.86086178910252984e-8*V02*V03*V09 + 2.32454659537992871e-8*V01*V04*V09 - 
      1.33786004905285951e-9*V07*V09 + 3.45269442491664714e-9*V022*V10 + 1.03580832747499414e-8*V01*V03*V10 - 
      8.61655419311815204e-10*V06*V10 + 2.28841374674708008e-9*V01*V02*V11 - 5.54981662007805799e-10*V05*V11 + 
      2.40885657552324219e-10*V012*V12 - 2.07822920241220895e-10*V04*V12 - 8.32472493011708698e-11*V03*V13 - 
      1.37761405462930517e-11*V02*V14 - 2.9520301170627968e-12*V01*V15 + 7.76850030805999158e-15*V18) + 
   delta2*eps8*(4.1753513975736198e-8*V025 + 0.0000140291806958473625*V01*V023*V03 + 
      0.0000188517115600448934*V012*V02*V032 - 2.104308279903518e-6*V034 + 
      0.0000125886844636844637*V012*V022*V04 + 5.82461519961519962e-6*V013*V03*V04 - 
      0.0000153405163325798246*V02*V032*V04 - 3.46221514376276281e-6*V022*V042 - 
      9.37767864851198185e-6*V01*V03*V042 + 2.94362273528940196e-6*V013*V02*V05 - 
      7.97973888251666029e-6*V022*V03*V05 - 8.09444633849395754e-6*V01*V032*V05 - 
      9.9663114296050804e-6*V01*V02*V04*V05 - 1.24727152256914162e-6*V012*V052 + 
      5.53495019640852974e-7*V04*V052 + 1.87890812890812891e-7*V014*V06 - 
      8.40346822489679633e-7*V023*V06 - 7.21314895422038279e-6*V01*V02*V03*V06 - 
      2.10547829595448643e-6*V012*V04*V06 + 4.143130073189597e-7*V042*V06 + 
      8.11973933253695158e-7*V03*V05*V06 + 1.64565051717829496e-7*V02*V062 - 
      1.3248711165377832e-6*V01*V022*V07 - 1.25380984755984756e-6*V012*V03*V07 + 
      5.84147719564386231e-7*V03*V04*V07 + 3.1668434446212224e-7*V02*V05*V07 + 1.46458479791813125e-7*V01*V06*V07 - 
      4.40820753320753321e-7*V012*V02*V08 + 1.6699971747094763e-7*V032*V08 + 
      1.84426647720298514e-7*V02*V04*V08 + 1.14231420034991464e-7*V01*V05*V08 - 1.09940630202554417e-9*V082 - 
      3.61328486328486328e-8*V013*V09 + 1.03781570795459684e-7*V02*V03*V09 + 6.52800131966798633e-8*V01*V04*V09 - 
      2.03867199884356747e-9*V07*V09 + 1.30479731174175619e-8*V022*V10 + 3.01107071940405274e-8*V01*V03*V10 - 
      1.42836085807024182e-9*V06*V10 + 7.82878387045053712e-9*V01*V02*V11 - 8.64354418275986903e-10*V05*V11 + 
      9.03321215821215821e-10*V012*V12 - 3.70184576679674719e-10*V04*V12 - 1.41697445619014246e-10*V03*V13 - 
      2.89298951472154087e-11*V02*V14 - 6.19926324583187328e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   delta4*eps7*(-1.3248711165377832e-6*V034 - 8.6670659587326254e-6*V02*V032*V04 - 
      1.31581381581381581e-6*V022*V042 - 5.14897910731244065e-6*V01*V03*V042 - 
      4.27957459207459207e-6*V022*V03*V05 - 4.63174942341609008e-6*V01*V032*V05 - 
      5.20023957523957524e-6*V01*V02*V04*V05 - 6.59063159063159063e-7*V012*V052 + 
      5.00520248784137673e-7*V04*V052 - 3.03928875357446786e-7*V023*V06 - 
      3.68334817739579644e-6*V01*V02*V03*V06 - 1.04922909982433792e-6*V012*V04*V06 + 
      3.34278174059920092e-7*V042*V06 + 7.29246916002868384e-7*V03*V05*V06 + 1.25604664295140486e-7*V02*V062 - 
      6.11367798867798868e-7*V01*V022*V07 - 6.07995399662066329e-7*V012*V03*V07 + 
      5.08188442216219994e-7*V03*V04*V07 + 2.63408466533466533e-7*V02*V05*V07 + 1.17724262069500165e-7*V01*V06*V07 - 
      1.95117382617382617e-7*V012*V02*V08 + 1.4478948630734345e-7*V032*V08 + 
      1.36065984280269995e-7*V02*V04*V08 + 9.21731762505572029e-8*V01*V05*V08 - 1.06818506921603716e-9*V082 - 
      1.44531394531394531e-8*V013*V09 + 8.19011235677902345e-8*V02*V03*V09 + 5.02246595996595997e-8*V01*V04*V09 - 
      2.03276793860944188e-9*V07*V09 + 8.67188367188367188e-9*V022*V10 + 2.30045802962469629e-8*V01*V03*V10 - 
      1.37834503351543501e-9*V06*V10 + 5.41992729492729493e-9*V01*V02*V11 - 8.5845035804186131e-10*V05*V11 + 
      6.02214143880810547e-10*V012*V12 - 3.45977929719759785e-10*V04*V12 - 1.35793385384888653e-10*V03*V13 - 
      2.47970529833274931e-11*V02*V14 - 5.31365421071303424e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   8.22063524662432972e-18*delta18*V18 + 3.69928586098094837e-17*delta16*eps*V18 + 
   delta16*eps2*(-4.99609107113593639e-14*V092 - 7.26704155801590747e-14*V08*V10 - 
      6.54033740221431672e-14*V07*V11 - 3.01861726256045387e-14*V06*V12 - 1.76086006982693143e-14*V05*V13 - 
      4.69562685287181713e-15*V04*V14 - 1.67700959031136326e-15*V03*V15 - 1.97295245918983913e-16*V02*V16 - 
      3.69928586098094837e-17*V01*V17 + 4.40391173926303378e-19*V20) + 
   delta14*eps3*(-3.99687285690874911e-13*V092 - 5.81363324641272598e-13*V08*V10 - 
      5.23226992177145338e-13*V07*V11 - 2.4148938100483631e-13*V06*V12 - 1.40868805586154514e-13*V05*V13 - 
      3.75650148229745371e-14*V04*V14 - 1.34160767224909061e-14*V03*V15 - 1.57836196735187131e-15*V02*V16 - 
      2.9594286887847587e-16*V01*V17 + 1.76156469570521351e-18*V20) + 
   delta12*eps4*(4.14465028435616671e-10*V052*V06 + 1.9311337588648513e-10*V04*V062 + 
      5.61121884651296416e-10*V04*V05*V07 + 3.94728598510111115e-10*V03*V06*V07 + 6.75424490783967908e-11*V02*V072 + 
      9.9293173004138872e-11*V042*V08 + 3.00188662570652404e-10*V03*V05*V08 + 7.05638284744001105e-11*V02*V06*V08 + 
      4.28840946529503434e-11*V01*V07*V08 + 1.55867190180915671e-10*V03*V04*V09 + 7.8799523924796256e-11*V02*V05*V09 + 
      3.28940498758425929e-11*V01*V06*V09 - 1.87500359022631024e-12*V092 + 3.28940498758425929e-11*V032*V10 + 
      2.19068749258602978e-11*V02*V04*V10 + 1.97364299255055558e-11*V01*V05*V10 - 2.808497825656736e-12*V08*V10 + 
      1.43271861681447738e-11*V02*V03*V11 + 8.50184673714085479e-12*V01*V04*V11 - 2.47282462663132475e-12*V07*V11 + 
      7.87208031216745814e-13*V022*V12 + 2.83394891238028493e-12*V01*V03*V12 - 1.183475532645025e-12*V06*V12 + 
      5.5104562185172207e-13*V01*V02*V13 - 6.80520626986055263e-13*V05*V13 + 3.93604015608372907e-14*V012*V14 - 
      1.89344247508448862e-13*V04*V14 - 6.71543693296741495e-14*V03*V15 - 8.28640032859732435e-15*V02*V16 - 
      1.55370006161199832e-15*V01*V17 + 6.16547643496824729e-18*V20) + 
   delta10*eps5*(3.26045822369351781e-9*V052*V06 + 1.65543101467471215e-9*V04*V062 + 
      4.38766140359277614e-9*V04*V05*V07 + 3.10519830827954077e-9*V03*V06*V07 + 5.25866210681803586e-10*V02*V072 + 
      8.54383116547241456e-10*V042*V08 + 2.38274750915455345e-9*V03*V05*V08 + 6.08564288665958964e-10*V02*V06*V08 + 
      3.40392501307793351e-10*V01*V07*V08 + 1.21879483433132671e-9*V03*V04*V09 + 6.1351057912877085e-10*V02*V05*V09 + 
      2.58766525689961731e-10*V01*V06*V09 - 6.38324106265132578e-12*V092 + 2.64979846222065332e-10*V032*V10 + 
      1.91044143347286827e-10*V02*V04*V10 + 1.58987907733239199e-10*V01*V05*V10 - 1.00156931590772184e-11*V08*V10 + 
      1.11547378023412882e-10*V02*V03*V11 + 6.6479718236254184e-11*V01*V04*V11 - 8.52071309503185762e-12*V07*V11 + 
      7.08487228095071232e-12*V022*V12 + 2.34981597318198625e-11*V01*V03*V12 - 4.3121835424282719e-12*V06*V12 + 
      4.29028377013126468e-12*V01*V02*V13 - 2.42687949623794137e-12*V05*V13 + 3.54243614047535616e-13*V012*V14 - 
      7.18016588472958155e-13*V04*V14 - 2.5221731000168106e-13*V03*V15 - 3.31456013143892974e-14*V02*V16 - 
      6.21480024644799327e-15*V01*V17 + 1.84964293049047419e-17*V20) + 
   delta8*eps6*(-8.45508658008658009e-8*V032*V042 - 1.14340392118169896e-8*V02*V043 - 
      5.74110817166372722e-8*V033*V05 - 1.70707635985413763e-7*V02*V03*V04*V05 - 
      5.07305194805194805e-8*V01*V042*V05 - 2.09931850556850557e-8*V022*V052 - 
      4.97910654160654161e-8*V01*V03*V052 - 5.99346457481378116e-8*V02*V032*V06 - 
      1.17185137026406868e-8*V022*V04*V06 - 6.97283683394794506e-8*V01*V03*V04*V06 - 
      3.5960787448882687e-8*V01*V02*V05*V06 + 1.29533113516637482e-8*V052*V06 - 
      3.43835599291948498e-9*V012*V062 + 7.392378229602008e-9*V04*V062 - 
      1.99935095768429102e-8*V022*V03*V07 - 2.28153129938844225e-8*V01*V032*V07 - 
      2.43868051407733947e-8*V01*V02*V04*V07 - 6.24582097796383511e-9*V012*V05*V07 + 
      1.75019961580419097e-8*V04*V05*V07 + 1.2518744403859561e-8*V03*V06*V07 + 2.14039052230578841e-9*V02*V072 - 
      6.57656080936504217e-10*V023*V08 - 1.26407616486981566e-8*V01*V02*V03*V08 - 
      3.52151889850302549e-9*V012*V04*V08 + 3.86929241225589394e-9*V042*V08 + 
      9.72664871847229976e-9*V03*V05*V08 + 2.79046504017974087e-9*V02*V06*V08 + 1.42857640312640831e-9*V01*V07*V08 - 
      1.66612579807024251e-9*V01*V022*V09 - 1.58583057888613444e-9*V012*V03*V09 + 
      5.00664307853850338e-9*V03*V04*V09 + 2.53392425148280268e-9*V02*V05*V09 + 1.08879305089038983e-9*V01*V06*V09 - 
      1.6748072821287926e-11*V092 - 3.81402291124513347e-10*V012*V02*V10 + 
      1.12917963434906323e-9*V032*V10 + 9.01690570613695419e-10*V02*V04*V10 + 6.8620642935438298e-10*V01*V05*V10 - 
      2.760150625644289e-11*V08*V10 - 2.00738047960270182e-11*V013*V11 + 4.80787305065627506e-10*V02*V03*V11 + 
      2.88905347456545714e-10*V01*V04*V11 - 2.26228347113945505e-11*V07*V11 + 3.54243614047535616e-11*V022*V12 + 
      1.07453896261085804e-10*V01*V03*V12 - 1.21478628817236775e-11*V06*V12 + 1.97786017843207386e-11*V01*V02*V13 - 
      6.6713291145516521e-12*V05*V13 + 1.77121807023767808e-12*V012*V14 - 2.11096048371016838e-12*V04*V14 - 
      7.32828529060325873e-13*V03*V15 - 1.03580004107466554e-13*V02*V16 - 1.9421250770149979e-14*V01*V17 + 
      4.62410732622618547e-17*V20) + eps10*(-4.32775172358505692e-6*V012*V024 - 
      9.24422799422799423e-6*V013*V022*V03 - 1.23068482443482443e-6*V014*V032 + 
      4.22450354245989167e-6*V023*V032 + 7.39166243258505163e-6*V01*V02*V033 - 
      1.69101731601731602e-6*V014*V02*V04 + 1.21747740795359843e-6*V024*V04 + 
      0.0000161214859875574161*V01*V022*V03*V04 + 6.33712696584720394e-6*V012*V032*V04 + 
      4.84675707889993604e-6*V012*V02*V042 - 1.07324812418438411e-6*V032*V042 - 
      4.62417873132158846e-7*V02*V043 - 9.39454064454064454e-8*V015*V05 + 
      3.19858299769014055e-6*V01*V023*V05 + 7.76295326146516623e-6*V012*V02*V03*V05 - 
      6.14896486982300474e-7*V033*V05 + 1.39724005051386004e-6*V013*V04*V05 - 
      2.56161679617780808e-6*V02*V03*V04*V05 - 8.20972733175114127e-7*V01*V042*V05 - 
      3.79289523169731503e-7*V022*V052 - 6.95468437903953777e-7*V01*V03*V052 + 
      2.05559775872275872e-6*V012*V022*V06 + 9.52221004304337638e-7*V013*V03*V06 - 
      9.2266376058538757e-7*V02*V032*V06 - 5.93101783577974054e-7*V022*V04*V06 - 
      1.16940150577303355e-6*V01*V03*V04*V06 - 7.07132752333645191e-7*V01*V02*V05*V06 + 
      2.89604486589270086e-8*V052*V06 - 7.63370950312914599e-8*V012*V062 + 
      2.35668492554580323e-8*V04*V062 + 4.33594183594183594e-7*V013*V02*V07 - 
      4.0140583760375427e-7*V022*V03*V07 - 3.62902846161774733e-7*V01*V032*V07 - 
      5.19422603685996543e-7*V01*V02*V04*V07 - 1.32534428479368956e-7*V012*V05*V07 + 
      4.25063111758883818e-8*V04*V05*V07 + 3.06977183828184645e-8*V03*V06*V07 + 6.76143520976766775e-9*V02*V072 + 
      2.70996364746364746e-8*V014*V08 - 4.80241882358284475e-8*V023*V08 - 
      2.87815345479035955e-7*V01*V02*V03*V08 - 8.72350202707345564e-8*V012*V04*V08 + 
      1.34766641195601669e-8*V042*V08 + 2.39151691290706619e-8*V03*V05*V08 + 1.16898143469883277e-8*V02*V06*V08 + 
      4.92813313471090471e-9*V01*V07*V08 - 5.07365416219582886e-8*V01*V022*V09 - 
      4.2305543607626941e-8*V012*V03*V09 + 1.39815526419386714e-8*V03*V04*V09 + 8.39144081076270619e-9*V02*V05*V09 + 
      3.92546204816425405e-9*V01*V06*V09 - 2.56298084717075669e-11*V092 - 1.40014788452288452e-8*V012*V02*V10 + 
      3.21391736030508206e-9*V032*V10 + 4.35416007894999492e-9*V02*V04*V10 + 2.49794462727031588e-9*V01*V05*V10 - 
      4.62118489039601052e-11*V08*V10 - 1.05387475179141846e-9*V013*V11 + 1.88841366588507111e-9*V02*V03*V11 + 
      1.22273087448741044e-9*V01*V04*V11 - 3.49496505466431814e-11*V07*V11 + 2.47970529833274931e-10*V022*V12 + 
      4.71144006683222369e-10*V01*V03*V12 - 2.1239079842236017e-11*V06*V12 + 1.20885633293721529e-10*V01*V02*V13 - 
      1.07535465514320433e-11*V05*V13 + 1.23985264916637466e-11*V012*V14 - 4.17634576561305147e-12*V04*V14 - 
      1.34395055329437854e-12*V03*V15 - 2.79666011090159697e-13*V02*V16 - 5.24373770794049432e-14*V01*V17 + 
      6.9361609893392782e-17*V20) + delta6*eps7*
    (-5.30269627491849714e-7*V032*V042 - 1.06760523427190094e-7*V02*V043 - 
      3.44466490299823633e-7*V033*V05 - 1.06134220717554051e-6*V02*V03*V04*V05 - 
      3.18161776495109828e-7*V01*V042*V05 - 1.30511849261849262e-7*V022*V052 - 
      3.03130511463844797e-7*V01*V03*V052 - 3.78534604725080916e-7*V02*V032*V06 - 
      1.11853534472582092e-7*V022*V04*V06 - 4.46345064400619956e-7*V01*V03*V04*V06 - 
      2.27120762835048549e-7*V01*V02*V05*V06 + 3.26639377224889207e-8*V052*V06 - 
      2.2585898081929828e-8*V012*V062 + 2.10193091164924343e-8*V04*V062 - 
      1.24296999296999297e-7*V022*V03*V07 - 1.41067229360880155e-7*V01*V032*V07 - 
      1.51620315310791501e-7*V01*V02*V04*V07 - 4.0124668100858577e-8*V012*V05*V07 + 4.4787492448848658e-8*V04*V05*V07 + 
      3.24298782831501475e-8*V03*V06*V07 + 5.68358575623981786e-9*V02*V072 - 6.5918551368286818e-9*V023*V08 - 
      8.25205438300676396e-8*V01*V02*V03*V08 - 2.34003210193686384e-8*V012*V04*V08 + 
      1.12529063924436888e-8*V042*V08 + 2.54356286410311724e-8*V03*V05*V08 + 8.30444495178907462e-9*V02*V06*V08 + 
      3.92657491666076582e-9*V01*V07*V08 - 1.03580832747499414e-8*V01*V022*V09 - 
      1.05989689323022656e-8*V012*V03*V09 + 1.3470310226165346e-8*V03*V04*V09 + 6.88846387716213424e-9*V02*V05*V09 + 
      3.03283139855268707e-9*V01*V06*V09 - 3.40039836055713167e-11*V092 - 2.64974223307556641e-9*V012*V02*V10 + 
      3.11981788600213748e-9*V032*V10 + 2.79278917817666651e-9*V02*V04*V10 + 1.94147992156084282e-9*V01*V05*V10 - 
      5.8329550274963918e-11*V08*V10 - 1.60590438368216146e-10*V013*V11 + 1.39296461123803172e-9*V02*V03*V11 + 
      8.47035841589218496e-10*V01*V04*V11 - 4.62613453487800303e-11*V07*V11 + 1.18081204682511872e-10*V022*V12 + 
      3.24723312876907648e-10*V01*V03*V12 - 2.6147736236888857e-11*V06*V12 + 6.25830384817312922e-11*V01*V02*V13 - 
      1.39998733551651795e-11*V05*V13 + 5.9040602341255936e-12*V012*V14 - 4.73567778779337087e-12*V04*V14 - 
      1.62102706428185158e-12*V03*V15 - 2.48592009857919731e-13*V02*V16 - 4.66110018483599495e-14*V01*V17 + 
      9.24821465245237093e-17*V20) + delta2*eps9*
    (4.15642466733736575e-6*V023*V032 + 8.35529109338633148e-6*V01*V02*V033 + 
      6.79829796893288957e-7*V024*V04 + 0.0000154207702570797809*V01*V022*V03*V04 + 
      6.74263732299446585e-6*V012*V032*V04 + 4.56072256667494763e-6*V012*V02*V042 - 
      1.91435273280511376e-6*V032*V042 - 6.72419695237155555e-7*V02*V043 + 
      2.49385480040241945e-6*V01*V023*V05 + 7.25582012784393737e-6*V012*V02*V03*V05 - 
      1.13434203215949248e-6*V033*V05 + 1.24703063691158929e-6*V013*V04*V05 - 
      4.15228372817658532e-6*V02*V03*V04*V05 - 1.29452411198442944e-6*V01*V042*V05 - 
      5.49420037267259489e-7*V022*V052 - 1.13306877939814448e-6*V01*V03*V052 + 
      1.63031413031413031e-6*V012*V022*V06 + 8.24792491459158126e-7*V013*V03*V06 - 
      1.51755096571564826e-6*V02*V032*V06 - 7.77042071684928828e-7*V022*V04*V06 - 
      1.86239140232195788e-6*V01*V03*V04*V06 - 1.01627938309485929e-6*V01*V02*V05*V06 + 
      5.68838491377298567e-8*V052*V06 - 1.07641476689095737e-7*V012*V062 + 
      4.41557917412842716e-8*V04*V062 + 3.20377924544591211e-7*V013*V02*V07 - 
      5.77443068762513207e-7*V022*V03*V07 - 5.83046527987004177e-7*V01*V032*V07 - 
      7.28552935894205735e-7*V01*V02*V04*V07 - 1.86531529537481918e-7*V012*V05*V07 + 
      8.20730498018079717e-8*V04*V05*V07 + 6.00686679154524626e-8*V03*V06*V07 + 1.19181468478999992e-8*V02*V072 + 
      1.80664243164243164e-8*V014*V08 - 5.42489795135297781e-8*V023*V08 - 
      4.0979812185169328e-7*V01*V02*V03*V08 - 1.20546065486541677e-7*V012*V04*V08 + 
      2.49040458005988663e-8*V042*V08 + 4.6958392905278604e-8*V03*V05*V08 + 2.00429912245193913e-8*V02*V06*V08 + 
      8.62016691568998603e-9*V01*V07*V08 - 6.16667283333950001e-8*V01*V022*V09 - 
      5.79330006413339747e-8*V012*V03*V09 + 2.68752821857397021e-8*V03*V04*V09 + 1.4780224390110011e-8*V02*V05*V09 + 
      6.83399189285918978e-9*V01*V06*V09 - 5.12537905681840888e-11*V092 - 1.68619960286626953e-8*V012*V02*V10 + 
      6.27264228017029137e-9*V032*V10 + 7.31125081907061366e-9*V02*V04*V10 + 4.36078106078397862e-9*V01*V05*V10 - 
      9.16586854918693502e-11*V08*V10 - 1.20442828776162109e-9*V013*V11 + 3.30686413713374498e-9*V02*V03*V11 + 
      2.08501887168145338e-9*V01*V04*V11 - 6.98876483428242728e-11*V07*V11 + 3.71955794749912397e-10*V022*V12 + 
      8.121034852039754e-10*V01*V03*V12 - 4.19521212350405431e-11*V06*V12 + 1.85092288339837359e-10*V01*V02*V13 - 
      2.14954403524019967e-11*V05*V13 + 1.85977897374956198e-11*V012*V14 - 8.11342172173785521e-12*V04*V14 - 
      2.6762483561266671e-12*V03*V15 - 4.97184019715839461e-13*V02*V16 - 9.3222003696719899e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + delta4*eps8*
    (1.12355953129762654e-6*V023*V032 + 2.5791971476495286e-6*V01*V02*V033 + 
      3.77616945077262538e-8*V024*V04 + 4.13625909657655689e-6*V01*V022*V03*V04 + 
      1.98785727059536583e-6*V012*V032*V04 + 1.22404326273373892e-6*V012*V02*V042 - 
      1.42409880133094419e-6*V032*V042 - 3.91505723846993688e-7*V02*V043 + 
      6.74135718778575921e-7*V01*V023*V05 + 2.06180916746392937e-6*V012*V02*V03*V05 - 
      8.81354738001563398e-7*V033*V05 + 3.3207808505427553e-7*V013*V04*V05 - 
      2.91372423688891943e-6*V02*V03*V04*V05 - 8.88464306123036282e-7*V01*V042*V05 - 
      3.66935769134843209e-7*V022*V052 - 8.12937475883904455e-7*V01*V03*V052 + 
      4.23557281196170085e-7*V012*V022*V06 + 2.13183806933806934e-7*V013*V03*V06 - 
      1.05803289707059548e-6*V02*V032*V06 - 4.22574620656631239e-7*V022*V04*V06 - 
      1.26838342984176318e-6*V01*V03*V04*V06 - 6.5878786116881355e-7*V01*V02*V05*V06 + 
      5.45632582627067921e-8*V052*V06 - 6.76716636538065109e-8*V012*V062 + 
      3.90218908615850726e-8*V04*V062 + 7.34701255534588868e-8*V013*V02*V07 - 
      3.63268954125435607e-7*V022*V03*V07 - 3.97088535729408745e-7*V01*V032*V07 - 
      4.49314840435872182e-7*V01*V02*V04*V07 - 1.17990956904647381e-7*V012*V05*V07 + 
      7.65859343014163276e-8*V04*V05*V07 + 5.59869380444485487e-8*V03*V06*V07 + 1.02824269600355035e-8*V02*V072 + 
      3.61328486328486328e-9*V014*V08 - 2.64209506934374659e-8*V023*V08 - 
      2.52155665102093674e-7*V01*V02*V03*V08 - 7.26442318704223466e-8*V012*V04*V08 + 
      2.14728983840795232e-8*V042*V08 + 4.39814532769423059e-8*V03*V05*V08 + 1.64109258267755e-8*V02*V06*V08 + 
      7.31276900598796024e-9*V01*V07*V08 - 3.37239920573253907e-8*V01*V022*V09 - 
      3.40250991292657959e-8*V012*V03*V09 + 2.42509274116708757e-8*V03*V04*V09 + 1.27037664057680398e-8*V02*V05*V09 + 
      5.74203595255766124e-9*V01*V06*V09 - 5.12110638164897588e-11*V092 - 9.03321215821215821e-9*V012*V02*V10 + 
      5.67822993017028965e-9*V032*V10 + 5.76472441260022959e-9*V02*V04*V10 + 3.68295277404754529e-9*V01*V05*V10 - 
      9.01908088622321099e-11*V08*V10 - 6.02214143880810547e-10*V013*V11 + 2.72767582816602424e-9*V02*V03*V11 + 
      1.68501879081944441e-9*V01*V04*V11 - 6.98021948394356129e-11*V07*V11 + 2.65682710535651712e-10*V022*V12 + 
      6.5535068598794089e-10*V01*V03*V12 - 4.09621923386420413e-11*V06*V12 + 1.35793385384888653e-10*V01*V02*V13 - 
      2.14099868490133368e-11*V05*V13 + 1.32841355267825856e-11*V012*V14 - 7.69703010522583966e-12*V04*V14 - 
      2.59079485273800719e-12*V03*V15 - 4.35036017251359529e-13*V02*V16 - 8.15692532346299116e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + 1.95729410633912612e-20*delta20*V20 + 
   9.78647053169563062e-20*delta18*eps*V20 + 
   delta18*eps2*(-3.73576270568999572e-16*V102 - 8.21867795251799059e-16*V09*V11 - 
      5.0576479707803019e-16*V08*V12 - 3.79323597808522643e-16*V07*V13 - 1.51729439123409057e-16*V06*V14 - 
      7.58647195617045285e-17*V05*V15 - 1.78505222498128302e-17*V04*V16 - 5.57828820306650945e-18*V03*V17 - 
      5.87188231901737837e-19*V02*V18 - 9.78647053169563062e-20*V01*V19 + 1.06374679692343811e-21*V22) + 
   delta16*eps3*(-3.36218643512099615e-15*V102 - 7.39681015726619153e-15*V09*V11 - 
      4.55188317370227171e-15*V08*V12 - 3.41391238027670378e-15*V07*V13 - 1.36556495211068151e-15*V06*V14 - 
      6.82782476055340757e-16*V05*V15 - 1.60654700248315472e-16*V04*V16 - 5.02045938275985851e-17*V03*V17 - 
      5.28469408711564053e-18*V02*V18 - 8.80782347852606755e-19*V01*V19 + 4.7868605861554715e-21*V22) + 
   delta14*eps4*(2.13459363566774952e-12*V063 + 1.7930586539609096e-11*V05*V06*V07 + 
      6.04327175964602865e-12*V04*V072 + 6.86735427232503256e-12*V052*V08 + 
      6.60875939349902034e-12*V04*V06*V08 + 6.54033740221431672e-12*V03*V07*V08 + 6.07011706610740506e-13*V02*V082 + 
      7.05048371958703343e-12*V04*V05*V09 + 4.98071848322474889e-12*V03*V06*V09 + 1.69279320998488198e-12*V02*V07*V09 + 
      5.4502811685119306e-13*V01*V08*V09 + 1.03773353448467159e-12*V042*V10 + 3.05215745436668114e-12*V03*V05*V10 + 
      7.38870695966594755e-13*V02*V06*V10 + 4.36022493480954448e-13*V01*V07*V10 - 1.85215182566314525e-14*V102 + 
      1.28190613083400608e-12*V03*V04*V11 + 6.463392256305913e-13*V02*V05*V11 + 2.71675553630440848e-13*V01*V06*V11 - 
      3.9838959969837207e-14*V09*V11 + 2.2639629469203404e-13*V032*V12 + 1.54600554702115794e-13*V02*V04*V12 + 
      1.35837776815220424e-13*V01*V05*V12 - 2.52150370543244262e-14*V08*V12 + 8.28640032859732435e-14*V02*V03*V13 + 
      4.93040819551540799e-14*V01*V04*V13 - 1.8596838492559939e-14*V07*V13 + 4.00509349215537344e-15*V022*V14 + 
      1.40868805586154514e-14*V01*V03*V14 - 7.6902868355706801e-15*V06*V14 + 2.36754295102780696e-15*V01*V02*V15 - 
      3.80321817802755597e-15*V05*V15 + 1.47971434439237935e-16*V012*V16 - 9.29401533454070648e-16*V04*V16 - 
      2.88896610095655016e-16*V03*V17 - 3.17081645226938432e-17*V02*V18 - 5.28469408711564053e-18*V01*V19 + 
      1.9147442344621886e-20*V22) + delta12*eps5*
    (2.10613238719217953e-11*V063 + 1.64612745870577951e-10*V05*V06*V07 + 5.52527703739065477e-11*V04*V072 + 
      6.34085711144678006e-11*V052*V08 + 6.53389768538752109e-11*V04*V06*V08 + 6.03891153471121911e-11*V03*V07*V08 + 
      6.02167012238729901e-12*V02*V082 + 6.44615654362243056e-11*V04*V05*V09 + 4.57257627418272085e-11*V03*V06*V09 + 
      1.54291047785080388e-11*V02*V07*V09 + 5.03242627892601592e-12*V01*V08*V09 + 1.03162921957593822e-11*V042*V10 + 
      2.84232162937897181e-11*V03*V05*V10 + 7.35516676785972028e-12*V02*V06*V10 + 4.0604594705413883e-12*V01*V07*V10 - 
      7.67994164653953858e-14*V102 + 1.17202846247680556e-11*V03*V04*V11 + 5.89111273361216028e-12*V02*V05*V11 + 
      2.49413251319057501e-12*V01*V06*V11 - 1.5942072417897397e-13*V09*V11 + 2.13818722764698816e-12*V032*V12 + 
      1.55808001607139976e-12*V02*V04*V12 + 1.2829123365881929e-12*V01*V05*V12 - 1.05441977990826965e-13*V08*V12 + 
      7.55270863283610293e-13*V02*V03*V13 + 4.50780177875694445e-13*V01*V04*V13 - 7.57798708621947274e-14*V07*V13 + 
      4.16161438725110068e-14*V022*V14 + 1.36760132089891674e-13*V01*V03*V14 - 3.29532384496182881e-14*V06*V14 + 
      2.15791675223888655e-14*V01*V02*V15 - 1.60364042073524112e-14*V05*V15 + 1.55370006161199832e-15*V012*V16 - 
      4.13580159257670028e-15*V04*V16 - 1.27625362203842719e-15*V03*V17 - 1.47971434439237935e-16*V02*V18 - 
      2.46619057398729892e-17*V01*V19 + 6.7016048206176601e-20*V22) + 
   delta10*eps6*(-2.95801289810004407e-10*V044 - 7.84358338143741194e-9*V03*V042*V05 - 
      4.09348176232707823e-9*V032*V052 - 3.92005983305002913e-9*V02*V04*V052 - 
      8.01299054975525564e-10*V01*V053 - 5.49887301462931715e-9*V032*V04*V06 - 
      1.23515189263710895e-9*V02*V042*V06 - 5.57736890117064409e-9*V02*V03*V05*V06 - 
      3.29932380877759029e-9*V01*V04*V05*V06 - 2.13153443195460002e-10*V022*V062 - 
      1.13590745155871206e-9*V01*V03*V062 + 1.11077632135397347e-10*V063 - 
      1.27190326186591359e-9*V033*V07 - 3.73339031719050393e-9*V02*V03*V04*V07 - 
      1.12051191163391599e-9*V01*V042*V07 - 9.11823062558356676e-10*V022*V05*V07 - 
      2.2213661141454481e-9*V01*V03*V05*V07 - 7.96766985881520584e-10*V01*V02*V06*V07 + 7.90818238274194341e-10*V05*V06*V07 - 
      7.07587561773680666e-11*V012*V072 + 2.66182291692605467e-10*V04*V072 - 
      1.0063142665720734e-9*V02*V032*V08 - 2.14750350915928258e-10*V022*V04*V08 - 
      1.16958121224642648e-9*V01*V03*V04*V08 - 6.03788559943244039e-10*V01*V02*V05*V08 + 
      3.07308867141893107e-10*V052*V08 - 1.15543395934255982e-10*V012*V06*V08 + 
      3.48020435329644263e-10*V04*V06*V08 + 2.95653173692384828e-10*V03*V07*V08 + 3.2678175994266238e-11*V02*V082 - 
      2.53284184043987966e-10*V022*V03*V09 - 2.92166637871586518e-10*V01*V032*V09 - 
      3.11115859765875328e-10*V01*V02*V04*V09 - 8.04807753628948774e-11*V012*V05*V09 + 
      3.13793240103475455e-10*V04*V05*V09 + 2.24240350892254344e-10*V03*V06*V09 + 7.61580611867156797e-11*V02*V07*V09 + 
      2.53822800065346792e-11*V01*V08*V09 - 7.30978886129835398e-12*V023*V10 - 
      1.29608179425328507e-10*V01*V02*V03*V10 - 3.60822424022704135e-11*V012*V04*V10 + 
      5.60804732543481649e-11*V042*V10 + 1.42000663750085985e-10*V03*V05*V10 + 4.03355333137918687e-11*V02*V06*V10 + 
      2.06774049390104097e-11*V01*V07*V10 - 2.53132042505487258e-13*V102 - 
      1.3815500947853889e-11*V01*V022*V11 - 1.32250949244413297e-11*V012*V03*V11 + 
      5.88245344526877608e-11*V03*V04*V11 + 2.96754985434489887e-11*V02*V05*V11 + 1.27296865619387611e-11*V01*V06*V11 - 
      5.05754031960445325e-13*V09*V11 - 2.63714690457609848e-12*V012*V02*V12 + 
      1.11352203701387527e-11*V032*V12 + 8.81730210584071817e-12*V02*V04*V12 + 6.74017282442450755e-12*V01*V05*V12 - 
      3.50568990092294541e-13*V08*V12 - 1.18081204682511872e-13*V013*V13 + 3.95761932360611793e-12*V02*V03*V13 + 
      2.37602171422117529e-12*V01*V04*V13 - 2.44874227567633878e-13*V07*V13 + 2.48384849849704798e-13*V022*V14 + 
      7.57584150042010379e-13*V01*V03*V14 - 1.12391703028323173e-13*V06*V14 + 1.1963490474412387e-13*V01*V02*V15 - 
      5.36951342721384656e-14*V05*V15 + 9.3222003696719899e-15*V012*V16 - 1.46935634398163269e-14*V04*V16 - 
      4.49463232109185227e-15*V03*V17 - 5.54892879147142256e-16*V02*V18 - 9.24821465245237093e-17*V01*V19 + 
      2.01048144618529803e-19*V22) + delta8*eps7*
    (-3.12288574815807931e-9*V044 - 6.13302756208529629e-8*V03*V042*V05 - 
      3.11053445414828857e-8*V032*V052 - 3.05407589414942356e-8*V02*V04*V052 - 
      6.13408242084712673e-9*V01*V053 - 4.34778369389713928e-8*V032*V04*V06 - 
      1.31957658023639972e-8*V02*V042*V06 - 4.3769553743682284e-8*V02*V03*V05*V06 - 
      2.60867021633828357e-8*V01*V04*V05*V06 - 2.31124277965236571e-9*V022*V062 - 
      9.11367606483152702e-9*V01*V03*V062 + 3.89361294085025683e-10*V063 - 
      9.73663876324940751e-9*V033*V07 - 2.90864370871373672e-8*V02*V03*V04*V07 - 
      8.76146794583613756e-9*V01*V042*V07 - 7.13092395077689195e-9*V022*V05*V07 - 
      1.71856509877829517e-8*V01*V03*V05*V07 - 6.252793391954612e-9*V01*V02*V06*V07 + 2.5282819527162001e-9*V05*V06*V07 - 
      5.70894510067401446e-10*V012*V072 + 8.58885837973415987e-10*V04*V072 - 
      8.03345795856689103e-9*V02*V032*V08 - 2.36162409365023744e-9*V022*V04*V08 - 
      9.43862429428878231e-9*V01*V03*V04*V08 - 4.82007477514013462e-9*V01*V02*V05*V08 + 
      9.90550771013638422e-10*V052*V08 - 9.52465488627175524e-10*V012*V06*V08 + 
      1.24013655702525207e-9*V04*V06*V08 + 9.70630955157051171e-10*V03*V07*V08 + 1.20233202577373189e-10*V02*V082 - 
      1.98081220854913665e-9*V022*V03*V09 - 2.30511380283789247e-9*V01*V032*V09 - 
      2.42386975726144727e-9*V01*V02*V04*V09 - 6.55688060858462352e-10*V012*V05*V09 + 
      1.03082561137740446e-9*V04*V05*V09 + 7.43326732405203706e-10*V03*V06*V09 + 2.56405271524897592e-10*V02*V07*V09 + 
      8.76982300491031469e-11*V01*V08*V09 - 8.45686342107132646e-11*V023*V10 - 1.06762277776516805e-9*V01*V02*V03*V10 - 
      3.02034852834339296e-10*V012*V04*V10 + 2.06123073726194409e-10*V042*V10 + 
      4.7748951503009169e-10*V03*V05*V10 + 1.50591515305042041e-10*V02*V06*V10 + 7.19068418752763738e-11*V01*V07*V10 - 
      6.67076525370678137e-13*V102 - 1.08044302284498363e-10*V01*V022*V11 - 
      1.12177144448386278e-10*V012*V03*V11 + 2.03127638655029436e-10*V03*V04*V11 + 
      1.03144968090215195e-10*V02*V05*V11 + 4.50206788567242398e-11*V01*V06*V11 - 1.29003346187058122e-12*V09*V11 - 
      2.30258349130898151e-11*V012*V02*V12 + 3.95028240664850572e-11*V032*V12 + 
      3.43243417611322668e-11*V02*V04*V12 + 2.42921004633035937e-11*V01*V05*V12 - 9.30432048801058198e-13*V08*V12 - 
      1.18081204682511872e-12*V013*V13 + 1.45685275777151709e-11*V02*V03*V13 + 8.81931944973023978e-12*V01*V04*V13 - 
      6.32855328667315743e-13*V07*V13 + 1.03165684091036688e-12*V022*V14 + 2.90075801502960086e-12*V01*V03*V14 - 
      3.05117097813708622e-13*V06*V14 + 4.73878518791659487e-13*V01*V02*V15 - 1.4295890209760875e-13*V05*V15 + 
      3.88425015402999579e-14*V012*V16 - 4.15429802188160502e-14*V04*V16 - 1.25775719273352245e-14*V03*V17 - 
      1.66467863744142677e-15*V02*V18 - 2.77446439573571128e-16*V01*V19 + 5.02620361546324507e-19*V22) + 
   eps11*(-9.01835117002665504e-8*V026 - 3.25916459348999032e-6*V01*V024*V03 - 
      7.35068548808628174e-6*V012*V022*V032 - 1.0854789500622834e-6*V013*V033 + 
      6.78100295225791258e-7*V02*V034 - 3.88445328921519398e-6*V012*V023*V04 - 
      4.99063464093225998e-6*V013*V02*V03*V04 + 2.84278006510562727e-6*V022*V032*V04 + 
      1.64707575731881287e-6*V01*V033*V04 - 2.84933320647606362e-7*V014*V042 + 
      5.87400058299529199e-7*V023*V042 + 3.58815504059799695e-6*V01*V02*V03*V042 + 
      3.5912954439740154e-7*V012*V043 - 2.81868399275952575e-8*V044 - 
      1.54110614180058625e-6*V013*V022*V05 - 4.60814262897596231e-7*V014*V03*V05 + 
      1.12000694579646299e-6*V023*V03*V05 + 3.00648528885136028e-6*V01*V02*V032*V05 + 
      2.15679602202006303e-6*V01*V022*V04*V05 + 1.75801937489685506e-6*V012*V03*V04*V05 - 
      3.02837308803974984e-7*V03*V042*V05 + 5.39000298734921751e-7*V012*V02*V052 - 
      1.30260107162109282e-7*V032*V052 - 1.81474604951678073e-7*V02*V04*V052 - 
      3.30907815972154207e-8*V01*V053 - 2.28841374674708008e-7*V014*V02*V06 + 
      1.2426335177657929e-7*V024*V06 + 1.53341242595954898e-6*V01*V022*V03*V06 + 
      6.11779025097477478e-7*V012*V032*V06 + 9.21724593289573448e-7*V012*V02*V04*V06 - 
      2.1732776138249265e-7*V032*V04*V06 - 1.45683102372722665e-7*V02*V042*V06 + 
      1.38048989425477521e-7*V013*V05*V06 - 2.61595716210939036e-7*V02*V03*V05*V06 - 
      1.66642922459441776e-7*V01*V04*V05*V06 - 3.13513920345541883e-8*V022*V062 - 
      5.92808427693683879e-8*V01*V03*V062 + 8.84509142307875836e-10*V063 - 
      1.08398545898545899e-8*V015*V07 + 2.24590985483015906e-7*V01*V023*V07 + 
      5.54011203192750812e-7*V012*V02*V03*V07 - 4.56228874516762589e-8*V033*V07 + 
      1.01933346911025482e-7*V013*V04*V07 - 1.91754429908024679e-7*V02*V03*V04*V07 - 
      6.13420781184067054e-8*V01*V042*V07 - 5.72043116871378037e-8*V022*V05*V07 - 
      1.03916952302356811e-7*V01*V03*V05*V07 - 5.3133259730785894e-8*V01*V02*V06*V07 + 4.73703555517935601e-9*V05*V06*V07 - 
      5.00584884186415077e-9*V012*V072 + 1.741265174578467e-9*V04*V072 + 
      1.12062015273820829e-7*V012*V022*V08 + 5.3898165877332544e-8*V013*V03*V08 - 
      5.36809105180029939e-8*V02*V032*V08 - 3.57374452845974788e-8*V022*V04*V08 - 
      6.77966188714758976e-8*V01*V03*V04*V08 - 4.12668507250089883e-8*V01*V02*V05*V08 + 
      1.84415328275492498e-9*V052*V08 - 8.89450891456902195e-9*V012*V06*V08 + 
      3.03796541544199087e-9*V04*V06*V08 + 1.95419862124377447e-9*V03*V07*V08 + 3.79246470634262349e-10*V02*V082 + 
      1.95719596761263428e-8*V013*V02*V09 - 1.87589213813852975e-8*V022*V03*V09 - 
      1.67786011778556713e-8*V01*V032*V09 - 2.41704845909809145e-8*V01*V02*V04*V09 - 
      6.17402338833098637e-9*V012*V05*V09 + 2.15772698503969466e-9*V04*V05*V09 + 1.55508035764887683e-9*V03*V06*V09 + 
      6.91653165373944804e-10*V02*V07*V09 + 2.50103168132130448e-10*V01*V08*V09 + 1.05387475179141846e-9*V014*V10 - 
      1.89829593813409562e-9*V023*V10 - 1.09471819705392301e-8*V01*V02*V03*V10 - 
      3.31517199332033599e-9*V012*V04*V10 + 5.66213951638936691e-10*V042*V10 + 
      9.90709445715168765e-10*V03*V05*V10 + 4.93857621869645393e-10*V02*V06*V10 + 2.04600194881280817e-10*V01*V07*V10 - 
      1.0592820988240287e-12*V102 - 1.62155014330259428e-9*V01*V022*V11 - 
      1.34701134241575418e-9*V012*V03*V11 + 4.83293552740012793e-10*V03*V04*V11 + 2.92311187466604348e-10*V02*V05*V11 + 
      1.35732624614622041e-10*V01*V06*V11 - 1.95010166215273807e-12*V09*V11 - 3.7815505799574427e-10*V012*V02*V12 + 
      9.37949305944393234e-11*V032*V12 + 1.29817854947928907e-10*V02*V04*V12 + 7.30666296474582508e-11*V01*V05*V12 - 
      1.49261560383255041e-12*V08*V12 - 2.47970529833274931e-11*V013*V13 + 4.77180131422584983e-11*V02*V03*V13 + 
      3.07298566685929087e-11*V01*V04*V13 - 9.64334462347839848e-13*V07*V13 + 5.53945861966731133e-12*V022*V14 + 
      1.02559741067008009e-11*V01*V03*V14 - 5.09835577360394305e-13*V06*V14 + 2.32278159210993748e-12*V01*V02*V15 - 
      2.25009062494166185e-13*V05*V15 + 2.09749508317619773e-13*V012*V16 - 7.75740245047704874e-14*V04*V16 - 
      2.20569919460989047e-14*V03*V17 - 4.16169659360356692e-15*V02*V18 - 6.9361609893392782e-16*V01*V19 + 
      7.53930542319486761e-19*V22) + delta6*eps8*
    (1.16714836456899949e-7*V02*V034 + 3.3167660895835499e-7*V022*V032*V04 + 
      2.55740273101384212e-7*V01*V033*V04 + 1.0639753805538638e-8*V023*V042 + 
      4.0211845767401323e-7*V01*V02*V03*V042 + 3.92643621810288477e-8*V012*V043 - 
      1.44647796358943781e-8*V044 + 1.06435773874045479e-7*V023*V03*V05 + 
      3.97805457329266853e-7*V01*V02*V032*V05 + 1.99005965375012994e-7*V01*V022*V04*V05 + 
      2.09450079241745908e-7*V012*V03*V04*V05 - 2.23205463736282545e-7*V03*V042*V05 + 
      5.46638381459810031e-8*V012*V02*V052 - 1.08785983451243074e-7*V032*V052 - 
      1.12518714013131224e-7*V02*V04*V052 - 2.20587498467400428e-8*V01*V053 + 
      1.74482785814355479e-9*V024*V06 + 1.40126628221866317e-7*V01*V022*V03*V06 + 
      6.90710946167295374e-8*V012*V032*V06 + 8.25320145756653693e-8*V012*V02*V04*V06 - 
      1.60306931018687944e-7*V032*V04*V06 - 6.23141806988030663e-8*V02*V042*V06 + 
      1.17976618472650219e-8*V013*V05*V06 - 1.63158892000544402e-7*V02*V03*V05*V06 - 
      9.83588207974490265e-8*V01*V04*V05*V06 - 1.11381689475890119e-8*V022*V062 - 
      3.48030855806882884e-8*V01*V03*V062 + 9.53886585144753617e-10*V063 + 
      1.52051105534350684e-8*V01*V023*V07 + 4.88653762463286273e-8*V012*V02*V03*V07 - 
      3.50760218509401516e-8*V033*V07 + 8.00084505441648299e-9*V013*V04*V07 - 
      1.0966831245289851e-7*V02*V03*V04*V07 - 3.33776917471737993e-8*V01*V042*V07 - 
      2.72838431539411932e-8*V022*V05*V07 - 6.36466502471469273e-8*V01*V03*V05*V07 - 
      2.43659066418494264e-8*V01*V02*V06*V07 + 5.73454430680343706e-9*V05*V06*V07 - 
      2.24285876770250149e-9*V012*V072 + 1.97943651812315506e-9*V04*V072 + 
      7.29348240922314996e-9*V012*V022*V08 + 3.81402291124513347e-9*V013*V03*V08 - 
      3.10448607244177324e-8*V02*V032*V08 - 1.1607382420290917e-8*V022*V04*V08 - 
      3.68885683428167088e-8*V01*V03*V04*V08 - 1.90217012623058375e-8*V01*V02*V05*V08 + 
      2.25567676854889474e-9*V052*V08 - 3.85231495904931946e-9*V012*V06*V08 + 
      3.10327793500338834e-9*V04*V06*V08 + 2.26552478541084656e-9*V03*V07*V08 + 3.14616699492002765e-10*V02*V082 + 
      1.00369023980135091e-9*V013*V02*V09 - 7.92456084758190786e-9*V022*V03*V09 - 
      9.03546132401563463e-9*V01*V032*V09 - 9.76593414783968783e-9*V01*V02*V04*V09 - 
      2.6475492964171769e-9*V012*V05*V09 + 2.41967965015243137e-9*V04*V05*V09 + 1.75967541052281089e-9*V03*V06*V09 + 
      6.25456165059616089e-10*V02*V07*V09 + 2.19248139960954814e-10*V01*V08*V09 + 4.01476095920540365e-11*V014*V10 - 
      4.41323816738797546e-10*V023*V10 - 4.45295468686769652e-9*V01*V02*V03*V10 - 
      1.27550192715147586e-9*V012*V04*V10 + 5.34938290003461784e-10*V042*V10 + 
      1.1361175216718043e-9*V03*V05*V10 + 4.00148693505997441e-10*V02*V06*V10 + 1.80018298529104411e-10*V01*V07*V10 - 
      1.37352914624220985e-12*V102 - 4.69963194636397251e-10*V01*V022*V11 - 
      4.90627405455836828e-10*V012*V03*V11 + 5.02893349542243018e-10*V03*V04*V11 + 
      2.59112630875115109e-10*V02*V05*V11 + 1.15332635287803027e-10*V01*V06*V11 - 2.59545595292284319e-12*V09*V11 - 
      1.05092272167435566e-10*V012*V02*V12 + 9.92078181483731716e-11*V032*V12 + 
      9.54439427562594958e-11*V02*V04*V12 + 6.26440027127202582e-11*V01*V05*V12 - 1.92513302396022541e-12*V08*V12 - 
      5.9040602341255936e-12*V013*V13 + 3.87855325380408513e-11*V02*V03*V13 + 2.3732250541102737e-11*V01*V04*V13 - 
      1.28109968651631223e-12*V07*V13 + 3.08841045580429443e-12*V022*V14 + 7.94458631504268473e-12*V01*V03*V14 - 
      6.42639939769610351e-13*V06*V14 + 1.37243505442393185e-12*V01*V02*V15 - 2.95332486711414013e-13*V05*V15 + 
      1.16527504620899874e-13*V012*V16 - 9.08914536043019015e-14*V04*V16 - 2.71897510782099705e-14*V03*V17 - 
      3.88425015402999579e-15*V02*V18 - 6.47375025671665965e-16*V01*V19 + 1.00524072309264901e-18*V22) + 
   delta2*eps10*(-1.05683802773749864e-9*V026 - 1.43624287969526065e-6*V01*V024*V03 - 
      4.03239837763647287e-6*V012*V022*V032 - 6.39695952195952196e-7*V013*V033 + 
      1.03731386283469617e-6*V02*V034 - 1.80719302743112267e-6*V012*V023*V04 - 
      2.58256954685526114e-6*V013*V02*V03*V04 + 3.76126895224117446e-6*V022*V032*V04 + 
      2.41349362443112443e-6*V01*V033*V04 - 1.39266322302036588e-7*V014*V042 + 
      5.67501373552960855e-7*V023*V042 + 4.64213503648027458e-6*V01*V02*V03*V042 + 
      4.56605646337789195e-7*V012*V043 - 4.8511255774108832e-8*V044 - 
      6.58099616432949766e-7*V013*V022*V05 - 2.11015836015836016e-7*V014*V03*V05 + 
      1.29053917496377814e-6*V023*V03*V05 + 3.9946842867229772e-6*V01*V02*V032*V05 + 
      2.44500548319992764e-6*V01*V022*V04*V05 + 2.24826843130414559e-6*V012*V03*V04*V05 - 
      5.60125414233724224e-7*V03*V042*V05 + 6.19076139909473243e-7*V012*V02*V052 - 
      2.49438911785360782e-7*V032*V052 - 3.07119530720429413e-7*V02*V04*V052 - 
      5.691691187504096e-8*V01*V053 - 8.67188367188367188e-8*V014*V02*V06 + 
      1.01721424886107426e-7*V024*V06 + 1.76647646885742124e-6*V01*V022*V03*V06 + 
      7.76630845455250217e-7*V012*V032*V06 + 1.04599434956577814e-6*V012*V02*V04*V06 - 
      4.0652457348302353e-7*V032*V04*V06 - 2.31405524903132279e-7*V02*V042*V06 + 
      1.52463415112224636e-7*V013*V05*V06 - 4.49494829929295382e-7*V02*V03*V05*V06 - 
      2.8006164438601997e-7*V01*V04*V05*V06 - 4.55565553349458578e-8*V022*V062 - 
      1.00457618621134027e-7*V01*V03*V062 + 1.71256554412201539e-9*V063 - 
      3.61328486328486328e-9*V015*V07 + 2.13711461231302501e-7*V01*V023*V07 + 
      6.20745133393942918e-7*V012*V02*V03*V07 - 8.67051308647217844e-8*V033*V07 + 
      1.10772990237275952e-7*V013*V04*V07 - 3.23151314667712894e-7*V02*V03*V04*V07 - 
      1.01333081107021933e-7*V01*V042*V07 - 8.70315157488360103e-8*V022*V05*V07 - 
      1.77061130153304523e-7*V01*V03*V05*V07 - 8.07420722001137501e-8*V01*V02*V06*V07 + 9.36414228087805413e-9*V05*V06*V07 - 
      7.52927932914510879e-9*V012*V072 + 3.39053821003755583e-9*V04*V072 + 
      1.08217881655381655e-7*V012*V022*V08 + 5.69694580111246778e-8*V013*V03*V08 - 
      9.20055009399080361e-8*V02*V032*V08 - 5.09313924784279593e-8*V022*V04*V08 - 
      1.13208170487071631e-7*V01*V03*V04*V08 - 6.28664755448281359e-8*V01*V02*V05*V08 + 
      3.65860240983193125e-9*V052*V08 - 1.33508092355693896e-8*V012*V06*V08 + 
      5.81472070492569043e-9*V04*V06*V08 + 3.86604911270109038e-9*V03*V07*V08 + 6.69355072471856466e-10*V02*V082 + 
      1.80664243164243164e-8*V013*V02*V09 - 2.83619245526925265e-8*V022*V03*V09 - 
      2.81638855036964281e-8*V01*V032*V09 - 3.58774136840050706e-8*V01*V02*V04*V09 - 
      9.23462495591347132e-9*V012*V05*V09 + 4.20004124525269606e-9*V04*V05*V09 + 3.06443310291299597e-9*V03*V06*V09 + 
      1.23744774342815094e-9*V02*V07*V09 + 4.45845885430025007e-10*V01*V08*V09 + 9.03321215821215821e-10*V014*V10 - 
      2.36809044533523214e-9*V023*V10 - 1.64647371186236732e-8*V01*V02*V03*V10 - 
      4.8689519595069315e-9*V012*V04*V10 + 1.06738757717012689e-9*V042*V10 + 
      1.95993066468536445e-9*V03*V05*V10 + 8.68331150576541423e-10*V02*V06*V10 + 3.64912169506311622e-10*V01*V07*V10 - 
      2.10980781986575818e-12*V102 - 2.1210336391096195e-9*V01*V022*V11 - 
      1.96605205796382267e-9*V012*V03*V11 + 9.3749562552640253e-10*V03*V04*V11 + 5.22594784223503694e-10*V02*V05*V11 + 
      2.40847369943663066e-10*V01*V06*V11 - 3.90006460108568935e-12*V09*V11 - 4.91513014490955667e-10*V012*V02*V12 + 
      1.84496333387633329e-10*V032*V12 + 2.23917921136611244e-10*V02*V04*V12 + 1.29959796546414746e-10*V01*V05*V12 - 
      2.97043406422117702e-12*V08*V12 - 3.09963162291593664e-11*V013*V13 + 8.4929129617865858e-11*V02*V03*V13 + 
      5.3556817973796388e-11*V01*V04*V13 - 1.92853020147589291e-12*V07*V13 + 8.62458904200820265e-12*V022*V14 + 
      1.80431188155001364e-11*V01*V03*V14 - 1.01084835794234905e-12*V06*V14 + 3.67061639555834602e-12*V01*V02*V15 - 
      4.49879401768545584e-13*V05*V15 + 3.26277012938519646e-13*V012*V16 - 1.51596734582999264e-13*V04*V16 - 
      4.39752606724110238e-14*V03*V17 - 7.49105386848642045e-15*V02*V18 - 1.24850897808107008e-15*V01*V19 + 
      1.50786108463897352e-18*V22) + delta4*eps9*
    (5.77265272205748396e-7*V02*V034 + 1.82975598402185704e-6*V022*V032*V04 + 
      1.29435893324782214e-6*V01*V033*V04 + 1.71045640622360199e-7*V023*V042 + 
      2.22836898184120406e-6*V01*V02*V03*V042 + 2.17760634427301094e-7*V012*V043 - 
      3.60906857706966639e-8*V044 + 5.88336453498490536e-7*V023*V03*V05 + 
      2.02834900255535176e-6*V01*V02*V032*V05 + 1.09785359041311422e-6*V01*V022*V04*V05 + 
      1.10349719724719725e-6*V012*V03*V04*V05 - 4.68083420578654783e-7*V03*V042*V05 + 
      2.91282378335949765e-7*V012*V02*V052 - 2.17885800504264557e-7*V032*V052 - 
      2.43074095879106772e-7*V02*V04*V052 - 4.63433304017454344e-8*V01*V053 + 
      2.92978136893480809e-8*V024*V06 + 7.90223105451280054e-7*V01*V022*V03*V06 + 
      3.71694599125154681e-7*V012*V032*V06 + 4.64519313725662932e-7*V012*V02*V04*V06 - 
      3.39387086707542668e-7*V032*V04*V06 - 1.61809756133596781e-7*V02*V042*V06 + 
      6.75684269434269434e-8*V013*V05*V06 - 3.55806643708089008e-7*V02*V03*V05*V06 - 
      2.17671871098866897e-7*V01*V04*V05*V06 - 3.00604608299908642e-8*V022*V062 - 
      7.77819282174149121e-8*V01*V03*V062 + 1.60833310225194172e-9*V063 + 
      8.40480647854986479e-8*V01*V023*V07 + 2.70296649264903233e-7*V012*V02*V03*V07 - 
      7.32294648124869102e-8*V033*V07 + 4.66974053283577093e-8*V013*V04*V07 - 
      2.46677484412856339e-7*V02*V03*V04*V07 - 7.61219370190736515e-8*V01*V042*V07 - 
      6.29359832025273202e-8*V022*V05*V07 - 1.38998120525801042e-7*V01*V03*V05*V07 - 
      5.7467395205441813e-8*V01*V02*V06*V07 + 9.13001277706507386e-9*V05*V06*V07 - 
      5.30907153538845104e-9*V012*V072 + 3.22444623072974743e-9*V04*V072 + 
      4.26367613867613868e-8*V012*V022*V08 + 2.3125023125023125e-8*V013*V03*V08 - 
      7.06136849830438377e-8*V02*V032*V08 - 3.23479074354424494e-8*V022*V04*V08 - 
      8.51545756400059232e-8*V01*V03*V04*V08 - 4.4997879418105842e-8*V01*V02*V05*V08 + 
      3.58588104686483122e-9*V052*V08 - 9.33831149945373413e-9*V012*V06*V08 + 
      5.35219682347953734e-9*V04*V06*V08 + 3.70330815615235731e-9*V03*V07*V08 + 5.74573573165675699e-10*V02*V082 + 
      6.62435558268891602e-9*V013*V02*V09 - 1.95347640966513516e-8*V022*V03*V09 - 
      2.10785071604399335e-8*V01*V032*V09 - 2.43510434044981197e-8*V01*V02*V04*V09 - 
      6.44571558874780163e-9*V012*V05*V09 + 3.98584660105880436e-9*V04*V05*V09 + 2.91333022299243766e-9*V03*V06*V09 + 
      1.09040704931153581e-9*V02*V07*V09 + 3.89198166147944597e-10*V01*V08*V09 + 3.01107071940405274e-10*V014*V10 - 
      1.34500115047889713e-9*V023*V10 - 1.12181361634267797e-8*V01*V02*V03*V10 - 
      3.25870387436680621e-9*V012*V04*V10 + 9.5573417761393829e-10*V042*V10 + 
      1.87501133817503019e-9*V03*V05*V10 + 7.39981468201118634e-10*V02*V06*V10 + 3.1894243886195272e-10*V01*V07*V10 - 
      2.09271123396052009e-12*V102 - 1.28944675513302964e-9*V01*V022*V11 - 
      1.29121797320326732e-9*V012*V03*V11 + 8.658560693855349e-10*V03*V04*V11 + 4.59043272703367589e-10*V02*V05*V11 + 
      2.08292359616979377e-10*V01*V06*V11 - 3.89895481532739506e-12*V09*V11 - 2.9520301170627968e-10*V012*V02*V12 + 
      1.71398086975365036e-10*V032*V12 + 1.84287767650791223e-10*V02*V04*V12 + 1.129495553361591e-10*V01*V05*V12 - 
      2.94167211665205015e-12*V08*V12 - 1.77121807023767808e-11*V013*V13 + 7.22146841136743384e-11*V02*V03*V13 + 
      4.47838505759042395e-11*V01*V04*V13 - 1.92742041571759863e-12*V07*V13 + 6.47582185679880898e-12*V022*V14 + 
      1.51042951489610416e-11*V01*V03*V14 - 9.94035103704190637e-13*V06*V14 + 2.80831286136368696e-12*V01*V02*V15 - 
      4.48769616010251299e-13*V05*V15 + 2.44707759703889735e-13*V012*V16 - 1.45326445048636557e-13*V04*V16 - 
      4.28654749141167393e-14*V03*V17 - 6.65871454976570707e-15*V02*V18 - 1.10978575829428451e-15*V01*V19 + 
      1.50786108463897352e-18*V22) + 3.86817017063068404e-23*delta22*V22 + 
   2.12749359384687622e-22*delta20*eps*V22 + 
   delta20*eps2*(-3.41091377476043088e-18*V112 - 5.24755965347758597e-18*V10*V12 - 
      4.81026301568778714e-18*V09*V13 - 2.56547360836681981e-18*V08*V14 - 1.64923303395009845e-18*V07*V15 - 
      5.82082247276505334e-19*V06*V16 - 2.54660983183471084e-19*V05*V17 - 5.36128385649412808e-20*V04*V18 - 
      1.48924551569281335e-20*V03*V19 - 1.41832906256458415e-21*V02*V20 - 2.12749359384687622e-22*V01*V21 + 
      2.12749359384687622e-24*V24) + delta18*eps3*
    (-3.41091377476043088e-17*V112 - 5.24755965347758597e-17*V10*V12 - 4.81026301568778714e-17*V09*V13 - 
      2.56547360836681981e-17*V08*V14 - 1.64923303395009845e-17*V07*V15 - 5.82082247276505334e-18*V06*V16 - 
      2.54660983183471084e-18*V05*V17 - 5.36128385649412808e-19*V04*V18 - 1.48924551569281335e-19*V03*V19 - 
      1.41832906256458415e-20*V02*V20 - 2.12749359384687622e-21*V01*V21 + 1.06374679692343811e-23*V24) + 
   delta16*eps4*(1.95275788151827456e-13*V06*V072 + 1.10155572803594975e-13*V062*V08 + 
      3.00424289464349933e-13*V05*V07*V08 + 5.69431659769029285e-14*V04*V082 + 2.27821752843798699e-13*V05*V06*V09 + 
      1.53157480903394083e-13*V04*V07*V09 + 8.34511915178749814e-14*V03*V08*V09 + 1.07059094381484351e-14*V02*V092 + 
      7.06059151375409192e-14*V052*V10 + 6.95537485590207015e-14*V04*V06*V10 + 6.7243728702419923e-14*V03*V07*V10 + 
      1.28135148350630137e-14*V02*V08*V10 + 5.60364405853499358e-15*V01*V09*V10 + 5.84783108903868319e-14*V04*V05*V11 + 
      4.14221368806906726e-14*V03*V06*V11 + 1.40150087190306787e-14*V02*V07*V11 + 4.55188317370227171e-15*V01*V08*V11 - 
      2.06888162885766611e-16*V112 + 7.37226568917269889e-15*V042*V12 + 2.1242121477277268e-14*V03*V05*V12 + 
      5.25463004964227156e-15*V02*V06*V12 + 3.03458878246818114e-15*V01*V07*V12 - 3.25473640412121701e-16*V10*V12 + 
      7.4972193449213887e-15*V03*V04*V13 + 3.77327157820056734e-15*V02*V05*V13 + 1.5931591107957951e-15*V01*V06*V13 - 
      2.93082453741548745e-16*V09*V13 + 1.13797079342556793e-15*V032*V14 + 7.91999487189063994e-16*V02*V04*V14 + 
      6.82782476055340757e-16*V01*V05*V14 - 1.60525348637809582e-16*V08*V14 + 3.59359197923863556e-16*V02*V03*V15 + 
      2.14206266997753963e-16*V01*V04*V15 - 1.01840139846418579e-16*V07*V15 + 1.55017693222058789e-17*V022*V16 + 
      5.35515667494384907e-17*V01*V03*V16 - 3.70592364099375063e-17*V06*V16 + 7.9270411306734608e-18*V01*V02*V17 - 
      1.60739587242709963e-17*V05*V17 + 4.40391173926303378e-19*V012*V18 - 3.50142895675318888e-18*V04*V18 - 
      9.68541458598790399e-19*V03*V19 - 9.57372117231094299e-20*V02*V20 - 1.43605817584664145e-20*V01*V21 + 
      4.7868605861554715e-23*V24) + delta14*eps5*
    (2.05039577559418829e-12*V06*V072 + 1.23173958680383473e-12*V062*V08 + 
      3.16697271810335554e-12*V05*V07*V08 + 6.37501651281648877e-13*V04*V082 + 2.39212840485988634e-12*V05*V06*V09 + 
      1.60336737820740681e-12*V04*V07*V09 + 8.79714643917598762e-13*V03*V08*V09 + 1.11817276353994767e-13*V02*V092 + 
      7.48422700457933743e-13*V052*V10 + 7.8015382937856978e-13*V04*V06*V10 + 7.12783524245651184e-13*V03*V07*V10 + 
      1.44021970804301276e-13*V02*V08*V10 + 5.9398627020470932e-14*V01*V09*V10 + 6.12194817133737146e-13*V04*V05*V11 + 
      4.34932437247252062e-13*V03*V06*V11 + 1.46378979954320422e-13*V02*V07*V11 + 4.79844351227781143e-14*V01*V08*V11 - 
      9.47746755987005437e-16*V112 + 8.32191347286274146e-14*V042*V12 + 2.27025173288400802e-13*V03*V05*V12 + 
      5.93661394970222595e-14*V02*V06*V12 + 3.24321676126286859e-14*V01*V07*V12 - 1.54428184088054673e-15*V10*V12 + 
      7.8486515017145788e-14*V03*V04*V13 + 3.94097253723170367e-14*V02*V05*V13 + 1.67281706633558485e-14*V01*V06*V13 - 
      1.35237108783908073e-15*V09*V13 + 1.23280169287769859e-14*V032*V14 + 9.06336779704970386e-15*V02*V04*V14 + 
      7.39681015726619153e-15*V01*V05*V14 - 7.71841059888646073e-16*V08*V14 + 3.75330717831590825e-15*V02*V03*V15 + 
      2.2424718576327368e-15*V01*V04*V15 - 4.79926812879478648e-16*V07*V15 + 1.82732977767820815e-16*V022*V16 + 
      5.95761180087503209e-16*V01*V03*V16 - 1.82773825644822675e-16*V06*V16 + 8.2793540698145035e-17*V01*V02*V17 - 
      7.82900622586899674e-17*V05*V17 + 5.28469408711564053e-18*V012*V18 - 1.78913701268146903e-17*V04*V18 - 
      4.9208926825678247e-18*V03*V19 - 5.10598462523250293e-19*V02*V20 - 7.65897693784875439e-20*V01*V21 + 
      1.9147442344621886e-22*V24) + delta12*eps6*
    (-1.81710194045720362e-10*V042*V052 - 1.29792995746943115e-10*V03*V053 - 
      4.18662090202051216e-11*V043*V06 - 5.14805050014601672e-10*V03*V04*V05*V06 - 
      1.29420107732156236e-10*V02*V052*V06 - 9.01865811069624174e-11*V032*V062 - 
      4.40269978275238859e-11*V02*V04*V062 - 5.41119486641774504e-11*V01*V05*V062 - 
      1.7305732766259082e-10*V03*V042*V07 - 1.82550878953343448e-10*V032*V05*V07 - 
      1.71981279391348682e-10*V02*V04*V05*V07 - 5.3904957766173305e-11*V01*V052*V07 - 
      1.23257245459196415e-10*V02*V03*V06*V07 - 7.35435785735145245e-11*V01*V04*V06*V07 - 
      9.95785605773606822e-12*V022*V072 - 2.49971695512631185e-11*V01*V03*V072 + 
      1.15250268045761243e-11*V06*V072 - 9.3124342549990002e-11*V032*V04*V08 - 
      2.23761745508195875e-11*V02*V042*V08 - 9.46468041976648278e-11*V02*V03*V05*V08 - 
      5.58746055299940012e-11*V01*V04*V05*V08 - 7.76241046146929228e-12*V022*V06*V08 - 
      3.85115190357462705e-11*V01*V03*V06*V08 + 7.53554676494466446e-12*V062*V08 - 
      1.35209720282378325e-11*V01*V02*V07*V08 + 1.79154934532962937e-11*V05*V07*V08 - 
      9.82119292914208671e-13*V012*V082 + 3.92859226055028743e-12*V04*V082 - 
      1.63718061254146838e-11*V033*V09 - 4.77725776087079673e-11*V02*V03*V04*V09 - 
      1.44214439718825684e-11*V01*V042*V09 - 1.16174987340254129e-11*V022*V05*V09 - 
      2.86854167432348997e-11*V01*V03*V05*V09 - 1.02714371215997013e-11*V01*V02*V06*V09 + 1.35496295737393273e-11*V05*V06*V09 - 
      1.84187443018241419e-12*V012*V07*V09 + 9.10052682992914154e-12*V04*V07*V09 + 
      5.05222430881163618e-12*V03*V08*V09 + 6.46063149296892166e-13*V02*V092 - 
      1.04307530326792808e-11*V02*V032*V10 - 2.36513594902759535e-12*V022*V04*V10 - 
      1.21170650938357241e-11*V01*V03*V04*V10 - 6.25845181960756846e-12*V01*V02*V05*V10 + 
      4.29758799138050964e-12*V052*V10 - 1.19770545225693172e-12*V012*V06*V10 + 
      4.84506694116438835e-12*V04*V06*V10 + 4.12322028399698023e-12*V03*V07*V10 + 9.06863113883747762e-13*V02*V08*V10 + 
      3.51171525289348256e-13*V01*V09*V10 - 2.11227249709552962e-12*V022*V03*V11 - 
      2.44960790856780832e-12*V01*V032*V11 - 2.60577696047498003e-12*V01*V02*V04*V11 - 
      6.77191269711172409e-13*V012*V05*V11 + 3.52815936324254369e-12*V04*V05*V11 + 
      2.52016808708015893e-12*V03*V06*V11 + 8.52167490935571267e-13*V02*V07*V11 + 2.83833873160198232e-13*V01*V08*V11 - 
      3.51413879689133865e-15*V112 - 5.41772745293529826e-14*V023*V12 - 
      9.0682813881742576e-13*V01*V02*V03*V12 - 2.52291295718900679e-13*V012*V04*V12 + 
      5.289041628784641e-13*V042*V12 + 1.34433281283334658e-12*V03*V05*V12 + 3.79763754107156185e-13*V02*V06*V12 + 
      1.94742738674907059e-13*V01*V07*V12 - 5.94631364944065399e-15*V10*V12 - 8.12412498882896009e-14*V01*V022*V13 - 
      7.79957430929223155e-14*V012*V03*V13 + 4.66023701813509939e-13*V03*V04*V13 + 
      2.34608709303411746e-13*V02*V05*V13 + 1.0055768755904512e-13*V01*V06*V13 - 5.05191543929168149e-15*V09*V13 - 
      1.32927671937915412e-14*V012*V02*V14 + 7.5919621661387341e-14*V032*V14 + 
      5.98495128495237701e-14*V02*V04*V14 + 4.58452496751368932e-14*V01*V05*V14 - 3.0134525591120312e-15*V08*V14 - 
      5.17900020537332772e-16*V013*V15 + 2.31657501249873611e-14*V02*V03*V15 + 1.3901916265566404e-14*V01*V04*V15 - 
      1.83240640289184556e-15*V07*V15 + 1.26762195502947164e-15*V022*V16 + 3.87685158230803389e-15*V01*V03*V16 - 
      7.33048341698442132e-16*V06*V16 + 5.36396449842237514e-16*V01*V02*V17 - 3.09533723454688484e-16*V05*V17 + 
      3.69928586098094837e-17*V012*V18 - 7.45754584438333215e-17*V04*V18 - 2.03728786546776867e-17*V03*V19 - 
      2.23386827353922003e-18*V02*V20 - 3.35080241030883005e-19*V01*V21 + 6.7016048206176601e-22*V24) + 
   delta10*eps7*(-1.70557610707464509e-9*V042*V052 - 1.19217270167562565e-9*V03*V053 - 
      5.01323905320006685e-10*V043*V06 - 4.86215725920891613e-9*V03*V04*V05*V06 - 
      1.21733642787349358e-9*V02*V052*V06 - 8.59173938356269183e-10*V032*V062 - 
      5.31289659696870534e-10*V02*V04*V062 - 5.1550436301376151e-10*V01*V05*V062 - 
      1.6243581972139477e-9*V03*V042*V07 - 1.68494184567353601e-9*V032*V05*V07 - 
      1.61287383824424957e-9*V02*V04*V05*V07 - 5.00033949543139184e-10*V01*V052*V07 - 
      1.15936802654618436e-9*V02*V03*V06*V07 - 6.94593894172702304e-10*V01*V04*V06*V07 - 
      9.39246312560111764e-11*V022*V072 - 2.33856304153575109e-10*V01*V03*V072 + 
      4.44102205900675288e-11*V06*V072 - 8.89988989578240483e-10*V032*V04*V08 - 
      2.7239765423050433e-10*V02*V042*V08 - 8.9868083163720132e-10*V02*V03*V05*V08 - 
      5.3399339374694429e-10*V01*V04*V05*V08 - 9.55675284983031473e-11*V022*V06*V08 - 
      3.723987620360497e-10*V01*V03*V06*V08 + 3.1674494679726012e-11*V062*V08 - 
      1.28382975948171617e-10*V01*V02*V07*V08 + 6.94986314416835163e-11*V05*V07*V08 - 
      9.71432467093597043e-12*V012*V082 + 1.67162671835187365e-11*V04*V082 - 
      1.52649797958091841e-10*V033*V09 - 4.48020510623402657e-10*V02*V03*V04*V09 - 
      1.35363183101162308e-10*V01*V042*V09 - 1.09578736465346372e-10*V022*V05*V09 - 
      2.69805352535325616e-10*V01*V03*V05*V09 - 9.66140022121820299e-11*V01*V02*V06*V09 + 5.29256680159109844e-11*V05*V06*V09 - 
      1.79602794741199031e-11*V012*V07*V09 + 3.57673098659722354e-11*V04*V07*V09 + 2.0127259476718193e-11*V03*V08*V09 + 
      2.61853949669536431e-12*V02*V092 - 1.00756215900251097e-10*V02*V032*V10 - 
      2.97018917149718008e-11*V022*V04*V10 - 1.18149015058534227e-10*V01*V03*V04*V10 - 
      6.04537295401506583e-11*V01*V02*V05*V10 + 1.69961237638805225e-11*V052*V10 - 
      1.19030688053496982e-11*V012*V06*V10 + 2.08588297254544514e-11*V04*V06*V10 + 
      1.65213712420960515e-11*V03*V07*V10 + 3.99657392471796277e-12*V02*V08*V10 + 1.46042761310808322e-12*V01*V09*V10 - 
      1.99234066300629768e-11*V022*V03*V11 - 2.35260967386419907e-11*V01*V032*V11 - 
      2.44374823976401449e-11*V01*V02*V04*V11 - 6.69245203681785332e-12*V012*V05*V11 + 
      1.42250735474288297e-11*V04*V05*V11 + 1.02303454542559249e-11*V03*V06*V11 + 3.49571416005116678e-12*V02*V07*V11 + 
      1.18753241613923411e-12*V01*V08*V11 - 1.07722042660262976e-14*V112 - 7.15353102653051873e-13*V023*V12 - 
      9.02525129503932721e-12*V01*V02*V03*V12 - 2.54954781538806962e-12*V012*V04*V12 + 
      2.35514294482179882e-12*V042*V12 + 5.54943436053908996e-12*V03*V05*V12 + 1.71018478591264041e-12*V02*V06*V12 + 
      8.23411708842879362e-13*V01*V07*V12 - 1.88276916619772124e-14*V10*V12 - 7.6628487038703757e-13*V01*V022*V13 - 
      8.02123551808220998e-13*V012*V03*V13 + 1.96948746143338698e-12*V03*V04*V13 + 
      9.95921739493290921e-13*V02*V05*V13 + 4.32416922861785017e-13*V01*V06*V13 - 1.55700618665683636e-14*V09*V13 - 
      1.39833005545079848e-13*V012*V02*V14 + 3.29532384496182881e-13*V032*V14 + 
      2.80820188278785753e-13*V02*V04*V14 + 2.01241150837363591e-13*V01*V05*V14 - 9.65495738769839211e-15*V08*V14 - 
      6.21480024644799327e-15*V013*V15 + 1.03543011248856745e-13*V02*V03*V15 + 6.25179310505780275e-14*V01*V04*V15 - 
      5.74558068332762718e-15*V07*V15 + 6.30358310711153603e-15*V022*V16 + 1.7985927856089371e-14*V01*V03*V16 - 
      2.40764535427438304e-15*V06*V16 + 2.55250724407685438e-15*V01*V02*V17 - 1.00124656661956089e-15*V05*V17 + 
      1.84964293049047419e-16*V012*V18 - 2.54660983183471084e-16*V04*V18 - 6.9026529652361899e-17*V03*V19 - 
      8.04192578474119211e-18*V02*V20 - 1.20628886771117882e-18*V01*V21 + 2.01048144618529803e-21*V24) + 
   delta8*eps8*(1.12851894189429203e-8*V034*V04 + 
      3.22772161542391857e-8*V02*V032*V042 + 1.32727772394750297e-9*V022*V043 + 
      1.28988759163051102e-8*V01*V03*V043 + 2.32560932622207132e-8*V02*V033*V05 + 
      3.15213839859809359e-8*V022*V03*V04*V05 + 3.88793049954736852e-8*V01*V032*V04*V05 + 
      1.93663296925435114e-8*V01*V02*V042*V05 + 2.50509275733948937e-9*V023*V052 + 
      2.01676793537496152e-8*V01*V02*V03*V052 + 5.42296366876198809e-9*V012*V04*V052 - 
      7.79716800769014296e-9*V042*V052 - 5.26980793180764275e-9*V03*V053 + 
      1.12944672278822606e-8*V022*V032*V06 + 8.727044463213931e-9*V01*V033*V06 + 
      8.90219825015965694e-10*V023*V04*V06 + 2.72517925412416542e-8*V01*V02*V03*V04*V06 + 
      3.97332007927635067e-9*V012*V042*V06 - 2.82619430165753763e-9*V043*V06 + 
      6.77668033672935634e-9*V01*V022*V05*V06 + 7.21389005435262827e-9*V012*V03*V05*V06 - 
      2.24289006366088539e-8*V03*V04*V05*V06 - 5.65439409962507944e-9*V02*V052*V06 + 
      1.39900924433487459e-9*V012*V02*V062 - 4.00160730277563195e-9*V032*V062 - 
      3.03640156876773161e-9*V02*V04*V062 - 2.43622427282075352e-9*V01*V05*V062 + 
      2.38580262603760892e-9*V023*V03*V07 + 9.24041655785742309e-9*V01*V02*V032*V07 + 
      4.5030548551401337e-9*V01*V022*V04*V07 + 4.91510203033701322e-9*V012*V03*V04*V07 - 
      7.54012879201343963e-9*V03*V042*V07 + 2.57138691939695675e-9*V012*V02*V05*V07 - 
      7.59338696663967903e-9*V032*V05*V07 - 7.5484574628484751e-9*V02*V04*V05*V07 - 
      2.29457182461032637e-9*V01*V052*V07 + 2.82523339489181381e-10*V013*V06*V07 - 
      5.4663977239129376e-9*V02*V03*V06*V07 - 3.30056967893175719e-9*V01*V04*V06*V07 - 
      4.51109044388735651e-10*V022*V072 - 1.09454741335667439e-9*V01*V03*V072 + 
      1.26631398443508704e-10*V06*V072 + 3.65989257687912458e-11*V024*V08 + 
      2.43314756620078749e-9*V01*V022*V03*V08 + 1.21284391647629535e-9*V012*V032*V08 + 
      1.42878257665839365e-9*V012*V02*V04*V08 - 4.21187584438707663e-9*V032*V04*V08 - 
      1.57900113818356684e-9*V02*V042*V08 + 2.09303621061842869e-10*V013*V05*V08 - 
      4.27845468704313461e-9*V02*V03*V05*V08 - 2.56344641051699639e-9*V01*V04*V05*V08 - 
      5.6232564871173011e-10*V022*V06*V08 - 1.80530156382735475e-9*V01*V03*V06*V08 + 
      9.74318743872451483e-11*V062*V08 - 6.28867334096473348e-10*V01*V02*V07*V08 + 
      1.99076135566589245e-10*V05*V07*V08 - 4.90493244688611919e-11*V012*V082 + 
      5.22622857692870916e-11*V04*V082 + 1.98816885503134077e-10*V01*V023*V09 + 
      6.53734098066692215e-10*V012*V02*V03*V09 - 7.14665652030552913e-10*V033*V09 + 
      1.07959958566867997e-10*V013*V04*V09 - 2.16039515045621509e-9*V02*V03*V04*V09 - 
      6.56907690744922031e-10*V01*V042*V09 - 5.34141365181383528e-10*V022*V05*V09 - 
      1.28674492004969786e-9*V01*V03*V05*V09 - 4.75848265203103142e-10*V01*V02*V06*V09 + 1.53293911446729409e-10*V05*V06*V09 - 
      8.93781990681032949e-11*V012*V07*V09 + 1.04748497532374607e-10*V04*V07*V09 + 
      5.96375848728657949e-11*V03*V08*V09 + 8.00285623282956963e-12*V02*V092 + 
      7.68511840475348101e-11*V012*V022*V10 + 4.10332186271728755e-11*V013*V03*V10 - 
      4.99307533109571225e-10*V02*V032*V10 - 1.79761814709409732e-10*V022*V04*V10 - 
      5.90560875518700023e-10*V01*V03*V04*V10 - 3.03615680992265154e-10*V01*V02*V05*V10 + 
      4.95593811626264585e-11*V052*V10 - 6.1010472062228291e-11*V012*V06*V10 + 
      6.60909927939994441e-11*V04*V06*V10 + 4.90642617367695468e-11*V03*V07*V10 + 1.30867700317987669e-11*V02*V08*V10 + 
      4.56632279958408988e-12*V01*V09*V10 + 8.75768934728629718e-12*V013*V02*V11 - 
      1.01397055520901697e-10*V022*V03*V11 - 1.18628329061350954e-10*V01*V032*V11 - 
      1.24778071200457163e-10*V01*V02*V04*V11 - 3.4528579333517025e-11*V012*V05*V11 + 
      4.27939492219946726e-11*V04*V05*V11 + 3.09900829324836135e-11*V03*V06*V11 + 1.08063045332860666e-11*V02*V07*V11 + 
      3.74521866042146181e-12*V01*V08*V11 - 2.71163685054242072e-14*V112 + 2.9520301170627968e-13*V014*V12 - 
      4.5881009438459709e-12*V023*V12 - 4.77907041094267739e-11*V01*V02*V03*V12 - 
      1.3647553369765354e-11*V012*V04*V12 + 7.75800666716767563e-12*V042*V12 + 
      1.69422051777957712e-11*V03*V05*V12 + 5.72886205574953589e-12*V02*V06*V12 + 2.60664012717587559e-12*V01*V07*V12 - 
      4.85079215546758719e-14*V10*V12 - 4.17427416553090214e-12*V01*V022*V13 - 
      4.44746642636434518e-12*V012*V03*V13 + 6.23590467228488958e-12*V03*V04*V13 + 
      3.18383353458829799e-12*V02*V05*V13 + 1.40300965206493938e-12*V01*V06*V13 - 3.92968703471378353e-14*V09*V13 - 
      8.00155531730179133e-13*V012*V02*V14 + 1.06004577715517818e-12*V032*V14 + 
      9.83467477094655061e-13*V02*V04*V14 + 6.59268229714719714e-13*V01*V05*V14 - 2.50933103808588833e-14*V08*V14 - 
      3.88425015402999579e-14*V013*V15 + 3.49335894805300891e-13*V02*V03*V15 + 2.12560965571965293e-13*V01*V04*V15 - 
      1.46526903520153798e-14*V07*V15 + 2.35521199815787046e-14*V022*V16 + 6.23329667575289801e-14*V01*V03*V16 - 
      6.38931003597687713e-15*V06*V16 + 9.24821465245237093e-15*V01*V02*V17 - 2.61613898184861906e-15*V05*V17 + 
      6.9361609893392782e-16*V012*V18 - 7.01658024718669012e-16*V04*V18 - 1.8848263557987169e-16*V03*V19 - 
      2.34556168721618103e-17*V02*V20 - 3.51834253082427155e-18*V01*V21 + 5.02620361546324507e-21*V24) + 
   eps12*(4.38492191964414187e-7*V012*V025 + 1.56443190297356964e-6*V013*V023*V03 + 
      6.26423152464819131e-7*V014*V02*V032 - 6.15952990446624706e-7*V024*V032 - 
      2.13342389991695547e-6*V01*V022*V033 - 4.02632490461111493e-7*V012*V034 + 
      4.3106488418988419e-7*V014*V022*V04 - 1.43889032777921667e-7*V025*V04 + 
      9.17774355274355274e-8*V015*V03*V04 - 3.11017509368203813e-6*V01*V023*V03*V04 - 
      3.63782652349120603e-6*V012*V02*V032*V04 + 1.63667367473803243e-7*V034*V04 - 
      1.39086131227128251e-6*V012*V022*V042 - 6.47181474004390671e-7*V013*V03*V042 + 
      6.94893262950216634e-7*V02*V032*V042 + 1.51283642180000723e-7*V022*V043 + 
      2.90338231387046747e-7*V01*V03*V043 + 4.81771315104648438e-8*V015*V02*V05 - 
      4.63494115837865838e-7*V01*V024*V05 - 2.22791129909185465e-6*V012*V022*V03*V05 - 
      5.21445756440796123e-7*V013*V032*V05 + 3.96565639823316158e-7*V02*V033*V05 - 
      7.97474910818164786e-7*V013*V02*V04*V05 + 8.3079202034726953e-7*V022*V03*V04*V05 + 
      7.30771143336125926e-7*V01*V032*V04*V05 + 5.27975212689593233e-7*V01*V02*V042*V05 - 
      3.96192383729586111e-8*V014*V052 + 8.21761150132950242e-8*V023*V052 + 
      4.45765187284624921e-7*V01*V02*V03*V052 + 1.3232200882651688e-7*V012*V04*V052 - 
      2.37469976794500349e-8*V042*V052 - 1.36096627499663723e-8*V03*V053 + 
      1.80664243164243164e-9*V016*V06 - 3.92472994469522247e-7*V012*V023*V06 - 
      5.43036567342122898e-7*V013*V02*V03*V06 + 2.9825624725585578e-7*V022*V032*V06 + 
      1.71632696794454206e-7*V01*V033*V06 - 6.66349950204116871e-8*V014*V04*V06 + 
      1.29177689090543121e-7*V023*V04*V06 + 7.4981900942536933e-7*V01*V02*V03*V04*V06 + 
      1.1252040651039834e-7*V012*V042*V06 - 1.29392157703847877e-8*V043*V06 + 
      2.26994879836485229e-7*V01*V022*V05*V06 + 1.8517650554189128e-7*V012*V03*V05*V06 - 
      6.81809509230165907e-8*V03*V04*V05*V06 - 2.05992629199890677e-8*V02*V052*V06 + 
      4.8446145797846895e-8*V012*V02*V062 - 1.22055305562127859e-8*V032*V062 - 
      1.68156090978436291e-8*V02*V04*V062 - 9.37819813764003117e-9*V01*V05*V062 - 
      1.2330334595959596e-7*V013*V022*V07 - 3.92944728882228882e-8*V014*V03*V07 + 
      8.66334246474497019e-8*V023*V03*V07 + 2.31846393732372082e-7*V01*V02*V032*V07 + 
      1.6665107427975075e-7*V01*V022*V04*V07 + 1.36708868964792167e-7*V012*V03*V04*V07 - 
      2.50571343461910233e-8*V03*V042*V07 + 8.40820834182762287e-8*V012*V02*V05*V07 - 
      2.14821947819303148e-8*V032*V05*V07 - 3.02261663079119173e-8*V02*V04*V05*V07 - 
      8.22752243934466367e-9*V01*V052*V07 + 1.09705030084640262e-8*V013*V06*V07 - 
      2.17543301382968463e-8*V02*V03*V06*V07 - 1.38315040954813512e-8*V01*V04*V06*V07 - 
      2.39937340072932961e-9*V022*V072 - 4.31306178988452739e-9*V01*V03*V072 + 
      2.14767307517493529e-10*V06*V072 - 1.5356460668960669e-8*V014*V02*V08 + 
      7.81750055533643043e-9*V024*V08 + 9.19141145218555349e-8*V01*V022*V03*V08 + 
      3.68678479028521823e-8*V012*V032*V08 + 5.52415504398901925e-8*V012*V02*V04*V08 - 
      1.39583195853626023e-8*V032*V04*V08 - 9.5986425764438334e-9*V02*V042*V08 + 
      8.45095936083720086e-9*V013*V05*V08 - 1.6922158316131765e-8*V02*V03*V05*V08 - 
      1.07323878817334722e-8*V01*V04*V05*V08 - 4.15583968693321596e-9*V022*V06*V08 - 
      7.63161126818879759e-9*V01*V03*V06*V08 + 1.88392481149618117e-10*V062*V08 - 
      3.44611396259379405e-9*V01*V02*V07*V08 + 3.34163144371482397e-10*V05*V07*V08 - 
      2.87881903030246724e-10*V012*V082 + 1.07955611905981345e-10*V04*V082 - 
      6.32324851074851075e-10*V015*V09 + 1.08012321958230183e-8*V01*V023*V09 + 
      2.67003744013037314e-8*V012*V02*V03*V09 - 2.32715627508698703e-9*V033*V09 + 
      4.97490875478007831e-9*V013*V04*V09 - 9.88389262871376166e-9*V02*V03*V04*V09 - 
      3.15013205391853196e-9*V01*V042*V09 - 2.97133665297839776e-9*V022*V05*V09 - 
      5.32644539790241181e-9*V01*V03*V05*V09 - 2.74320110204596492e-9*V01*V02*V06*V09 + 2.65885815201741545e-10*V05*V06*V09 - 
      5.17205072695488891e-10*V012*V07*V09 + 1.95841700939319757e-10*V04*V07*V09 + 1.096083942566415e-10*V03*V08*V09 + 
      1.95715989957548972e-11*V02*V092 + 4.40590494971622423e-9*V012*V022*V10 + 
      2.16310006827776436e-9*V013*V03*V10 - 2.25902809958179182e-9*V02*V032*V10 - 
      1.54286144998219302e-9*V022*V04*V10 - 2.84471333483214826e-9*V01*V03*V04*V10 - 
      1.74167770044125429e-9*V01*V02*V05*V10 + 8.46077491142124186e-11*V052*V10 - 
      3.74968030744362659e-10*V012*V06*V10 + 1.40534807154727983e-10*V04*V06*V10 + 
      8.96631141416310435e-11*V03*V07*V10 + 3.53068698438173758e-11*V02*V08*V10 + 1.14933982587741202e-11*V01*V09*V10 + 
      6.56088693517206589e-10*V013*V02*V11 - 6.63592935339787407e-10*V022*V03*V11 - 
      5.86501686136304238e-10*V01*V032*V11 - 8.50965315512898983e-10*V01*V02*V04*V11 - 
      2.17109607466627468e-10*V012*V05*V11 + 8.25656605053924563e-11*V04*V05*V11 + 
      5.93973291009376551e-11*V03*V06*V11 + 2.66550932927223941e-11*V02*V07*V11 + 9.56771272405064299e-12*V01*V08*V11 - 
      4.07749009133190344e-14*V112 + 3.09963162291593664e-11*V014*V12 - 
      5.82036759080676063e-11*V023*V12 - 3.25941413725211455e-10*V01*V02*V03*V12 - 
      9.86366484114377131e-11*V012*V04*V12 + 1.84687031573766897e-11*V042*V12 + 
      3.1993273768693732e-11*V03*V05*V12 + 1.61905904420380971e-11*V02*V06*V12 + 6.62190665544894663e-12*V01*V07*V12 - 
      7.51070723847808455e-14*V10*V12 - 4.17471438054835888e-11*V01*V022*V13 - 
      3.44956371929249896e-11*V012*V03*V13 + 1.34089170629807992e-11*V03*V04*V13 + 
      8.16679779260448407e-12*V02*V05*V13 + 3.76684869312443917e-12*V01*V06*V13 - 5.91460018310722003e-14*V09*V13 - 
      8.42882283424509087e-12*V012*V02*V14 + 2.25096920533364482e-12*V032*V14 + 
      3.16777246847520571e-12*V02*V04*V14 + 1.75706830181942595e-12*V01*V05*V14 - 3.93062525938867e-14*V08*V14 - 
      4.8941551940777947e-13*V013*V15 + 1.01138475439219129e-12*V02*V03*V15 + 6.48114882843862155e-13*V01*V04*V15 - 
      2.21797318383885171e-14*V07*V15 + 1.05207689886298172e-13*V022*V16 + 1.90772171850787508e-13*V01*V03*V16 - 
      1.03716716845807155e-14*V06*V16 + 3.87037783205131723e-14*V01*V02*V17 - 4.05901125373965282e-15*V05*V17 + 
      3.12127244520267519e-15*V012*V18 - 1.25755614458890392e-15*V04*V18 - 3.20420480485781873e-16*V03*V19 - 
      5.52882397700956958e-17*V02*V20 - 8.29323596551435437e-18*V01*V21 + 7.53930542319486761e-21*V24) + 
   delta6*eps9*(7.65183075086203004e-8*V034*V04 + 
      2.36200532725392669e-7*V02*V032*V042 + 2.10474956623416007e-8*V022*V043 + 
      9.48188609885232979e-8*V01*V03*V043 + 1.57752553415679777e-7*V02*V033*V05 + 
      2.30720518966025502e-7*V022*V03*V04*V05 + 2.68114688535634692e-7*V01*V032*V04*V05 + 
      1.41720319635235602e-7*V01*V02*V042*V05 + 1.84747491222164425e-8*V023*V052 + 
      1.39170980163627222e-7*V01*V02*V03*V052 + 3.83673161377993311e-8*V012*V04*V052 - 
      2.2023741600738457e-8*V042*V052 - 1.42734771738816095e-8*V03*V053 + 
      8.35556661619725734e-8*V022*V032*V06 + 6.10311140773325647e-8*V01*V033*V06 + 
      1.45381579205108617e-8*V023*V04*V06 + 2.02131518633813996e-7*V01*V02*V03*V04*V06 + 
      2.94928838394835905e-8*V012*V042*V06 - 9.41028310842586455e-9*V043*V06 + 
      5.01333996971835441e-8*V01*V022*V05*V06 + 5.18720048632708141e-8*V012*V03*V05*V06 - 
      6.38881832797249232e-8*V03*V04*V05*V06 - 1.63995054407892911e-8*V02*V052*V06 + 
      1.04752648131110627e-8*V012*V02*V062 - 1.14954440383213866e-8*V032*V062 - 
      1.0373940513735223e-8*V02*V04*V062 - 7.1995374382365363e-9*V01*V05*V062 + 
      1.75949991640156595e-8*V023*V03*V07 + 6.49355534538774501e-8*V01*V02*V032*V07 + 
      3.29600741380036431e-8*V01*V022*V04*V07 + 3.5490127012847212e-8*V012*V03*V04*V07 - 
      2.19073568194984549e-8*V03*V042*V07 + 1.86392868465697597e-8*V012*V02*V05*V07 - 
      2.1179389152059458e-8*V032*V05*V07 - 2.23122299449632283e-8*V02*V04*V05*V07 - 
      6.59696094049781919e-9*V01*V052*V07 + 2.17904805955303932e-9*V013*V06*V07 - 
      1.62855136239927535e-8*V02*V03*V06*V07 - 9.93213689609712688e-9*V01*V04*V06*V07 - 
      1.39055312077097546e-9*V022*V072 - 3.23282820827403963e-9*V01*V03*V072 + 
      2.70691673066425051e-10*V06*V072 + 6.3274781919956039e-10*V024*V08 + 
      1.84578803786903694e-8*V01*V022*V03*V08 + 9.01661706319217472e-9*V012*V032*V08 + 
      1.08198370142036497e-8*V012*V02*V04*V08 - 1.23996749144077e-8*V032*V04*V08 - 
      5.5206283010412297e-9*V02*V042*V08 + 1.63325049124276223e-9*V013*V05*V08 - 
      1.28086576834036954e-8*V02*V03*V05*V08 - 7.75394468687961361e-9*V01*V04*V05*V08 - 
      2.01580544695901625e-9*V022*V06*V08 - 5.50766241918738492e-9*V01*V03*V06*V08 + 
      2.20755502650434519e-10*V062*V08 - 1.97947906813119159e-9*V01*V02*V07*V08 + 4.2591718923221259e-10*V05*V07*V08 - 
      1.583082256110483e-10*V012*V082 + 1.20675045280608754e-10*V04*V082 + 
      1.46624993033463829e-9*V01*V023*V09 + 4.95485603591345888e-9*V012*V02*V03*V09 - 
      2.10097487807609381e-9*V033*V09 + 8.58787732912382772e-10*V013*V04*V09 - 
      6.70950969054189387e-9*V02*V03*V04*V09 - 2.05870427299032854e-9*V01*V042*V09 - 
      1.68483925214565814e-9*V022*V05*V09 - 3.89132664126299495e-9*V01*V03*V05*V09 - 
      1.52386038876203899e-9*V01*V02*V06*V09 + 3.32066820728828843e-10*V05*V06*V09 - 
      2.85511375988624393e-10*V012*V07*V09 + 2.30855487854577695e-10*V04*V07*V09 + 
      1.32285455360861002e-10*V03*V08*V09 + 1.86224886360941026e-11*V02*V092 + 
      6.04575767974460785e-10*V012*V022*V10 + 3.40073869485634192e-10*V013*V03*V10 - 
      1.57213310981915158e-9*V02*V032*V10 - 6.71181261929988321e-10*V022*V04*V10 - 
      1.87883873030537691e-9*V01*V03*V04*V10 - 9.79242152784242622e-10*V01*V02*V05*V10 + 
      1.07336839085989354e-10*V052*V10 - 2.00661102814361779e-10*V012*V06*V10 + 
      1.54495629503149789e-10*V04*V06*V10 + 1.08715403184487502e-10*V03*V07*V10 + 3.19419553321709642e-11*V02*V08*V10 + 
      1.07962929205513937e-11*V01*V09*V10 + 7.75399910748494626e-11*V013*V02*V11 - 
      3.40440197433494265e-10*V022*V03*V11 - 3.83107217992122246e-10*V01*V032*V11 - 
      4.21791587392818139e-10*V01*V02*V04*V11 - 1.14751107550456822e-10*V012*V05*V11 + 
      9.62065320400714134e-11*V04*V05*V11 + 7.0053450335113439e-11*V03*V06*V11 + 2.5310464537020169e-11*V02*V07*V11 + 
      8.92101281804860605e-12*V01*V08*V11 - 5.43372820460500498e-14*V112 + 2.9520301170627968e-12*V014*V12 - 
      1.849485094293739e-11*V023*V12 - 1.63911361271335963e-10*V01*V02*V03*V12 - 
      4.73197850193238992e-11*V012*V04*V12 + 1.88537309952640217e-11*V042*V12 + 
      3.82877627980636899e-11*V03*V05*V12 + 1.42638050703933002e-11*V02*V06*V12 + 6.20117454352671344e-12*V01*V07*V12 - 
      9.861716111939824e-14*V10*V12 - 1.52801222059334661e-11*V01*V022*V13 - 
      1.59005664305371908e-11*V012*V03*V13 + 1.46902340825414441e-11*V03*V04*V13 + 
      7.63906846126070317e-12*V02*V05*V13 + 3.41839908555666496e-12*V01*V06*V13 - 7.88028307646789415e-14*V09*V13 - 
      3.00382011911653008e-12*V012*V02*V14 + 2.51465121876614934e-12*V032*V14 + 
      2.55827813001998466e-12*V02*V04*V14 + 1.60913386023879783e-12*V01*V05*V14 - 5.13051632836443249e-14*V08*V14 - 
      1.55370006161199832e-13*V013*V15 + 8.81293201614361267e-13*V02*V03*V15 + 5.4133499646664708e-13*V01*V04*V15 - 
      2.95144707744340306e-14*V07*V15 + 6.57733026082412621e-14*V022*V16 + 1.60419531361438826e-13*V01*V03*V16 - 
      1.32723943151368635e-14*V06*V16 + 2.52476260011949726e-14*V01*V02*V17 - 5.35350999490221159e-15*V05*V17 + 
      1.9421250770149979e-15*V012*V18 - 1.50866527721744764e-15*V04*V18 - 4.01091048513966957e-16*V03*V19 - 
      5.36128385649412808e-17*V02*V20 - 8.04192578474119211e-18*V01*V21 + 1.00524072309264901e-20*V24) + 
   delta2*eps11*(-5.19942132872027052e-7*V024*V032 - 
      2.12909656114021193e-6*V01*V022*V033 - 4.30973118225102352e-7*V012*V034 - 
      6.80612866459427306e-8*V025*V04 - 2.60643787429501715e-6*V01*V023*V03*V04 - 
      3.48396023619237905e-6*V012*V02*V032*V04 + 2.92634394072278254e-7*V034*V04 - 
      1.17616437060881505e-6*V012*V022*V042 - 5.9607155961322628e-7*V013*V03*V042 + 
      1.1082481523457393e-6*V02*V032*V042 + 1.95584655809718057e-7*V022*V043 + 
      4.54467079326658575e-7*V01*V03*V043 - 3.11965279723216231e-7*V01*V024*V05 - 
      1.86285023214586707e-6*V012*V022*V03*V05 - 4.72547688569513966e-7*V013*V032*V05 + 
      6.54479977676270082e-7*V02*V033*V05 - 6.53448229093070363e-7*V013*V02*V04*V05 + 
      1.19518228764965654e-6*V022*V03*V04*V05 + 1.16986246668154153e-6*V01*V032*V04*V05 + 
      7.49205341404634316e-7*V01*V02*V042*V05 - 3.07473335747145271e-8*V014*V052 + 
      1.0472435081384564e-7*V023*V052 + 6.53677756463315131e-7*V01*V02*V03*V052 + 
      1.8926780842484624e-7*V012*V04*V052 - 4.49111369355517819e-8*V042*V052 - 
      2.66308862018481758e-8*V03*V053 - 2.7752321899147296e-7*V012*V023*V06 - 
      4.30835469277929595e-7*V013*V02*V03*V06 + 4.35860386828621345e-7*V022*V032*V06 + 
      2.74950060854005765e-7*V01*V033*V06 - 5.11709961114723019e-8*V014*V04*V06 + 
      1.49373083789906074e-7*V023*V04*V06 + 1.07553785650458347e-6*V01*V02*V03*V04*V06 + 
      1.58959003141207273e-7*V012*V042*V06 - 2.34589188319894784e-8*V043*V06 + 
      2.91743367359030291e-7*V01*V022*V05*V06 + 2.64325940625106125e-7*V012*V03*V05*V06 - 
      1.30477649586021645e-7*V03*V04*V05*V06 - 3.63982154243717568e-8*V02*V052*V06 + 
      6.21909667103265376e-8*V012*V02*V062 - 2.35866641208131788e-8*V032*V062 - 
      2.83830922891645865e-8*V02*V04*V062 - 1.64809807039780169e-8*V01*V05*V062 - 
      8.3627470780248558e-8*V013*V022*V07 - 2.86653932487265821e-8*V014*V03*V07 + 
      1.09769440570337318e-7*V023*V03*V07 + 3.35492824806258513e-7*V01*V02*V032*V07 + 
      2.09044847038933562e-7*V01*V022*V04*V07 + 1.92355750008498608e-7*V012*V03*V04*V07 - 
      4.72618338936615608e-8*V03*V042*V07 + 1.07650164092011664e-7*V012*V02*V05*V07 - 
      4.18304532027872241e-8*V032*V05*V07 - 5.2495110872022949e-8*V02*V04*V05*V07 - 
      1.45549356985976133e-8*V01*V052*V07 + 1.36847681855268223e-8*V013*V06*V07 - 
      3.83220680268478737e-8*V02*V03*V06*V07 - 2.39667134245575088e-8*V01*V04*V06*V07 - 
      3.78370234356419949e-9*V022*V072 - 7.57514185448521646e-9*V01*V03*V072 + 
      4.26147160475657499e-10*V06*V072 - 9.63542630209296876e-9*V014*V02*V08 + 
      7.72535223236800164e-9*V024*V08 + 1.17120217666946775e-7*V01*V022*V03*V08 + 
      5.1466665825082803e-8*V012*V032*V08 + 6.95025549042676727e-8*V012*V02*V04*V08 - 
      2.66734083953653464e-8*V032*V04*V08 - 1.59763800882102491e-8*V02*V042*V08 + 
      1.04776967236360716e-8*V013*V05*V08 - 2.9909484601287233e-8*V02*V03*V05*V08 - 
      1.86295937434687129e-8*V01*V04*V05*V08 - 6.38461798617259437e-9*V022*V06*V08 - 
      1.33424917612395601e-8*V01*V03*V06*V08 + 3.69473760663051925e-10*V062*V08 - 
      5.46385122184290841e-9*V01*V02*V07*V08 + 6.65193360464561812e-10*V05*V07*V08 - 
      4.51929472006984006e-10*V012*V082 + 2.09622080250661849e-10*V04*V082 - 
      3.61328486328486328e-10*V015*V09 + 1.16554442820539537e-8*V01*V023*V09 + 
      3.32813562272012319e-8*V012*V02*V03*V09 - 4.49623559158400142e-9*V033*V09 + 
      6.05996959616532446e-9*V013*V04*V09 - 1.71008894358145883e-8*V02*V03*V04*V09 - 
      5.36744415768178965e-9*V01*V042*V09 - 4.68188403056017865e-9*V022*V05*V09 - 
      9.32814612085776875e-9*V01*V03*V05*V09 - 4.32938137442453789e-9*V01*V02*V06*V09 + 5.27480366322598665e-10*V05*V06*V09 - 
      8.11379645939557258e-10*V012*V07*V09 + 3.83426984261945439e-10*V04*V07*V09 + 2.1768055216367305e-10*V03*V08*V09 + 
      3.5427496549520743e-11*V02*V092 + 4.80738104563676459e-9*V012*V022*V10 + 
      2.57712229219582161e-9*V013*V03*V10 - 3.97089667710882205e-9*V02*V032*V10 - 
      2.32086891334837589e-9*V022*V04*V10 - 4.89421578838019756e-9*V01*V03*V04*V10 - 
      2.7556254125600797e-9*V01*V02*V05*V10 + 1.68525837843121799e-10*V052*V10 - 
      5.86367513038126459e-10*V012*V06*V10 + 2.72167713347360047e-10*V04*V06*V10 + 
      1.78212007585668558e-10*V03*V07*V10 + 6.34254219220624266e-11*V02*V08*V10 + 2.07887313037605561e-11*V01*V09*V10 + 
      6.93727077509757248e-10*V013*V02*V11 - 1.04023300630045484e-9*V022*V03*V11 - 
      1.01343227212338563e-9*V01*V032*V11 - 1.31535377883894447e-9*V01*V02*V04*V11 - 
      3.38479662243844452e-10*V012*V05*V11 + 1.61601702895817855e-10*V04*V05*V11 + 
      1.17549811516796611e-10*V03*V06*V11 + 4.82422574380474134e-11*V02*V07*V11 + 1.72881408123471871e-11*V01*V08*V11 - 
      8.15490478960957494e-14*V112 + 3.09963162291593664e-11*V014*V12 - 
      7.7737976854129163e-11*V023*V12 - 5.09456252588209318e-10*V01*V02*V03*V12 - 
      1.51223846568212385e-10*V012*V04*V12 + 3.5268177555702946e-11*V042*V12 + 
      6.35409685554323088e-11*V03*V05*V12 + 2.89625228485092606e-11*V02*V06*V12 + 1.19713052157937093e-11*V01*V07*V12 - 
      1.49876201115561999e-13*V10*V12 - 5.76407185857435255e-11*V01*V022*V13 - 
      5.26657709884619069e-11*V012*V03*V13 + 2.61749907254696341e-11*V03*V04*V13 + 
      1.47714796482632382e-11*V02*V05*V13 + 6.77909855989667958e-12*V01*V06*V13 - 1.18290495801059762e-13*V09*V13 - 
      1.15828339593174474e-11*V012*V02*V14 + 4.4488998996354753e-12*V032*V14 + 
      5.57193834952672406e-12*V02*V04*V14 + 3.16827187206643814e-12*V01*V05*V14 - 7.8365081937796196e-14*V08*V14 - 
      6.52554025877039293e-13*V013*V15 + 1.82291559014488683e-12*V02*V03*V15 + 1.14846179197084033e-12*V01*V04*V15 - 
      4.43579558156923953e-14*V07*V15 + 1.68539463826292008e-13*V022*V16 + 3.40815206372174774e-13*V01*V03*V16 - 
      2.06130641714486236e-14*V06*V16 + 6.27028953436270749e-14*V01*V02*V17 - 8.11651464639466667e-15*V05*V17 + 
      4.9940359123242803e-15*V012*V18 - 2.46806702333707186e-15*V04*V18 - 6.39333099886924773e-16*V03*V19 - 
      1.00524072309264901e-16*V02*V20 - 1.50786108463897352e-17*V01*V21 + 1.50786108463897352e-20*V24) + 
   delta4*eps10*(-1.17745291769762669e-7*V024*V032 - 
      5.79433243123719314e-7*V01*V022*V033 - 1.24555091072948216e-7*V012*V034 - 
      1.48202033122668043e-9*V025*V04 - 5.98870803897258924e-7*V01*V023*V03*V04 - 
      9.19068255377779187e-7*V012*V02*V032*V04 + 2.14311482438524922e-7*V034*V04 - 
      2.78216052025575835e-7*V012*V022*V042 - 1.52528798362131695e-7*V013*V03*V042 + 
      7.28419279216334149e-7*V02*V032*V042 + 9.77137892841674354e-8*V022*V043 + 
      2.94835574485628952e-7*V01*V03*V043 - 7.06471750618576015e-8*V01*V024*V05 - 
      4.70752516883469264e-7*V012*V022*V03*V05 - 1.22944598391026962e-7*V013*V032*V05 + 
      4.53829576895904121e-7*V02*V033*V05 - 1.57814517933565553e-7*V013*V02*V04*V05 + 
      7.3417265658745584e-7*V022*V03*V04*V05 + 7.89349551944867849e-7*V01*V032*V04*V05 + 
      4.54844988100998839e-7*V01*V02*V042*V05 - 7.17495137137994281e-9*V014*V052 + 
      6.06452340719542971e-8*V023*V052 + 4.1961331835354361e-7*V01*V02*V03*V052 + 
      1.18468274871461146e-7*V012*V04*V052 - 4.026399605523601e-8*V042*V052 - 
      2.49344252732416599e-8*V03*V053 - 6.40105840171977738e-8*V012*V023*V06 - 
      1.01929045381426334e-7*V013*V02*V03*V06 + 2.68121481016361191e-7*V022*V032*V06 + 
      1.83131423420507804e-7*V01*V033*V06 - 1.15108932073217788e-8*V014*V04*V06 + 
      6.94660406346006512e-8*V023*V04*V06 + 6.53241508264072845e-7*V01*V02*V03*V04*V06 + 
      9.57025503606288698e-8*V012*V042*V06 - 1.94107261144450045e-8*V043*V06 + 
      1.67111827140421912e-7*V01*V022*V05*V06 + 1.63286817054226796e-7*V012*V03*V05*V06 - 
      1.17292675685637981e-7*V03*V04*V05*V06 - 3.1097029829286499e-8*V02*V052*V06 + 
      3.52784186586804856e-8*V012*V02*V062 - 2.12175240295383638e-8*V032*V062 - 
      2.22496709765014992e-8*V02*V04*V062 - 1.3892605532982901e-8*V01*V05*V062 - 
      1.7584653001319668e-8*V013*V022*V07 - 6.08236285319618653e-9*V014*V03*V07 + 
      6.00239001444391008e-8*V023*V03*V07 + 2.05120027408751926e-7*V01*V02*V032*V07 + 
      1.13262007082035093e-7*V01*V022*V04*V07 + 1.1481891901160303e-7*V012*V03*V04*V07 - 
      4.13685034628376481e-8*V03*V042*V07 + 6.13554156716213205e-8*V012*V02*V05*V07 - 
      3.81989797524358541e-8*V032*V05*V07 - 4.35034561212444647e-8*V02*V04*V05*V07 - 
      1.24465574767207969e-8*V01*V052*V07 + 7.51825841670807435e-9*V013*V06*V07 - 
      3.18774024187369472e-8*V02*V03*V06*V07 - 1.9667871997796414e-8*V01*V04*V06*V07 - 
      2.88384332637313435e-9*V022*V072 - 6.2963852833022967e-9*V01*V03*V072 + 
      4.1939913591699306e-10*V06*V072 - 1.80664243164243164e-9*V014*V02*V08 + 
      3.19339934526286845e-9*V024*V08 + 6.40864146422619812e-8*V01*V022*V03*V08 + 
      3.00955337592388246e-8*V012*V032*V08 + 3.77117630268890773e-8*V012*V02*V04*V08 - 
      2.34923487086251406e-8*V032*V04*V08 - 1.21932300356941412e-8*V02*V042*V08 + 
      5.71217827651651181e-9*V013*V05*V08 - 2.5025281349342178e-8*V02*V03*V05*V08 - 
      1.53470257143579543e-8*V01*V04*V05*V08 - 4.61685998131022047e-9*V022*V06*V08 - 
      1.09728674070220722e-8*V01*V03*V06*V08 + 3.55652899273829005e-10*V062*V08 - 
      4.15881740242510684e-9*V01*V02*V07*V08 + 6.57949166107055085e-10*V05*V07*V08 - 
      3.39306748576642572e-10*V012*V082 + 1.98294607994327916e-10*V04*V082 - 
      6.02214143880810547e-11*V015*V09 + 5.56862526910962952e-9*V01*V023*V09 + 
      1.77171569817169724e-8*V012*V02*V03*V09 - 3.97927241519096207e-9*V033*V09 + 
      3.15622625744591197e-9*V013*V04*V09 - 1.37407137803524885e-8*V02*V03*V04*V09 - 
      4.2604639747773317e-9*V01*V042*V09 - 3.55753189027397834e-9*V022*V05*V09 - 
      7.70861279121372267e-9*V01*V03*V05*V09 - 3.26262256487220193e-9*V01*V02*V06*V09 + 5.18422609402698898e-10*V05*V06*V09 - 
      6.09370338393160972e-10*V012*V07*V09 + 3.68525742913893642e-10*V04*V07*V09 + 
      2.10984752273151009e-10*V03*V08*V09 + 3.17026393750257638e-11*V02*V092 + 
      2.31409640876552641e-9*V012*V022*V10 + 1.29948365753104315e-9*V013*V03*V10 - 
      3.22012106269394711e-9*V02*V032*V10 - 1.61126775629484608e-9*V022*V04*V10 - 
      3.90065748563062876e-9*V01*V03*V04*V10 - 2.08963724511459505e-9*V01*V02*V05*V10 + 
      1.66708646337348923e-10*V052*V10 - 4.36754705462371277e-10*V012*V06*V10 + 
      2.56156280440564972e-10*V04*V06*V10 + 1.72991833207666797e-10*V03*V07*V10 + 5.59156137952565482e-11*V02*V08*V10 + 
      1.85371567607405689e-11*V01*V09*V10 + 3.18819252642782055e-10*V013*V02*V11 - 
      7.60905183923706026e-10*V022*V03*V11 - 8.04406011184446243e-10*V01*V032*V11 - 
      9.51332212403664011e-10*V01*V02*V04*V11 - 2.51421963541570156e-10*V012*V05*V11 + 
      1.55046124435856297e-10*V04*V05*V11 + 1.13147716831517197e-10*V03*V06*V11 + 4.31537972541215944e-11*V02*V07*V11 + 
      1.53827773885756874e-11*V01*V08*V11 - 8.15425138313956472e-14*V112 + 1.32841355267825856e-11*V014*V12 - 
      4.86248930710779778e-11*V023*V12 - 3.70489767763205647e-10*V01*V02*V03*V12 - 
      1.0830510193769752e-10*V012*V04*V12 + 3.23502918471370033e-11*V042*V12 + 
      6.15313315114544086e-11*V03*V05*V12 + 2.53281964472471377e-11*V02*V06*V12 + 1.06661509229663684e-11*V01*V07*V12 - 
      1.4921036621479354e-13*V10*V12 - 3.77044162451691691e-11*V01*V022*V13 - 
      3.72150007257613897e-11*V012*V03*V13 + 2.45643216615985292e-11*V03*V04*V13 + 
      1.31821739602392982e-11*V02*V05*V13 + 5.98357638370737909e-12*V01*V06*V13 - 1.18277427671659557e-13*V09*V13 - 
      7.51602404804804186e-12*V012*V02*V14 + 4.20331355953960259e-12*V032*V14 + 
      4.72524580166540459e-12*V02*V04*V14 + 2.80845158458347374e-12*V01*V05*V14 - 7.78802878450727144e-14*V08*V14 - 
      4.07846266173149558e-13*V013*V15 + 1.58477406284423828e-12*V02*V03*V15 + 9.84657414046603933e-13*V01*V04*V15 - 
      4.43448876862921908e-14*V07*V15 + 1.31287655206213858e-13*V022*V16 + 2.92872461613861683e-13*V01*V03*V16 - 
      2.03625581832539355e-14*V06*V16 + 4.95241894638824463e-14*V01*V02*V17 - 8.10344651699446223e-15*V05*V17 + 
      3.88425015402999579e-15*V012*V18 - 2.3840288988865264e-15*V04*V18 - 6.26264970486720336e-16*V03*V19 - 
      9.04716650783384113e-17*V02*V20 - 1.35707497617507617e-17*V01*V21 + 1.50786108463897352e-20*V24) + 
   6.4469502843844734e-26*delta24*V24 + 3.86817017063068404e-25*delta22*eps*V24;
}
#endif


#ifdef p14 /* Uses: V00 - V26. */
double Vp(void)
{

   V012 = V01 * V01;
   V013 = V01 * V012;
   V014 = V01 * V013;
   V015 = V01 * V014;
   V016 = V01 * V015;
   V022 = V02 * V02;
   V023 = V02 * V022;
   V024 = V02 * V023;
   V025 = V02 * V024;
   V026 = V02 * V025;
   V027 = V02 * V026;
   V032 = V03 * V03;
   V033 = V03 * V032;
   V034 = V03 * V033;
   V035 = V03 * V034;
   V042 = V04 * V04;
   V043 = V04 * V042;
   V044 = V04 * V043;
   V052 = V05 * V05;
   V053 = V05 * V052;
   V054 = V05 * V053;
   V062 = V06 * V06;
   V063 = V06 * V062;
   V072 = V07 * V07;
   V082 = V08 * V08;
   V092 = V09 * V09;
   V102 = V10 * V10;
   V112 = V11 * V11;
   V122 = V12 * V12;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;
   delta8 = delta2 * delta6;
   delta10 = delta2 * delta8;
   delta12 = delta2 * delta10;
   delta14 = delta2 * delta12;
   delta16 = delta2 * delta14;
   delta18 = delta2 * delta16;
   delta20 = delta2 * delta18;
   delta22 = delta2 * delta20;
   delta24 = delta2 * delta22;
   delta26 = delta2 * delta24;

   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 + 
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) + 
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 + 
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) + 
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 
      0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 + 
   0.000297619047619047619*delta4*eps*V06 + 
   eps4*(0.00416666666666666667*V012*V02 - 0.000570436507936507937*V032 - 
      0.000595238095238095238*V02*V04 - 0.000446428571428571429*V01*V05 + 4.1335978835978836e-6*V08) + 
   delta2*eps3*(-0.000992063492063492063*V032 - 0.000793650793650793651*V02*V04 - 
      0.000595238095238095238*V01*V05 + 8.2671957671957672e-6*V08) + 
   delta4*eps2*(-0.000496031746031746032*V032 - 0.000396825396825396825*V02*V04 - 
      0.000297619047619047619*V01*V05 + 8.2671957671957672e-6*V08) + 2.75573192239858907e-6*delta8*V08 + 
   5.51146384479717813e-6*delta6*eps*V08 + eps5*
    (0.0001763668430335097*V023 + 0.00143849206349206349*V01*V02*V03 + 0.000446428571428571429*V012*V04 - 
      0.0000388558201058201058*V042 - 0.0000785383597883597884*V03*V05 - 0.0000330687830687830688*V02*V06 - 
      0.0000165343915343915344*V01*V07 + 9.39454064454064454e-8*V10) + 
   delta6*eps2*(-0.0000154320987654320988*V042 - 0.0000385802469135802469*V03*V05 - 
      0.0000110229276895943563*V02*V06 - 5.51146384479717813e-6*V01*V07 + 1.25260541927208594e-7*V10) + 
   delta2*eps4*(0.0000661375661375661376*V023 + 0.00119047619047619048*V01*V02*V03 + 
      0.000297619047619047619*V012*V04 - 0.0000644841269841269841*V042 - 0.00014880952380952381*V03*V05 - 
      0.0000496031746031746032*V02*V06 - 0.0000248015873015873016*V01*V07 + 1.87890812890812891e-7*V10) + 
   delta4*eps3*(-0.0000462962962962962963*V042 - 0.000115740740740740741*V03*V05 - 
      0.0000330687830687830688*V02*V06 - 0.0000165343915343915344*V01*V07 + 1.87890812890812891e-7*V10) + 
   2.50521083854417188e-8*delta10*V10 + 6.26302709636042969e-8*delta8*eps*V10 + 
   delta8*eps2*(-7.89141414141414141e-7*V052 - 9.01875901875901876e-7*V04*V06 - 
      7.51563251563251563e-7*V03*V07 - 1.67014055902944792e-7*V02*V08 - 6.26302709636042969e-8*V01*V09 + 
      1.20442828776162109e-9*V12) + eps6*(-0.000421626984126984127*V012*V022 - 
      0.00014880952380952381*V013*V03 + 0.000144675925925925926*V02*V032 + 
      0.0000793650793650793651*V022*V04 + 0.000188492063492063492*V01*V03*V04 + 0.000111607142857142857*V01*V02*V05 - 
      3.33506192881192881e-6*V052 + 0.0000248015873015873016*V012*V06 - 5.11063011063011063e-6*V04*V06 - 
      3.56992544492544493e-6*V03*V07 - 1.25260541927208594e-6*V02*V08 - 4.69727032227032227e-7*V01*V09 + 
      1.80664243164243164e-9*V12) + delta6*eps3*
    (-3.15656565656565657e-6*V052 - 3.6075036075036075e-6*V04*V06 - 3.00625300625300625e-6*V03*V07 - 
      6.68056223611779167e-7*V02*V08 - 2.50521083854417188e-7*V01*V09 + 2.40885657552324219e-9*V12) + 
   delta2*eps5*(0.00020667989417989418*V02*V032 + 0.0000727513227513227513*V022*V04 + 
      0.000243055555555555556*V01*V03*V04 + 0.000124007936507936508*V01*V02*V05 - 6.57617845117845118e-6*V052 + 
      0.0000248015873015873016*V012*V06 - 9.16907166907166907e-6*V04*V06 - 6.95196007696007696e-6*V03*V07 - 
      2.0041686708353375e-6*V02*V08 - 7.51563251563251563e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   delta4*eps4*(0.000082671957671957672*V02*V032 + 0.0000198412698412698413*V022*V04 + 
      0.0000925925925925925926*V01*V03*V04 + 0.0000496031746031746032*V01*V02*V05 - 6.1377665544332211e-6*V052 + 
      8.2671957671957672e-6*V012*V06 - 7.56573673240339907e-6*V04*V06 - 6.0751362834696168e-6*V03*V07 - 
      1.50312650312650313e-6*V02*V08 - 5.63672438672438672e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   1.60590438368216146e-10*delta12*V12 + 4.81771315104648438e-10*delta10*eps*V12 + 
   delta10*eps2*(-1.3627245770102913e-8*V062 - 3.17969067969067969e-8*V05*V07 - 
      1.41319585764030208e-8*V04*V08 - 8.83247411025188803e-9*V03*V09 - 1.60590438368216146e-9*V02*V10 - 
      4.81771315104648438e-10*V01*V11 + 8.0295219184108073e-12*V14) + 
   delta8*eps3*(-6.81362288505145648e-8*V062 - 1.58984533984533985e-7*V05*V07 - 
      7.06597928820151042e-8*V04*V08 - 4.41623705512594401e-8*V03*V09 - 8.0295219184108073e-9*V02*V10 - 
      2.40885657552324219e-9*V01*V11 + 2.00738047960270182e-11*V14) + 
   eps7*(-0.0000132275132275132275*V024 - 0.000203373015873015873*V01*V022*V03 - 
      0.0000777116402116402116*V012*V032 - 0.000124007936507936508*V012*V02*V04 + 
      0.0000224842672759339426*V032*V04 + 0.000013452982202982203*V02*V042 - 
      0.0000165343915343915344*V013*V05 + 0.0000264299743466410133*V02*V03*V05 + 0.0000173485850569183903*V01*V04*V05 + 
      5.71188071188071188e-6*V022*V06 + 0.0000124383718133718134*V01*V03*V06 - 1.95667978406073644e-7*V062 + 
      5.44883357383357383e-6*V01*V02*V07 - 3.61569371986038653e-7*V05*V07 + 9.39454064454064454e-7*V012*V08 - 
      2.24023661523661524e-7*V04*V08 - 1.20442828776162109e-7*V03*V09 - 3.61328486328486328e-8*V02*V10 - 
      1.08398545898545899e-8*V01*V11 + 3.01107071940405274e-11*V14) + 
   delta6*eps4*(6.76406926406926407e-6*V032*V04 + 1.90396023729357063e-6*V02*V042 + 
      7.01459034792368126e-6*V02*V03*V05 + 4.05844155844155844e-6*V01*V04*V05 + 6.51354818021484688e-7*V022*V06 + 
      2.70562770562770563e-6*V01*V03*V06 - 1.88303759732331161e-7*V062 + 1.00208433541766875e-6*V01*V02*V07 - 
      4.20586358086358086e-7*V05*V07 + 1.25260541927208594e-7*V012*V08 - 1.99453324453324453e-7*V04*V08 - 
      1.22048733159844271e-7*V03*V09 - 2.40885657552324219e-8*V02*V10 - 7.22656972656972657e-9*V01*V11 + 
      4.01476095920540365e-11*V14) + delta2*eps6*
    (-1.65343915343915344e-6*V024 - 0.000133928571428571429*V01*V022*V03 - 
      0.0000562169312169312169*V012*V032 - 0.0000744047619047619048*V012*V02*V04 + 
      0.0000395197009780343114*V032*V04 + 0.0000179623617123617124*V02*V042 - 
      8.2671957671957672e-6*V013*V05 + 0.0000417743907327240661*V02*V03*V05 + 0.0000256408329324995992*V01*V04*V05 + 
      6.68891293891293891e-6*V022*V06 + 0.0000185636123136123136*V01*V03*V06 - 3.70998324867372486e-7*V062 + 
      6.95196007696007696e-6*V01*V02*V07 - 7.19525459108792442e-7*V05*V07 + 1.12734487734487734e-6*V012*V08 - 
      4.17213958880625547e-7*V04*V08 - 2.37272372689039356e-7*V03*V09 - 6.02214143880810547e-8*V02*V10 - 
      1.80664243164243164e-8*V01*V11 + 6.02214143880810547e-11*V14) + 
   delta4*eps5*(0.0000263047138047138047*V032*V04 + 9.11896745230078563e-6*V02*V042 + 
      0.0000267431257014590348*V02*V03*V05 + 0.0000157828282828282828*V01*V04*V05 + 3.20666987333654e-6*V022*V06 + 
      0.0000109352453102453102*V01*V03*V06 - 3.36345202416630988e-7*V062 + 3.82044652877986211e-6*V01*V02*V07 - 
      7.00254606504606505e-7*V05*V07 + 5.63672438672438672e-7*V012*V08 - 3.67591513424846758e-7*V04*V08 - 
      2.18001520084853418e-7*V03*V09 - 4.81771315104648438e-8*V02*V10 - 1.44531394531394531e-8*V01*V11 + 
      6.02214143880810547e-11*V14) + 7.64716373181981648e-13*delta14*V14 + 
   2.67650730613693577e-12*delta12*eps*V14 + 
   delta12*eps2*(-3.28063324095070127e-10*V072 - 4.37417765460093502e-10*V06*V08 - 
      3.82740544777581815e-10*V05*V09 - 1.3917837991912066e-10*V04*V10 - 6.95891899595603299e-11*V03*V11 - 
      1.07060292245477431e-11*V02*V12 - 2.67650730613693577e-12*V01*V13 + 3.93604015608372907e-14*V16) + 
   delta10*eps3*(-1.96837994457042076e-9*V072 - 2.62450659276056101e-9*V06*V08 - 
      2.29644326866549089e-9*V05*V09 - 8.35070279514723959e-10*V04*V10 - 4.1753513975736198e-10*V03*V11 - 
      6.42361753472864584e-11*V02*V12 - 1.60590438368216146e-11*V01*V13 + 1.18081204682511872e-13*V16) + 
   delta8*eps4*(5.93542260208926876e-8*V043 + 5.93542260208926876e-7*V03*V04*V05 + 
      1.51757964257964258e-7*V02*V052 + 2.04408686551543694e-7*V032*V06 + 1.2498524403286308e-7*V02*V04*V06 + 
      1.22645211930926217e-7*V01*V05*V06 + 1.44531394531394531e-7*V02*V03*V07 + 8.47917514584181251e-8*V01*V04*V07 - 
      6.52972193150764579e-9*V072 + 1.09201498090386979e-8*V022*V08 + 4.23958757292090625e-8*V01*V03*V08 - 
      9.08483051340194197e-9*V06*V08 + 1.20442828776162109e-8*V01*V02*V09 - 7.72841484647040203e-9*V05*V09 + 
      1.20442828776162109e-9*V012*V10 - 2.9709231098119987e-9*V04*V10 - 1.46538775010997233e-9*V03*V11 - 
      2.40885657552324219e-10*V02*V12 - 6.02214143880810547e-11*V01*V13 + 2.9520301170627968e-13*V16) + 
   eps8*(0.0000427138447971781305*V012*V023 + 0.0000454695767195767196*V013*V02*V03 - 
      0.0000265865500240500241*V022*V032 - 0.0000157201980118646785*V01*V033 + 
      4.1335978835978836e-6*V014*V04 - 0.0000100208433541766875*V023*V04 - 
      0.000068329625621292288*V01*V02*V03*V04 - 0.0000103840989257655924*V012*V042 + 
      8.50711788211788212e-7*V043 - 0.0000202922077922077922*V01*V022*V05 - 
      0.0000166283369408369408*V012*V03*V05 + 4.77122221913888581e-6*V03*V04*V05 + 
      1.40881976819476819e-6*V02*V052 - 8.83086820586820587e-6*V012*V02*V06 + 
      1.726031766954386e-6*V032*V06 + 2.18586528110337634e-6*V02*V04*V06 + 1.33467860402384212e-6*V01*V05*V06 - 
      9.39454064454064454e-7*V013*V07 + 1.49830878997545664e-6*V02*V03*V07 + 9.8088639755306422e-7*V01*V04*V07 - 
      1.13969026729443396e-8*V072 + 2.66580127691238802e-7*V022*V08 + 5.46810442643775977e-7*V01*V03*V08 - 
      1.96493872089110184e-8*V06*V08 + 1.92708526041859375e-7*V01*V02*V09 - 1.41821430883930884e-8*V05*V09 + 
      2.70996364746364746e-8*V012*V10 - 7.34701255534588868e-9*V04*V10 - 3.22184566976233643e-9*V03*V11 - 
      8.43099801433134766e-10*V02*V12 - 2.10774950358283692e-10*V01*V13 + 4.4280451755941952e-13*V16) + 
   delta6*eps5*(3.56125356125356125e-7*V043 + 3.07900047483380817e-6*V03*V04*V05 + 
      7.79024216524216524e-7*V02*V052 + 1.07882362346648061e-6*V032*V06 + 7.57069209450161831e-7*V02*V04*V06 + 
      6.47294174079888366e-7*V01*V05*V06 + 7.41927825261158594e-7*V02*V03*V07 + 4.39857210690544024e-7*V01*V04*V07 - 
      1.45735822819156152e-8*V072 + 6.83044664526146008e-8*V022*V08 + 2.31410821688599466e-7*V01*V03*V08 - 
      2.17026506709046392e-8*V06*V08 + 6.18273187717632162e-8*V01*V02*V09 - 1.76649482205037761e-8*V05*V09 + 
      7.22656972656972657e-9*V012*V10 - 7.38716016493794272e-9*V04*V10 - 3.57313725369280925e-9*V03*V11 - 
      6.42361753472864584e-10*V02*V12 - 1.60590438368216146e-10*V01*V13 + 5.9040602341255936e-13*V16) + 
   delta2*eps7*(-0.0000311898749398749399*V022*V032 - 
      0.0000202922077922077922*V01*V033 - 6.91438191438191438e-6*V023*V04 - 
      0.0000756072631072631073*V01*V02*V03*V04 - 0.0000108976671476671477*V012*V042 + 
      1.41486599819933153e-6*V043 - 0.0000187139249639249639*V01*V022*V05 - 
      0.0000174362674362674363*V012*V03*V05 + 8.83134997718331052e-6*V03*V04*V05 + 
      2.36067944401277735e-6*V02*V052 - 7.89141414141414141e-6*V012*V02*V06 + 
      3.2333737690880548e-6*V032*V06 + 3.3093559879274165e-6*V02*V04*V06 + 2.16549323692180835e-6*V01*V05*V06 - 
      7.51563251563251563e-7*V013*V07 + 2.48834884251550918e-6*V02*V03*V07 + 1.55419426252759586e-6*V01*V04*V07 - 
      2.27636946386946387e-8*V072 + 3.52656602656602657e-7*V022*V08 + 8.77305564805564806e-7*V01*V03*V08 - 
      3.81287583668536049e-8*V06*V08 + 2.67383079883079883e-7*V01*V02*V09 - 2.83040647623980957e-8*V05*V09 + 
      3.61328486328486328e-8*V012*V10 - 1.39713681380348047e-8*V04*V10 - 6.3834699251365918e-9*V03*V11 - 
      1.44531394531394531e-9*V02*V12 - 3.61328486328486328e-10*V01*V13 + 8.8560903511883904e-13*V16) + 
   delta4*eps6*(-0.0000102087341670675004*V022*V032 - 7.13985088985088985e-6*V01*V033 - 
      9.01875901875901876e-7*V023*V04 - 0.0000239999198332531666*V01*V02*V03*V04 - 
      3.34445646945646946e-6*V012*V042 + 9.90714532381199048e-7*V043 - 
      6.12524050024050024e-6*V01*V022*V05 - 5.59914622414622415e-6*V012*V03*V05 + 
      7.18272853689520356e-6*V03*V04*V05 + 1.84751269820714265e-6*V02*V052 - 
      2.31732002565335899e-6*V012*V02*V06 + 2.5855634114562686e-6*V032*V06 + 
      2.17219215235088251e-6*V02*V04*V06 + 1.60770529074100503e-6*V01*V05*V06 - 1.87890812890812891e-7*V013*V07 + 
      1.8291250930139819e-6*V02*V03*V07 + 1.10662871079537746e-6*V01*V04*V07 - 2.25830303955303955e-8*V072 + 
      2.09088750755417422e-7*V022*V08 + 6.12813112813112813e-7*V01*V03*V08 - 3.60296119224690653e-8*V06*V08 + 
      1.69824388574388574e-7*V01*V02*V09 - 2.79427362760696094e-8*V05*V09 + 2.16797091797091797e-8*V012*V10 - 
      1.27669398502731836e-8*V04*V10 - 6.02214143880810547e-9*V03*V11 - 1.20442828776162109e-9*V02*V12 - 
      3.01107071940405274e-10*V01*V13 + 8.8560903511883904e-13*V16) + 2.81145725434552076e-15*delta16*V16 + 
   1.12458290173820831e-14*delta14*eps*V16 + 
   delta14*eps2*(-3.57367455441252861e-12*V082 - 8.04076774742818938e-12*V07*V09 - 
      4.38587331677901239e-12*V06*V10 - 3.07011132174530867e-12*V05*V11 - 9.44649637460094976e-13*V04*V12 - 
      3.93604015608372907e-13*V03*V13 - 5.24805354144497209e-14*V02*V14 - 1.12458290173820831e-14*V01*V15 + 
      1.47971434439237935e-16*V18) + delta12*eps3*
    (-2.50157218808877003e-11*V082 - 5.62853742319973257e-11*V07*V09 - 3.07011132174530867e-11*V06*V10 - 
      2.14907792522171607e-11*V05*V11 - 6.61254746222066484e-12*V04*V12 - 2.75522810925861035e-12*V03*V13 - 
      3.67363747901148046e-13*V02*V14 - 7.87208031216745814e-14*V01*V15 + 5.17900020537332772e-16*V18) + 
   delta10*eps4*(1.31523569023569024e-8*V04*V052 + 5.84549195660306771e-9*V042*V06 + 
      1.83715461493239271e-8*V03*V05*V06 + 2.06932250583044234e-9*V02*V062 + 1.25260541927208594e-8*V03*V04*V07 + 
      6.35938135938135938e-9*V02*V05*V07 + 2.62450659276056101e-9*V01*V06*V07 + 3.28063324095070127e-9*V032*V08 + 
      2.11061718998226935e-9*V02*V04*V08 + 1.96837994457042076e-9*V01*V05*V08 - 1.03457878350242703e-10*V082 + 
      1.76649482205037761e-9*V02*V03*V09 + 1.04383784939340495e-9*V01*V04*V09 - 2.25945573702732122e-10*V07*V09 + 
      1.12413306857751302e-10*V022*V10 + 4.1753513975736198e-10*V01*V03*V10 - 1.28213696627173129e-10*V06*V10 + 
      9.63542630209296876e-11*V01*V02*V11 - 8.8009857890032182e-11*V05*V11 + 8.0295219184108073e-12*V012*V12 - 
      2.84182099269245239e-11*V04*V12 - 1.17293996651295126e-11*V03*V13 - 1.65313686555516621e-12*V02*V14 - 
      3.54243614047535616e-13*V01*V15 + 1.55370006161199832e-15*V18) + 
   delta8*eps5*(8.54903198653198653e-8*V04*V052 + 4.25885842552509219e-8*V042*V06 + 
      1.20563271604938272e-7*V03*V05*V06 + 1.51413841890032366e-8*V02*V062 + 8.1419352252685586e-8*V03*V04*V07 + 
      4.10710046126712793e-8*V02*V05*V07 + 1.72233245149911817e-8*V01*V06*V07 + 2.18708882730046751e-8*V032*V08 + 
      1.55696253579851463e-8*V02*V04*V08 + 1.31225329638028051e-8*V01*V05*V08 - 3.06889302360175895e-10*V082 + 
      1.14086123924086887e-8*V02*V03*V09 + 6.78494602105713217e-9*V01*V04*V09 - 6.39241035920541056e-10*V07*V09 + 
      8.56482337963819445e-10*V022*V10 + 2.87055408583186361e-9*V01*V03*V10 - 3.8595685187655309e-10*V06*V10 + 
      6.22287948676837566e-10*V01*V02*V11 - 2.57121823196169601e-10*V05*V11 + 6.02214143880810547e-11*V012*V12 - 
      8.91513095352964634e-11*V04*V12 - 3.63099704398724007e-11*V03*V13 - 5.5104562185172207e-12*V02*V14 - 
      1.18081204682511872e-12*V01*V15 + 3.88425015402999579e-15*V18) + 
   eps9*(1.06888995777884667e-6*V025 + 0.0000263923961840628507*V01*V023*V03 + 
      0.0000299748476831810165*V012*V02*V032 - 1.21518211175949271e-6*V034 + 
      0.0000238245550745550746*V012*V022*V04 + 0.0000102212602212602213*V013*V03*V04 - 
      0.0000101287830702513242*V02*V032*V04 - 3.09484386865339246e-6*V022*V042 - 
      6.45033978367311701e-6*V01*V03*V042 + 6.32565736732403399e-6*V013*V02*V05 - 
      5.97243869813314258e-6*V022*V03*V05 - 5.42102848650467698e-6*V01*V032*V05 - 
      7.74114737408388202e-6*V01*V02*V04*V05 - 9.78856075582266058e-7*V012*V052 + 
      2.90447881593714927e-7*V04*V052 + 4.69727032227032227e-7*V014*V06 - 
      8.74346112441350537e-7*V023*V06 - 5.52347371543800115e-6*V01*V02*V03*V06 - 
      1.67601358077548554e-6*V012*V04*V06 + 2.3201418290704005e-7*V042*V06 + 
      4.20311060192012573e-7*V03*V05*V06 + 1.000249016122032e-7*V02*V062 - 
      1.21213662880329547e-6*V01*V022*V07 - 1.0095517908017908e-6*V012*V03*V07 + 
      3.08183088131004798e-7*V03*V04*V07 + 1.83444465128492906e-7*V02*V05*V07 + 8.64564434132886514e-8*V01*V06*V07 - 
      4.09505617838951172e-7*V012*V02*V08 + 8.67546827988296242e-8*V032*V08 + 
      1.14248626153388058e-7*V02*V04*V08 + 6.72587168122882409e-8*V01*V05*V08 - 5.58025064485634825e-10*V082 - 
      3.61328486328486328e-8*V013*V09 + 6.05727059720115276e-8*V02*V03*V09 + 3.94450264241930909e-8*V01*V04*V09 - 
      1.01977880393934316e-9*V07*V09 + 9.15365498698832032e-9*V022*V10 + 1.79760921948421948e-8*V01*V03*V10 - 
      7.27717595714794594e-10*V06*V10 + 5.32959517334517335e-9*V01*V02*V11 - 4.32620013655552871e-10*V05*V11 + 
      6.32324851074851075e-10*V012*V12 - 1.92177160620788072e-10*V04*V12 - 7.12915273270665428e-11*V03*V13 - 
      1.65313686555516621e-11*V02*V14 - 3.54243614047535616e-12*V01*V15 + 5.82637523104499369e-15*V18) + 
   delta6*eps6*(-3.02827683780064732e-7*V034 - 1.85757254209635162e-6*V02*V032*V04 - 
      1.58222876476844731e-7*V022*V042 - 1.08321462488129155e-6*V01*V03*V042 - 
      9.25161515439293217e-7*V022*V03*V05 - 1.03112826327112041e-6*V01*V032*V05 - 
      1.11454352525781097e-6*V01*V02*V04*V05 - 1.39369559012416155e-7*V012*V052 + 
      2.68161943509165731e-7*V04*V052 - 3.51463645114438765e-8*V023*V06 - 
      7.62712816284244856e-7*V01*V02*V03*V06 - 2.12598798908322718e-7*V012*V04*V06 + 
      1.55031715051556321e-7*V042*V06 + 3.8440189109831967e-7*V03*V05*V06 + 5.61607704464847322e-8*V02*V062 - 
      1.32165930777041888e-7*V01*V022*V07 - 1.24296999296999297e-7*V012*V03*V07 + 
      2.6128064322508767e-7*V03*V04*V07 + 1.32968882968882969e-7*V02*V05*V07 + 5.73479926158497587e-8*V01*V06*V07 - 
      3.77387530165307943e-8*V012*V02*V08 + 7.26576144069530313e-8*V032*V08 + 
      5.89825738635262445e-8*V02*V04*V08 + 4.44778160551970076e-8*V01*V05*V08 - 6.7521831725198257e-10*V082 - 
      2.40885657552324219e-9*V013*V09 + 3.86086178910252984e-8*V02*V03*V09 + 2.32454659537992871e-8*V01*V04*V09 - 
      1.33786004905285951e-9*V07*V09 + 3.45269442491664714e-9*V022*V10 + 1.03580832747499414e-8*V01*V03*V10 - 
      8.61655419311815204e-10*V06*V10 + 2.28841374674708008e-9*V01*V02*V11 - 5.54981662007805799e-10*V05*V11 + 
      2.40885657552324219e-10*V012*V12 - 2.07822920241220895e-10*V04*V12 - 8.32472493011708698e-11*V03*V13 - 
      1.37761405462930517e-11*V02*V14 - 2.9520301170627968e-12*V01*V15 + 7.76850030805999158e-15*V18) + 
   delta2*eps8*(4.1753513975736198e-8*V025 + 0.0000140291806958473625*V01*V023*V03 + 
      0.0000188517115600448934*V012*V02*V032 - 2.104308279903518e-6*V034 + 
      0.0000125886844636844637*V012*V022*V04 + 5.82461519961519962e-6*V013*V03*V04 - 
      0.0000153405163325798246*V02*V032*V04 - 3.46221514376276281e-6*V022*V042 - 
      9.37767864851198185e-6*V01*V03*V042 + 2.94362273528940196e-6*V013*V02*V05 - 
      7.97973888251666029e-6*V022*V03*V05 - 8.09444633849395754e-6*V01*V032*V05 - 
      9.9663114296050804e-6*V01*V02*V04*V05 - 1.24727152256914162e-6*V012*V052 + 
      5.53495019640852974e-7*V04*V052 + 1.87890812890812891e-7*V014*V06 - 
      8.40346822489679633e-7*V023*V06 - 7.21314895422038279e-6*V01*V02*V03*V06 - 
      2.10547829595448643e-6*V012*V04*V06 + 4.143130073189597e-7*V042*V06 + 
      8.11973933253695158e-7*V03*V05*V06 + 1.64565051717829496e-7*V02*V062 - 
      1.3248711165377832e-6*V01*V022*V07 - 1.25380984755984756e-6*V012*V03*V07 + 
      5.84147719564386231e-7*V03*V04*V07 + 3.1668434446212224e-7*V02*V05*V07 + 1.46458479791813125e-7*V01*V06*V07 - 
      4.40820753320753321e-7*V012*V02*V08 + 1.6699971747094763e-7*V032*V08 + 
      1.84426647720298514e-7*V02*V04*V08 + 1.14231420034991464e-7*V01*V05*V08 - 1.09940630202554417e-9*V082 - 
      3.61328486328486328e-8*V013*V09 + 1.03781570795459684e-7*V02*V03*V09 + 6.52800131966798633e-8*V01*V04*V09 - 
      2.03867199884356747e-9*V07*V09 + 1.30479731174175619e-8*V022*V10 + 3.01107071940405274e-8*V01*V03*V10 - 
      1.42836085807024182e-9*V06*V10 + 7.82878387045053712e-9*V01*V02*V11 - 8.64354418275986903e-10*V05*V11 + 
      9.03321215821215821e-10*V012*V12 - 3.70184576679674719e-10*V04*V12 - 1.41697445619014246e-10*V03*V13 - 
      2.89298951472154087e-11*V02*V14 - 6.19926324583187328e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   delta4*eps7*(-1.3248711165377832e-6*V034 - 8.6670659587326254e-6*V02*V032*V04 - 
      1.31581381581381581e-6*V022*V042 - 5.14897910731244065e-6*V01*V03*V042 - 
      4.27957459207459207e-6*V022*V03*V05 - 4.63174942341609008e-6*V01*V032*V05 - 
      5.20023957523957524e-6*V01*V02*V04*V05 - 6.59063159063159063e-7*V012*V052 + 
      5.00520248784137673e-7*V04*V052 - 3.03928875357446786e-7*V023*V06 - 
      3.68334817739579644e-6*V01*V02*V03*V06 - 1.04922909982433792e-6*V012*V04*V06 + 
      3.34278174059920092e-7*V042*V06 + 7.29246916002868384e-7*V03*V05*V06 + 1.25604664295140486e-7*V02*V062 - 
      6.11367798867798868e-7*V01*V022*V07 - 6.07995399662066329e-7*V012*V03*V07 + 
      5.08188442216219994e-7*V03*V04*V07 + 2.63408466533466533e-7*V02*V05*V07 + 1.17724262069500165e-7*V01*V06*V07 - 
      1.95117382617382617e-7*V012*V02*V08 + 1.4478948630734345e-7*V032*V08 + 
      1.36065984280269995e-7*V02*V04*V08 + 9.21731762505572029e-8*V01*V05*V08 - 1.06818506921603716e-9*V082 - 
      1.44531394531394531e-8*V013*V09 + 8.19011235677902345e-8*V02*V03*V09 + 5.02246595996595997e-8*V01*V04*V09 - 
      2.03276793860944188e-9*V07*V09 + 8.67188367188367188e-9*V022*V10 + 2.30045802962469629e-8*V01*V03*V10 - 
      1.37834503351543501e-9*V06*V10 + 5.41992729492729493e-9*V01*V02*V11 - 8.5845035804186131e-10*V05*V11 + 
      6.02214143880810547e-10*V012*V12 - 3.45977929719759785e-10*V04*V12 - 1.35793385384888653e-10*V03*V13 - 
      2.47970529833274931e-11*V02*V14 - 5.31365421071303424e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   8.22063524662432972e-18*delta18*V18 + 3.69928586098094837e-17*delta16*eps*V18 + 
   delta16*eps2*(-4.99609107113593639e-14*V092 - 7.26704155801590747e-14*V08*V10 - 
      6.54033740221431672e-14*V07*V11 - 3.01861726256045387e-14*V06*V12 - 1.76086006982693143e-14*V05*V13 - 
      4.69562685287181713e-15*V04*V14 - 1.67700959031136326e-15*V03*V15 - 1.97295245918983913e-16*V02*V16 - 
      3.69928586098094837e-17*V01*V17 + 4.40391173926303378e-19*V20) + 
   delta14*eps3*(-3.99687285690874911e-13*V092 - 5.81363324641272598e-13*V08*V10 - 
      5.23226992177145338e-13*V07*V11 - 2.4148938100483631e-13*V06*V12 - 1.40868805586154514e-13*V05*V13 - 
      3.75650148229745371e-14*V04*V14 - 1.34160767224909061e-14*V03*V15 - 1.57836196735187131e-15*V02*V16 - 
      2.9594286887847587e-16*V01*V17 + 1.76156469570521351e-18*V20) + 
   delta12*eps4*(4.14465028435616671e-10*V052*V06 + 1.9311337588648513e-10*V04*V062 + 
      5.61121884651296416e-10*V04*V05*V07 + 3.94728598510111115e-10*V03*V06*V07 + 6.75424490783967908e-11*V02*V072 + 
      9.9293173004138872e-11*V042*V08 + 3.00188662570652404e-10*V03*V05*V08 + 7.05638284744001105e-11*V02*V06*V08 + 
      4.28840946529503434e-11*V01*V07*V08 + 1.55867190180915671e-10*V03*V04*V09 + 7.8799523924796256e-11*V02*V05*V09 + 
      3.28940498758425929e-11*V01*V06*V09 - 1.87500359022631024e-12*V092 + 3.28940498758425929e-11*V032*V10 + 
      2.19068749258602978e-11*V02*V04*V10 + 1.97364299255055558e-11*V01*V05*V10 - 2.808497825656736e-12*V08*V10 + 
      1.43271861681447738e-11*V02*V03*V11 + 8.50184673714085479e-12*V01*V04*V11 - 2.47282462663132475e-12*V07*V11 + 
      7.87208031216745814e-13*V022*V12 + 2.83394891238028493e-12*V01*V03*V12 - 1.183475532645025e-12*V06*V12 + 
      5.5104562185172207e-13*V01*V02*V13 - 6.80520626986055263e-13*V05*V13 + 3.93604015608372907e-14*V012*V14 - 
      1.89344247508448862e-13*V04*V14 - 6.71543693296741495e-14*V03*V15 - 8.28640032859732435e-15*V02*V16 - 
      1.55370006161199832e-15*V01*V17 + 6.16547643496824729e-18*V20) + 
   delta10*eps5*(3.26045822369351781e-9*V052*V06 + 1.65543101467471215e-9*V04*V062 + 
      4.38766140359277614e-9*V04*V05*V07 + 3.10519830827954077e-9*V03*V06*V07 + 5.25866210681803586e-10*V02*V072 + 
      8.54383116547241456e-10*V042*V08 + 2.38274750915455345e-9*V03*V05*V08 + 6.08564288665958964e-10*V02*V06*V08 + 
      3.40392501307793351e-10*V01*V07*V08 + 1.21879483433132671e-9*V03*V04*V09 + 6.1351057912877085e-10*V02*V05*V09 + 
      2.58766525689961731e-10*V01*V06*V09 - 6.38324106265132578e-12*V092 + 2.64979846222065332e-10*V032*V10 + 
      1.91044143347286827e-10*V02*V04*V10 + 1.58987907733239199e-10*V01*V05*V10 - 1.00156931590772184e-11*V08*V10 + 
      1.11547378023412882e-10*V02*V03*V11 + 6.6479718236254184e-11*V01*V04*V11 - 8.52071309503185762e-12*V07*V11 + 
      7.08487228095071232e-12*V022*V12 + 2.34981597318198625e-11*V01*V03*V12 - 4.3121835424282719e-12*V06*V12 + 
      4.29028377013126468e-12*V01*V02*V13 - 2.42687949623794137e-12*V05*V13 + 3.54243614047535616e-13*V012*V14 - 
      7.18016588472958155e-13*V04*V14 - 2.5221731000168106e-13*V03*V15 - 3.31456013143892974e-14*V02*V16 - 
      6.21480024644799327e-15*V01*V17 + 1.84964293049047419e-17*V20) + 
   delta8*eps6*(-8.45508658008658009e-8*V032*V042 - 1.14340392118169896e-8*V02*V043 - 
      5.74110817166372722e-8*V033*V05 - 1.70707635985413763e-7*V02*V03*V04*V05 - 
      5.07305194805194805e-8*V01*V042*V05 - 2.09931850556850557e-8*V022*V052 - 
      4.97910654160654161e-8*V01*V03*V052 - 5.99346457481378116e-8*V02*V032*V06 - 
      1.17185137026406868e-8*V022*V04*V06 - 6.97283683394794506e-8*V01*V03*V04*V06 - 
      3.5960787448882687e-8*V01*V02*V05*V06 + 1.29533113516637482e-8*V052*V06 - 
      3.43835599291948498e-9*V012*V062 + 7.392378229602008e-9*V04*V062 - 
      1.99935095768429102e-8*V022*V03*V07 - 2.28153129938844225e-8*V01*V032*V07 - 
      2.43868051407733947e-8*V01*V02*V04*V07 - 6.24582097796383511e-9*V012*V05*V07 + 
      1.75019961580419097e-8*V04*V05*V07 + 1.2518744403859561e-8*V03*V06*V07 + 2.14039052230578841e-9*V02*V072 - 
      6.57656080936504217e-10*V023*V08 - 1.26407616486981566e-8*V01*V02*V03*V08 - 
      3.52151889850302549e-9*V012*V04*V08 + 3.86929241225589394e-9*V042*V08 + 
      9.72664871847229976e-9*V03*V05*V08 + 2.79046504017974087e-9*V02*V06*V08 + 1.42857640312640831e-9*V01*V07*V08 - 
      1.66612579807024251e-9*V01*V022*V09 - 1.58583057888613444e-9*V012*V03*V09 + 
      5.00664307853850338e-9*V03*V04*V09 + 2.53392425148280268e-9*V02*V05*V09 + 1.08879305089038983e-9*V01*V06*V09 - 
      1.6748072821287926e-11*V092 - 3.81402291124513347e-10*V012*V02*V10 + 
      1.12917963434906323e-9*V032*V10 + 9.01690570613695419e-10*V02*V04*V10 + 6.8620642935438298e-10*V01*V05*V10 - 
      2.760150625644289e-11*V08*V10 - 2.00738047960270182e-11*V013*V11 + 4.80787305065627506e-10*V02*V03*V11 + 
      2.88905347456545714e-10*V01*V04*V11 - 2.26228347113945505e-11*V07*V11 + 3.54243614047535616e-11*V022*V12 + 
      1.07453896261085804e-10*V01*V03*V12 - 1.21478628817236775e-11*V06*V12 + 1.97786017843207386e-11*V01*V02*V13 - 
      6.6713291145516521e-12*V05*V13 + 1.77121807023767808e-12*V012*V14 - 2.11096048371016838e-12*V04*V14 - 
      7.32828529060325873e-13*V03*V15 - 1.03580004107466554e-13*V02*V16 - 1.9421250770149979e-14*V01*V17 + 
      4.62410732622618547e-17*V20) + eps10*(-4.32775172358505692e-6*V012*V024 - 
      9.24422799422799423e-6*V013*V022*V03 - 1.23068482443482443e-6*V014*V032 + 
      4.22450354245989167e-6*V023*V032 + 7.39166243258505163e-6*V01*V02*V033 - 
      1.69101731601731602e-6*V014*V02*V04 + 1.21747740795359843e-6*V024*V04 + 
      0.0000161214859875574161*V01*V022*V03*V04 + 6.33712696584720394e-6*V012*V032*V04 + 
      4.84675707889993604e-6*V012*V02*V042 - 1.07324812418438411e-6*V032*V042 - 
      4.62417873132158846e-7*V02*V043 - 9.39454064454064454e-8*V015*V05 + 
      3.19858299769014055e-6*V01*V023*V05 + 7.76295326146516623e-6*V012*V02*V03*V05 - 
      6.14896486982300474e-7*V033*V05 + 1.39724005051386004e-6*V013*V04*V05 - 
      2.56161679617780808e-6*V02*V03*V04*V05 - 8.20972733175114127e-7*V01*V042*V05 - 
      3.79289523169731503e-7*V022*V052 - 6.95468437903953777e-7*V01*V03*V052 + 
      2.05559775872275872e-6*V012*V022*V06 + 9.52221004304337638e-7*V013*V03*V06 - 
      9.2266376058538757e-7*V02*V032*V06 - 5.93101783577974054e-7*V022*V04*V06 - 
      1.16940150577303355e-6*V01*V03*V04*V06 - 7.07132752333645191e-7*V01*V02*V05*V06 + 
      2.89604486589270086e-8*V052*V06 - 7.63370950312914599e-8*V012*V062 + 
      2.35668492554580323e-8*V04*V062 + 4.33594183594183594e-7*V013*V02*V07 - 
      4.0140583760375427e-7*V022*V03*V07 - 3.62902846161774733e-7*V01*V032*V07 - 
      5.19422603685996543e-7*V01*V02*V04*V07 - 1.32534428479368956e-7*V012*V05*V07 + 
      4.25063111758883818e-8*V04*V05*V07 + 3.06977183828184645e-8*V03*V06*V07 + 6.76143520976766775e-9*V02*V072 + 
      2.70996364746364746e-8*V014*V08 - 4.80241882358284475e-8*V023*V08 - 
      2.87815345479035955e-7*V01*V02*V03*V08 - 8.72350202707345564e-8*V012*V04*V08 + 
      1.34766641195601669e-8*V042*V08 + 2.39151691290706619e-8*V03*V05*V08 + 1.16898143469883277e-8*V02*V06*V08 + 
      4.92813313471090471e-9*V01*V07*V08 - 5.07365416219582886e-8*V01*V022*V09 - 
      4.2305543607626941e-8*V012*V03*V09 + 1.39815526419386714e-8*V03*V04*V09 + 8.39144081076270619e-9*V02*V05*V09 + 
      3.92546204816425405e-9*V01*V06*V09 - 2.56298084717075669e-11*V092 - 1.40014788452288452e-8*V012*V02*V10 + 
      3.21391736030508206e-9*V032*V10 + 4.35416007894999492e-9*V02*V04*V10 + 2.49794462727031588e-9*V01*V05*V10 - 
      4.62118489039601052e-11*V08*V10 - 1.05387475179141846e-9*V013*V11 + 1.88841366588507111e-9*V02*V03*V11 + 
      1.22273087448741044e-9*V01*V04*V11 - 3.49496505466431814e-11*V07*V11 + 2.47970529833274931e-10*V022*V12 + 
      4.71144006683222369e-10*V01*V03*V12 - 2.1239079842236017e-11*V06*V12 + 1.20885633293721529e-10*V01*V02*V13 - 
      1.07535465514320433e-11*V05*V13 + 1.23985264916637466e-11*V012*V14 - 4.17634576561305147e-12*V04*V14 - 
      1.34395055329437854e-12*V03*V15 - 2.79666011090159697e-13*V02*V16 - 5.24373770794049432e-14*V01*V17 + 
      6.9361609893392782e-17*V20) + delta6*eps7*
    (-5.30269627491849714e-7*V032*V042 - 1.06760523427190094e-7*V02*V043 - 
      3.44466490299823633e-7*V033*V05 - 1.06134220717554051e-6*V02*V03*V04*V05 - 
      3.18161776495109828e-7*V01*V042*V05 - 1.30511849261849262e-7*V022*V052 - 
      3.03130511463844797e-7*V01*V03*V052 - 3.78534604725080916e-7*V02*V032*V06 - 
      1.11853534472582092e-7*V022*V04*V06 - 4.46345064400619956e-7*V01*V03*V04*V06 - 
      2.27120762835048549e-7*V01*V02*V05*V06 + 3.26639377224889207e-8*V052*V06 - 
      2.2585898081929828e-8*V012*V062 + 2.10193091164924343e-8*V04*V062 - 
      1.24296999296999297e-7*V022*V03*V07 - 1.41067229360880155e-7*V01*V032*V07 - 
      1.51620315310791501e-7*V01*V02*V04*V07 - 4.0124668100858577e-8*V012*V05*V07 + 4.4787492448848658e-8*V04*V05*V07 + 
      3.24298782831501475e-8*V03*V06*V07 + 5.68358575623981786e-9*V02*V072 - 6.5918551368286818e-9*V023*V08 - 
      8.25205438300676396e-8*V01*V02*V03*V08 - 2.34003210193686384e-8*V012*V04*V08 + 
      1.12529063924436888e-8*V042*V08 + 2.54356286410311724e-8*V03*V05*V08 + 8.30444495178907462e-9*V02*V06*V08 + 
      3.92657491666076582e-9*V01*V07*V08 - 1.03580832747499414e-8*V01*V022*V09 - 
      1.05989689323022656e-8*V012*V03*V09 + 1.3470310226165346e-8*V03*V04*V09 + 6.88846387716213424e-9*V02*V05*V09 + 
      3.03283139855268707e-9*V01*V06*V09 - 3.40039836055713167e-11*V092 - 2.64974223307556641e-9*V012*V02*V10 + 
      3.11981788600213748e-9*V032*V10 + 2.79278917817666651e-9*V02*V04*V10 + 1.94147992156084282e-9*V01*V05*V10 - 
      5.8329550274963918e-11*V08*V10 - 1.60590438368216146e-10*V013*V11 + 1.39296461123803172e-9*V02*V03*V11 + 
      8.47035841589218496e-10*V01*V04*V11 - 4.62613453487800303e-11*V07*V11 + 1.18081204682511872e-10*V022*V12 + 
      3.24723312876907648e-10*V01*V03*V12 - 2.6147736236888857e-11*V06*V12 + 6.25830384817312922e-11*V01*V02*V13 - 
      1.39998733551651795e-11*V05*V13 + 5.9040602341255936e-12*V012*V14 - 4.73567778779337087e-12*V04*V14 - 
      1.62102706428185158e-12*V03*V15 - 2.48592009857919731e-13*V02*V16 - 4.66110018483599495e-14*V01*V17 + 
      9.24821465245237093e-17*V20) + delta2*eps9*
    (4.15642466733736575e-6*V023*V032 + 8.35529109338633148e-6*V01*V02*V033 + 
      6.79829796893288957e-7*V024*V04 + 0.0000154207702570797809*V01*V022*V03*V04 + 
      6.74263732299446585e-6*V012*V032*V04 + 4.56072256667494763e-6*V012*V02*V042 - 
      1.91435273280511376e-6*V032*V042 - 6.72419695237155555e-7*V02*V043 + 
      2.49385480040241945e-6*V01*V023*V05 + 7.25582012784393737e-6*V012*V02*V03*V05 - 
      1.13434203215949248e-6*V033*V05 + 1.24703063691158929e-6*V013*V04*V05 - 
      4.15228372817658532e-6*V02*V03*V04*V05 - 1.29452411198442944e-6*V01*V042*V05 - 
      5.49420037267259489e-7*V022*V052 - 1.13306877939814448e-6*V01*V03*V052 + 
      1.63031413031413031e-6*V012*V022*V06 + 8.24792491459158126e-7*V013*V03*V06 - 
      1.51755096571564826e-6*V02*V032*V06 - 7.77042071684928828e-7*V022*V04*V06 - 
      1.86239140232195788e-6*V01*V03*V04*V06 - 1.01627938309485929e-6*V01*V02*V05*V06 + 
      5.68838491377298567e-8*V052*V06 - 1.07641476689095737e-7*V012*V062 + 
      4.41557917412842716e-8*V04*V062 + 3.20377924544591211e-7*V013*V02*V07 - 
      5.77443068762513207e-7*V022*V03*V07 - 5.83046527987004177e-7*V01*V032*V07 - 
      7.28552935894205735e-7*V01*V02*V04*V07 - 1.86531529537481918e-7*V012*V05*V07 + 
      8.20730498018079717e-8*V04*V05*V07 + 6.00686679154524626e-8*V03*V06*V07 + 1.19181468478999992e-8*V02*V072 + 
      1.80664243164243164e-8*V014*V08 - 5.42489795135297781e-8*V023*V08 - 
      4.0979812185169328e-7*V01*V02*V03*V08 - 1.20546065486541677e-7*V012*V04*V08 + 
      2.49040458005988663e-8*V042*V08 + 4.6958392905278604e-8*V03*V05*V08 + 2.00429912245193913e-8*V02*V06*V08 + 
      8.62016691568998603e-9*V01*V07*V08 - 6.16667283333950001e-8*V01*V022*V09 - 
      5.79330006413339747e-8*V012*V03*V09 + 2.68752821857397021e-8*V03*V04*V09 + 1.4780224390110011e-8*V02*V05*V09 + 
      6.83399189285918978e-9*V01*V06*V09 - 5.12537905681840888e-11*V092 - 1.68619960286626953e-8*V012*V02*V10 + 
      6.27264228017029137e-9*V032*V10 + 7.31125081907061366e-9*V02*V04*V10 + 4.36078106078397862e-9*V01*V05*V10 - 
      9.16586854918693502e-11*V08*V10 - 1.20442828776162109e-9*V013*V11 + 3.30686413713374498e-9*V02*V03*V11 + 
      2.08501887168145338e-9*V01*V04*V11 - 6.98876483428242728e-11*V07*V11 + 3.71955794749912397e-10*V022*V12 + 
      8.121034852039754e-10*V01*V03*V12 - 4.19521212350405431e-11*V06*V12 + 1.85092288339837359e-10*V01*V02*V13 - 
      2.14954403524019967e-11*V05*V13 + 1.85977897374956198e-11*V012*V14 - 8.11342172173785521e-12*V04*V14 - 
      2.6762483561266671e-12*V03*V15 - 4.97184019715839461e-13*V02*V16 - 9.3222003696719899e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + delta4*eps8*
    (1.12355953129762654e-6*V023*V032 + 2.5791971476495286e-6*V01*V02*V033 + 
      3.77616945077262538e-8*V024*V04 + 4.13625909657655689e-6*V01*V022*V03*V04 + 
      1.98785727059536583e-6*V012*V032*V04 + 1.22404326273373892e-6*V012*V02*V042 - 
      1.42409880133094419e-6*V032*V042 - 3.91505723846993688e-7*V02*V043 + 
      6.74135718778575921e-7*V01*V023*V05 + 2.06180916746392937e-6*V012*V02*V03*V05 - 
      8.81354738001563398e-7*V033*V05 + 3.3207808505427553e-7*V013*V04*V05 - 
      2.91372423688891943e-6*V02*V03*V04*V05 - 8.88464306123036282e-7*V01*V042*V05 - 
      3.66935769134843209e-7*V022*V052 - 8.12937475883904455e-7*V01*V03*V052 + 
      4.23557281196170085e-7*V012*V022*V06 + 2.13183806933806934e-7*V013*V03*V06 - 
      1.05803289707059548e-6*V02*V032*V06 - 4.22574620656631239e-7*V022*V04*V06 - 
      1.26838342984176318e-6*V01*V03*V04*V06 - 6.5878786116881355e-7*V01*V02*V05*V06 + 
      5.45632582627067921e-8*V052*V06 - 6.76716636538065109e-8*V012*V062 + 
      3.90218908615850726e-8*V04*V062 + 7.34701255534588868e-8*V013*V02*V07 - 
      3.63268954125435607e-7*V022*V03*V07 - 3.97088535729408745e-7*V01*V032*V07 - 
      4.49314840435872182e-7*V01*V02*V04*V07 - 1.17990956904647381e-7*V012*V05*V07 + 
      7.65859343014163276e-8*V04*V05*V07 + 5.59869380444485487e-8*V03*V06*V07 + 1.02824269600355035e-8*V02*V072 + 
      3.61328486328486328e-9*V014*V08 - 2.64209506934374659e-8*V023*V08 - 
      2.52155665102093674e-7*V01*V02*V03*V08 - 7.26442318704223466e-8*V012*V04*V08 + 
      2.14728983840795232e-8*V042*V08 + 4.39814532769423059e-8*V03*V05*V08 + 1.64109258267755e-8*V02*V06*V08 + 
      7.31276900598796024e-9*V01*V07*V08 - 3.37239920573253907e-8*V01*V022*V09 - 
      3.40250991292657959e-8*V012*V03*V09 + 2.42509274116708757e-8*V03*V04*V09 + 1.27037664057680398e-8*V02*V05*V09 + 
      5.74203595255766124e-9*V01*V06*V09 - 5.12110638164897588e-11*V092 - 9.03321215821215821e-9*V012*V02*V10 + 
      5.67822993017028965e-9*V032*V10 + 5.76472441260022959e-9*V02*V04*V10 + 3.68295277404754529e-9*V01*V05*V10 - 
      9.01908088622321099e-11*V08*V10 - 6.02214143880810547e-10*V013*V11 + 2.72767582816602424e-9*V02*V03*V11 + 
      1.68501879081944441e-9*V01*V04*V11 - 6.98021948394356129e-11*V07*V11 + 2.65682710535651712e-10*V022*V12 + 
      6.5535068598794089e-10*V01*V03*V12 - 4.09621923386420413e-11*V06*V12 + 1.35793385384888653e-10*V01*V02*V13 - 
      2.14099868490133368e-11*V05*V13 + 1.32841355267825856e-11*V012*V14 - 7.69703010522583966e-12*V04*V14 - 
      2.59079485273800719e-12*V03*V15 - 4.35036017251359529e-13*V02*V16 - 8.15692532346299116e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + 1.95729410633912612e-20*delta20*V20 + 
   9.78647053169563062e-20*delta18*eps*V20 + 
   delta18*eps2*(-3.73576270568999572e-16*V102 - 8.21867795251799059e-16*V09*V11 - 
      5.0576479707803019e-16*V08*V12 - 3.79323597808522643e-16*V07*V13 - 1.51729439123409057e-16*V06*V14 - 
      7.58647195617045285e-17*V05*V15 - 1.78505222498128302e-17*V04*V16 - 5.57828820306650945e-18*V03*V17 - 
      5.87188231901737837e-19*V02*V18 - 9.78647053169563062e-20*V01*V19 + 1.06374679692343811e-21*V22) + 
   delta16*eps3*(-3.36218643512099615e-15*V102 - 7.39681015726619153e-15*V09*V11 - 
      4.55188317370227171e-15*V08*V12 - 3.41391238027670378e-15*V07*V13 - 1.36556495211068151e-15*V06*V14 - 
      6.82782476055340757e-16*V05*V15 - 1.60654700248315472e-16*V04*V16 - 5.02045938275985851e-17*V03*V17 - 
      5.28469408711564053e-18*V02*V18 - 8.80782347852606755e-19*V01*V19 + 4.7868605861554715e-21*V22) + 
   delta14*eps4*(2.13459363566774952e-12*V063 + 1.7930586539609096e-11*V05*V06*V07 + 
      6.04327175964602865e-12*V04*V072 + 6.86735427232503256e-12*V052*V08 + 
      6.60875939349902034e-12*V04*V06*V08 + 6.54033740221431672e-12*V03*V07*V08 + 6.07011706610740506e-13*V02*V082 + 
      7.05048371958703343e-12*V04*V05*V09 + 4.98071848322474889e-12*V03*V06*V09 + 1.69279320998488198e-12*V02*V07*V09 + 
      5.4502811685119306e-13*V01*V08*V09 + 1.03773353448467159e-12*V042*V10 + 3.05215745436668114e-12*V03*V05*V10 + 
      7.38870695966594755e-13*V02*V06*V10 + 4.36022493480954448e-13*V01*V07*V10 - 1.85215182566314525e-14*V102 + 
      1.28190613083400608e-12*V03*V04*V11 + 6.463392256305913e-13*V02*V05*V11 + 2.71675553630440848e-13*V01*V06*V11 - 
      3.9838959969837207e-14*V09*V11 + 2.2639629469203404e-13*V032*V12 + 1.54600554702115794e-13*V02*V04*V12 + 
      1.35837776815220424e-13*V01*V05*V12 - 2.52150370543244262e-14*V08*V12 + 8.28640032859732435e-14*V02*V03*V13 + 
      4.93040819551540799e-14*V01*V04*V13 - 1.8596838492559939e-14*V07*V13 + 4.00509349215537344e-15*V022*V14 + 
      1.40868805586154514e-14*V01*V03*V14 - 7.6902868355706801e-15*V06*V14 + 2.36754295102780696e-15*V01*V02*V15 - 
      3.80321817802755597e-15*V05*V15 + 1.47971434439237935e-16*V012*V16 - 9.29401533454070648e-16*V04*V16 - 
      2.88896610095655016e-16*V03*V17 - 3.17081645226938432e-17*V02*V18 - 5.28469408711564053e-18*V01*V19 + 
      1.9147442344621886e-20*V22) + delta12*eps5*
    (2.10613238719217953e-11*V063 + 1.64612745870577951e-10*V05*V06*V07 + 5.52527703739065477e-11*V04*V072 + 
      6.34085711144678006e-11*V052*V08 + 6.53389768538752109e-11*V04*V06*V08 + 6.03891153471121911e-11*V03*V07*V08 + 
      6.02167012238729901e-12*V02*V082 + 6.44615654362243056e-11*V04*V05*V09 + 4.57257627418272085e-11*V03*V06*V09 + 
      1.54291047785080388e-11*V02*V07*V09 + 5.03242627892601592e-12*V01*V08*V09 + 1.03162921957593822e-11*V042*V10 + 
      2.84232162937897181e-11*V03*V05*V10 + 7.35516676785972028e-12*V02*V06*V10 + 4.0604594705413883e-12*V01*V07*V10 - 
      7.67994164653953858e-14*V102 + 1.17202846247680556e-11*V03*V04*V11 + 5.89111273361216028e-12*V02*V05*V11 + 
      2.49413251319057501e-12*V01*V06*V11 - 1.5942072417897397e-13*V09*V11 + 2.13818722764698816e-12*V032*V12 + 
      1.55808001607139976e-12*V02*V04*V12 + 1.2829123365881929e-12*V01*V05*V12 - 1.05441977990826965e-13*V08*V12 + 
      7.55270863283610293e-13*V02*V03*V13 + 4.50780177875694445e-13*V01*V04*V13 - 7.57798708621947274e-14*V07*V13 + 
      4.16161438725110068e-14*V022*V14 + 1.36760132089891674e-13*V01*V03*V14 - 3.29532384496182881e-14*V06*V14 + 
      2.15791675223888655e-14*V01*V02*V15 - 1.60364042073524112e-14*V05*V15 + 1.55370006161199832e-15*V012*V16 - 
      4.13580159257670028e-15*V04*V16 - 1.27625362203842719e-15*V03*V17 - 1.47971434439237935e-16*V02*V18 - 
      2.46619057398729892e-17*V01*V19 + 6.7016048206176601e-20*V22) + 
   delta10*eps6*(-2.95801289810004407e-10*V044 - 7.84358338143741194e-9*V03*V042*V05 - 
      4.09348176232707823e-9*V032*V052 - 3.92005983305002913e-9*V02*V04*V052 - 
      8.01299054975525564e-10*V01*V053 - 5.49887301462931715e-9*V032*V04*V06 - 
      1.23515189263710895e-9*V02*V042*V06 - 5.57736890117064409e-9*V02*V03*V05*V06 - 
      3.29932380877759029e-9*V01*V04*V05*V06 - 2.13153443195460002e-10*V022*V062 - 
      1.13590745155871206e-9*V01*V03*V062 + 1.11077632135397347e-10*V063 - 
      1.27190326186591359e-9*V033*V07 - 3.73339031719050393e-9*V02*V03*V04*V07 - 
      1.12051191163391599e-9*V01*V042*V07 - 9.11823062558356676e-10*V022*V05*V07 - 
      2.2213661141454481e-9*V01*V03*V05*V07 - 7.96766985881520584e-10*V01*V02*V06*V07 + 7.90818238274194341e-10*V05*V06*V07 - 
      7.07587561773680666e-11*V012*V072 + 2.66182291692605467e-10*V04*V072 - 
      1.0063142665720734e-9*V02*V032*V08 - 2.14750350915928258e-10*V022*V04*V08 - 
      1.16958121224642648e-9*V01*V03*V04*V08 - 6.03788559943244039e-10*V01*V02*V05*V08 + 
      3.07308867141893107e-10*V052*V08 - 1.15543395934255982e-10*V012*V06*V08 + 
      3.48020435329644263e-10*V04*V06*V08 + 2.95653173692384828e-10*V03*V07*V08 + 3.2678175994266238e-11*V02*V082 - 
      2.53284184043987966e-10*V022*V03*V09 - 2.92166637871586518e-10*V01*V032*V09 - 
      3.11115859765875328e-10*V01*V02*V04*V09 - 8.04807753628948774e-11*V012*V05*V09 + 
      3.13793240103475455e-10*V04*V05*V09 + 2.24240350892254344e-10*V03*V06*V09 + 7.61580611867156797e-11*V02*V07*V09 + 
      2.53822800065346792e-11*V01*V08*V09 - 7.30978886129835398e-12*V023*V10 - 
      1.29608179425328507e-10*V01*V02*V03*V10 - 3.60822424022704135e-11*V012*V04*V10 + 
      5.60804732543481649e-11*V042*V10 + 1.42000663750085985e-10*V03*V05*V10 + 4.03355333137918687e-11*V02*V06*V10 + 
      2.06774049390104097e-11*V01*V07*V10 - 2.53132042505487258e-13*V102 - 
      1.3815500947853889e-11*V01*V022*V11 - 1.32250949244413297e-11*V012*V03*V11 + 
      5.88245344526877608e-11*V03*V04*V11 + 2.96754985434489887e-11*V02*V05*V11 + 1.27296865619387611e-11*V01*V06*V11 - 
      5.05754031960445325e-13*V09*V11 - 2.63714690457609848e-12*V012*V02*V12 + 
      1.11352203701387527e-11*V032*V12 + 8.81730210584071817e-12*V02*V04*V12 + 6.74017282442450755e-12*V01*V05*V12 - 
      3.50568990092294541e-13*V08*V12 - 1.18081204682511872e-13*V013*V13 + 3.95761932360611793e-12*V02*V03*V13 + 
      2.37602171422117529e-12*V01*V04*V13 - 2.44874227567633878e-13*V07*V13 + 2.48384849849704798e-13*V022*V14 + 
      7.57584150042010379e-13*V01*V03*V14 - 1.12391703028323173e-13*V06*V14 + 1.1963490474412387e-13*V01*V02*V15 - 
      5.36951342721384656e-14*V05*V15 + 9.3222003696719899e-15*V012*V16 - 1.46935634398163269e-14*V04*V16 - 
      4.49463232109185227e-15*V03*V17 - 5.54892879147142256e-16*V02*V18 - 9.24821465245237093e-17*V01*V19 + 
      2.01048144618529803e-19*V22) + delta8*eps7*
    (-3.12288574815807931e-9*V044 - 6.13302756208529629e-8*V03*V042*V05 - 
      3.11053445414828857e-8*V032*V052 - 3.05407589414942356e-8*V02*V04*V052 - 
      6.13408242084712673e-9*V01*V053 - 4.34778369389713928e-8*V032*V04*V06 - 
      1.31957658023639972e-8*V02*V042*V06 - 4.3769553743682284e-8*V02*V03*V05*V06 - 
      2.60867021633828357e-8*V01*V04*V05*V06 - 2.31124277965236571e-9*V022*V062 - 
      9.11367606483152702e-9*V01*V03*V062 + 3.89361294085025683e-10*V063 - 
      9.73663876324940751e-9*V033*V07 - 2.90864370871373672e-8*V02*V03*V04*V07 - 
      8.76146794583613756e-9*V01*V042*V07 - 7.13092395077689195e-9*V022*V05*V07 - 
      1.71856509877829517e-8*V01*V03*V05*V07 - 6.252793391954612e-9*V01*V02*V06*V07 + 2.5282819527162001e-9*V05*V06*V07 - 
      5.70894510067401446e-10*V012*V072 + 8.58885837973415987e-10*V04*V072 - 
      8.03345795856689103e-9*V02*V032*V08 - 2.36162409365023744e-9*V022*V04*V08 - 
      9.43862429428878231e-9*V01*V03*V04*V08 - 4.82007477514013462e-9*V01*V02*V05*V08 + 
      9.90550771013638422e-10*V052*V08 - 9.52465488627175524e-10*V012*V06*V08 + 
      1.24013655702525207e-9*V04*V06*V08 + 9.70630955157051171e-10*V03*V07*V08 + 1.20233202577373189e-10*V02*V082 - 
      1.98081220854913665e-9*V022*V03*V09 - 2.30511380283789247e-9*V01*V032*V09 - 
      2.42386975726144727e-9*V01*V02*V04*V09 - 6.55688060858462352e-10*V012*V05*V09 + 
      1.03082561137740446e-9*V04*V05*V09 + 7.43326732405203706e-10*V03*V06*V09 + 2.56405271524897592e-10*V02*V07*V09 + 
      8.76982300491031469e-11*V01*V08*V09 - 8.45686342107132646e-11*V023*V10 - 1.06762277776516805e-9*V01*V02*V03*V10 - 
      3.02034852834339296e-10*V012*V04*V10 + 2.06123073726194409e-10*V042*V10 + 
      4.7748951503009169e-10*V03*V05*V10 + 1.50591515305042041e-10*V02*V06*V10 + 7.19068418752763738e-11*V01*V07*V10 - 
      6.67076525370678137e-13*V102 - 1.08044302284498363e-10*V01*V022*V11 - 
      1.12177144448386278e-10*V012*V03*V11 + 2.03127638655029436e-10*V03*V04*V11 + 
      1.03144968090215195e-10*V02*V05*V11 + 4.50206788567242398e-11*V01*V06*V11 - 1.29003346187058122e-12*V09*V11 - 
      2.30258349130898151e-11*V012*V02*V12 + 3.95028240664850572e-11*V032*V12 + 
      3.43243417611322668e-11*V02*V04*V12 + 2.42921004633035937e-11*V01*V05*V12 - 9.30432048801058198e-13*V08*V12 - 
      1.18081204682511872e-12*V013*V13 + 1.45685275777151709e-11*V02*V03*V13 + 8.81931944973023978e-12*V01*V04*V13 - 
      6.32855328667315743e-13*V07*V13 + 1.03165684091036688e-12*V022*V14 + 2.90075801502960086e-12*V01*V03*V14 - 
      3.05117097813708622e-13*V06*V14 + 4.73878518791659487e-13*V01*V02*V15 - 1.4295890209760875e-13*V05*V15 + 
      3.88425015402999579e-14*V012*V16 - 4.15429802188160502e-14*V04*V16 - 1.25775719273352245e-14*V03*V17 - 
      1.66467863744142677e-15*V02*V18 - 2.77446439573571128e-16*V01*V19 + 5.02620361546324507e-19*V22) + 
   eps11*(-9.01835117002665504e-8*V026 - 3.25916459348999032e-6*V01*V024*V03 - 
      7.35068548808628174e-6*V012*V022*V032 - 1.0854789500622834e-6*V013*V033 + 
      6.78100295225791258e-7*V02*V034 - 3.88445328921519398e-6*V012*V023*V04 - 
      4.99063464093225998e-6*V013*V02*V03*V04 + 2.84278006510562727e-6*V022*V032*V04 + 
      1.64707575731881287e-6*V01*V033*V04 - 2.84933320647606362e-7*V014*V042 + 
      5.87400058299529199e-7*V023*V042 + 3.58815504059799695e-6*V01*V02*V03*V042 + 
      3.5912954439740154e-7*V012*V043 - 2.81868399275952575e-8*V044 - 
      1.54110614180058625e-6*V013*V022*V05 - 4.60814262897596231e-7*V014*V03*V05 + 
      1.12000694579646299e-6*V023*V03*V05 + 3.00648528885136028e-6*V01*V02*V032*V05 + 
      2.15679602202006303e-6*V01*V022*V04*V05 + 1.75801937489685506e-6*V012*V03*V04*V05 - 
      3.02837308803974984e-7*V03*V042*V05 + 5.39000298734921751e-7*V012*V02*V052 - 
      1.30260107162109282e-7*V032*V052 - 1.81474604951678073e-7*V02*V04*V052 - 
      3.30907815972154207e-8*V01*V053 - 2.28841374674708008e-7*V014*V02*V06 + 
      1.2426335177657929e-7*V024*V06 + 1.53341242595954898e-6*V01*V022*V03*V06 + 
      6.11779025097477478e-7*V012*V032*V06 + 9.21724593289573448e-7*V012*V02*V04*V06 - 
      2.1732776138249265e-7*V032*V04*V06 - 1.45683102372722665e-7*V02*V042*V06 + 
      1.38048989425477521e-7*V013*V05*V06 - 2.61595716210939036e-7*V02*V03*V05*V06 - 
      1.66642922459441776e-7*V01*V04*V05*V06 - 3.13513920345541883e-8*V022*V062 - 
      5.92808427693683879e-8*V01*V03*V062 + 8.84509142307875836e-10*V063 - 
      1.08398545898545899e-8*V015*V07 + 2.24590985483015906e-7*V01*V023*V07 + 
      5.54011203192750812e-7*V012*V02*V03*V07 - 4.56228874516762589e-8*V033*V07 + 
      1.01933346911025482e-7*V013*V04*V07 - 1.91754429908024679e-7*V02*V03*V04*V07 - 
      6.13420781184067054e-8*V01*V042*V07 - 5.72043116871378037e-8*V022*V05*V07 - 
      1.03916952302356811e-7*V01*V03*V05*V07 - 5.3133259730785894e-8*V01*V02*V06*V07 + 4.73703555517935601e-9*V05*V06*V07 - 
      5.00584884186415077e-9*V012*V072 + 1.741265174578467e-9*V04*V072 + 
      1.12062015273820829e-7*V012*V022*V08 + 5.3898165877332544e-8*V013*V03*V08 - 
      5.36809105180029939e-8*V02*V032*V08 - 3.57374452845974788e-8*V022*V04*V08 - 
      6.77966188714758976e-8*V01*V03*V04*V08 - 4.12668507250089883e-8*V01*V02*V05*V08 + 
      1.84415328275492498e-9*V052*V08 - 8.89450891456902195e-9*V012*V06*V08 + 
      3.03796541544199087e-9*V04*V06*V08 + 1.95419862124377447e-9*V03*V07*V08 + 3.79246470634262349e-10*V02*V082 + 
      1.95719596761263428e-8*V013*V02*V09 - 1.87589213813852975e-8*V022*V03*V09 - 
      1.67786011778556713e-8*V01*V032*V09 - 2.41704845909809145e-8*V01*V02*V04*V09 - 
      6.17402338833098637e-9*V012*V05*V09 + 2.15772698503969466e-9*V04*V05*V09 + 1.55508035764887683e-9*V03*V06*V09 + 
      6.91653165373944804e-10*V02*V07*V09 + 2.50103168132130448e-10*V01*V08*V09 + 1.05387475179141846e-9*V014*V10 - 
      1.89829593813409562e-9*V023*V10 - 1.09471819705392301e-8*V01*V02*V03*V10 - 
      3.31517199332033599e-9*V012*V04*V10 + 5.66213951638936691e-10*V042*V10 + 
      9.90709445715168765e-10*V03*V05*V10 + 4.93857621869645393e-10*V02*V06*V10 + 2.04600194881280817e-10*V01*V07*V10 - 
      1.0592820988240287e-12*V102 - 1.62155014330259428e-9*V01*V022*V11 - 
      1.34701134241575418e-9*V012*V03*V11 + 4.83293552740012793e-10*V03*V04*V11 + 2.92311187466604348e-10*V02*V05*V11 + 
      1.35732624614622041e-10*V01*V06*V11 - 1.95010166215273807e-12*V09*V11 - 3.7815505799574427e-10*V012*V02*V12 + 
      9.37949305944393234e-11*V032*V12 + 1.29817854947928907e-10*V02*V04*V12 + 7.30666296474582508e-11*V01*V05*V12 - 
      1.49261560383255041e-12*V08*V12 - 2.47970529833274931e-11*V013*V13 + 4.77180131422584983e-11*V02*V03*V13 + 
      3.07298566685929087e-11*V01*V04*V13 - 9.64334462347839848e-13*V07*V13 + 5.53945861966731133e-12*V022*V14 + 
      1.02559741067008009e-11*V01*V03*V14 - 5.09835577360394305e-13*V06*V14 + 2.32278159210993748e-12*V01*V02*V15 - 
      2.25009062494166185e-13*V05*V15 + 2.09749508317619773e-13*V012*V16 - 7.75740245047704874e-14*V04*V16 - 
      2.20569919460989047e-14*V03*V17 - 4.16169659360356692e-15*V02*V18 - 6.9361609893392782e-16*V01*V19 + 
      7.53930542319486761e-19*V22) + delta6*eps8*
    (1.16714836456899949e-7*V02*V034 + 3.3167660895835499e-7*V022*V032*V04 + 
      2.55740273101384212e-7*V01*V033*V04 + 1.0639753805538638e-8*V023*V042 + 
      4.0211845767401323e-7*V01*V02*V03*V042 + 3.92643621810288477e-8*V012*V043 - 
      1.44647796358943781e-8*V044 + 1.06435773874045479e-7*V023*V03*V05 + 
      3.97805457329266853e-7*V01*V02*V032*V05 + 1.99005965375012994e-7*V01*V022*V04*V05 + 
      2.09450079241745908e-7*V012*V03*V04*V05 - 2.23205463736282545e-7*V03*V042*V05 + 
      5.46638381459810031e-8*V012*V02*V052 - 1.08785983451243074e-7*V032*V052 - 
      1.12518714013131224e-7*V02*V04*V052 - 2.20587498467400428e-8*V01*V053 + 
      1.74482785814355479e-9*V024*V06 + 1.40126628221866317e-7*V01*V022*V03*V06 + 
      6.90710946167295374e-8*V012*V032*V06 + 8.25320145756653693e-8*V012*V02*V04*V06 - 
      1.60306931018687944e-7*V032*V04*V06 - 6.23141806988030663e-8*V02*V042*V06 + 
      1.17976618472650219e-8*V013*V05*V06 - 1.63158892000544402e-7*V02*V03*V05*V06 - 
      9.83588207974490265e-8*V01*V04*V05*V06 - 1.11381689475890119e-8*V022*V062 - 
      3.48030855806882884e-8*V01*V03*V062 + 9.53886585144753617e-10*V063 + 
      1.52051105534350684e-8*V01*V023*V07 + 4.88653762463286273e-8*V012*V02*V03*V07 - 
      3.50760218509401516e-8*V033*V07 + 8.00084505441648299e-9*V013*V04*V07 - 
      1.0966831245289851e-7*V02*V03*V04*V07 - 3.33776917471737993e-8*V01*V042*V07 - 
      2.72838431539411932e-8*V022*V05*V07 - 6.36466502471469273e-8*V01*V03*V05*V07 - 
      2.43659066418494264e-8*V01*V02*V06*V07 + 5.73454430680343706e-9*V05*V06*V07 - 
      2.24285876770250149e-9*V012*V072 + 1.97943651812315506e-9*V04*V072 + 
      7.29348240922314996e-9*V012*V022*V08 + 3.81402291124513347e-9*V013*V03*V08 - 
      3.10448607244177324e-8*V02*V032*V08 - 1.1607382420290917e-8*V022*V04*V08 - 
      3.68885683428167088e-8*V01*V03*V04*V08 - 1.90217012623058375e-8*V01*V02*V05*V08 + 
      2.25567676854889474e-9*V052*V08 - 3.85231495904931946e-9*V012*V06*V08 + 
      3.10327793500338834e-9*V04*V06*V08 + 2.26552478541084656e-9*V03*V07*V08 + 3.14616699492002765e-10*V02*V082 + 
      1.00369023980135091e-9*V013*V02*V09 - 7.92456084758190786e-9*V022*V03*V09 - 
      9.03546132401563463e-9*V01*V032*V09 - 9.76593414783968783e-9*V01*V02*V04*V09 - 
      2.6475492964171769e-9*V012*V05*V09 + 2.41967965015243137e-9*V04*V05*V09 + 1.75967541052281089e-9*V03*V06*V09 + 
      6.25456165059616089e-10*V02*V07*V09 + 2.19248139960954814e-10*V01*V08*V09 + 4.01476095920540365e-11*V014*V10 - 
      4.41323816738797546e-10*V023*V10 - 4.45295468686769652e-9*V01*V02*V03*V10 - 
      1.27550192715147586e-9*V012*V04*V10 + 5.34938290003461784e-10*V042*V10 + 
      1.1361175216718043e-9*V03*V05*V10 + 4.00148693505997441e-10*V02*V06*V10 + 1.80018298529104411e-10*V01*V07*V10 - 
      1.37352914624220985e-12*V102 - 4.69963194636397251e-10*V01*V022*V11 - 
      4.90627405455836828e-10*V012*V03*V11 + 5.02893349542243018e-10*V03*V04*V11 + 
      2.59112630875115109e-10*V02*V05*V11 + 1.15332635287803027e-10*V01*V06*V11 - 2.59545595292284319e-12*V09*V11 - 
      1.05092272167435566e-10*V012*V02*V12 + 9.92078181483731716e-11*V032*V12 + 
      9.54439427562594958e-11*V02*V04*V12 + 6.26440027127202582e-11*V01*V05*V12 - 1.92513302396022541e-12*V08*V12 - 
      5.9040602341255936e-12*V013*V13 + 3.87855325380408513e-11*V02*V03*V13 + 2.3732250541102737e-11*V01*V04*V13 - 
      1.28109968651631223e-12*V07*V13 + 3.08841045580429443e-12*V022*V14 + 7.94458631504268473e-12*V01*V03*V14 - 
      6.42639939769610351e-13*V06*V14 + 1.37243505442393185e-12*V01*V02*V15 - 2.95332486711414013e-13*V05*V15 + 
      1.16527504620899874e-13*V012*V16 - 9.08914536043019015e-14*V04*V16 - 2.71897510782099705e-14*V03*V17 - 
      3.88425015402999579e-15*V02*V18 - 6.47375025671665965e-16*V01*V19 + 1.00524072309264901e-18*V22) + 
   delta2*eps10*(-1.05683802773749864e-9*V026 - 1.43624287969526065e-6*V01*V024*V03 - 
      4.03239837763647287e-6*V012*V022*V032 - 6.39695952195952196e-7*V013*V033 + 
      1.03731386283469617e-6*V02*V034 - 1.80719302743112267e-6*V012*V023*V04 - 
      2.58256954685526114e-6*V013*V02*V03*V04 + 3.76126895224117446e-6*V022*V032*V04 + 
      2.41349362443112443e-6*V01*V033*V04 - 1.39266322302036588e-7*V014*V042 + 
      5.67501373552960855e-7*V023*V042 + 4.64213503648027458e-6*V01*V02*V03*V042 + 
      4.56605646337789195e-7*V012*V043 - 4.8511255774108832e-8*V044 - 
      6.58099616432949766e-7*V013*V022*V05 - 2.11015836015836016e-7*V014*V03*V05 + 
      1.29053917496377814e-6*V023*V03*V05 + 3.9946842867229772e-6*V01*V02*V032*V05 + 
      2.44500548319992764e-6*V01*V022*V04*V05 + 2.24826843130414559e-6*V012*V03*V04*V05 - 
      5.60125414233724224e-7*V03*V042*V05 + 6.19076139909473243e-7*V012*V02*V052 - 
      2.49438911785360782e-7*V032*V052 - 3.07119530720429413e-7*V02*V04*V052 - 
      5.691691187504096e-8*V01*V053 - 8.67188367188367188e-8*V014*V02*V06 + 
      1.01721424886107426e-7*V024*V06 + 1.76647646885742124e-6*V01*V022*V03*V06 + 
      7.76630845455250217e-7*V012*V032*V06 + 1.04599434956577814e-6*V012*V02*V04*V06 - 
      4.0652457348302353e-7*V032*V04*V06 - 2.31405524903132279e-7*V02*V042*V06 + 
      1.52463415112224636e-7*V013*V05*V06 - 4.49494829929295382e-7*V02*V03*V05*V06 - 
      2.8006164438601997e-7*V01*V04*V05*V06 - 4.55565553349458578e-8*V022*V062 - 
      1.00457618621134027e-7*V01*V03*V062 + 1.71256554412201539e-9*V063 - 
      3.61328486328486328e-9*V015*V07 + 2.13711461231302501e-7*V01*V023*V07 + 
      6.20745133393942918e-7*V012*V02*V03*V07 - 8.67051308647217844e-8*V033*V07 + 
      1.10772990237275952e-7*V013*V04*V07 - 3.23151314667712894e-7*V02*V03*V04*V07 - 
      1.01333081107021933e-7*V01*V042*V07 - 8.70315157488360103e-8*V022*V05*V07 - 
      1.77061130153304523e-7*V01*V03*V05*V07 - 8.07420722001137501e-8*V01*V02*V06*V07 + 9.36414228087805413e-9*V05*V06*V07 - 
      7.52927932914510879e-9*V012*V072 + 3.39053821003755583e-9*V04*V072 + 
      1.08217881655381655e-7*V012*V022*V08 + 5.69694580111246778e-8*V013*V03*V08 - 
      9.20055009399080361e-8*V02*V032*V08 - 5.09313924784279593e-8*V022*V04*V08 - 
      1.13208170487071631e-7*V01*V03*V04*V08 - 6.28664755448281359e-8*V01*V02*V05*V08 + 
      3.65860240983193125e-9*V052*V08 - 1.33508092355693896e-8*V012*V06*V08 + 
      5.81472070492569043e-9*V04*V06*V08 + 3.86604911270109038e-9*V03*V07*V08 + 6.69355072471856466e-10*V02*V082 + 
      1.80664243164243164e-8*V013*V02*V09 - 2.83619245526925265e-8*V022*V03*V09 - 
      2.81638855036964281e-8*V01*V032*V09 - 3.58774136840050706e-8*V01*V02*V04*V09 - 
      9.23462495591347132e-9*V012*V05*V09 + 4.20004124525269606e-9*V04*V05*V09 + 3.06443310291299597e-9*V03*V06*V09 + 
      1.23744774342815094e-9*V02*V07*V09 + 4.45845885430025007e-10*V01*V08*V09 + 9.03321215821215821e-10*V014*V10 - 
      2.36809044533523214e-9*V023*V10 - 1.64647371186236732e-8*V01*V02*V03*V10 - 
      4.8689519595069315e-9*V012*V04*V10 + 1.06738757717012689e-9*V042*V10 + 
      1.95993066468536445e-9*V03*V05*V10 + 8.68331150576541423e-10*V02*V06*V10 + 3.64912169506311622e-10*V01*V07*V10 - 
      2.10980781986575818e-12*V102 - 2.1210336391096195e-9*V01*V022*V11 - 
      1.96605205796382267e-9*V012*V03*V11 + 9.3749562552640253e-10*V03*V04*V11 + 5.22594784223503694e-10*V02*V05*V11 + 
      2.40847369943663066e-10*V01*V06*V11 - 3.90006460108568935e-12*V09*V11 - 4.91513014490955667e-10*V012*V02*V12 + 
      1.84496333387633329e-10*V032*V12 + 2.23917921136611244e-10*V02*V04*V12 + 1.29959796546414746e-10*V01*V05*V12 - 
      2.97043406422117702e-12*V08*V12 - 3.09963162291593664e-11*V013*V13 + 8.4929129617865858e-11*V02*V03*V13 + 
      5.3556817973796388e-11*V01*V04*V13 - 1.92853020147589291e-12*V07*V13 + 8.62458904200820265e-12*V022*V14 + 
      1.80431188155001364e-11*V01*V03*V14 - 1.01084835794234905e-12*V06*V14 + 3.67061639555834602e-12*V01*V02*V15 - 
      4.49879401768545584e-13*V05*V15 + 3.26277012938519646e-13*V012*V16 - 1.51596734582999264e-13*V04*V16 - 
      4.39752606724110238e-14*V03*V17 - 7.49105386848642045e-15*V02*V18 - 1.24850897808107008e-15*V01*V19 + 
      1.50786108463897352e-18*V22) + delta4*eps9*
    (5.77265272205748396e-7*V02*V034 + 1.82975598402185704e-6*V022*V032*V04 + 
      1.29435893324782214e-6*V01*V033*V04 + 1.71045640622360199e-7*V023*V042 + 
      2.22836898184120406e-6*V01*V02*V03*V042 + 2.17760634427301094e-7*V012*V043 - 
      3.60906857706966639e-8*V044 + 5.88336453498490536e-7*V023*V03*V05 + 
      2.02834900255535176e-6*V01*V02*V032*V05 + 1.09785359041311422e-6*V01*V022*V04*V05 + 
      1.10349719724719725e-6*V012*V03*V04*V05 - 4.68083420578654783e-7*V03*V042*V05 + 
      2.91282378335949765e-7*V012*V02*V052 - 2.17885800504264557e-7*V032*V052 - 
      2.43074095879106772e-7*V02*V04*V052 - 4.63433304017454344e-8*V01*V053 + 
      2.92978136893480809e-8*V024*V06 + 7.90223105451280054e-7*V01*V022*V03*V06 + 
      3.71694599125154681e-7*V012*V032*V06 + 4.64519313725662932e-7*V012*V02*V04*V06 - 
      3.39387086707542668e-7*V032*V04*V06 - 1.61809756133596781e-7*V02*V042*V06 + 
      6.75684269434269434e-8*V013*V05*V06 - 3.55806643708089008e-7*V02*V03*V05*V06 - 
      2.17671871098866897e-7*V01*V04*V05*V06 - 3.00604608299908642e-8*V022*V062 - 
      7.77819282174149121e-8*V01*V03*V062 + 1.60833310225194172e-9*V063 + 
      8.40480647854986479e-8*V01*V023*V07 + 2.70296649264903233e-7*V012*V02*V03*V07 - 
      7.32294648124869102e-8*V033*V07 + 4.66974053283577093e-8*V013*V04*V07 - 
      2.46677484412856339e-7*V02*V03*V04*V07 - 7.61219370190736515e-8*V01*V042*V07 - 
      6.29359832025273202e-8*V022*V05*V07 - 1.38998120525801042e-7*V01*V03*V05*V07 - 
      5.7467395205441813e-8*V01*V02*V06*V07 + 9.13001277706507386e-9*V05*V06*V07 - 
      5.30907153538845104e-9*V012*V072 + 3.22444623072974743e-9*V04*V072 + 
      4.26367613867613868e-8*V012*V022*V08 + 2.3125023125023125e-8*V013*V03*V08 - 
      7.06136849830438377e-8*V02*V032*V08 - 3.23479074354424494e-8*V022*V04*V08 - 
      8.51545756400059232e-8*V01*V03*V04*V08 - 4.4997879418105842e-8*V01*V02*V05*V08 + 
      3.58588104686483122e-9*V052*V08 - 9.33831149945373413e-9*V012*V06*V08 + 
      5.35219682347953734e-9*V04*V06*V08 + 3.70330815615235731e-9*V03*V07*V08 + 5.74573573165675699e-10*V02*V082 + 
      6.62435558268891602e-9*V013*V02*V09 - 1.95347640966513516e-8*V022*V03*V09 - 
      2.10785071604399335e-8*V01*V032*V09 - 2.43510434044981197e-8*V01*V02*V04*V09 - 
      6.44571558874780163e-9*V012*V05*V09 + 3.98584660105880436e-9*V04*V05*V09 + 2.91333022299243766e-9*V03*V06*V09 + 
      1.09040704931153581e-9*V02*V07*V09 + 3.89198166147944597e-10*V01*V08*V09 + 3.01107071940405274e-10*V014*V10 - 
      1.34500115047889713e-9*V023*V10 - 1.12181361634267797e-8*V01*V02*V03*V10 - 
      3.25870387436680621e-9*V012*V04*V10 + 9.5573417761393829e-10*V042*V10 + 
      1.87501133817503019e-9*V03*V05*V10 + 7.39981468201118634e-10*V02*V06*V10 + 3.1894243886195272e-10*V01*V07*V10 - 
      2.09271123396052009e-12*V102 - 1.28944675513302964e-9*V01*V022*V11 - 
      1.29121797320326732e-9*V012*V03*V11 + 8.658560693855349e-10*V03*V04*V11 + 4.59043272703367589e-10*V02*V05*V11 + 
      2.08292359616979377e-10*V01*V06*V11 - 3.89895481532739506e-12*V09*V11 - 2.9520301170627968e-10*V012*V02*V12 + 
      1.71398086975365036e-10*V032*V12 + 1.84287767650791223e-10*V02*V04*V12 + 1.129495553361591e-10*V01*V05*V12 - 
      2.94167211665205015e-12*V08*V12 - 1.77121807023767808e-11*V013*V13 + 7.22146841136743384e-11*V02*V03*V13 + 
      4.47838505759042395e-11*V01*V04*V13 - 1.92742041571759863e-12*V07*V13 + 6.47582185679880898e-12*V022*V14 + 
      1.51042951489610416e-11*V01*V03*V14 - 9.94035103704190637e-13*V06*V14 + 2.80831286136368696e-12*V01*V02*V15 - 
      4.48769616010251299e-13*V05*V15 + 2.44707759703889735e-13*V012*V16 - 1.45326445048636557e-13*V04*V16 - 
      4.28654749141167393e-14*V03*V17 - 6.65871454976570707e-15*V02*V18 - 1.10978575829428451e-15*V01*V19 + 
      1.50786108463897352e-18*V22) + 3.86817017063068404e-23*delta22*V22 + 
   2.12749359384687622e-22*delta20*eps*V22 + 
   delta20*eps2*(-3.41091377476043088e-18*V112 - 5.24755965347758597e-18*V10*V12 - 
      4.81026301568778714e-18*V09*V13 - 2.56547360836681981e-18*V08*V14 - 1.64923303395009845e-18*V07*V15 - 
      5.82082247276505334e-19*V06*V16 - 2.54660983183471084e-19*V05*V17 - 5.36128385649412808e-20*V04*V18 - 
      1.48924551569281335e-20*V03*V19 - 1.41832906256458415e-21*V02*V20 - 2.12749359384687622e-22*V01*V21 + 
      2.12749359384687622e-24*V24) + delta18*eps3*
    (-3.41091377476043088e-17*V112 - 5.24755965347758597e-17*V10*V12 - 4.81026301568778714e-17*V09*V13 - 
      2.56547360836681981e-17*V08*V14 - 1.64923303395009845e-17*V07*V15 - 5.82082247276505334e-18*V06*V16 - 
      2.54660983183471084e-18*V05*V17 - 5.36128385649412808e-19*V04*V18 - 1.48924551569281335e-19*V03*V19 - 
      1.41832906256458415e-20*V02*V20 - 2.12749359384687622e-21*V01*V21 + 1.06374679692343811e-23*V24) + 
   delta16*eps4*(1.95275788151827456e-13*V06*V072 + 1.10155572803594975e-13*V062*V08 + 
      3.00424289464349933e-13*V05*V07*V08 + 5.69431659769029285e-14*V04*V082 + 2.27821752843798699e-13*V05*V06*V09 + 
      1.53157480903394083e-13*V04*V07*V09 + 8.34511915178749814e-14*V03*V08*V09 + 1.07059094381484351e-14*V02*V092 + 
      7.06059151375409192e-14*V052*V10 + 6.95537485590207015e-14*V04*V06*V10 + 6.7243728702419923e-14*V03*V07*V10 + 
      1.28135148350630137e-14*V02*V08*V10 + 5.60364405853499358e-15*V01*V09*V10 + 5.84783108903868319e-14*V04*V05*V11 + 
      4.14221368806906726e-14*V03*V06*V11 + 1.40150087190306787e-14*V02*V07*V11 + 4.55188317370227171e-15*V01*V08*V11 - 
      2.06888162885766611e-16*V112 + 7.37226568917269889e-15*V042*V12 + 2.1242121477277268e-14*V03*V05*V12 + 
      5.25463004964227156e-15*V02*V06*V12 + 3.03458878246818114e-15*V01*V07*V12 - 3.25473640412121701e-16*V10*V12 + 
      7.4972193449213887e-15*V03*V04*V13 + 3.77327157820056734e-15*V02*V05*V13 + 1.5931591107957951e-15*V01*V06*V13 - 
      2.93082453741548745e-16*V09*V13 + 1.13797079342556793e-15*V032*V14 + 7.91999487189063994e-16*V02*V04*V14 + 
      6.82782476055340757e-16*V01*V05*V14 - 1.60525348637809582e-16*V08*V14 + 3.59359197923863556e-16*V02*V03*V15 + 
      2.14206266997753963e-16*V01*V04*V15 - 1.01840139846418579e-16*V07*V15 + 1.55017693222058789e-17*V022*V16 + 
      5.35515667494384907e-17*V01*V03*V16 - 3.70592364099375063e-17*V06*V16 + 7.9270411306734608e-18*V01*V02*V17 - 
      1.60739587242709963e-17*V05*V17 + 4.40391173926303378e-19*V012*V18 - 3.50142895675318888e-18*V04*V18 - 
      9.68541458598790399e-19*V03*V19 - 9.57372117231094299e-20*V02*V20 - 1.43605817584664145e-20*V01*V21 + 
      4.7868605861554715e-23*V24) + delta14*eps5*
    (2.05039577559418829e-12*V06*V072 + 1.23173958680383473e-12*V062*V08 + 
      3.16697271810335554e-12*V05*V07*V08 + 6.37501651281648877e-13*V04*V082 + 2.39212840485988634e-12*V05*V06*V09 + 
      1.60336737820740681e-12*V04*V07*V09 + 8.79714643917598762e-13*V03*V08*V09 + 1.11817276353994767e-13*V02*V092 + 
      7.48422700457933743e-13*V052*V10 + 7.8015382937856978e-13*V04*V06*V10 + 7.12783524245651184e-13*V03*V07*V10 + 
      1.44021970804301276e-13*V02*V08*V10 + 5.9398627020470932e-14*V01*V09*V10 + 6.12194817133737146e-13*V04*V05*V11 + 
      4.34932437247252062e-13*V03*V06*V11 + 1.46378979954320422e-13*V02*V07*V11 + 4.79844351227781143e-14*V01*V08*V11 - 
      9.47746755987005437e-16*V112 + 8.32191347286274146e-14*V042*V12 + 2.27025173288400802e-13*V03*V05*V12 + 
      5.93661394970222595e-14*V02*V06*V12 + 3.24321676126286859e-14*V01*V07*V12 - 1.54428184088054673e-15*V10*V12 + 
      7.8486515017145788e-14*V03*V04*V13 + 3.94097253723170367e-14*V02*V05*V13 + 1.67281706633558485e-14*V01*V06*V13 - 
      1.35237108783908073e-15*V09*V13 + 1.23280169287769859e-14*V032*V14 + 9.06336779704970386e-15*V02*V04*V14 + 
      7.39681015726619153e-15*V01*V05*V14 - 7.71841059888646073e-16*V08*V14 + 3.75330717831590825e-15*V02*V03*V15 + 
      2.2424718576327368e-15*V01*V04*V15 - 4.79926812879478648e-16*V07*V15 + 1.82732977767820815e-16*V022*V16 + 
      5.95761180087503209e-16*V01*V03*V16 - 1.82773825644822675e-16*V06*V16 + 8.2793540698145035e-17*V01*V02*V17 - 
      7.82900622586899674e-17*V05*V17 + 5.28469408711564053e-18*V012*V18 - 1.78913701268146903e-17*V04*V18 - 
      4.9208926825678247e-18*V03*V19 - 5.10598462523250293e-19*V02*V20 - 7.65897693784875439e-20*V01*V21 + 
      1.9147442344621886e-22*V24) + delta12*eps6*
    (-1.81710194045720362e-10*V042*V052 - 1.29792995746943115e-10*V03*V053 - 
      4.18662090202051216e-11*V043*V06 - 5.14805050014601672e-10*V03*V04*V05*V06 - 
      1.29420107732156236e-10*V02*V052*V06 - 9.01865811069624174e-11*V032*V062 - 
      4.40269978275238859e-11*V02*V04*V062 - 5.41119486641774504e-11*V01*V05*V062 - 
      1.7305732766259082e-10*V03*V042*V07 - 1.82550878953343448e-10*V032*V05*V07 - 
      1.71981279391348682e-10*V02*V04*V05*V07 - 5.3904957766173305e-11*V01*V052*V07 - 
      1.23257245459196415e-10*V02*V03*V06*V07 - 7.35435785735145245e-11*V01*V04*V06*V07 - 
      9.95785605773606822e-12*V022*V072 - 2.49971695512631185e-11*V01*V03*V072 + 
      1.15250268045761243e-11*V06*V072 - 9.3124342549990002e-11*V032*V04*V08 - 
      2.23761745508195875e-11*V02*V042*V08 - 9.46468041976648278e-11*V02*V03*V05*V08 - 
      5.58746055299940012e-11*V01*V04*V05*V08 - 7.76241046146929228e-12*V022*V06*V08 - 
      3.85115190357462705e-11*V01*V03*V06*V08 + 7.53554676494466446e-12*V062*V08 - 
      1.35209720282378325e-11*V01*V02*V07*V08 + 1.79154934532962937e-11*V05*V07*V08 - 
      9.82119292914208671e-13*V012*V082 + 3.92859226055028743e-12*V04*V082 - 
      1.63718061254146838e-11*V033*V09 - 4.77725776087079673e-11*V02*V03*V04*V09 - 
      1.44214439718825684e-11*V01*V042*V09 - 1.16174987340254129e-11*V022*V05*V09 - 
      2.86854167432348997e-11*V01*V03*V05*V09 - 1.02714371215997013e-11*V01*V02*V06*V09 + 1.35496295737393273e-11*V05*V06*V09 - 
      1.84187443018241419e-12*V012*V07*V09 + 9.10052682992914154e-12*V04*V07*V09 + 
      5.05222430881163618e-12*V03*V08*V09 + 6.46063149296892166e-13*V02*V092 - 
      1.04307530326792808e-11*V02*V032*V10 - 2.36513594902759535e-12*V022*V04*V10 - 
      1.21170650938357241e-11*V01*V03*V04*V10 - 6.25845181960756846e-12*V01*V02*V05*V10 + 
      4.29758799138050964e-12*V052*V10 - 1.19770545225693172e-12*V012*V06*V10 + 
      4.84506694116438835e-12*V04*V06*V10 + 4.12322028399698023e-12*V03*V07*V10 + 9.06863113883747762e-13*V02*V08*V10 + 
      3.51171525289348256e-13*V01*V09*V10 - 2.11227249709552962e-12*V022*V03*V11 - 
      2.44960790856780832e-12*V01*V032*V11 - 2.60577696047498003e-12*V01*V02*V04*V11 - 
      6.77191269711172409e-13*V012*V05*V11 + 3.52815936324254369e-12*V04*V05*V11 + 
      2.52016808708015893e-12*V03*V06*V11 + 8.52167490935571267e-13*V02*V07*V11 + 2.83833873160198232e-13*V01*V08*V11 - 
      3.51413879689133865e-15*V112 - 5.41772745293529826e-14*V023*V12 - 
      9.0682813881742576e-13*V01*V02*V03*V12 - 2.52291295718900679e-13*V012*V04*V12 + 
      5.289041628784641e-13*V042*V12 + 1.34433281283334658e-12*V03*V05*V12 + 3.79763754107156185e-13*V02*V06*V12 + 
      1.94742738674907059e-13*V01*V07*V12 - 5.94631364944065399e-15*V10*V12 - 8.12412498882896009e-14*V01*V022*V13 - 
      7.79957430929223155e-14*V012*V03*V13 + 4.66023701813509939e-13*V03*V04*V13 + 
      2.34608709303411746e-13*V02*V05*V13 + 1.0055768755904512e-13*V01*V06*V13 - 5.05191543929168149e-15*V09*V13 - 
      1.32927671937915412e-14*V012*V02*V14 + 7.5919621661387341e-14*V032*V14 + 
      5.98495128495237701e-14*V02*V04*V14 + 4.58452496751368932e-14*V01*V05*V14 - 3.0134525591120312e-15*V08*V14 - 
      5.17900020537332772e-16*V013*V15 + 2.31657501249873611e-14*V02*V03*V15 + 1.3901916265566404e-14*V01*V04*V15 - 
      1.83240640289184556e-15*V07*V15 + 1.26762195502947164e-15*V022*V16 + 3.87685158230803389e-15*V01*V03*V16 - 
      7.33048341698442132e-16*V06*V16 + 5.36396449842237514e-16*V01*V02*V17 - 3.09533723454688484e-16*V05*V17 + 
      3.69928586098094837e-17*V012*V18 - 7.45754584438333215e-17*V04*V18 - 2.03728786546776867e-17*V03*V19 - 
      2.23386827353922003e-18*V02*V20 - 3.35080241030883005e-19*V01*V21 + 6.7016048206176601e-22*V24) + 
   delta10*eps7*(-1.70557610707464509e-9*V042*V052 - 1.19217270167562565e-9*V03*V053 - 
      5.01323905320006685e-10*V043*V06 - 4.86215725920891613e-9*V03*V04*V05*V06 - 
      1.21733642787349358e-9*V02*V052*V06 - 8.59173938356269183e-10*V032*V062 - 
      5.31289659696870534e-10*V02*V04*V062 - 5.1550436301376151e-10*V01*V05*V062 - 
      1.6243581972139477e-9*V03*V042*V07 - 1.68494184567353601e-9*V032*V05*V07 - 
      1.61287383824424957e-9*V02*V04*V05*V07 - 5.00033949543139184e-10*V01*V052*V07 - 
      1.15936802654618436e-9*V02*V03*V06*V07 - 6.94593894172702304e-10*V01*V04*V06*V07 - 
      9.39246312560111764e-11*V022*V072 - 2.33856304153575109e-10*V01*V03*V072 + 
      4.44102205900675288e-11*V06*V072 - 8.89988989578240483e-10*V032*V04*V08 - 
      2.7239765423050433e-10*V02*V042*V08 - 8.9868083163720132e-10*V02*V03*V05*V08 - 
      5.3399339374694429e-10*V01*V04*V05*V08 - 9.55675284983031473e-11*V022*V06*V08 - 
      3.723987620360497e-10*V01*V03*V06*V08 + 3.1674494679726012e-11*V062*V08 - 
      1.28382975948171617e-10*V01*V02*V07*V08 + 6.94986314416835163e-11*V05*V07*V08 - 
      9.71432467093597043e-12*V012*V082 + 1.67162671835187365e-11*V04*V082 - 
      1.52649797958091841e-10*V033*V09 - 4.48020510623402657e-10*V02*V03*V04*V09 - 
      1.35363183101162308e-10*V01*V042*V09 - 1.09578736465346372e-10*V022*V05*V09 - 
      2.69805352535325616e-10*V01*V03*V05*V09 - 9.66140022121820299e-11*V01*V02*V06*V09 + 5.29256680159109844e-11*V05*V06*V09 - 
      1.79602794741199031e-11*V012*V07*V09 + 3.57673098659722354e-11*V04*V07*V09 + 2.0127259476718193e-11*V03*V08*V09 + 
      2.61853949669536431e-12*V02*V092 - 1.00756215900251097e-10*V02*V032*V10 - 
      2.97018917149718008e-11*V022*V04*V10 - 1.18149015058534227e-10*V01*V03*V04*V10 - 
      6.04537295401506583e-11*V01*V02*V05*V10 + 1.69961237638805225e-11*V052*V10 - 
      1.19030688053496982e-11*V012*V06*V10 + 2.08588297254544514e-11*V04*V06*V10 + 
      1.65213712420960515e-11*V03*V07*V10 + 3.99657392471796277e-12*V02*V08*V10 + 1.46042761310808322e-12*V01*V09*V10 - 
      1.99234066300629768e-11*V022*V03*V11 - 2.35260967386419907e-11*V01*V032*V11 - 
      2.44374823976401449e-11*V01*V02*V04*V11 - 6.69245203681785332e-12*V012*V05*V11 + 
      1.42250735474288297e-11*V04*V05*V11 + 1.02303454542559249e-11*V03*V06*V11 + 3.49571416005116678e-12*V02*V07*V11 + 
      1.18753241613923411e-12*V01*V08*V11 - 1.07722042660262976e-14*V112 - 7.15353102653051873e-13*V023*V12 - 
      9.02525129503932721e-12*V01*V02*V03*V12 - 2.54954781538806962e-12*V012*V04*V12 + 
      2.35514294482179882e-12*V042*V12 + 5.54943436053908996e-12*V03*V05*V12 + 1.71018478591264041e-12*V02*V06*V12 + 
      8.23411708842879362e-13*V01*V07*V12 - 1.88276916619772124e-14*V10*V12 - 7.6628487038703757e-13*V01*V022*V13 - 
      8.02123551808220998e-13*V012*V03*V13 + 1.96948746143338698e-12*V03*V04*V13 + 
      9.95921739493290921e-13*V02*V05*V13 + 4.32416922861785017e-13*V01*V06*V13 - 1.55700618665683636e-14*V09*V13 - 
      1.39833005545079848e-13*V012*V02*V14 + 3.29532384496182881e-13*V032*V14 + 
      2.80820188278785753e-13*V02*V04*V14 + 2.01241150837363591e-13*V01*V05*V14 - 9.65495738769839211e-15*V08*V14 - 
      6.21480024644799327e-15*V013*V15 + 1.03543011248856745e-13*V02*V03*V15 + 6.25179310505780275e-14*V01*V04*V15 - 
      5.74558068332762718e-15*V07*V15 + 6.30358310711153603e-15*V022*V16 + 1.7985927856089371e-14*V01*V03*V16 - 
      2.40764535427438304e-15*V06*V16 + 2.55250724407685438e-15*V01*V02*V17 - 1.00124656661956089e-15*V05*V17 + 
      1.84964293049047419e-16*V012*V18 - 2.54660983183471084e-16*V04*V18 - 6.9026529652361899e-17*V03*V19 - 
      8.04192578474119211e-18*V02*V20 - 1.20628886771117882e-18*V01*V21 + 2.01048144618529803e-21*V24) + 
   delta8*eps8*(1.12851894189429203e-8*V034*V04 + 
      3.22772161542391857e-8*V02*V032*V042 + 1.32727772394750297e-9*V022*V043 + 
      1.28988759163051102e-8*V01*V03*V043 + 2.32560932622207132e-8*V02*V033*V05 + 
      3.15213839859809359e-8*V022*V03*V04*V05 + 3.88793049954736852e-8*V01*V032*V04*V05 + 
      1.93663296925435114e-8*V01*V02*V042*V05 + 2.50509275733948937e-9*V023*V052 + 
      2.01676793537496152e-8*V01*V02*V03*V052 + 5.42296366876198809e-9*V012*V04*V052 - 
      7.79716800769014296e-9*V042*V052 - 5.26980793180764275e-9*V03*V053 + 
      1.12944672278822606e-8*V022*V032*V06 + 8.727044463213931e-9*V01*V033*V06 + 
      8.90219825015965694e-10*V023*V04*V06 + 2.72517925412416542e-8*V01*V02*V03*V04*V06 + 
      3.97332007927635067e-9*V012*V042*V06 - 2.82619430165753763e-9*V043*V06 + 
      6.77668033672935634e-9*V01*V022*V05*V06 + 7.21389005435262827e-9*V012*V03*V05*V06 - 
      2.24289006366088539e-8*V03*V04*V05*V06 - 5.65439409962507944e-9*V02*V052*V06 + 
      1.39900924433487459e-9*V012*V02*V062 - 4.00160730277563195e-9*V032*V062 - 
      3.03640156876773161e-9*V02*V04*V062 - 2.43622427282075352e-9*V01*V05*V062 + 
      2.38580262603760892e-9*V023*V03*V07 + 9.24041655785742309e-9*V01*V02*V032*V07 + 
      4.5030548551401337e-9*V01*V022*V04*V07 + 4.91510203033701322e-9*V012*V03*V04*V07 - 
      7.54012879201343963e-9*V03*V042*V07 + 2.57138691939695675e-9*V012*V02*V05*V07 - 
      7.59338696663967903e-9*V032*V05*V07 - 7.5484574628484751e-9*V02*V04*V05*V07 - 
      2.29457182461032637e-9*V01*V052*V07 + 2.82523339489181381e-10*V013*V06*V07 - 
      5.4663977239129376e-9*V02*V03*V06*V07 - 3.30056967893175719e-9*V01*V04*V06*V07 - 
      4.51109044388735651e-10*V022*V072 - 1.09454741335667439e-9*V01*V03*V072 + 
      1.26631398443508704e-10*V06*V072 + 3.65989257687912458e-11*V024*V08 + 
      2.43314756620078749e-9*V01*V022*V03*V08 + 1.21284391647629535e-9*V012*V032*V08 + 
      1.42878257665839365e-9*V012*V02*V04*V08 - 4.21187584438707663e-9*V032*V04*V08 - 
      1.57900113818356684e-9*V02*V042*V08 + 2.09303621061842869e-10*V013*V05*V08 - 
      4.27845468704313461e-9*V02*V03*V05*V08 - 2.56344641051699639e-9*V01*V04*V05*V08 - 
      5.6232564871173011e-10*V022*V06*V08 - 1.80530156382735475e-9*V01*V03*V06*V08 + 
      9.74318743872451483e-11*V062*V08 - 6.28867334096473348e-10*V01*V02*V07*V08 + 
      1.99076135566589245e-10*V05*V07*V08 - 4.90493244688611919e-11*V012*V082 + 
      5.22622857692870916e-11*V04*V082 + 1.98816885503134077e-10*V01*V023*V09 + 
      6.53734098066692215e-10*V012*V02*V03*V09 - 7.14665652030552913e-10*V033*V09 + 
      1.07959958566867997e-10*V013*V04*V09 - 2.16039515045621509e-9*V02*V03*V04*V09 - 
      6.56907690744922031e-10*V01*V042*V09 - 5.34141365181383528e-10*V022*V05*V09 - 
      1.28674492004969786e-9*V01*V03*V05*V09 - 4.75848265203103142e-10*V01*V02*V06*V09 + 1.53293911446729409e-10*V05*V06*V09 - 
      8.93781990681032949e-11*V012*V07*V09 + 1.04748497532374607e-10*V04*V07*V09 + 
      5.96375848728657949e-11*V03*V08*V09 + 8.00285623282956963e-12*V02*V092 + 
      7.68511840475348101e-11*V012*V022*V10 + 4.10332186271728755e-11*V013*V03*V10 - 
      4.99307533109571225e-10*V02*V032*V10 - 1.79761814709409732e-10*V022*V04*V10 - 
      5.90560875518700023e-10*V01*V03*V04*V10 - 3.03615680992265154e-10*V01*V02*V05*V10 + 
      4.95593811626264585e-11*V052*V10 - 6.1010472062228291e-11*V012*V06*V10 + 
      6.60909927939994441e-11*V04*V06*V10 + 4.90642617367695468e-11*V03*V07*V10 + 1.30867700317987669e-11*V02*V08*V10 + 
      4.56632279958408988e-12*V01*V09*V10 + 8.75768934728629718e-12*V013*V02*V11 - 
      1.01397055520901697e-10*V022*V03*V11 - 1.18628329061350954e-10*V01*V032*V11 - 
      1.24778071200457163e-10*V01*V02*V04*V11 - 3.4528579333517025e-11*V012*V05*V11 + 
      4.27939492219946726e-11*V04*V05*V11 + 3.09900829324836135e-11*V03*V06*V11 + 1.08063045332860666e-11*V02*V07*V11 + 
      3.74521866042146181e-12*V01*V08*V11 - 2.71163685054242072e-14*V112 + 2.9520301170627968e-13*V014*V12 - 
      4.5881009438459709e-12*V023*V12 - 4.77907041094267739e-11*V01*V02*V03*V12 - 
      1.3647553369765354e-11*V012*V04*V12 + 7.75800666716767563e-12*V042*V12 + 
      1.69422051777957712e-11*V03*V05*V12 + 5.72886205574953589e-12*V02*V06*V12 + 2.60664012717587559e-12*V01*V07*V12 - 
      4.85079215546758719e-14*V10*V12 - 4.17427416553090214e-12*V01*V022*V13 - 
      4.44746642636434518e-12*V012*V03*V13 + 6.23590467228488958e-12*V03*V04*V13 + 
      3.18383353458829799e-12*V02*V05*V13 + 1.40300965206493938e-12*V01*V06*V13 - 3.92968703471378353e-14*V09*V13 - 
      8.00155531730179133e-13*V012*V02*V14 + 1.06004577715517818e-12*V032*V14 + 
      9.83467477094655061e-13*V02*V04*V14 + 6.59268229714719714e-13*V01*V05*V14 - 2.50933103808588833e-14*V08*V14 - 
      3.88425015402999579e-14*V013*V15 + 3.49335894805300891e-13*V02*V03*V15 + 2.12560965571965293e-13*V01*V04*V15 - 
      1.46526903520153798e-14*V07*V15 + 2.35521199815787046e-14*V022*V16 + 6.23329667575289801e-14*V01*V03*V16 - 
      6.38931003597687713e-15*V06*V16 + 9.24821465245237093e-15*V01*V02*V17 - 2.61613898184861906e-15*V05*V17 + 
      6.9361609893392782e-16*V012*V18 - 7.01658024718669012e-16*V04*V18 - 1.8848263557987169e-16*V03*V19 - 
      2.34556168721618103e-17*V02*V20 - 3.51834253082427155e-18*V01*V21 + 5.02620361546324507e-21*V24) + 
   eps12*(4.38492191964414187e-7*V012*V025 + 1.56443190297356964e-6*V013*V023*V03 + 
      6.26423152464819131e-7*V014*V02*V032 - 6.15952990446624706e-7*V024*V032 - 
      2.13342389991695547e-6*V01*V022*V033 - 4.02632490461111493e-7*V012*V034 + 
      4.3106488418988419e-7*V014*V022*V04 - 1.43889032777921667e-7*V025*V04 + 
      9.17774355274355274e-8*V015*V03*V04 - 3.11017509368203813e-6*V01*V023*V03*V04 - 
      3.63782652349120603e-6*V012*V02*V032*V04 + 1.63667367473803243e-7*V034*V04 - 
      1.39086131227128251e-6*V012*V022*V042 - 6.47181474004390671e-7*V013*V03*V042 + 
      6.94893262950216634e-7*V02*V032*V042 + 1.51283642180000723e-7*V022*V043 + 
      2.90338231387046747e-7*V01*V03*V043 + 4.81771315104648438e-8*V015*V02*V05 - 
      4.63494115837865838e-7*V01*V024*V05 - 2.22791129909185465e-6*V012*V022*V03*V05 - 
      5.21445756440796123e-7*V013*V032*V05 + 3.96565639823316158e-7*V02*V033*V05 - 
      7.97474910818164786e-7*V013*V02*V04*V05 + 8.3079202034726953e-7*V022*V03*V04*V05 + 
      7.30771143336125926e-7*V01*V032*V04*V05 + 5.27975212689593233e-7*V01*V02*V042*V05 - 
      3.96192383729586111e-8*V014*V052 + 8.21761150132950242e-8*V023*V052 + 
      4.45765187284624921e-7*V01*V02*V03*V052 + 1.3232200882651688e-7*V012*V04*V052 - 
      2.37469976794500349e-8*V042*V052 - 1.36096627499663723e-8*V03*V053 + 
      1.80664243164243164e-9*V016*V06 - 3.92472994469522247e-7*V012*V023*V06 - 
      5.43036567342122898e-7*V013*V02*V03*V06 + 2.9825624725585578e-7*V022*V032*V06 + 
      1.71632696794454206e-7*V01*V033*V06 - 6.66349950204116871e-8*V014*V04*V06 + 
      1.29177689090543121e-7*V023*V04*V06 + 7.4981900942536933e-7*V01*V02*V03*V04*V06 + 
      1.1252040651039834e-7*V012*V042*V06 - 1.29392157703847877e-8*V043*V06 + 
      2.26994879836485229e-7*V01*V022*V05*V06 + 1.8517650554189128e-7*V012*V03*V05*V06 - 
      6.81809509230165907e-8*V03*V04*V05*V06 - 2.05992629199890677e-8*V02*V052*V06 + 
      4.8446145797846895e-8*V012*V02*V062 - 1.22055305562127859e-8*V032*V062 - 
      1.68156090978436291e-8*V02*V04*V062 - 9.37819813764003117e-9*V01*V05*V062 - 
      1.2330334595959596e-7*V013*V022*V07 - 3.92944728882228882e-8*V014*V03*V07 + 
      8.66334246474497019e-8*V023*V03*V07 + 2.31846393732372082e-7*V01*V02*V032*V07 + 
      1.6665107427975075e-7*V01*V022*V04*V07 + 1.36708868964792167e-7*V012*V03*V04*V07 - 
      2.50571343461910233e-8*V03*V042*V07 + 8.40820834182762287e-8*V012*V02*V05*V07 - 
      2.14821947819303148e-8*V032*V05*V07 - 3.02261663079119173e-8*V02*V04*V05*V07 - 
      8.22752243934466367e-9*V01*V052*V07 + 1.09705030084640262e-8*V013*V06*V07 - 
      2.17543301382968463e-8*V02*V03*V06*V07 - 1.38315040954813512e-8*V01*V04*V06*V07 - 
      2.39937340072932961e-9*V022*V072 - 4.31306178988452739e-9*V01*V03*V072 + 
      2.14767307517493529e-10*V06*V072 - 1.5356460668960669e-8*V014*V02*V08 + 
      7.81750055533643043e-9*V024*V08 + 9.19141145218555349e-8*V01*V022*V03*V08 + 
      3.68678479028521823e-8*V012*V032*V08 + 5.52415504398901925e-8*V012*V02*V04*V08 - 
      1.39583195853626023e-8*V032*V04*V08 - 9.5986425764438334e-9*V02*V042*V08 + 
      8.45095936083720086e-9*V013*V05*V08 - 1.6922158316131765e-8*V02*V03*V05*V08 - 
      1.07323878817334722e-8*V01*V04*V05*V08 - 4.15583968693321596e-9*V022*V06*V08 - 
      7.63161126818879759e-9*V01*V03*V06*V08 + 1.88392481149618117e-10*V062*V08 - 
      3.44611396259379405e-9*V01*V02*V07*V08 + 3.34163144371482397e-10*V05*V07*V08 - 
      2.87881903030246724e-10*V012*V082 + 1.07955611905981345e-10*V04*V082 - 
      6.32324851074851075e-10*V015*V09 + 1.08012321958230183e-8*V01*V023*V09 + 
      2.67003744013037314e-8*V012*V02*V03*V09 - 2.32715627508698703e-9*V033*V09 + 
      4.97490875478007831e-9*V013*V04*V09 - 9.88389262871376166e-9*V02*V03*V04*V09 - 
      3.15013205391853196e-9*V01*V042*V09 - 2.97133665297839776e-9*V022*V05*V09 - 
      5.32644539790241181e-9*V01*V03*V05*V09 - 2.74320110204596492e-9*V01*V02*V06*V09 + 2.65885815201741545e-10*V05*V06*V09 - 
      5.17205072695488891e-10*V012*V07*V09 + 1.95841700939319757e-10*V04*V07*V09 + 1.096083942566415e-10*V03*V08*V09 + 
      1.95715989957548972e-11*V02*V092 + 4.40590494971622423e-9*V012*V022*V10 + 
      2.16310006827776436e-9*V013*V03*V10 - 2.25902809958179182e-9*V02*V032*V10 - 
      1.54286144998219302e-9*V022*V04*V10 - 2.84471333483214826e-9*V01*V03*V04*V10 - 
      1.74167770044125429e-9*V01*V02*V05*V10 + 8.46077491142124186e-11*V052*V10 - 
      3.74968030744362659e-10*V012*V06*V10 + 1.40534807154727983e-10*V04*V06*V10 + 
      8.96631141416310435e-11*V03*V07*V10 + 3.53068698438173758e-11*V02*V08*V10 + 1.14933982587741202e-11*V01*V09*V10 + 
      6.56088693517206589e-10*V013*V02*V11 - 6.63592935339787407e-10*V022*V03*V11 - 
      5.86501686136304238e-10*V01*V032*V11 - 8.50965315512898983e-10*V01*V02*V04*V11 - 
      2.17109607466627468e-10*V012*V05*V11 + 8.25656605053924563e-11*V04*V05*V11 + 
      5.93973291009376551e-11*V03*V06*V11 + 2.66550932927223941e-11*V02*V07*V11 + 9.56771272405064299e-12*V01*V08*V11 - 
      4.07749009133190344e-14*V112 + 3.09963162291593664e-11*V014*V12 - 
      5.82036759080676063e-11*V023*V12 - 3.25941413725211455e-10*V01*V02*V03*V12 - 
      9.86366484114377131e-11*V012*V04*V12 + 1.84687031573766897e-11*V042*V12 + 
      3.1993273768693732e-11*V03*V05*V12 + 1.61905904420380971e-11*V02*V06*V12 + 6.62190665544894663e-12*V01*V07*V12 - 
      7.51070723847808455e-14*V10*V12 - 4.17471438054835888e-11*V01*V022*V13 - 
      3.44956371929249896e-11*V012*V03*V13 + 1.34089170629807992e-11*V03*V04*V13 + 
      8.16679779260448407e-12*V02*V05*V13 + 3.76684869312443917e-12*V01*V06*V13 - 5.91460018310722003e-14*V09*V13 - 
      8.42882283424509087e-12*V012*V02*V14 + 2.25096920533364482e-12*V032*V14 + 
      3.16777246847520571e-12*V02*V04*V14 + 1.75706830181942595e-12*V01*V05*V14 - 3.93062525938867e-14*V08*V14 - 
      4.8941551940777947e-13*V013*V15 + 1.01138475439219129e-12*V02*V03*V15 + 6.48114882843862155e-13*V01*V04*V15 - 
      2.21797318383885171e-14*V07*V15 + 1.05207689886298172e-13*V022*V16 + 1.90772171850787508e-13*V01*V03*V16 - 
      1.03716716845807155e-14*V06*V16 + 3.87037783205131723e-14*V01*V02*V17 - 4.05901125373965282e-15*V05*V17 + 
      3.12127244520267519e-15*V012*V18 - 1.25755614458890392e-15*V04*V18 - 3.20420480485781873e-16*V03*V19 - 
      5.52882397700956958e-17*V02*V20 - 8.29323596551435437e-18*V01*V21 + 7.53930542319486761e-21*V24) + 
   delta6*eps9*(7.65183075086203004e-8*V034*V04 + 
      2.36200532725392669e-7*V02*V032*V042 + 2.10474956623416007e-8*V022*V043 + 
      9.48188609885232979e-8*V01*V03*V043 + 1.57752553415679777e-7*V02*V033*V05 + 
      2.30720518966025502e-7*V022*V03*V04*V05 + 2.68114688535634692e-7*V01*V032*V04*V05 + 
      1.41720319635235602e-7*V01*V02*V042*V05 + 1.84747491222164425e-8*V023*V052 + 
      1.39170980163627222e-7*V01*V02*V03*V052 + 3.83673161377993311e-8*V012*V04*V052 - 
      2.2023741600738457e-8*V042*V052 - 1.42734771738816095e-8*V03*V053 + 
      8.35556661619725734e-8*V022*V032*V06 + 6.10311140773325647e-8*V01*V033*V06 + 
      1.45381579205108617e-8*V023*V04*V06 + 2.02131518633813996e-7*V01*V02*V03*V04*V06 + 
      2.94928838394835905e-8*V012*V042*V06 - 9.41028310842586455e-9*V043*V06 + 
      5.01333996971835441e-8*V01*V022*V05*V06 + 5.18720048632708141e-8*V012*V03*V05*V06 - 
      6.38881832797249232e-8*V03*V04*V05*V06 - 1.63995054407892911e-8*V02*V052*V06 + 
      1.04752648131110627e-8*V012*V02*V062 - 1.14954440383213866e-8*V032*V062 - 
      1.0373940513735223e-8*V02*V04*V062 - 7.1995374382365363e-9*V01*V05*V062 + 
      1.75949991640156595e-8*V023*V03*V07 + 6.49355534538774501e-8*V01*V02*V032*V07 + 
      3.29600741380036431e-8*V01*V022*V04*V07 + 3.5490127012847212e-8*V012*V03*V04*V07 - 
      2.19073568194984549e-8*V03*V042*V07 + 1.86392868465697597e-8*V012*V02*V05*V07 - 
      2.1179389152059458e-8*V032*V05*V07 - 2.23122299449632283e-8*V02*V04*V05*V07 - 
      6.59696094049781919e-9*V01*V052*V07 + 2.17904805955303932e-9*V013*V06*V07 - 
      1.62855136239927535e-8*V02*V03*V06*V07 - 9.93213689609712688e-9*V01*V04*V06*V07 - 
      1.39055312077097546e-9*V022*V072 - 3.23282820827403963e-9*V01*V03*V072 + 
      2.70691673066425051e-10*V06*V072 + 6.3274781919956039e-10*V024*V08 + 
      1.84578803786903694e-8*V01*V022*V03*V08 + 9.01661706319217472e-9*V012*V032*V08 + 
      1.08198370142036497e-8*V012*V02*V04*V08 - 1.23996749144077e-8*V032*V04*V08 - 
      5.5206283010412297e-9*V02*V042*V08 + 1.63325049124276223e-9*V013*V05*V08 - 
      1.28086576834036954e-8*V02*V03*V05*V08 - 7.75394468687961361e-9*V01*V04*V05*V08 - 
      2.01580544695901625e-9*V022*V06*V08 - 5.50766241918738492e-9*V01*V03*V06*V08 + 
      2.20755502650434519e-10*V062*V08 - 1.97947906813119159e-9*V01*V02*V07*V08 + 4.2591718923221259e-10*V05*V07*V08 - 
      1.583082256110483e-10*V012*V082 + 1.20675045280608754e-10*V04*V082 + 
      1.46624993033463829e-9*V01*V023*V09 + 4.95485603591345888e-9*V012*V02*V03*V09 - 
      2.10097487807609381e-9*V033*V09 + 8.58787732912382772e-10*V013*V04*V09 - 
      6.70950969054189387e-9*V02*V03*V04*V09 - 2.05870427299032854e-9*V01*V042*V09 - 
      1.68483925214565814e-9*V022*V05*V09 - 3.89132664126299495e-9*V01*V03*V05*V09 - 
      1.52386038876203899e-9*V01*V02*V06*V09 + 3.32066820728828843e-10*V05*V06*V09 - 
      2.85511375988624393e-10*V012*V07*V09 + 2.30855487854577695e-10*V04*V07*V09 + 
      1.32285455360861002e-10*V03*V08*V09 + 1.86224886360941026e-11*V02*V092 + 
      6.04575767974460785e-10*V012*V022*V10 + 3.40073869485634192e-10*V013*V03*V10 - 
      1.57213310981915158e-9*V02*V032*V10 - 6.71181261929988321e-10*V022*V04*V10 - 
      1.87883873030537691e-9*V01*V03*V04*V10 - 9.79242152784242622e-10*V01*V02*V05*V10 + 
      1.07336839085989354e-10*V052*V10 - 2.00661102814361779e-10*V012*V06*V10 + 
      1.54495629503149789e-10*V04*V06*V10 + 1.08715403184487502e-10*V03*V07*V10 + 3.19419553321709642e-11*V02*V08*V10 + 
      1.07962929205513937e-11*V01*V09*V10 + 7.75399910748494626e-11*V013*V02*V11 - 
      3.40440197433494265e-10*V022*V03*V11 - 3.83107217992122246e-10*V01*V032*V11 - 
      4.21791587392818139e-10*V01*V02*V04*V11 - 1.14751107550456822e-10*V012*V05*V11 + 
      9.62065320400714134e-11*V04*V05*V11 + 7.0053450335113439e-11*V03*V06*V11 + 2.5310464537020169e-11*V02*V07*V11 + 
      8.92101281804860605e-12*V01*V08*V11 - 5.43372820460500498e-14*V112 + 2.9520301170627968e-12*V014*V12 - 
      1.849485094293739e-11*V023*V12 - 1.63911361271335963e-10*V01*V02*V03*V12 - 
      4.73197850193238992e-11*V012*V04*V12 + 1.88537309952640217e-11*V042*V12 + 
      3.82877627980636899e-11*V03*V05*V12 + 1.42638050703933002e-11*V02*V06*V12 + 6.20117454352671344e-12*V01*V07*V12 - 
      9.861716111939824e-14*V10*V12 - 1.52801222059334661e-11*V01*V022*V13 - 
      1.59005664305371908e-11*V012*V03*V13 + 1.46902340825414441e-11*V03*V04*V13 + 
      7.63906846126070317e-12*V02*V05*V13 + 3.41839908555666496e-12*V01*V06*V13 - 7.88028307646789415e-14*V09*V13 - 
      3.00382011911653008e-12*V012*V02*V14 + 2.51465121876614934e-12*V032*V14 + 
      2.55827813001998466e-12*V02*V04*V14 + 1.60913386023879783e-12*V01*V05*V14 - 5.13051632836443249e-14*V08*V14 - 
      1.55370006161199832e-13*V013*V15 + 8.81293201614361267e-13*V02*V03*V15 + 5.4133499646664708e-13*V01*V04*V15 - 
      2.95144707744340306e-14*V07*V15 + 6.57733026082412621e-14*V022*V16 + 1.60419531361438826e-13*V01*V03*V16 - 
      1.32723943151368635e-14*V06*V16 + 2.52476260011949726e-14*V01*V02*V17 - 5.35350999490221159e-15*V05*V17 + 
      1.9421250770149979e-15*V012*V18 - 1.50866527721744764e-15*V04*V18 - 4.01091048513966957e-16*V03*V19 - 
      5.36128385649412808e-17*V02*V20 - 8.04192578474119211e-18*V01*V21 + 1.00524072309264901e-20*V24) + 
   delta2*eps11*(-5.19942132872027052e-7*V024*V032 - 
      2.12909656114021193e-6*V01*V022*V033 - 4.30973118225102352e-7*V012*V034 - 
      6.80612866459427306e-8*V025*V04 - 2.60643787429501715e-6*V01*V023*V03*V04 - 
      3.48396023619237905e-6*V012*V02*V032*V04 + 2.92634394072278254e-7*V034*V04 - 
      1.17616437060881505e-6*V012*V022*V042 - 5.9607155961322628e-7*V013*V03*V042 + 
      1.1082481523457393e-6*V02*V032*V042 + 1.95584655809718057e-7*V022*V043 + 
      4.54467079326658575e-7*V01*V03*V043 - 3.11965279723216231e-7*V01*V024*V05 - 
      1.86285023214586707e-6*V012*V022*V03*V05 - 4.72547688569513966e-7*V013*V032*V05 + 
      6.54479977676270082e-7*V02*V033*V05 - 6.53448229093070363e-7*V013*V02*V04*V05 + 
      1.19518228764965654e-6*V022*V03*V04*V05 + 1.16986246668154153e-6*V01*V032*V04*V05 + 
      7.49205341404634316e-7*V01*V02*V042*V05 - 3.07473335747145271e-8*V014*V052 + 
      1.0472435081384564e-7*V023*V052 + 6.53677756463315131e-7*V01*V02*V03*V052 + 
      1.8926780842484624e-7*V012*V04*V052 - 4.49111369355517819e-8*V042*V052 - 
      2.66308862018481758e-8*V03*V053 - 2.7752321899147296e-7*V012*V023*V06 - 
      4.30835469277929595e-7*V013*V02*V03*V06 + 4.35860386828621345e-7*V022*V032*V06 + 
      2.74950060854005765e-7*V01*V033*V06 - 5.11709961114723019e-8*V014*V04*V06 + 
      1.49373083789906074e-7*V023*V04*V06 + 1.07553785650458347e-6*V01*V02*V03*V04*V06 + 
      1.58959003141207273e-7*V012*V042*V06 - 2.34589188319894784e-8*V043*V06 + 
      2.91743367359030291e-7*V01*V022*V05*V06 + 2.64325940625106125e-7*V012*V03*V05*V06 - 
      1.30477649586021645e-7*V03*V04*V05*V06 - 3.63982154243717568e-8*V02*V052*V06 + 
      6.21909667103265376e-8*V012*V02*V062 - 2.35866641208131788e-8*V032*V062 - 
      2.83830922891645865e-8*V02*V04*V062 - 1.64809807039780169e-8*V01*V05*V062 - 
      8.3627470780248558e-8*V013*V022*V07 - 2.86653932487265821e-8*V014*V03*V07 + 
      1.09769440570337318e-7*V023*V03*V07 + 3.35492824806258513e-7*V01*V02*V032*V07 + 
      2.09044847038933562e-7*V01*V022*V04*V07 + 1.92355750008498608e-7*V012*V03*V04*V07 - 
      4.72618338936615608e-8*V03*V042*V07 + 1.07650164092011664e-7*V012*V02*V05*V07 - 
      4.18304532027872241e-8*V032*V05*V07 - 5.2495110872022949e-8*V02*V04*V05*V07 - 
      1.45549356985976133e-8*V01*V052*V07 + 1.36847681855268223e-8*V013*V06*V07 - 
      3.83220680268478737e-8*V02*V03*V06*V07 - 2.39667134245575088e-8*V01*V04*V06*V07 - 
      3.78370234356419949e-9*V022*V072 - 7.57514185448521646e-9*V01*V03*V072 + 
      4.26147160475657499e-10*V06*V072 - 9.63542630209296876e-9*V014*V02*V08 + 
      7.72535223236800164e-9*V024*V08 + 1.17120217666946775e-7*V01*V022*V03*V08 + 
      5.1466665825082803e-8*V012*V032*V08 + 6.95025549042676727e-8*V012*V02*V04*V08 - 
      2.66734083953653464e-8*V032*V04*V08 - 1.59763800882102491e-8*V02*V042*V08 + 
      1.04776967236360716e-8*V013*V05*V08 - 2.9909484601287233e-8*V02*V03*V05*V08 - 
      1.86295937434687129e-8*V01*V04*V05*V08 - 6.38461798617259437e-9*V022*V06*V08 - 
      1.33424917612395601e-8*V01*V03*V06*V08 + 3.69473760663051925e-10*V062*V08 - 
      5.46385122184290841e-9*V01*V02*V07*V08 + 6.65193360464561812e-10*V05*V07*V08 - 
      4.51929472006984006e-10*V012*V082 + 2.09622080250661849e-10*V04*V082 - 
      3.61328486328486328e-10*V015*V09 + 1.16554442820539537e-8*V01*V023*V09 + 
      3.32813562272012319e-8*V012*V02*V03*V09 - 4.49623559158400142e-9*V033*V09 + 
      6.05996959616532446e-9*V013*V04*V09 - 1.71008894358145883e-8*V02*V03*V04*V09 - 
      5.36744415768178965e-9*V01*V042*V09 - 4.68188403056017865e-9*V022*V05*V09 - 
      9.32814612085776875e-9*V01*V03*V05*V09 - 4.32938137442453789e-9*V01*V02*V06*V09 + 5.27480366322598665e-10*V05*V06*V09 - 
      8.11379645939557258e-10*V012*V07*V09 + 3.83426984261945439e-10*V04*V07*V09 + 2.1768055216367305e-10*V03*V08*V09 + 
      3.5427496549520743e-11*V02*V092 + 4.80738104563676459e-9*V012*V022*V10 + 
      2.57712229219582161e-9*V013*V03*V10 - 3.97089667710882205e-9*V02*V032*V10 - 
      2.32086891334837589e-9*V022*V04*V10 - 4.89421578838019756e-9*V01*V03*V04*V10 - 
      2.7556254125600797e-9*V01*V02*V05*V10 + 1.68525837843121799e-10*V052*V10 - 
      5.86367513038126459e-10*V012*V06*V10 + 2.72167713347360047e-10*V04*V06*V10 + 
      1.78212007585668558e-10*V03*V07*V10 + 6.34254219220624266e-11*V02*V08*V10 + 2.07887313037605561e-11*V01*V09*V10 + 
      6.93727077509757248e-10*V013*V02*V11 - 1.04023300630045484e-9*V022*V03*V11 - 
      1.01343227212338563e-9*V01*V032*V11 - 1.31535377883894447e-9*V01*V02*V04*V11 - 
      3.38479662243844452e-10*V012*V05*V11 + 1.61601702895817855e-10*V04*V05*V11 + 
      1.17549811516796611e-10*V03*V06*V11 + 4.82422574380474134e-11*V02*V07*V11 + 1.72881408123471871e-11*V01*V08*V11 - 
      8.15490478960957494e-14*V112 + 3.09963162291593664e-11*V014*V12 - 
      7.7737976854129163e-11*V023*V12 - 5.09456252588209318e-10*V01*V02*V03*V12 - 
      1.51223846568212385e-10*V012*V04*V12 + 3.5268177555702946e-11*V042*V12 + 
      6.35409685554323088e-11*V03*V05*V12 + 2.89625228485092606e-11*V02*V06*V12 + 1.19713052157937093e-11*V01*V07*V12 - 
      1.49876201115561999e-13*V10*V12 - 5.76407185857435255e-11*V01*V022*V13 - 
      5.26657709884619069e-11*V012*V03*V13 + 2.61749907254696341e-11*V03*V04*V13 + 
      1.47714796482632382e-11*V02*V05*V13 + 6.77909855989667958e-12*V01*V06*V13 - 1.18290495801059762e-13*V09*V13 - 
      1.15828339593174474e-11*V012*V02*V14 + 4.4488998996354753e-12*V032*V14 + 
      5.57193834952672406e-12*V02*V04*V14 + 3.16827187206643814e-12*V01*V05*V14 - 7.8365081937796196e-14*V08*V14 - 
      6.52554025877039293e-13*V013*V15 + 1.82291559014488683e-12*V02*V03*V15 + 1.14846179197084033e-12*V01*V04*V15 - 
      4.43579558156923953e-14*V07*V15 + 1.68539463826292008e-13*V022*V16 + 3.40815206372174774e-13*V01*V03*V16 - 
      2.06130641714486236e-14*V06*V16 + 6.27028953436270749e-14*V01*V02*V17 - 8.11651464639466667e-15*V05*V17 + 
      4.9940359123242803e-15*V012*V18 - 2.46806702333707186e-15*V04*V18 - 6.39333099886924773e-16*V03*V19 - 
      1.00524072309264901e-16*V02*V20 - 1.50786108463897352e-17*V01*V21 + 1.50786108463897352e-20*V24) + 
   delta4*eps10*(-1.17745291769762669e-7*V024*V032 - 
      5.79433243123719314e-7*V01*V022*V033 - 1.24555091072948216e-7*V012*V034 - 
      1.48202033122668043e-9*V025*V04 - 5.98870803897258924e-7*V01*V023*V03*V04 - 
      9.19068255377779187e-7*V012*V02*V032*V04 + 2.14311482438524922e-7*V034*V04 - 
      2.78216052025575835e-7*V012*V022*V042 - 1.52528798362131695e-7*V013*V03*V042 + 
      7.28419279216334149e-7*V02*V032*V042 + 9.77137892841674354e-8*V022*V043 + 
      2.94835574485628952e-7*V01*V03*V043 - 7.06471750618576015e-8*V01*V024*V05 - 
      4.70752516883469264e-7*V012*V022*V03*V05 - 1.22944598391026962e-7*V013*V032*V05 + 
      4.53829576895904121e-7*V02*V033*V05 - 1.57814517933565553e-7*V013*V02*V04*V05 + 
      7.3417265658745584e-7*V022*V03*V04*V05 + 7.89349551944867849e-7*V01*V032*V04*V05 + 
      4.54844988100998839e-7*V01*V02*V042*V05 - 7.17495137137994281e-9*V014*V052 + 
      6.06452340719542971e-8*V023*V052 + 4.1961331835354361e-7*V01*V02*V03*V052 + 
      1.18468274871461146e-7*V012*V04*V052 - 4.026399605523601e-8*V042*V052 - 
      2.49344252732416599e-8*V03*V053 - 6.40105840171977738e-8*V012*V023*V06 - 
      1.01929045381426334e-7*V013*V02*V03*V06 + 2.68121481016361191e-7*V022*V032*V06 + 
      1.83131423420507804e-7*V01*V033*V06 - 1.15108932073217788e-8*V014*V04*V06 + 
      6.94660406346006512e-8*V023*V04*V06 + 6.53241508264072845e-7*V01*V02*V03*V04*V06 + 
      9.57025503606288698e-8*V012*V042*V06 - 1.94107261144450045e-8*V043*V06 + 
      1.67111827140421912e-7*V01*V022*V05*V06 + 1.63286817054226796e-7*V012*V03*V05*V06 - 
      1.17292675685637981e-7*V03*V04*V05*V06 - 3.1097029829286499e-8*V02*V052*V06 + 
      3.52784186586804856e-8*V012*V02*V062 - 2.12175240295383638e-8*V032*V062 - 
      2.22496709765014992e-8*V02*V04*V062 - 1.3892605532982901e-8*V01*V05*V062 - 
      1.7584653001319668e-8*V013*V022*V07 - 6.08236285319618653e-9*V014*V03*V07 + 
      6.00239001444391008e-8*V023*V03*V07 + 2.05120027408751926e-7*V01*V02*V032*V07 + 
      1.13262007082035093e-7*V01*V022*V04*V07 + 1.1481891901160303e-7*V012*V03*V04*V07 - 
      4.13685034628376481e-8*V03*V042*V07 + 6.13554156716213205e-8*V012*V02*V05*V07 - 
      3.81989797524358541e-8*V032*V05*V07 - 4.35034561212444647e-8*V02*V04*V05*V07 - 
      1.24465574767207969e-8*V01*V052*V07 + 7.51825841670807435e-9*V013*V06*V07 - 
      3.18774024187369472e-8*V02*V03*V06*V07 - 1.9667871997796414e-8*V01*V04*V06*V07 - 
      2.88384332637313435e-9*V022*V072 - 6.2963852833022967e-9*V01*V03*V072 + 
      4.1939913591699306e-10*V06*V072 - 1.80664243164243164e-9*V014*V02*V08 + 
      3.19339934526286845e-9*V024*V08 + 6.40864146422619812e-8*V01*V022*V03*V08 + 
      3.00955337592388246e-8*V012*V032*V08 + 3.77117630268890773e-8*V012*V02*V04*V08 - 
      2.34923487086251406e-8*V032*V04*V08 - 1.21932300356941412e-8*V02*V042*V08 + 
      5.71217827651651181e-9*V013*V05*V08 - 2.5025281349342178e-8*V02*V03*V05*V08 - 
      1.53470257143579543e-8*V01*V04*V05*V08 - 4.61685998131022047e-9*V022*V06*V08 - 
      1.09728674070220722e-8*V01*V03*V06*V08 + 3.55652899273829005e-10*V062*V08 - 
      4.15881740242510684e-9*V01*V02*V07*V08 + 6.57949166107055085e-10*V05*V07*V08 - 
      3.39306748576642572e-10*V012*V082 + 1.98294607994327916e-10*V04*V082 - 
      6.02214143880810547e-11*V015*V09 + 5.56862526910962952e-9*V01*V023*V09 + 
      1.77171569817169724e-8*V012*V02*V03*V09 - 3.97927241519096207e-9*V033*V09 + 
      3.15622625744591197e-9*V013*V04*V09 - 1.37407137803524885e-8*V02*V03*V04*V09 - 
      4.2604639747773317e-9*V01*V042*V09 - 3.55753189027397834e-9*V022*V05*V09 - 
      7.70861279121372267e-9*V01*V03*V05*V09 - 3.26262256487220193e-9*V01*V02*V06*V09 + 5.18422609402698898e-10*V05*V06*V09 - 
      6.09370338393160972e-10*V012*V07*V09 + 3.68525742913893642e-10*V04*V07*V09 + 
      2.10984752273151009e-10*V03*V08*V09 + 3.17026393750257638e-11*V02*V092 + 
      2.31409640876552641e-9*V012*V022*V10 + 1.29948365753104315e-9*V013*V03*V10 - 
      3.22012106269394711e-9*V02*V032*V10 - 1.61126775629484608e-9*V022*V04*V10 - 
      3.90065748563062876e-9*V01*V03*V04*V10 - 2.08963724511459505e-9*V01*V02*V05*V10 + 
      1.66708646337348923e-10*V052*V10 - 4.36754705462371277e-10*V012*V06*V10 + 
      2.56156280440564972e-10*V04*V06*V10 + 1.72991833207666797e-10*V03*V07*V10 + 5.59156137952565482e-11*V02*V08*V10 + 
      1.85371567607405689e-11*V01*V09*V10 + 3.18819252642782055e-10*V013*V02*V11 - 
      7.60905183923706026e-10*V022*V03*V11 - 8.04406011184446243e-10*V01*V032*V11 - 
      9.51332212403664011e-10*V01*V02*V04*V11 - 2.51421963541570156e-10*V012*V05*V11 + 
      1.55046124435856297e-10*V04*V05*V11 + 1.13147716831517197e-10*V03*V06*V11 + 4.31537972541215944e-11*V02*V07*V11 + 
      1.53827773885756874e-11*V01*V08*V11 - 8.15425138313956472e-14*V112 + 1.32841355267825856e-11*V014*V12 - 
      4.86248930710779778e-11*V023*V12 - 3.70489767763205647e-10*V01*V02*V03*V12 - 
      1.0830510193769752e-10*V012*V04*V12 + 3.23502918471370033e-11*V042*V12 + 
      6.15313315114544086e-11*V03*V05*V12 + 2.53281964472471377e-11*V02*V06*V12 + 1.06661509229663684e-11*V01*V07*V12 - 
      1.4921036621479354e-13*V10*V12 - 3.77044162451691691e-11*V01*V022*V13 - 
      3.72150007257613897e-11*V012*V03*V13 + 2.45643216615985292e-11*V03*V04*V13 + 
      1.31821739602392982e-11*V02*V05*V13 + 5.98357638370737909e-12*V01*V06*V13 - 1.18277427671659557e-13*V09*V13 - 
      7.51602404804804186e-12*V012*V02*V14 + 4.20331355953960259e-12*V032*V14 + 
      4.72524580166540459e-12*V02*V04*V14 + 2.80845158458347374e-12*V01*V05*V14 - 7.78802878450727144e-14*V08*V14 - 
      4.07846266173149558e-13*V013*V15 + 1.58477406284423828e-12*V02*V03*V15 + 9.84657414046603933e-13*V01*V04*V15 - 
      4.43448876862921908e-14*V07*V15 + 1.31287655206213858e-13*V022*V16 + 2.92872461613861683e-13*V01*V03*V16 - 
      2.03625581832539355e-14*V06*V16 + 4.95241894638824463e-14*V01*V02*V17 - 8.10344651699446223e-15*V05*V17 + 
      3.88425015402999579e-15*V012*V18 - 2.3840288988865264e-15*V04*V18 - 6.26264970486720336e-16*V03*V19 - 
      9.04716650783384113e-17*V02*V20 - 1.35707497617507617e-17*V01*V21 + 1.50786108463897352e-20*V24) + 
   6.4469502843844734e-26*delta24*V24 + 3.86817017063068404e-25*delta22*eps*V24 + 
   delta22*eps2*(-1.85682880046129965e-20*V122 - 4.02312906766614924e-20*V11*V13 - 
      2.68208604511076616e-20*V10*V14 - 2.10735332115845913e-20*V09*V15 - 9.91695680545157236e-21*V08*V16 - 
      5.57828820306650945e-21*V07*V17 - 1.76156469570521351e-21*V06*V18 - 6.85052937218694143e-22*V05*V19 - 
      1.30486273755941742e-22*V04*V20 - 3.26215684389854354e-23*V03*V21 - 2.83665812512916829e-24*V02*V22 - 
      3.86817017063068404e-25*V01*V23 + 3.581639046880263e-27*V26) + 
   delta20*eps3*(-2.04251168050742961e-19*V122 - 4.42544197443276416e-19*V11*V13 - 
      2.95029464962184278e-19*V10*V14 - 2.31808865327430504e-19*V09*V15 - 1.09086524859967296e-19*V08*V16 - 
      6.1361170233731604e-20*V07*V17 - 1.93772116527573486e-20*V06*V18 - 7.53558230940563557e-21*V05*V19 - 
      1.43534901131535916e-21*V04*V20 - 3.58837252828839789e-22*V03*V21 - 3.12032393764208512e-23*V02*V22 - 
      4.25498718769375244e-24*V01*V23 + 1.96990147578414465e-26*V26) + 
   delta18*eps4*(3.30176453396809709e-15*V072*V08 + 1.9052198711412549e-15*V06*V082 + 
      4.99426568163241577e-15*V06*V07*V09 + 3.85205862296277994e-15*V05*V08*V09 + 9.77496079135291902e-16*V04*V092 + 
      1.16561970017120193e-15*V062*V10 + 3.11705043416568606e-15*V05*V07*V10 + 1.2063126956394299e-15*V04*V08*V10 + 
      8.65847342823801684e-16*V03*V09*V10 + 6.80933335986972465e-17*V02*V102 + 1.90690144207783147e-15*V05*V06*V11 + 
      1.27963123086801849e-15*V04*V07*V11 + 7.00374295084141807e-16*V03*V08*V11 + 1.78666912011260665e-16*V02*V09*V11 + 
      4.72280368812982737e-17*V01*V10*V11 + 4.95894387253631874e-16*V052*V12 + 4.97254203795415384e-16*V04*V06*V12 + 
      4.72280368812982737e-16*V03*V07*V12 + 9.17573287979509317e-17*V02*V08*V12 + 3.93566974010818947e-17*V01*V09*V12 - 
      1.4057404994796687e-18*V122 + 3.4451610061831267e-16*V04*V05*V13 + 2.4447454385613224e-16*V03*V06*V13 + 
      8.24616516975049223e-17*V02*V07*V13 + 2.6937472887851608e-17*V01*V08*V13 - 2.991109002482224e-18*V11*V13 + 
      3.79960143891801628e-17*V042*V14 + 1.07749891551406432e-16*V03*V05*V14 + 2.70991624009839705e-17*V02*V06*V14 + 
      1.53928416502009188e-17*V01*V07*V14 - 2.03780233210046255e-18*V10*V14 + 3.28110572017440638e-17*V03*V04*V15 + 
      1.64923303395009845e-17*V02*V05*V15 + 6.98498696731806401e-18*V01*V06*V15 - 1.57822438943280254e-18*V09*V15 + 
      4.36561685457379e-18*V032*V16 + 3.08401471364043177e-18*V02*V04*V16 + 2.619370112744274e-18*V01*V05*V16 - 
      7.61557606853427812e-19*V08*V16 + 1.21267134849271945e-18*V02*V03*V17 + 7.2377332062670729e-19*V01*V04*V17 - 
      4.23828636298205446e-19*V07*V17 + 4.72303577834006521e-20*V022*V18 + 1.60838515694823842e-19*V01*V03*V18 - 
      1.3767011045783136e-19*V06*V18 + 2.12749359384687622e-20*V01*V02*V19 - 5.31660649102334368e-20*V05*V19 + 
      1.06374679692343811e-21*V012*V20 - 1.04459935457881622e-20*V04*V20 - 2.60263382980601191e-21*V03*V21 - 
      2.34024295323156384e-22*V02*V22 - 3.19124039077031433e-23*V01*V23 + 9.84950737892072324e-26*V26) + 
   delta16*eps5*(3.91494937599074369e-14*V072*V08 + 2.38059997491145151e-14*V06*V082 + 
      5.90467869651332489e-14*V06*V07*V09 + 4.56744093865586764e-14*V05*V08*V09 + 1.15308333779477952e-14*V04*V092 + 
      1.45811602942764586e-14*V062*V10 + 3.71015586399999022e-14*V05*V07*V10 + 1.51019979579681752e-14*V04*V08*V10 + 
      1.03059885111110839e-14*V03*V09*V10 + 8.54602572137778286e-16*V02*V102 + 2.2545136841232695e-14*V05*V06*V11 + 
      1.50949091493134774e-14*V04*V07*V11 + 8.30443807028339571e-15*V03*V08*V11 + 2.10380288893259433e-15*V02*V09*V11 + 
      5.62144827878786397e-16*V01*V10*V11 + 5.93420283413512809e-15*V052*V12 + 6.24345874560816188e-15*V04*V06*V12 + 
      5.65162174679536008e-15*V03*V07*V12 + 1.15366349562739614e-15*V02*V08*V12 + 4.7096847889961334e-16*V01*V09*V12 - 
      7.4883685401212359e-18*V122 + 4.06401400173824391e-15*V04*V05*V13 + 2.8904021591323968e-15*V03*V06*V13 + 
      9.7098594873812046e-16*V02*V07*V13 + 3.19401464241669066e-16*V01*V08*V13 - 1.54868604273257256e-17*V11*V13 + 
      4.80337674442322357e-16*V042*V14 + 1.29973306683884008e-15*V03*V05*V14 + 3.42781767840608697e-16*V02*V06*V14 + 
      1.85676152405548583e-16*V01*V07*V14 - 1.09149240792333788e-17*V10*V14 + 3.8704895254649942e-16*V03*V04*V15 + 
      1.94197189747624092e-16*V02*V05*V15 + 8.25829188323541943e-17*V01*V06*V15 - 8.26678058267486846e-18*V09*V15 + 
      5.33575393336796556e-17*V032*V16 + 3.95203209992995727e-17*V02*V04*V16 + 3.20145236002077934e-17*V01*V05*V16 - 
      4.14491066914811507e-18*V08*V16 + 1.42792051285017715e-17*V02*V03*V17 + 8.53784454146689896e-18*V01*V04*V17 - 
      2.2701207643783708e-18*V07*V17 + 6.22930124278365357e-19*V022*V18 + 2.01718305100591569e-18*V01*V03*V18 - 
      7.68578335713122504e-19*V06*V18 + 2.50512370675469675e-19*V01*V02*V19 - 2.93865371384084395e-19*V05*V19 + 
      1.43605817584664145e-20*V012*V20 - 6.02825309816512377e-20*V04*V20 - 1.49509612307589226e-20*V03*V21 - 
      1.40414577193893831e-21*V02*V22 - 1.9147442344621886e-22*V01*V23 + 4.43227832051432546e-25*V26) + 
   delta14*eps6*(-1.54203318660389367e-12*V054 - 1.20222768349253792e-11*V04*V052*V06 - 
      2.20810148842809719e-12*V042*V062 - 8.49950385609556685e-12*V03*V05*V062 - 
      5.19154254600674884e-13*V02*V063 - 8.03458254146862924e-12*V042*V05*V07 - 
      8.72037364191043845e-12*V03*V052*V07 - 1.14497874618336945e-11*V03*V04*V06*V07 - 
      5.72782625570846122e-12*V02*V05*V06*V07 - 1.21421483658508098e-12*V01*V062*V07 - 
      2.04958885084975925e-12*V032*V072 - 1.89411468817236972e-12*V02*V04*V072 - 
      1.21671837233061723e-12*V01*V05*V072 - 7.53220636853102185e-13*V043*V08 - 
      8.7898649136415848e-12*V03*V04*V05*V08 - 2.21582514890753923e-12*V02*V052*V08 - 
      3.07934896700958681e-12*V032*V06*V08 - 1.58993354704801313e-12*V02*V04*V06*V08 - 
      1.84760938020575209e-12*V01*V05*V06*V08 - 2.11030966562622784e-12*V02*V03*V07*V08 - 
      1.25569498766308354e-12*V01*V04*V07*V08 + 2.52902464207594821e-13*V072*V08 - 
      7.05860041184046148e-14*V022*V082 - 3.2938676181467125e-13*V01*V03*V082 + 
      1.65322644154544154e-13*V06*V082 - 2.2318284837412859e-12*V03*V042*V09 - 
      2.36584127953175572e-12*V032*V05*V09 - 2.20980046953443135e-12*V02*V04*V05*V09 - 
      7.00410678164405918e-13*V01*V052*V09 - 1.5910628488079059e-12*V02*V03*V06*V09 - 
      9.54148955152807872e-13*V01*V04*V06*V09 - 2.55178500255161524e-13*V022*V07*V09 - 
      6.50858439786300493e-13*V01*V03*V07*V09 + 3.8183588904119501e-13*V06*V07*V09 - 1.75859138802185653e-13*V01*V02*V08*V09 + 
      2.96791441398816354e-13*V05*V08*V09 - 1.20920740210491967e-14*V012*V092 + 
      7.51242092489750279e-14*V04*V092 - 9.72977199189485451e-13*V032*V04*V10 - 
      2.45301962166125281e-13*V02*V042*V10 - 9.89880319917499004e-13*V02*V03*V05*V10 - 
      5.8378631951369127e-13*V01*V04*V05*V10 - 8.53406564866380643e-14*V022*V06*V10 - 
      4.02592159254841163e-13*V01*V03*V06*V10 + 1.01860733210772983e-13*V062*V10 - 
      1.41411474273928429e-13*V01*V02*V07*V10 + 2.42414016797913357e-13*V05*V07*V10 - 
      2.05587945175887093e-14*V012*V08*V10 + 1.06087349072260034e-13*V04*V08*V10 + 
      6.81155107853280148e-14*V03*V09*V10 + 6.10328012679467652e-15*V02*V102 - 
      1.38073789602302242e-13*V033*V11 - 4.0178190355171479e-13*V02*V03*V04*V11 - 
      1.21736099113161049e-13*V01*V042*V11 - 9.74317910065162182e-14*V022*V05*V11 - 
      2.4234761532458389e-13*V01*V03*V05*V11 - 8.67852462986130488e-14*V01*V02*V06*V11 + 1.47517807276666873e-13*V05*V06*V11 - 
      1.56321251096880647e-14*V012*V07*V11 + 9.89245613535953171e-14*V04*V07*V11 + 
      5.49103892488515527e-14*V03*V08*V11 + 1.39755139279545053e-14*V02*V09*V11 + 3.80029519523811889e-15*V01*V10*V11 - 
      7.36486711745073699e-14*V02*V032*V12 - 1.74606292638300763e-14*V022*V04*V12 - 
      8.55307773599781761e-14*V01*V03*V04*V12 - 4.4189202704704422e-14*V01*V02*V05*V12 + 
      3.94736305220268869e-14*V052*V12 - 8.45492335115312311e-15*V012*V06*V12 + 
      4.4391093491512922e-14*V04*V06*V12 + 3.7804669162617643e-14*V03*V07*V12 + 8.28983170499228742e-15*V02*V08*V12 + 
      3.20307292991376506e-15*V01*V09*V12 - 3.2885668253304498e-17*V122 - 1.2491255257245669e-14*V022*V03*V13 - 
      1.45258624807851906e-14*V01*V032*V13 - 1.5453150136604415e-14*V01*V02*V04*V13 - 
      4.02482301674727183e-15*V012*V05*V13 + 2.71021119581024799e-14*V04*V05*V13 + 
      1.93550835918877473e-14*V03*V06*V13 + 6.52510369708493555e-15*V02*V07*V13 + 2.17272708614309219e-15*V01*V08*V13 - 
      6.59474565261144479e-17*V11*V13 - 2.87957108924612235e-16*V023*V14 - 4.61600412862594148e-15*V01*V02*V03*V14 - 
      1.28347603729081856e-15*V012*V04*V14 + 3.49836247258676175e-15*V042*V14 + 
      8.9090194133122693e-15*V03*V05*V14 + 2.5090229770134993e-15*V02*V06*V14 + 1.28626433039491428e-15*V01*V07*V14 - 
      4.82088307689125368e-17*V10*V14 - 3.56893007349876257e-16*V01*V022*V15 - 
      3.43152802723375592e-16*V012*V03*V15 + 2.65553069586017059e-15*V03*V04*V15 + 
      1.33496733924397574e-15*V02*V05*V15 + 5.71968568230076054e-16*V01*V06*V15 - 3.56303053376302519e-17*V09*V15 - 
      5.10853761754511918e-17*V012*V02*V16 + 3.79444864943371915e-16*V032*V16 + 
      2.98429483390964099e-16*V02*V04*V16 + 2.28782576606636451e-16*V01*V05*V16 - 1.86185474371915526e-17*V08*V16 - 
      1.76156469570521351e-18*V013*V17 + 1.01462296984151374e-16*V02*V03*V17 + 6.08748251981782081e-17*V01*V04*V17 - 
      1.00166653385498626e-17*V07*V17 + 4.92472217103674908e-18*V022*V18 + 1.50805255906241974e-17*V01*V03*V18 - 
      3.54738281838028141e-18*V06*V18 + 1.85730190742832294e-18*V01*V02*V19 - 1.34095921220168608e-18*V05*V19 + 
      1.14884654067731316e-19*V012*V20 - 2.88488131325636416e-19*V04*V20 - 7.11646607141780096e-20*V03*V21 - 
      7.02072885969469153e-21*V02*V22 - 9.57372117231094299e-22*V01*V23 + 1.77291132820573018e-24*V26) + 
   delta12*eps7*(-1.66065112403496242e-11*V054 - 1.32286910338566607e-10*V04*V052*V06 - 
      2.9624444362982876e-11*V042*V062 - 9.40202849236138478e-11*V03*V05*V062 - 
      6.99935888436239844e-12*V02*V063 - 8.81082588939342752e-11*V042*V05*V07 - 
      9.41948082625692053e-11*V03*V052*V07 - 1.25987533655777721e-10*V03*V04*V06*V07 - 
      6.28954061798325235e-11*V02*V05*V06*V07 - 1.34314692748019783e-11*V01*V062*V07 - 
      2.22227074615757362e-11*V032*V072 - 2.07868960496107846e-11*V02*V04*V072 - 
      1.32336899509046145e-11*V01*V05*V072 - 1.0160231656237466e-11*V043*V08 - 
      9.74169938630722944e-11*V03*V04*V05*V08 - 2.44607475427185688e-11*V02*V052*V08 - 
      3.43735457862127048e-11*V032*V06*V08 - 2.15689127816977362e-11*V02*V04*V06*V08 - 
      2.06241274717276229e-11*V01*V05*V06*V08 - 2.32959500406843512e-11*V02*V03*V07*V08 - 
      1.39167134090103278e-11*V01*V04*V07*V08 + 1.14358065959054919e-12*V072*V08 - 
      9.72492181709934615e-13*V022*V082 - 3.72143225233535432e-12*V01*V03*V082 + 
      8.06832513790939047e-13*V06*V082 - 2.44745163594261876e-11*V03*V042*V09 - 
      2.57321749045367505e-11*V032*V05*V09 - 2.42513787245459154e-11*V02*V04*V05*V09 - 
      7.64803272769843236e-12*V01*V052*V09 - 1.74709461610645899e-11*V02*V03*V06*V09 - 
      1.04989611379814768e-11*V01*V04*V06*V09 - 2.81955869038106904e-12*V022*V07*V09 - 
      7.15964568449305329e-12*V01*V03*V07*V09 + 1.73526454756329624e-12*V06*V07*V09 - 1.94132917005702927e-12*V01*V02*V08*V09 + 
      1.35608337396241624e-12*V05*V08*V09 - 1.37908629566892789e-13*V012*V092 + 
      3.46474443578993563e-13*V04*V092 - 1.09131825067883835e-11*V032*V04*V10 - 
      3.37043773226947542e-12*V02*V042*V10 - 1.10387250589529224e-11*V02*V03*V05*V10 - 
      6.54790950407303009e-12*V01*V04*V05*V10 - 1.18352037247364295e-12*V022*V06*V10 - 
      4.56141900382685922e-12*V01*V03*V06*V10 + 5.0179374673263931e-13*V062*V10 - 
      1.57696072270756034e-12*V01*V02*V07*V10 + 1.11318188386107411e-12*V05*V07*V10 - 
      2.37735166353798372e-13*V012*V08*V10 + 5.27507721727871024e-13*V04*V08*V10 + 
      3.19132526809428339e-13*V03*V09*V10 + 3.11787899621623516e-14*V02*V102 - 
      1.51881168562532466e-12*V033*V11 - 4.40934158628107553e-12*V02*V03*V04*V11 - 
      1.33497361960506478e-12*V01*V042*V11 - 1.07655877269095363e-12*V022*V05*V11 - 
      2.68644112176895661e-12*V01*V03*V05*V11 - 9.52960699694432174e-13*V01*V02*V06*V11 + 6.84129584149527379e-13*V05*V06*V11 - 
      1.79020773765738028e-13*V012*V07*V11 + 4.60774808337594117e-13*V04*V07*V11 + 
      2.58509306778680506e-13*V03*V08*V11 + 6.66112563825561374e-14*V02*V09*V11 + 1.84889018457526946e-14*V01*V10*V11 - 
      8.35290526774251518e-13*V02*V032*V12 - 2.47605533628324811e-13*V022*V04*V12 - 
      9.78324647684366881e-13*V01*V03*V04*V12 - 5.01174316064550911e-13*V01*V02*V05*V12 + 
      1.85755303096988537e-13*V052*V12 - 9.84544380311962849e-14*V012*V06*V12 + 
      2.24702992214237174e-13*V04*V06*V12 + 1.79638835024222621e-13*V03*V07*V12 + 4.27110664190148531e-14*V02*V08*V12 + 
      1.56521585564102695e-14*V01*V09*V12 - 1.21283886108971637e-16*V122 - 
      1.38020355473199184e-13*V022*V03*V13 - 1.64470249379212965e-13*V01*V032*V13 - 
      1.69590061010810597e-13*V01*V02*V04*V13 - 4.6788567569687035e-14*V012*V05*V13 + 
      1.2987681548843124e-13*V04*V05*V13 + 9.32407235128521577e-14*V03*V06*V13 + 3.16695058366000516e-14*V02*V07*V13 + 
      1.07086075255241517e-14*V01*V08*V13 - 2.36726161901129699e-16*V11*V13 - 4.28788334463925038e-15*V023*V14 - 
      5.38763992793265321e-14*V01*V02*V03*V14 - 1.52040648886316978e-14*V012*V04*V14 + 
      1.83220005303319117e-14*V042*V14 + 4.36973912871109959e-14*V03*V05*V14 + 1.32520690923386879e-14*V02*V06*V14 + 
      6.42266317854633338e-15*V01*V07*V14 - 1.7866191433540021e-16*V10*V14 - 3.94343872780569097e-15*V01*V022*V15 - 
      4.14813254544663678e-15*V012*V03*V15 + 1.32933569350157555e-14*V03*V04*V15 + 
      6.70424078518043637e-15*V02*V05*V15 + 2.90109792042610258e-15*V01*V06*V15 - 1.29107459341060207e-16*V09*V15 - 
      6.28878596366761223e-16*V012*V02*V16 + 1.9498542612414436e-15*V032*V16 + 
      1.63958782899303425e-15*V02*V04*V16 + 1.18553176371345238e-15*V01*V05*V16 - 7.00374295084141807e-17*V08*V16 - 
      2.46619057398729892e-17*V013*V17 + 5.33805162644932019e-16*V02*V03*V17 + 3.2177532159368341e-16*V01*V04*V17 - 
      3.70192182554372465e-17*V07*V17 + 2.85220301165487614e-17*V022*V18 + 8.2215287939337454e-17*V01*V03*V18 - 
      1.36918254221765874e-17*V06*V18 + 1.03204714237511965e-17*V01*V02*V19 - 5.11287770447656681e-18*V05*V19 + 
      6.7016048206176601e-19*V012*V20 - 1.1553566710744846e-18*V04*V20 - 2.832544970847731e-19*V03*V21 - 
      2.94870612107177044e-20*V02*V22 - 4.02096289237059606e-21*V01*V23 + 6.20518964872005564e-24*V26) + 
   delta10*eps8*(1.03644223710013184e-9*V032*V043 + 7.69281785172546935e-11*V02*V044 + 
      2.23576403065925483e-9*V033*V04*V05 + 3.0758151273048265e-9*V02*V03*V042*V05 + 
      6.21865342260079102e-10*V01*V043*V05 + 1.72425317004195095e-9*V02*V032*V052 + 
      7.44933924140365489e-10*V022*V04*V052 + 1.95196621320524829e-9*V01*V03*V04*V052 + 
      3.37044154365490795e-10*V01*V02*V053 - 8.86044777363391133e-11*V054 + 
      3.8244802639047179e-10*V034*V06 + 2.19627954448125206e-9*V02*V032*V04*V06 + 
      1.57554740974366134e-10*V022*V042*V06 + 1.3106433671735816e-9*V01*V03*V042*V06 + 
      1.07889346598353593e-9*V022*V03*V05*V06 + 1.32380166356476179e-9*V01*V032*V05*V06 + 
      1.31776772668875124e-9*V01*V02*V04*V05*V06 + 1.85737232406228952e-10*V012*V052*V06 - 
      7.31437823120934984e-10*V04*V052*V06 + 1.78028801454292508e-11*V023*V062 + 
      4.63481031146693903e-10*V01*V02*V03*V062 + 1.3454676832729077e-10*V012*V04*V062 - 
      1.95663925615815219e-10*V042*V062 - 5.235117843415e-10*V03*V05*V062 - 
      4.66936333251060897e-11*V02*V063 + 5.34990721215064754e-10*V02*V033*V07 + 
      7.09460880133681418e-10*V022*V03*V04*V07 + 9.00830856579603447e-10*V01*V032*V04*V07 + 
      4.39402161043546643e-10*V01*V02*V042*V07 + 1.12101974959691146e-10*V023*V05*V07 + 
      9.34561339650519572e-10*V01*V02*V03*V05*V07 + 2.53549200883068641e-10*V012*V04*V05*V07 - 
      4.89345958036449584e-10*V042*V05*V07 - 5.0936164839679545e-10*V03*V052*V07 + 
      1.5412763799764799e-10*V01*V022*V06*V07 + 1.6931956922865567e-10*V012*V03*V06*V07 - 
      7.04068186757063522e-10*V03*V04*V06*V07 - 3.53228899935868542e-10*V02*V05*V06*V07 - 
      7.6362931160826196e-11*V01*V062*V07 + 3.02631670953244222e-11*V012*V02*V072 - 
      1.21809194119213621e-10*V032*V072 - 1.17419159346054373e-10*V02*V04*V072 - 
      7.34560746088200637e-11*V01*V05*V072 + 1.9730626157021439e-10*V022*V032*V08 + 
      1.52448556807254477e-10*V01*V033*V08 + 1.77815628638582902e-11*V023*V04*V08 + 
      4.7487650391059968e-10*V01*V02*V03*V04*V08 + 6.90528428335295722e-11*V012*V042*V08 - 
      6.78083241517972135e-11*V043*V08 + 1.18383756942128634e-10*V01*V022*V05*V08 + 
      1.26591387143792804e-10*V012*V03*V05*V08 - 5.48630925336919625e-10*V03*V04*V05*V08 - 
      1.38327168512975287e-10*V02*V052*V08 + 4.8745308936170531e-11*V012*V02*V06*V08 - 
      1.95031783256437153e-10*V032*V06*V08 - 1.4543219266699888e-10*V02*V04*V06*V08 - 
      1.18210669118258031e-10*V01*V05*V06*V08 + 5.01746472277715964e-12*V013*V07*V08 - 
      1.33112230181405307e-10*V02*V03*V07*V08 - 8.00030249249020578e-11*V01*V04*V07*V08 + 
      3.92990368802391292e-12*V072*V08 - 6.70541348750019e-12*V022*V082 - 
      2.17404810478333747e-11*V01*V03*V082 + 2.97203456063187927e-12*V06*V082 + 
      3.1139437488803096e-11*V023*V03*V09 + 1.22754882439275202e-10*V01*V02*V032*V09 + 
      5.91217400111401182e-11*V01*V022*V04*V09 + 6.56508562462427927e-11*V012*V03*V04*V09 - 
      1.38854417015004065e-10*V03*V042*V09 + 3.43776854632476121e-11*V012*V02*V05*V09 - 
      1.42941449688980166e-10*V032*V05*V09 - 1.38448103897304411e-10*V02*V04*V05*V09 - 
      4.30276258233606887e-11*V01*V052*V09 + 3.81396372267135777e-12*V013*V06*V09 - 
      1.00202658874331531e-10*V02*V03*V06*V09 - 6.05375329378461776e-11*V01*V04*V06*V09 - 
      1.64118652809714842e-11*V022*V07*V09 - 4.08646481491317894e-11*V01*V03*V07*V09 + 
      6.01397796505936062e-12*V06*V07*V09 - 1.14357032716647961e-11*V01*V02*V08*V09 + 4.72038477027008684e-12*V05*V08*V09 - 
      8.2482864742720661e-13*V012*V092 + 1.22588102727520073e-12*V04*V092 + 
      4.41628966719152241e-13*V024*V10 + 2.58472555773542445e-11*V01*V022*V03*V10 + 
      1.29549237470610211e-11*V012*V032*V10 + 1.51456161720281988e-11*V012*V02*V04*V10 - 
      6.3325802769482879e-11*V032*V04*V10 - 2.32112737609917358e-11*V02*V042*V10 + 
      2.24854925583291979e-12*V013*V05*V10 - 6.42691019807710967e-11*V02*V03*V05*V10 - 
      3.83706426821222986e-11*V01*V04*V05*V10 - 8.24636658227674083e-12*V022*V06*V10 - 
      2.69448662011830399e-11*V01*V03*V06*V10 + 1.86934827302314237e-12*V062*V10 - 
      9.3636809477959793e-12*V01*V02*V07*V10 + 3.88547034161994706e-12*V05*V07*V10 - 
      1.44871320788164355e-12*V012*V08*V10 + 1.99004986634628615e-12*V04*V08*V10 + 
      1.14387030318298649e-12*V03*V09*V10 + 1.21953854967834181e-13*V02*V102 + 
      1.69851477211653251e-12*V01*V023*V11 + 5.6508811098000575e-12*V012*V02*V03*V11 - 
      8.77872595288240884e-12*V033*V11 + 9.38064908627548888e-13*V013*V04*V11 - 
      2.59682468869140614e-11*V02*V03*V04*V11 - 7.89296648013855657e-12*V01*V042*V11 - 
      6.39681333144350255e-12*V022*V05*V11 - 1.57396968193959993e-11*V01*V03*V05*V11 - 
      5.69289266622793113e-12*V01*V02*V06*V11 + 2.42670699692985867e-12*V05*V06*V11 - 
      1.08447647752873986e-12*V012*V07*V11 + 1.64742693740948427e-12*V04*V07*V11 + 
      9.33604454491042186e-13*V03*V08*V11 + 2.46029316174515537e-13*V02*V09*V11 + 6.96299380888316339e-14*V01*V10*V11 + 
      5.48801388429393628e-13*V012*V022*V12 + 2.96756711767891678e-13*V013*V03*V12 - 
      5.06091900069081585e-12*V02*V032*V12 - 1.78082799284098192e-12*V022*V04*V12 - 
      5.96983353673383486e-12*V01*V03*V04*V12 - 3.06467337152966668e-12*V01*V02*V05*V12 + 
      6.64541833429161692e-13*V052*V12 - 6.12971667164543145e-13*V012*V06*V12 + 
      8.64904687778891982e-13*V04*V06*V12 + 6.515886536102613e-13*V03*V07*V12 + 1.6855302949908041e-13*V02*V08*V12 + 
      5.90505816400706376e-14*V01*V09*V12 - 3.74596196056266142e-16*V122 + 
      5.33437021153452755e-14*V013*V02*V13 - 8.53556778292250779e-13*V022*V03*V13 - 
      1.01555261646222982e-12*V01*V032*V13 - 1.04979567258204347e-12*V01*V02*V04*V13 - 
      2.945001473926933e-13*V012*V05*V13 + 4.78694801337721704e-13*V04*V05*V13 + 3.45583666266237063e-13*V03*V06*V13 + 
      1.1908242444271215e-13*V02*V07*V13 + 4.09234391918326829e-14*V01*V08*V13 - 7.16541842251606127e-16*V11*V13 + 
      1.55370006161199832e-15*V014*V14 - 3.25948187528654673e-14*V023*V14 - 
      3.46142178011987339e-13*V01*V02*V03*V14 - 9.8667352484083855e-14*V012*V04*V14 + 
      7.33058474524930906e-14*V042*V14 + 1.6352256203831978e-13*V03*V05*V14 + 5.36870923463537244e-14*V02*V06*V14 + 
      2.46884977078012e-14*V01*V07*V14 - 5.53761160863980495e-16*V10*V14 - 2.58210153096470196e-14*V01*V022*V15 - 
      2.7874118962491446e-14*V012*V03*V15 + 5.13986819450477708e-14*V03*V04*V15 + 2.60977111694806816e-14*V02*V05*V15 + 
      1.14235555772248634e-14*V01*V06*V15 - 3.92931397871210248e-16*V09*V15 - 4.3281644573477096e-15*V012*V02*V16 + 
      7.66455841729221167e-15*V032*V16 + 6.93053164128995936e-15*V02*V04*V16 + 4.72235285289644036e-15*V01*V05*V16 - 
      2.19634375428030821e-16*V08*V16 - 1.84964293049047419e-16*V013*V17 + 2.18324881846082131e-15*V02*V03*V17 + 
      1.32375459700696516e-15*V01*V04*V17 - 1.14226173525499769e-16*V07*V17 + 1.27732587880972601e-16*V022*V18 + 
      3.44998616165397142e-16*V01*V03*V18 - 4.39182970314357737e-17*V06*V18 + 4.49007522981383226e-17*V01*V02*V19 - 
      1.61950982095046374e-17*V05*V19 + 3.01572216927794704e-18*V012*V20 - 3.8427002041421663e-18*V04*V20 - 
      9.35544032958225349e-19*V03*V21 - 1.03204714237511965e-19*V02*V22 - 1.40733701232970862e-20*V01*V23 + 
      1.86155689461601669e-23*V26) + delta8*eps9*
    (9.45532553415107021e-9*V032*V043 + 1.26121885620031857e-9*V02*V044 + 
      1.9236691918831295e-8*V033*V04*V05 + 2.80143356086422153e-8*V02*V03*V042*V05 + 
      5.67319532049064213e-9*V01*V043*V05 + 1.48129746610753902e-8*V02*V032*V052 + 
      6.81024771582047124e-9*V022*V04*V052 + 1.69721695215116268e-8*V01*V03*V04*V052 + 
      2.92333949172506964e-9*V01*V02*V053 - 3.01794207563108192e-10*V054 + 
      3.32166487416964801e-9*V034*V06 + 2.01536861179702234e-8*V02*V032*V04*V06 + 
      2.63380560248332698e-9*V022*V042*V06 + 1.20713226448484733e-8*V01*V03*V042*V06 + 
      9.90150503351099135e-9*V022*V03*V05*V06 + 1.16365122459848362e-8*V01*V032*V05*V06 + 
      1.20922116707821341e-8*V01*V02*V04*V05*V06 + 1.66451337448793449e-9*V012*V052*V06 - 
      2.60533004952591578e-9*V04*V052*V06 + 3.04152605911516103e-10*V023*V062 + 
      4.29268672053267617e-9*V01*V02*V03*V062 + 1.24788195969702198e-9*V012*V04*V062 - 
      8.06569167406602239e-10*V042*V062 - 1.87772943073893864e-9*V03*V05*V062 - 
      1.96002792948003781e-10*V02*V063 + 4.64022141543661848e-9*V02*V033*V07 + 
      6.48595020554330594e-9*V022*V03*V04*V07 + 7.91967443622623238e-9*V01*V032*V04*V07 + 
      4.00204794409174504e-9*V01*V02*V042*V07 + 1.03563623669674131e-9*V023*V05*V07 + 
      8.20429847684633615e-9*V01*V02*V03*V05*V07 + 2.27371485633562394e-9*V012*V04*V05*V07 - 
      1.76603097599484093e-9*V042*V05*V07 - 1.7725841772712883e-9*V03*V052*V07 + 
      1.41450071907299876e-9*V01*V022*V06*V07 + 1.53932493269909523e-9*V012*V03*V06*V07 - 
      2.55804468490423388e-9*V03*V04*V06*V07 - 1.29848555321289188e-9*V02*V05*V06*V07 - 
      2.84730444412418445e-10*V01*V062*V07 + 2.75556597736724661e-10*V012*V02*V072 - 
      4.32782883923761649e-10*V032*V072 - 4.37045606733090645e-10*V02*V04*V072 - 
      2.66544802682082887e-10*V01*V05*V072 + 1.83748806362752038e-9*V022*V032*V08 + 
      1.36783610224156033e-9*V01*V033*V08 + 3.09244777418661657e-10*V023*V04*V08 + 
      4.4295562598826887e-9*V01*V02*V03*V04*V08 + 6.4469062655569227e-10*V012*V042*V08 - 
      2.84375948424868838e-10*V043*V08 + 1.10249283817651223e-9*V01*V022*V05*V08 + 
      1.16187002620730595e-9*V012*V03*V05*V08 - 2.00379019114445587e-9*V03*V04*V05*V08 - 
      5.11059549984255632e-10*V02*V052*V08 + 4.57908455110747334e-10*V012*V02*V06*V08 - 
      7.17308210461874218e-10*V032*V06*V08 - 6.20926322796909474e-10*V02*V04*V06*V08 - 
      4.43164997112489852e-10*V01*V05*V06*V08 + 4.87383378374813935e-11*V013*V07*V08 - 
      5.00958232930441006e-10*V02*V03*V07*V08 - 3.03361359199640337e-10*V01*V04*V07*V08 + 
      1.05185172877049743e-11*V072*V08 - 2.96368428745279302e-11*V022*V082 - 
      8.34852942360073705e-11*V01*V03*V082 + 8.42135875274038724e-12*V06*V082 + 
      2.87676732415761474e-10*V023*V03*V09 + 1.10333888951482431e-9*V01*V02*V032*V09 + 
      5.40495850461942162e-10*V01*V022*V04*V09 + 6.04535618391916272e-10*V012*V03*V04*V09 - 
      5.20240032580919634e-10*V03*V042*V09 + 3.16809430634511105e-10*V012*V02*V05*V09 - 
      5.17637658963436757e-10*V032*V05*V09 - 5.24562163091996322e-10*V02*V04*V05*V09 - 
      1.59044648426037593e-10*V01*V052*V09 + 3.71995253799096194e-11*V013*V06*V09 - 
      3.81897553570740288e-10*V02*V03*V06*V09 - 2.3236488317619325e-10*V01*V04*V06*V09 - 
      6.40105065788137506e-11*V022*V07*V09 - 1.53992753440856139e-10*V01*V03*V07*V09 + 
      1.62711915862272012e-11*V06*V07*V09 - 4.53052324091337561e-11*V01*V02*V08*V09 + 1.27970839761365963e-11*V05*V08*V09 - 
      3.29435978864654287e-12*V012*V092 + 3.40283698966436004e-12*V04*V092 + 
      8.1607890220289046e-12*V024*V10 + 2.46944717864024914e-10*V01*V022*V03*V10 + 
      1.23282523912579785e-10*V012*V032*V10 + 1.44532282360001167e-10*V012*V02*V04*V10 - 
      2.40824437360646892e-10*V032*V04*V10 - 1.02282749004364433e-10*V02*V042*V10 + 
      2.23117494323917926e-11*V013*V05*V10 - 2.46940637439620681e-10*V02*V03*V05*V10 - 
      1.48568020885695002e-10*V01*V04*V05*V10 - 3.69865033114333662e-11*V022*V06*V10 - 
      1.05079828554496227e-10*V01*V03*V06*V10 + 5.3573388311976452e-12*V062*V10 - 
      3.7225474562396066e-11*V01*V02*V07*V10 + 1.05331784243999658e-11*V05*V07*V10 - 
      5.88727892826532548e-12*V012*V08*V10 + 5.79164320309262717e-12*V04*V08*V10 + 
      3.19802563074875501e-12*V03*V09*V10 + 3.7107362635932425e-13*V02*V102 + 
      1.56914581317688077e-11*V01*V023*V11 + 5.45080893329476388e-11*V012*V02*V03*V11 - 
      3.35412399372212098e-11*V033*V11 + 9.46750831829132155e-12*V013*V04*V11 - 
      1.03379823418576005e-10*V02*V03*V04*V11 - 3.16140969679431848e-11*V01*V042*V11 - 
      2.57464068793074689e-11*V022*V05*V11 - 6.13166742838945541e-11*V01*V03*V05*V11 - 
      2.314427988088199e-11*V01*V02*V06*V11 + 6.70145101878702692e-12*V05*V06*V11 - 
      4.39712531127282944e-12*V012*V07*V11 + 4.60832450404364041e-12*V04*V07*V11 + 
      2.63025586772588469e-12*V03*V08*V11 + 7.18500274567017961e-13*V02*V09*V11 + 2.0643658012849413e-13*V01*V10*V11 + 
      5.43484281551877011e-12*V012*V022*V12 + 3.12397292388119128e-12*V013*V03*V12 - 
      2.04535364896567126e-11*V02*V032*V12 - 8.33434307335563745e-12*V022*V04*V12 - 
      2.43186859976911768e-11*V01*V03*V04*V12 - 1.25867461562704572e-11*V01*V02*V05*V12 + 
      1.83811761205944291e-12*V052*V12 - 2.55921528243809983e-12*V012*V06*V12 + 
      2.56527370540687419e-12*V04*V06*V12 + 1.83501369778612031e-12*V03*V07*V12 + 5.16770641723490209e-13*V02*V08*V12 + 
      1.7500680491185295e-13*V01*V09*V12 - 9.51467811463379367e-16*V122 + 
      5.92995523515246024e-13*V013*V02*V13 - 3.63570130250712084e-12*V022*V03*V13 - 
      4.20778969543138954e-12*V01*V032*V13 - 4.48928068754629983e-12*V01*V02*V04*V13 - 
      1.24654835657475017e-12*V012*V05*V13 + 1.37299761393899378e-12*V04*V05*V13 + 
      9.96161857994013652e-13*V03*V06*V13 + 3.52057919143315269e-13*V02*V07*V13 + 1.22784748364545112e-13*V01*V08*V13 - 
      1.79621550299223666e-15*V11*V13 + 1.9421250770149979e-14*V014*V14 - 1.63228933456972691e-13*V023*V14 - 
      1.50547987041411165e-12*V01*V02*V03*V14 - 4.33112388603649435e-13*V012*V04*V14 + 
      2.26134324491859549e-13*V042*V14 + 4.72403651941420687e-13*V03*V05*V14 + 1.68587357962076689e-13*V02*V06*V14 + 
      7.409507624095008e-14*V01*V07*V14 - 1.40971547280422602e-15*V10*V14 - 1.1822917611695111e-13*V01*V022*V15 - 
      1.26164144288755244e-13*V012*V03*V15 + 1.54348581062465391e-13*V03*V04*V15 + 
      7.93638556122369489e-14*V02*V05*V15 + 3.51664367400224497e-14*V01*V06*V15 - 9.87189392041246962e-16*V09*V15 - 
      2.0346072235395216e-14*V012*V02*V16 + 2.32222334842838003e-14*V032*V16 + 
      2.27093261593378277e-14*V02*V04*V16 + 1.45999822301012219e-14*V01*V05*V16 - 5.63749049917588494e-16*V08*V16 - 
      9.24821465245237093e-16*V013*V17 + 6.96548051042948046e-15*V02*V03*V17 + 4.25303946730858563e-15*V01*V04*V17 - 
      2.89206080632549967e-16*V07*V17 + 4.45522688474662043e-16*V022*V18 + 1.12194917104370556e-15*V01*V03*V18 - 
      1.14825296996462988e-16*V06*V18 + 1.53299210271628975e-16*V01*V02*V19 - 4.18163386794490446e-17*V05*V19 + 
      1.05550275924728147e-17*V012*V20 - 1.03975398791882996e-17*V04*V20 - 2.51142640652646812e-18*V03*V21 - 
      2.94870612107177044e-19*V02*V22 - 4.02096289237059606e-20*V01*V23 + 4.65389223654004173e-23*V26) + 
   eps13*(7.83069566138349207e-9*V027 + 3.89470526809316492e-7*V01*V025*V03 + 
      1.4560094596883618e-6*V012*V023*V032 + 6.43388385203861394e-7*V013*V02*V033 - 
      2.25963672458806971e-7*V022*V034 - 7.40421868182868416e-8*V01*V035 + 
      5.75913158068416005e-7*V012*V024*V04 + 1.47733453165000784e-6*V013*V022*V03*V04 + 
      2.2660888081274986e-7*V014*V032*V04 - 6.34316323392156272e-7*V023*V032*V04 - 
      1.09169531821405071e-6*V01*V02*V033*V04 + 1.68546834283441426e-7*V014*V02*V042 - 
      9.93094869534334209e-8*V024*V042 - 1.19255469126537345e-6*V01*V022*V03*V042 - 
      4.7194417974956753e-7*V012*V032*V042 - 2.36977895033304697e-7*V012*V02*V043 + 
      6.15396422160911125e-8*V032*V043 + 2.08755249185163841e-8*V02*V044 + 
      3.0365453335856775e-7*V013*V023*V05 + 2.72437377162079543e-7*V014*V02*V03*V05 - 
      1.87735168274331277e-7*V024*V03*V05 - 9.9695598435458963e-7*V01*V022*V032*V05 - 
      2.57829614588594222e-7*V012*V033*V05 + 2.32669736017950304e-8*V015*V04*V05 - 
      4.78481933545874632e-7*V01*V023*V04*V05 - 1.15909676568249893e-6*V012*V02*V03*V04*V05 + 
      1.04774569359265628e-7*V033*V04*V05 - 1.06365326721047134e-7*V013*V042*V05 + 
      2.22867743488102149e-7*V02*V03*V042*V05 + 4.68070079918040045e-8*V01*V043*V05 - 
      1.77712107617533329e-7*V012*V022*V052 - 8.62823368941701691e-8*V013*V03*V052 + 
      9.55102875060511121e-8*V02*V032*V052 + 6.68835757659441601e-8*V022*V04*V052 + 
      1.18262788679119731e-7*V01*V03*V04*V052 + 2.4114996135405519e-8*V01*V02*V053 - 
      5.87971432306545918e-10*V054 + 6.7598537650620984e-8*V014*V022*V06 - 
      1.67841748918624113e-8*V025*V06 + 1.55672356193189527e-8*V015*V03*V06 - 
      3.39250098452824682e-7*V01*V023*V03*V06 - 4.02710445142131358e-7*V012*V02*V032*V06 + 
      1.85997849341130047e-8*V034*V06 - 3.03600293319488289e-7*V012*V022*V04*V06 - 
      1.4652365639961199e-7*V013*V03*V04*V06 + 1.59493451267026331e-7*V02*V032*V04*V06 + 
      5.38775891387696344e-8*V022*V042*V06 + 9.95998783780060399e-8*V01*V03*V042*V06 - 
      9.0371657699760816e-8*V013*V02*V05*V06 + 9.61234477073195602e-8*V022*V03*V05*V06 + 
      8.35480469489877804e-8*V01*V032*V05*V06 + 1.21508776031097569e-7*V01*V02*V04*V05*V06 + 
      1.52399636306011813e-8*V012*V052*V06 - 5.89896157218003488e-9*V04*V052*V06 - 
      3.96868820344981643e-9*V014*V062 + 7.7188754804050435e-9*V023*V062 + 
      4.31138384904303964e-8*V01*V02*V03*V062 + 1.29330943052344899e-8*V012*V04*V062 - 
      2.43809977936439083e-9*V042*V062 - 4.2243022736965277e-9*V03*V05*V062 - 
      7.07716085533879318e-10*V02*V063 + 6.41358063233063233e-9*V015*V02*V07 - 
      3.72903536990352272e-8*V01*V024*V07 - 1.82159404246676656e-7*V012*V022*V03*V07 - 
      4.37857125942516349e-8*V013*V032*V07 + 3.33510664947870221e-8*V02*V033*V07 - 
      6.66512522719849401e-8*V013*V02*V04*V07 + 7.0436522298911306e-8*V022*V03*V04*V07 + 
      6.1629967050080088e-8*V01*V032*V04*V07 + 4.47039502924786497e-8*V01*V02*V042*V07 - 
      6.89687013435262735e-9*V014*V05*V07 + 1.40319220319051179e-8*V023*V05*V07 + 
      7.55002763583002605e-8*V01*V02*V03*V05*V07 + 2.25165618306410122e-8*V012*V04*V05*V07 - 
      4.3390872573251391e-9*V042*V05*V07 - 3.71581570466195363e-9*V03*V052*V07 + 
      1.93279029537411271e-8*V01*V022*V06*V07 + 1.57967461763094828e-8*V012*V03*V06*V07 - 
      6.22175490190489495e-9*V03*V04*V06*V07 - 3.78129113979179746e-9*V02*V05*V06*V07 - 
      8.58084901628134437e-10*V01*V062*V07 + 3.60138821890595882e-9*V012*V02*V072 - 
      9.78266741482981504e-10*V032*V072 - 1.38948128968561484e-9*V02*V04*V072 - 
      7.52394819580870262e-10*V01*V05*V072 + 2.10774950358283692e-10*V016*V08 - 
      2.45112683534232709e-8*V012*V023*V08 - 3.51761800156262108e-8*V013*V02*V03*V08 + 
      1.96330626303350956e-8*V022*V032*V08 + 1.1216843817911246e-8*V01*V033*V08 - 
      4.47633195393757952e-9*V014*V04*V08 + 8.78358434831316382e-9*V023*V04*V08 + 
      4.92151309619481556e-8*V01*V02*V03*V04*V08 + 7.3841526455329652e-9*V012*V042*V08 - 
      9.28787617588229207e-10*V043*V08 + 1.49915135042101125e-8*V01*V022*V05*V08 + 
      1.22042032643364276e-8*V012*V03*V05*V08 - 4.83269600788884407e-9*V03*V04*V05*V08 - 
      1.47011713658956168e-9*V02*V052*V08 + 6.3955703261807191e-9*V012*V02*V06*V08 - 
      1.72787802715219131e-9*V032*V06*V08 - 2.42668113764751516e-9*V02*V04*V06*V08 - 
      1.33087411285108721e-9*V01*V05*V06*V08 + 7.34425621745087177e-10*V013*V07*V08 - 
      1.55259713298449543e-9*V02*V03*V07*V08 - 9.82807179230375702e-10*V01*V04*V07*V08 + 
      1.66409833207679984e-11*V072*V08 - 1.50941041769118968e-10*V022*V082 - 
      2.70912027194210816e-10*V01*V03*V082 + 1.46477147933849181e-11*V06*V082 - 
      6.3675289625044527e-9*V013*V022*V09 - 2.10996352617063401e-9*V014*V03*V09 + 
      4.57593414678611544e-9*V023*V03*V09 + 1.21308679000675984e-8*V01*V02*V032*V09 + 
      8.77025813340971257e-9*V01*V022*V04*V09 + 7.1834582491458546e-9*V012*V03*V04*V09 - 
      1.4153130144278294e-9*V03*V042*V09 + 4.43374919694538825e-9*V012*V02*V05*V09 - 
      1.2085493846929004e-9*V032*V05*V09 - 1.71860988325774967e-9*V02*V04*V05*V09 - 
      4.64537966320880956e-10*V01*V052*V09 + 5.85119928881510634e-10*V013*V06*V09 - 
      1.23485121005822109e-9*V02*V03*V06*V09 - 7.82527221124742941e-10*V01*V04*V06*V09 - 
      2.74866492876620447e-10*V022*V07*V09 - 4.87679733209617839e-10*V01*V03*V07*V09 + 
      2.64872102510882816e-11*V06*V07*V09 - 1.96132737209951713e-10*V01*V02*V08*V09 + 2.05915231695656882e-11*V05*V08*V09 - 
      1.47194794595128582e-11*V012*V092 + 6.04604398570575428e-12*V04*V092 - 
      6.81918957041506061e-10*V014*V02*V10 + 3.48265568096190404e-10*V024*V10 + 
      3.9527475182641169e-9*V01*V022*V03*V10 + 1.58723639999545373e-9*V012*V032*V10 + 
      2.37547505225306883e-9*V012*V02*V04*V10 - 6.43522757525397723e-10*V032*V04*V10 - 
      4.50952228298101522e-10*V02*V042*V10 + 3.68274912836089829e-10*V013*V05*V10 - 
      7.85069953286181082e-10*V02*V03*V05*V10 - 4.96120765508822204e-10*V01*V04*V05*V10 - 
      1.96309128408017937e-10*V022*V06*V10 - 3.52688219460775253e-10*V01*V03*V06*V10 + 
      9.5316233966908681e-12*V062*V10 - 1.60333731470374093e-10*V01*V02*V07*V10 + 1.68369529618378081e-11*V05*V07*V10 - 
      2.67557676759354174e-11*V012*V08*V10 + 1.0935460066826233e-11*V04*V08*V10 + 5.52161429611184481e-12*V03*V09*V10 + 
      8.9919967036980298e-13*V02*V102 - 2.47970529833274931e-11*V015*V11 + 
      3.89954577624368677e-10*V01*V023*V11 + 9.61437921518691765e-10*V012*V02*V03*V11 - 
      8.91464542226039259e-11*V033*V11 + 1.80678947825540564e-10*V013*V04*V11 - 
      3.82417051477253683e-10*V02*V03*V04*V11 - 1.21402737967798751e-10*V01*V042*V11 - 
      1.1579794533571919e-10*V022*V05*V11 - 2.04845647122264229e-10*V01*V03*V05*V11 - 
      1.06250624924977204e-10*V01*V02*V06*V11 + 1.11490964617701429e-11*V05*V06*V11 - 
      2.0020992866254189e-11*V012*V07*V11 + 8.22649391242126872e-12*V04*V07*V11 + 4.59415296211132609e-12*V03*V08*V11 + 
      1.65438981434644094e-12*V02*V09*V11 + 4.82472259286606351e-13*V01*V10*V11 + 
      1.34548483210522039e-10*V012*V022*V12 + 6.68595979013183176e-11*V013*V03*V12 - 
      7.38062556142881292e-11*V02*V032*V12 - 5.13963980381249043e-11*V022*V04*V12 - 
      9.27015141760798796e-11*V01*V03*V04*V12 - 5.70547794500081007e-11*V01*V02*V05*V12 + 
      2.99860569026803575e-12*V052*V12 - 1.2273583111709115e-11*V012*V06*V12 + 
      5.01003651777715458e-12*V04*V06*V12 + 3.17860203949389117e-12*V03*V07*V12 + 1.2659976078683143e-12*V02*V08*V12 + 
      4.08194929348678229e-13*V01*V09*V12 - 1.4504663090396124e-15*V122 + 
      1.74558201922108011e-11*V013*V02*V13 - 1.87565584625415959e-11*V022*V03*V13 - 
      1.63891079936603135e-11*V01*V032*V13 - 2.39430034807101478e-11*V01*V02*V04*V13 - 
      6.09778721055783964e-12*V012*V05*V13 + 2.51300746588976029e-12*V04*V05*V13 + 
      1.80512891105252166e-12*V03*V06*V13 + 8.16578853091849905e-13*V02*V07*V13 + 2.91207984024564874e-13*V01*V08*V13 - 
      2.69675342393643147e-15*V11*V13 + 7.34123279111669205e-13*V014*V14 - 1.4520930099637216e-12*V023*V14 - 
      7.94578858294750353e-12*V01*V02*V03*V14 - 2.40313008101044368e-12*V012*V04*V14 + 
      4.89671735163281324e-13*V042*V14 + 8.42069244727671752e-13*V03*V05*V14 + 4.31272395984100651e-13*V02*V06*V14 + 
      1.74658263583684653e-13*V01*V07*V14 - 2.15457447914380396e-15*V10*V14 - 8.9781667846007617e-13*V01*V022*V15 - 
      7.37730082826125629e-13*V012*V03*V15 + 3.09546490011871761e-13*V03*V04*V15 + 
      1.89703701486212331e-13*V02*V05*V15 + 8.69839823895684655e-14*V01*V06*V15 - 1.48321425750994692e-15*V09*V15 - 
      1.5980914919437697e-13*V012*V02*V16 + 4.57771546685545971e-14*V032*V16 + 
      6.52843535205289976e-14*V02*V04*V16 + 3.57966221493292314e-14*V01*V05*V16 - 8.70649042677774238e-16*V08*V16 - 
      8.32339318720713384e-15*V013*V17 + 1.84343556902537708e-14*V02*V03*V17 + 1.17610148879670657e-14*V01*V04*V17 - 
      4.36239290396901429e-16*V07*V17 + 1.7370559695040975e-15*V022*V18 + 3.09639273730613213e-15*V01*V03*V18 - 
      1.8281307790162915e-16*V06*V18 + 5.69217559451212504e-16*V01*V02*V19 - 6.42876573435826361e-17*V05*V19 + 
      4.14661798275717718e-17*V012*V20 - 1.80792544048212925e-17*V04*V20 - 4.17426210264222503e-18*V03*V21 - 
      6.63458877241148349e-19*V02*V22 - 9.04716650783384113e-20*V01*V23 + 6.9808383548100626e-23*V26) + 
   delta6*eps10*(-2.74769340381696435e-8*V022*V034 - 1.07639452439872608e-8*V01*V035 - 
      4.89821079515290533e-8*V023*V032*V04 - 1.22930855987967722e-7*V01*V02*V033*V04 - 
      6.21784885258793341e-10*V024*V042 - 9.20991292139751524e-8*V01*V022*V03*V042 - 
      4.92875941492888272e-8*V012*V032*V042 - 1.87580428009933145e-8*V012*V02*V043 + 
      3.8824614260066828e-8*V032*V043 + 7.35917308458240036e-9*V02*V044 - 
      1.14557399132108646e-8*V024*V03*V05 - 9.39409530971155621e-8*V01*V022*V032*V05 - 
      2.85950056049067876e-8*V012*V033*V05 - 2.9389264770917432e-8*V01*V023*V04*V05 - 
      1.01809884577158153e-7*V012*V02*V03*V04*V05 + 7.44574559481591069e-8*V033*V04*V05 - 
      8.71032191546508384e-9*V013*V042*V05 + 1.17074384057691148e-7*V02*V03*V042*V05 + 
      2.38540431258448046e-8*V01*V043*V05 - 1.30756378568003218e-8*V012*V022*V052 - 
      7.29685615792836459e-9*V013*V03*V052 + 5.81283378552467414e-8*V02*V032*V052 + 
      2.89942622476878869e-8*V022*V04*V052 + 6.76905840804596579e-8*V01*V03*V04*V052 + 
      1.18056790875543742e-8*V01*V02*V053 - 7.06794045525907851e-10*V054 - 
      8.08275217575974916e-11*V025*V06 - 2.12515129940433395e-8*V01*V023*V03*V06 - 
      3.38762155989046745e-8*V012*V02*V032*V06 + 1.30392731897766477e-8*V034*V06 - 
      1.95949349048088544e-8*V012*V022*V04*V06 - 1.13983674421738536e-8*V013*V03*V04*V06 + 
      8.48076389399461026e-8*V02*V032*V04*V06 + 1.56786788592745625e-8*V022*V042*V06 + 
      5.10787322326783384e-8*V01*V03*V042*V06 - 5.92992564086557239e-9*V013*V02*V05*V06 + 
      4.24257291634024247e-8*V022*V03*V05*V06 + 4.70787089119660635e-8*V01*V032*V05*V06 + 
      5.20706209726761905e-8*V01*V02*V04*V05*V06 + 6.94713693255276068e-9*V012*V052*V06 - 
      6.40105790975212439e-9*V04*V052*V06 - 2.24298059751685646e-10*V014*V062 + 
      1.84866682635380758e-9*V023*V062 + 1.85948157653287073e-8*V01*V02*V03*V062 + 
      5.42265501444226541e-9*V012*V04*V062 - 2.22130745594143576e-9*V042*V062 - 
      4.63736991429361019e-9*V03*V05*V062 - 5.54580846146333209e-10*V02*V063 - 
      1.63653427331583779e-9*V01*V024*V07 - 1.17421299435771891e-8*V012*V022*V03*V07 - 
      3.20093405070451445e-9*V013*V032*V07 + 1.87592204069923935e-8*V02*V033*V07 - 
      4.00733871205393148e-9*V013*V02*V04*V07 + 2.82652039123999253e-8*V022*V03*V04*V07 + 
      3.2547018463495343e-8*V01*V032*V04*V07 + 1.75210095995387451e-8*V01*V02*V042*V07 - 
      3.83623342355446308e-10*V014*V05*V07 + 4.60317291956745984e-9*V023*V05*V07 + 
      3.41071335553664913e-8*V01*V02*V03*V05*V07 + 9.62912321222397202e-9*V012*V04*V05*V07 - 
      4.42951313977359782e-9*V042*V05*V07 - 4.25973443487603526e-9*V03*V052*V07 + 
      6.34079407561570895e-9*V01*V022*V06*V07 + 6.61773317046439941e-9*V012*V03*V06*V07 - 
      6.44617457894883118e-9*V03*V04*V06*V07 - 3.34149468111654351e-9*V02*V05*V06*V07 - 
      7.42741450773490953e-10*V01*V062*V07 + 1.21142067789604728e-9*V012*V02*V072 - 
      1.06680612584732195e-9*V032*V072 - 1.14702018027081605e-9*V02*V04*V072 - 
      6.77478100005880002e-10*V01*V05*V072 - 1.14891137851247821e-9*V012*V023*V08 - 
      1.92910950964172253e-9*V013*V02*V03*V08 + 8.11039841871320418e-9*V022*V032*V08 + 
      5.76365642877216439e-9*V01*V033*V08 - 2.22498727108904513e-10*V014*V04*V08 + 
      1.91415314893434211e-9*V023*V04*V08 + 1.96330381410626959e-8*V01*V02*V03*V04*V08 + 
      2.86591172869538992e-9*V012*V042*V08 - 8.01282368730101966e-10*V043*V08 + 
      4.97306318106403491e-9*V01*V022*V05*V08 + 5.05041475517903175e-9*V012*V03*V05*V08 - 
      5.05492119438749656e-9*V03*V04*V05*V08 - 1.31604917227658524e-9*V02*V052*V08 + 
      2.08191788365372175e-9*V012*V02*V06*V08 - 1.82019520578530927e-9*V032*V06*V08 - 
      1.79627438518836763e-9*V02*V04*V06*V08 - 1.15840113098896455e-9*V01*V05*V06*V08 + 
      2.25606373851185909e-10*V013*V07*V08 - 1.32165695838759844e-9*V02*V03*V07*V08 - 
      8.07434980281941008e-10*V01*V04*V07*V08 + 2.17051692867928172e-11*V072*V08 - 
      8.98487444929676867e-11*V022*V082 - 2.24134068354309549e-10*V01*V03*V082 + 
      1.81331803232160107e-11*V06*V082 - 2.52693778020575406e-10*V013*V022*V09 - 
      9.09225276055341415e-11*V014*V03*V09 + 1.3370593591798383e-9*V023*V03*V09 + 
      4.85068722880645286e-9*V01*V02*V032*V09 + 2.51833886420762107e-9*V01*V022*V04*V09 + 
      2.70947346742516175e-9*V012*V03*V04*V09 - 1.36161805484418992e-9*V03*V042*V09 + 
      1.43096367560202802e-9*V012*V02*V05*V09 - 1.29851267719888812e-9*V032*V05*V09 - 
      1.40116539159537664e-9*V02*V04*V05*V09 - 4.11291740294556219e-10*V01*V052*V09 + 
      1.74891630887711094e-10*V013*V06*V09 - 1.02452104590438096e-9*V02*V03*V06*V09 - 
      6.28379847623859237e-10*V01*V04*V06*V09 - 1.78484697920670409e-10*V022*V07*V09 - 
      4.08092701013585716e-10*V01*V03*V07*V09 + 3.3953132833433193e-11*V06*V07*V09 - 1.27888002532006643e-10*V01*V02*V08*V09 + 
      2.6678956657570525e-11*V05*V08*V09 - 9.36810066023675533e-12*V012*V092 + 
      7.3042193898542391e-12*V04*V092 - 2.1254616842852137e-11*V014*V02*V10 + 
      5.34565056721994546e-11*V024*V10 + 1.16830609307205209e-9*V01*V022*V03*V10 + 
      5.7084323796536825e-10*V012*V032*V10 + 6.85449851410095157e-10*V012*V02*V04*V10 - 
      6.33606321810949201e-10*V032*V04*V10 - 3.07470334617415872e-10*V02*V042*V10 + 
      1.06936736097720667e-10*V013*V05*V10 - 6.62203685910129601e-10*V02*V03*V05*V10 - 
      4.02223295614672744e-10*V01*V04*V05*V10 - 1.13976288763887216e-10*V022*V06*V10 - 
      2.86328062844170295e-10*V01*V03*V06*V10 + 1.16480856420793068e-11*V062*V10 - 
      1.04988399583446367e-10*V01*V02*V07*V10 + 2.19163995634344966e-11*V05*V07*V10 - 
      1.69271171359636885e-11*V012*V08*V10 + 1.28132665874286097e-11*V04*V08*V10 + 
      6.86706159496541213e-12*V03*V09*V10 + 8.64949181561006468e-13*V02*V102 - 
      5.9040602341255936e-13*V015*V11 + 7.9301443030414151e-11*V01*V023*V11 + 
      2.6594713548899463e-10*V012*V02*V03*V11 - 8.87299917031129082e-11*V033*V11 + 
      4.73697993641643616e-11*V013*V04*V11 - 2.90710931892431905e-10*V02*V03*V04*V11 - 
      8.95415287043420387e-11*V01*V042*V11 - 7.38304027027456823e-11*V022*V05*V11 - 
      1.6709053987121586e-10*V01*V03*V05*V11 - 6.70736015883760654e-11*V01*V02*V06*V11 + 1.41806766887971536e-11*V05*V06*V11 - 
      1.26383881868897513e-11*V012*V07*V11 + 9.92787536971747346e-12*V04*V07*V11 + 
      5.68022819682475523e-12*V03*V08*V11 + 1.63246143178152037e-12*V02*V09*V11 + 4.7344232554941086e-13*V01*V10*V11 + 
      2.78562884046415178e-11*V012*V022*V12 + 1.62444520441739797e-11*V013*V03*V12 - 
      5.77149632529734132e-11*V02*V032*V12 - 2.6944414439909714e-11*V022*V04*V12 - 
      6.92962743396114235e-11*V01*V03*V04*V12 - 3.64699830497891316e-11*V01*V02*V05*V12 + 
      3.87536377323733394e-12*V052*V12 - 7.53905826800908323e-12*V012*V06*V12 + 
      5.76198889094579598e-12*V04*V06*V12 + 3.95150326642972839e-12*V03*V07*V12 + 1.21099716344026668e-12*V02*V08*V12 + 
      4.00943552284233181e-13*V01*V09*V12 - 1.91905668480552483e-15*V122 + 
      3.26277012938519646e-12*V013*V02*V13 - 1.10242787871679341e-11*V022*V03*V13 - 
      1.21615132465506972e-11*V01*V032*V13 - 1.36914823893645027e-11*V01*V02*V04*V13 - 
      3.70892250064880374e-12*V012*V05*V13 + 3.00593384548658181e-12*V04*V05*V13 + 
      2.18822945116350435e-12*V03*V06*V13 + 8.0426113589143413e-13*V02*V07*V13 + 2.83733661829447263e-13*V01*V08*V13 - 
      3.5950044222355905e-15*V11*V13 + 1.16527504620899874e-13*V014*V14 - 5.70142157529630388e-13*V023*V14 - 
      4.61744861167641976e-12*V01*V02*V03*V14 - 1.3414535353382164e-12*V012*V04*V14 + 
      5.26901714422590449e-13*V042*V14 + 1.03479343769192604e-12*V03*V05*V14 + 4.02694965934368117e-13*V02*V06*V14 + 
      1.70833668881899522e-13*V01*V07*V14 - 2.84703099736483097e-15*V10*V14 - 3.89072390428671245e-13*V01*V022*V15 - 
      4.00077765865089566e-13*V012*V03*V15 + 3.51758725996098794e-13*V03*V04*V15 + 
      1.84741598720858294e-13*V02*V05*V15 + 8.28519403972961318e-14*V01*V06*V15 - 1.97695220033361111e-15*V09*V15 - 
      6.79743776955249263e-14*V012*V02*V16 + 5.30733593768815591e-14*V032*V16 + 
      5.64663818975602804e-14*V02*V04*V16 + 3.43795678100096272e-14*V01*V05*V16 - 1.14444869229479259e-15*V08*V16 - 
      3.23687512835832983e-15*V013*V17 + 1.69279186966391785e-14*V02*V03*V17 + 1.04222688009763788e-14*V01*V04*V17 - 
      5.80985577516217115e-16*V07*V17 + 1.18497776438161466e-15*V022*V18 + 2.76682456624020715e-15*V01*V03*V18 - 
      2.36325392394261166e-16*V06*V18 + 4.01091048513966957e-16*V01*V02*V19 - 8.50500667784587243e-17*V05*V19 + 
      2.81467402465941724e-17*V012*V20 - 2.20750862791145724e-17*V04*V20 - 5.28421540105702499e-18*V03*V21 - 
      6.63458877241148349e-19*V02*V22 - 9.04716650783384113e-20*V01*V23 + 9.30778447308008347e-23*V26) + 
   delta2*eps12*(2.67650730613693577e-11*V027 + 1.45976708476708477e-7*V01*V025*V03 + 
      7.0347310654023617e-7*V012*V023*V032 + 3.42178076553076553e-7*V013*V02*V033 - 
      3.084430776406004e-7*V022*V034 - 1.08118735615307161e-7*V01*V035 + 
      2.37633701175367842e-7*V012*V024*V04 + 6.93810915165081832e-7*V013*V022*V03*V04 + 
      1.13156037635204302e-7*V014*V032*V04 - 7.43688622196506832e-7*V023*V032*V04 - 
      1.44359805672247316e-6*V01*V02*V033*V04 + 7.64811962728629395e-8*V014*V02*V042 - 
      8.46192910475220622e-8*V024*V042 - 1.38524165905300651e-6*V01*V022*V03*V042 - 
      6.05303266276509741e-7*V012*V032*V042 - 2.74664734491634001e-7*V012*V02*V043 + 
      1.11694089518080728e-7*V032*V043 + 3.25142589196534057e-8*V02*V044 + 
      1.18629495076254336e-7*V013*V023*V05 + 1.16106886940220274e-7*V014*V02*V03*V05 - 
      1.89987803884635766e-7*V024*V03*V05 - 1.18823842681875478e-6*V01*V022*V032*V05 - 
      3.31736914716460702e-7*V012*V033*V05 + 9.63542630209296876e-9*V015*V04*V05 - 
      4.83504726572034514e-7*V01*V023*V04*V05 - 1.34919420843425862e-6*V012*V02*V03*V04*V05 + 
      1.95378476733736308e-7*V033*V04*V05 - 1.21287286511449093e-7*V013*V042*V05 + 
      3.72522518500135835e-7*V02*V03*V042*V05 + 7.73089389403570869e-8*V01*V043*V05 - 
      1.8487438634533931e-7*V012*V022*V052 - 9.78097825560769072e-8*V013*V03*V052 + 
      1.65316922135894928e-7*V02*V032*V052 + 1.01740062258203634e-7*V022*V04*V052 + 
      2.00321126014137137e-7*V01*V03*V04*V052 + 3.76852254599081583e-8*V01*V02*V053 - 
      1.16437164809287144e-9*V054 + 2.40283443408443408e-8*V014*V022*V06 - 
      1.2002167247946115e-8*V025*V06 + 5.90169861003194337e-9*V015*V03*V06 - 
      3.48537536633261034e-7*V01*V023*V03*V06 - 4.65194063466705857e-7*V012*V02*V032*V06 + 
      3.48391497335826987e-8*V034*V06 - 3.12553644628662136e-7*V012*V022*V04*V06 - 
      1.64529391194015377e-7*V013*V03*V04*V06 + 2.69770771364478109e-7*V02*V032*V04*V06 + 
      7.7090098636797543e-8*V022*V042*V06 + 1.65806390843634817e-7*V01*V03*V042*V06 - 
      9.2022791402022261e-8*V013*V02*V05*V06 + 1.48557661675356213e-7*V022*V03*V05*V06 + 
      1.41952602899461084e-7*V01*V032*V05*V06 + 1.85640328809827055e-7*V01*V02*V04*V05*V06 + 
      2.34643216241922976e-8*V012*V052*V06 - 1.14432768100795188e-8*V04*V052*V06 - 
      3.87938929240866683e-9*V014*V062 + 1.00510417097837275e-8*V023*V062 + 
      6.64465440764529479e-8*V01*V02*V03*V062 + 1.96674517835845123e-8*V012*V04*V062 - 
      4.58348028122747872e-9*V042*V062 - 8.278219783333639e-9*V03*V05*V062 - 
      1.24683518334632837e-9*V02*V063 + 2.04752808919475586e-9*V015*V02*V07 - 
      3.13823433674672781e-8*V01*V024*V07 - 1.84926089044246724e-7*V012*V022*V03*V07 - 
      4.810012569626832e-8*V013*V032*V07 + 5.73194526254322907e-8*V02*V033*V07 - 
      6.68356487246543269e-8*V013*V02*V04*V07 + 1.0676507036741326e-7*V022*V03*V04*V07 + 
      1.03432916432419505e-7*V01*V032*V04*V07 + 6.71412123632643145e-8*V01*V02*V042*V07 - 
      6.69646946126287863e-9*V014*V05*V07 + 1.90859584989206258e-8*V023*V05*V07 + 
      1.16939449769792707e-7*V01*V02*V03*V05*V07 + 3.4238071677382654e-8*V012*V04*V05*V07 - 
      8.30823257228058229e-9*V042*V05*V07 - 7.33675818986803955e-9*V03*V052*V07 + 
      2.65804099641751113e-8*V01*V022*V06*V07 + 2.40101095250355247e-8*V012*V03*V06*V07 - 
      1.20455061030964279e-8*V03*V04*V06*V07 - 6.79398788954425902e-9*V02*V05*V06*V07 - 
      1.53869034002724677e-9*V01*V062*V07 + 4.96562880025493872e-9*V012*V02*V072 - 
      1.92466642630860559e-9*V032*V072 - 2.45920200644826241e-9*V02*V04*V072 - 
      1.35724029323924052e-9*V01*V05*V072 + 6.02214143880810547e-11*V016*V08 - 
      2.13611851300781039e-8*V012*V023*V08 - 3.42695272229585955e-8*V013*V02*V03*V08 + 
      3.02792194681157412e-8*V022*V032*V08 + 1.88389345300225058e-8*V01*V033*V08 - 
      4.26361709807379742e-9*V014*V04*V08 + 1.12167139606465727e-8*V023*V04*V08 + 
      7.47344361790665714e-8*V01*V02*V03*V04*V08 + 1.10687472366313311e-8*V012*V042*V08 - 
      1.72772347997289948e-9*V043*V08 + 2.06640487907188666e-8*V01*V022*V05*V08 + 
      1.85082141198720689e-8*V012*V03*V05*V08 - 9.37950419429437389e-9*V03*V04*V05*V08 - 
      2.65050454855617483e-9*V02*V052*V08 + 8.80299398332571031e-9*V012*V02*V06*V08 - 
      3.38269656824215663e-9*V032*V06*V08 - 4.22589433929602085e-9*V02*V04*V06*V08 - 
      2.38981532068142626e-9*V01*V05*V06*V08 + 9.90515159221750045e-10*V013*V07*V08 - 
      2.79267731905870259e-9*V02*V03*V07*V08 - 1.74370892281823102e-9*V01*V04*V07*V08 + 
      3.31867925608791034e-11*V072*V08 - 2.41409229250683865e-10*V022*V082 - 
      4.84349766673563639e-10*V01*V03*V082 + 2.89712894379706975e-11*V06*V082 - 
      5.41549924975170073e-9*V013*V022*V09 - 1.93062769655906911e-9*V014*V03*V09 + 
      6.18950644102830038e-9*V023*V03*V09 + 1.85179574839370135e-8*V01*V02*V032*V09 + 
      1.17828203493836249e-8*V01*V022*V04*V09 + 1.07257156401284082e-8*V012*V03*V04*V09 - 
      2.70359820304872567e-9*V03*V042*V09 + 6.07914170003273737e-9*V012*V02*V05*V09 - 
      2.37460104972733882e-9*V032*V05*V09 - 3.04046225768207461e-9*V02*V04*V05*V09 - 
      8.36430987272470724e-10*V01*V052*V09 + 7.86772810235201405e-10*V013*V06*V09 - 
      2.21263297880806407e-9*V02*V03*V06*V09 - 1.38398602015655266e-9*V01*V04*V06*V09 - 
      4.4520846148331938e-10*V022*V07*V09 - 8.72931442629041828e-10*V01*V03*V07*V09 + 
      5.26721248135003586e-11*V06*V07*V09 - 3.19721355448360149e-10*V01*V02*V08*V09 + 4.10606581135547258e-11*V05*V08*V09 - 
      2.38199168900336927e-11*V012*V092 + 1.18839211140883258e-11*V04*V092 - 
      5.49077601773680205e-10*V014*V02*V10 + 3.86984390179204898e-10*V024*V10 + 
      5.38127123739438841e-9*V01*V022*V03*V10 + 2.35425271167935375e-9*V012*V032*V10 + 
      3.1997553842434887e-9*V012*V02*V04*V10 - 1.24450308167573351e-9*V032*V04*V10 - 
      7.73375929443341844e-10*V02*V042*V10 + 4.92008163903447967e-10*V013*V05*V10 - 
      1.41186771676983161e-9*V02*V03*V05*V10 - 8.79027095323632989e-10*V01*V04*V05*V10 - 
      3.12777136181320367e-10*V022*V06*V10 - 6.28829694329919415e-10*V01*V03*V06*V10 + 
      1.88137017465615999e-11*V062*V10 - 2.61467955813591311e-10*V01*V02*V07*V10 + 
      3.36011857984340028e-11*V05*V07*V10 - 4.32819850759256635e-11*V012*V08*V10 + 
      2.13961039994227219e-11*V04*V08*V10 + 1.09996421190625787e-11*V03*V09*V10 + 1.63674936427126164e-12*V02*V102 - 
      1.85977897374956198e-11*V015*V11 + 4.59321643964406406e-10*V01*V023*V11 + 
      1.28685984453044567e-9*V012*V02*V03*V11 - 1.73965530086105601e-10*V033*V11 + 
      2.37428674915237523e-10*V013*V04*V11 - 6.74434524894710797e-10*V02*V03*V04*V11 - 
      2.11500334074548793e-10*V01*V042*V11 - 1.87388333343387057e-10*V022*V05*V11 - 
      3.65495445156227141e-10*V01*V03*V05*V11 - 1.72407649831470694e-10*V01*V02*V06*V11 + 2.21675458077228265e-11*V05*V06*V11 - 
      3.23547309901701805e-11*V012*V07*V11 + 1.61689362500497414e-11*V04*V07*V11 + 
      9.14425764956572053e-12*V03*V08*V11 + 3.02273164582402388e-12*V02*V09*V11 + 8.81698213101695296e-13*V01*V10*V11 + 
      1.59805819837102087e-10*V012*V022*V12 + 8.63507651742408364e-11*V013*V03*V12 - 
      1.32009755806277339e-10*V02*V032*V12 - 8.03257382924611658e-11*V022*V04*V12 - 
      1.62859423095692768e-10*V01*V03*V04*V12 - 9.27706260841776561e-11*V01*V02*V05*V12 + 
      5.98372199130302705e-12*V052*V12 - 1.97702321500602692e-11*V012*V06*V12 + 
      9.77437966473708316e-12*V04*V06*V12 + 6.3322572941193529e-12*V03*V07*V12 + 2.30242322547588044e-12*V02*V08*V12 + 
      7.46025996387384221e-13*V01*V09*V12 - 2.89767620050883711e-15*V122 + 
      2.02563645532664281e-11*V013*V02*V13 - 3.02249688860715764e-11*V022*V03*V13 - 
      2.89074219856099494e-11*V01*V032*V13 - 3.81567556720352671e-11*V01*V02*V04*V13 - 
      9.79910305465500131e-12*V012*V05*V13 + 4.93805918318293845e-12*V04*V05*V13 + 
      3.58232318765102169e-12*V03*V06*V13 + 1.49168263991744812e-12*V02*V07*V13 + 5.31637941831333841e-13*V01*V08*V13 - 
      5.39349176926201655e-15*V11*V13 + 8.15692532346299116e-13*V014*V14 - 2.0394039642059269e-12*V023*V14 - 
      1.27822904068819101e-11*V01*V02*V03*V14 - 3.80462302587238088e-12*V012*V04*V14 + 
      9.43493087903362422e-13*V042*V14 + 1.6761637137509049e-12*V03*V05*V14 + 7.81357932304635833e-13*V02*V06*V14 + 
      3.18991229225688745e-13*V01*V07*V14 - 4.30350651164704879e-15*V10*V14 - 1.2922900262457796e-12*V01*V022*V15 - 
      1.16469240868589424e-12*V012*V03*V15 + 6.0699923045643279e-13*V03*V04*V15 + 3.46354183280487579e-13*V02*V05*V15 + 
      1.58266004160357444e-13*V01*V06*V15 - 2.96641343640904745e-15*V09*V15 - 2.29170759087769752e-13*V012*V02*V16 + 
      9.0756148202973631e-14*V032*V16 + 1.1655806393888189e-13*V02*V04*V16 + 6.52324830992174169e-14*V01*V05*V16 - 
      1.73765241233313247e-15*V08*V16 - 1.16527504620899874e-14*V013*V17 + 3.35629772626173653e-14*V02*V03*V17 + 
      2.11142771959826184e-14*V01*V04*V17 - 8.72463502182956469e-16*V07*V17 + 2.84623858336452642e-15*V022*V18 + 
      5.59838663504758089e-15*V01*V03*V18 - 3.6390719416676987e-16*V06*V18 + 9.40905316814719477e-16*V01*V02*V19 - 
      1.28560236076318882e-16*V05*V19 + 6.78537488087538085e-17*V012*V20 - 3.55955740047107016e-17*V04*V20 - 
      8.33344559443806033e-18*V03*V21 - 1.21634127494210531e-18*V02*V22 - 1.65864719310287087e-19*V01*V23 + 
      1.39616767096201252e-22*V26) + delta4*eps11*
    (-1.52806918959560572e-7*V022*V034 - 5.68856203558000944e-8*V01*V035 - 
      3.15876669022093859e-7*V023*V032*V04 - 6.958119979804348e-7*V01*V02*V033*V04 - 
      2.12135350797297057e-8*V024*V042 - 5.88091694777424625e-7*V01*V022*V03*V042 - 
      2.84453623063372519e-7*V012*V032*V042 - 1.17619271009793886e-7*V012*V02*V043 + 
      8.86966561558005104e-8*V032*V043 + 2.14460056215349951e-8*V02*V044 - 
      7.48091926548262786e-8*V024*V03*V05 - 5.39058962601990924e-7*V01*V022*V032*V05 - 
      1.58909001373938738e-7*V012*V033*V05 - 1.89526001413256315e-7*V01*V023*V04*V05 - 
      5.98055205770687797e-7*V012*V02*V03*V04*V05 + 1.61506258237866329e-7*V033*V04*V05 - 
      5.25955727480781947e-8*V013*V042*V05 + 2.7817888422773766e-7*V02*V03*V042*V05 + 
      5.71626170411310686e-8*V01*V043*V05 - 7.79750415933013972e-8*V012*V022*V052 - 
      4.30718512656148822e-8*V013*V03*V052 + 1.29951972063580657e-7*V02*V032*V052 + 
      7.14529200788832413e-8*V022*V04*V052 + 1.54251296369004045e-7*V01*V03*V04*V052 + 
      2.7666147109001462e-8*V01*V02*V053 - 1.13709972354473621e-9*V054 - 
      2.88534984820906597e-9*V025*V06 - 1.37982768361308666e-7*V01*V023*V03*V06 - 
      2.02380681221523114e-7*V012*V02*V032*V06 + 2.86427995168255253e-8*V034*V06 - 
      1.2455520353123839e-7*V012*V022*V04*V06 - 6.98371886039661483e-8*V013*V03*V04*V06 + 
      2.02138696129166647e-7*V02*V032*V04*V06 + 4.76440170839494897e-8*V022*V042*V06 + 
      1.22766511580894927e-7*V01*V03*V042*V06 - 3.73179340947003568e-8*V013*V02*V05*V06 + 
      1.04883064752468015e-7*V022*V03*V05*V06 + 1.08613935887695355e-7*V01*V032*V05*V06 + 
      1.29739082094093604e-7*V01*V02*V04*V05*V06 + 1.67949996998712611e-8*V012*V052*V06 - 
      1.07734910420858212e-8*V04*V052*V06 - 1.49676361306846834e-9*V014*V062 + 
      5.84866874828278493e-9*V023*V062 + 4.6490749479958687e-8*V01*V02*V03*V062 + 
      1.36335308620654137e-8*V012*V04*V062 - 4.07075243007609874e-9*V042*V062 - 
      7.81909983324219675e-9*V03*V05*V062 - 1.05468946841692334e-9*V02*V063 - 
      1.06870275221180398e-8*V01*V024*V07 - 7.26839521385117401e-8*V012*V022*V03*V07 - 
      1.97934519015381916e-8*V013*V032*V07 + 4.36427528289873252e-8*V02*V033*V07 - 
      2.5795429568918131e-8*V013*V02*V04*V07 + 7.24637097784827881e-8*V022*V03*V04*V07 + 
      7.71187361798493556e-8*V01*V032*V04*V07 + 4.5233620195199384e-8*V01*V02*V042*V07 - 
      2.55167860404399464e-9*V014*V05*V07 + 1.21804939863605216e-8*V023*V05*V07 + 
      8.29641982955464781e-8*V01*V02*V03*V05*V07 + 2.38538285080762939e-8*V012*V04*V05*V07 - 
      7.64283130640170456e-9*V042*V05*V07 - 7.0292409799740354e-9*V03*V052*V07 + 
      1.69392668103744883e-8*V01*V022*V06*V07 + 1.6595678076758996e-8*V012*V03*V06*V07 - 
      1.11310141599262844e-8*V03*V04*V06*V07 - 5.96678959169407956e-9*V02*V05*V06*V07 - 
      1.34126360695585486e-9*V01*V062*V07 + 3.18336816442698659e-9*V012*V02*V072 - 
      1.80743274343053554e-9*V032*V072 - 2.10266307800613464e-9*V02*V04*V072 - 
      1.19842672976589113e-9*V01*V05*V072 - 7.53560510796738621e-9*V012*V023*V08 - 
      1.27980626820787885e-8*V013*V02*V03*V08 + 2.07894937321814828e-8*V022*V032*V08 + 
      1.3921933471288758e-8*V01*V033*V08 - 1.54652640647038406e-9*V014*V04*V08 + 
      6.26249873969185865e-9*V023*V04*V08 + 5.07187641611914184e-8*V01*V02*V03*V04*V08 + 
      7.44622710619452884e-9*V012*V042*V08 - 1.50432993014089171e-9*V043*V08 + 
      1.32561219817359938e-8*V01*V022*V05*V08 + 1.27619496246252961e-8*V012*V03*V05*V08 - 
      8.70482219950651634e-9*V03*V04*V05*V08 - 2.34132189036775429e-9*V02*V052*V08 + 
      5.60267195480498943e-9*V012*V02*V06*V08 - 3.14457965704656587e-9*V032*V06*V08 - 
      3.49886763160363477e-9*V02*V04*V06*V08 - 2.08946769759537164e-9*V01*V05*V06*V08 + 
      6.17035147718537668e-10*V013*V07*V08 - 2.4147989327076599e-9*V02*V03*V07*V08 - 
      1.49030395092540559e-9*V01*V04*V07*V08 + 3.29892849746113782e-11*V072*V08 - 
      1.85769012528000428e-10*V022*V082 - 4.15060292854459985e-10*V01*V03*V082 + 
      2.8347059314050546e-11*V06*V082 - 1.82258339427457075e-9*V013*V022*V09 - 
      6.67749212479604636e-10*V014*V03*V09 + 3.77339507269355975e-9*V023*V03*V09 + 
      1.25618347953540254e-8*V01*V02*V032*V09 + 7.14196990737920524e-9*V01*V022*V04*V09 + 
      7.14037566314455689e-9*V012*V03*V04*V09 - 2.43543286477891104e-9*V03*V042*V09 + 
      3.85955520133643137e-9*V012*V02*V05*V09 - 2.22293375126654135e-9*V032*V05*V09 - 
      2.59506546555557269e-9*V02*V04*V05*V09 - 7.3581687943856921e-10*V01*V052*V09 + 
      4.8665825669129732e-10*V013*V06*V09 - 1.89847107157496911e-9*V02*V03*V06*V09 - 
      1.17490485564995988e-9*V01*V04*V06*V09 - 3.51426447562011315e-10*V022*V07*V09 - 
      7.50335709632982461e-10*V01*V03*V07*V09 + 5.20763182348270563e-11*V06*V07*V09 - 2.5303234703178275e-10*V01*V02*V08*V09 + 
      4.07778441576321774e-11*V05*V08*V09 - 1.8695582881471011e-11*V012*V092 + 
      1.15072965190096386e-11*V04*V092 - 1.71217746789642214e-10*V014*V02*V10 + 
      1.92113878170659558e-10*V024*V10 + 3.29879529180663194e-9*V01*V022*V03*V10 + 
      1.54202785290627957e-9*V012*V032*V10 + 1.94591185098659104e-9*V012*V02*V04*V10 - 
      1.13024061335515152e-9*V032*V04*V10 - 6.21893994910565973e-10*V02*V042*V10 + 
      3.01718378928932375e-10*V013*V05*V10 - 1.21968969858732122e-9*V02*V03*V05*V10 - 
      7.49404778180590171e-10*V01*V04*V05*V10 - 2.38893190799719848e-10*V022*V06*V10 - 
      5.35874668934533298e-10*V01*V03*V06*V10 + 1.83359842204111559e-11*V062*V10 - 
      2.0718693649376069e-10*V01*V02*V07*V10 + 3.34199798567538781e-11*V05*V07*V10 - 
      3.3924902962824983e-11*V012*V08*V10 + 2.05328632884404755e-11*V04*V08*V10 + 1.07581102072366036e-11*V03*V09*V10 + 
      1.47070404889579494e-12*V02*V102 - 5.31365421071303424e-12*V015*V11 + 
      2.48358769884384882e-10*V01*V023*V11 + 7.71874861251565881e-10*V012*V02*V03*V11 - 
      1.58559391707317819e-10*V033*V11 + 1.40032212088693673e-10*V013*V04*V11 - 
      5.61357991571373525e-10*V02*V03*V04*V11 - 1.7433030741664228e-10*V01*V042*V11 - 
      1.47512793895455299e-10*V022*V05*V11 - 3.12222269925821467e-10*V01*V03*V05*V11 - 
      1.35159910425839623e-10*V01*V02*V06*V11 + 2.18922952159847789e-11*V05*V06*V11 - 
      2.5333763872467914e-11*V012*V07*V11 + 1.56536001965007288e-11*V04*V07*V11 + 8.92813645643280211e-12*V03*V08*V11 + 
      2.73641576630246169e-12*V02*V09*V11 + 7.97100635634540666e-13*V01*V10*V11 + 
      8.70369827014528024e-11*V012*V022*V12 + 4.96329484681952862e-11*V013*V03*V12 - 
      1.1096220648949361e-10*V02*V032*V12 - 5.91343175830674534e-11*V022*V04*V12 - 
      1.34862071672957394e-10*V01*V03*V04*V12 - 7.31229327782623809e-11*V01*V02*V05*V12 + 
      5.9457389675347873e-12*V052*V12 - 1.53633191449469276e-11*V012*V06*V12 + 
      9.3275632375441689e-12*V04*V06*V12 + 6.19310925351062037e-12*V03*V07*V12 + 2.06544449972002528e-12*V02*V08*V12 + 
      6.74624177338058683e-13*V01*V09*V12 - 2.89121865360783184e-15*V122 + 
      1.06816879235824884e-11*V013*V02*V13 - 2.30842065612378769e-11*V022*V03*V13 - 
      2.38773642772143671e-11*V01*V032*V13 - 2.88804264470394409e-11*V01*V02*V04*V13 - 
      7.59812044951786155e-12*V012*V05*V13 + 4.77430004109124123e-12*V04*V05*V13 + 
      3.47710866212780649e-12*V03*V06*V13 + 1.34988740448089142e-12*V02*V07*V13 + 4.7964793038172923e-13*V01*V08*V13 - 
      5.39335103556078358e-15*V11*V13 + 4.07846266173149558e-13*V014*V14 - 1.36409933028385478e-12*V023*V14 - 
      9.72954723225390703e-12*V01*V02*V03*V14 - 2.85819773119901505e-12*V012*V04*V14 + 
      8.79942667404491114e-13*V042*V14 + 1.63558710494722192e-12*V03*V05*V14 + 6.95851218173700222e-13*V02*V06*V14 + 
      2.88122330608983782e-13*V01*V07*V14 - 4.29233219484547072e-15*V10*V14 - 8.92212260380690033e-13*V01*V022*V15 - 
      8.66576209364092061e-13*V012*V03*V15 + 5.76254546085077975e-13*V03*V04*V15 + 
      3.12876249383043852e-13*V02*V05*V15 + 1.418321277710942e-13*V01*V06*V15 - 2.96627270270781448e-15*V09*V15 - 
      1.5731213123821483e-13*V012*V02*V16 + 8.6747750819641693e-14*V032*V16 + 
      1.01055643603636294e-13*V02*V04*V16 + 5.86680601292778003e-14*V01*V05*V16 - 1.73047164276784065e-15*V08*V16 - 
      7.76850030805999158e-15*V013*V17 + 2.96757113864180916e-14*V02*V03*V17 + 1.84515955686548097e-14*V01*V04*V17 - 
      8.72322768481723498e-16*V07*V17 + 2.28069015255260208e-15*V022*V18 + 4.90597682498136425e-15*V01*V03*V18 - 
      3.60579847373333201e-16*V06*V18 + 7.61972468104227953e-16*V01*V02*V19 - 1.28419502375085912e-16*V05*V19 + 
      5.42829990470030468e-17*V012*V20 - 3.45802808743871261e-17*V04*V20 - 8.19271189320508947e-18*V03*V21 - 
      1.10576479540191392e-18*V02*V22 - 1.50786108463897352e-19*V01*V23 + 1.39616767096201252e-22*V26) + 
   9.18368986379554615e-29*delta26*V26 + 5.969398411467105e-28*delta24*eps*V26;
}
#endif


#ifdef p15 /* Uses: V00 - V28. */
double Vp(void)
{

   V012 = V01 * V01;
   V013 = V01 * V012;
   V014 = V01 * V013;
   V015 = V01 * V014;
   V016 = V01 * V015;
   V017 = V01 * V016;
   V022 = V02 * V02;
   V023 = V02 * V022;
   V024 = V02 * V023;
   V025 = V02 * V024;
   V026 = V02 * V025;
   V027 = V02 * V026;
   V032 = V03 * V03;
   V033 = V03 * V032;
   V034 = V03 * V033;
   V035 = V03 * V034;
   V036 = V03 * V035;
   V042 = V04 * V04;
   V043 = V04 * V042;
   V044 = V04 * V043;
   V045 = V04 * V044;
   V052 = V05 * V05;
   V053 = V05 * V052;
   V054 = V05 * V053;
   V062 = V06 * V06;
   V063 = V06 * V062;
   V072 = V07 * V07;
   V073 = V07 * V072;
   V082 = V08 * V08;
   V083 = V08 * V082;
   V092 = V09 * V09;
   V102 = V10 * V10;
   V112 = V11 * V11;
   V122 = V12 * V12;
   V132 = V13 * V13;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;
   delta8 = delta2 * delta6;
   delta10 = delta2 * delta8;
   delta12 = delta2 * delta10;
   delta14 = delta2 * delta12;
   delta16 = delta2 * delta14;
   delta18 = delta2 * delta16;
   delta20 = delta2 * delta18;
   delta22 = delta2 * delta20;
   delta24 = delta2 * delta22;
   delta26 = delta2 * delta24;
   delta28 = delta2 * delta26;

   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 + 
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) + 
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 + 
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) + 
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 
      0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 + 
   0.000297619047619047619*delta4*eps*V06 + 
   eps4*(0.00416666666666666667*V012*V02 - 0.000570436507936507937*V032 - 
      0.000595238095238095238*V02*V04 - 0.000446428571428571429*V01*V05 + 4.1335978835978836e-6*V08) + 
   delta2*eps3*(-0.000992063492063492063*V032 - 0.000793650793650793651*V02*V04 - 
      0.000595238095238095238*V01*V05 + 8.2671957671957672e-6*V08) + 
   delta4*eps2*(-0.000496031746031746032*V032 - 0.000396825396825396825*V02*V04 - 
      0.000297619047619047619*V01*V05 + 8.2671957671957672e-6*V08) + 2.75573192239858907e-6*delta8*V08 + 
   5.51146384479717813e-6*delta6*eps*V08 + eps5*
    (0.0001763668430335097*V023 + 0.00143849206349206349*V01*V02*V03 + 0.000446428571428571429*V012*V04 - 
      0.0000388558201058201058*V042 - 0.0000785383597883597884*V03*V05 - 0.0000330687830687830688*V02*V06 - 
      0.0000165343915343915344*V01*V07 + 9.39454064454064454e-8*V10) + 
   delta6*eps2*(-0.0000154320987654320988*V042 - 0.0000385802469135802469*V03*V05 - 
      0.0000110229276895943563*V02*V06 - 5.51146384479717813e-6*V01*V07 + 1.25260541927208594e-7*V10) + 
   delta2*eps4*(0.0000661375661375661376*V023 + 0.00119047619047619048*V01*V02*V03 + 
      0.000297619047619047619*V012*V04 - 0.0000644841269841269841*V042 - 0.00014880952380952381*V03*V05 - 
      0.0000496031746031746032*V02*V06 - 0.0000248015873015873016*V01*V07 + 1.87890812890812891e-7*V10) + 
   delta4*eps3*(-0.0000462962962962962963*V042 - 0.000115740740740740741*V03*V05 - 
      0.0000330687830687830688*V02*V06 - 0.0000165343915343915344*V01*V07 + 1.87890812890812891e-7*V10) + 
   2.50521083854417188e-8*delta10*V10 + 6.26302709636042969e-8*delta8*eps*V10 + 
   delta8*eps2*(-7.89141414141414141e-7*V052 - 9.01875901875901876e-7*V04*V06 - 
      7.51563251563251563e-7*V03*V07 - 1.67014055902944792e-7*V02*V08 - 6.26302709636042969e-8*V01*V09 + 
      1.20442828776162109e-9*V12) + eps6*(-0.000421626984126984127*V012*V022 - 
      0.00014880952380952381*V013*V03 + 0.000144675925925925926*V02*V032 + 
      0.0000793650793650793651*V022*V04 + 0.000188492063492063492*V01*V03*V04 + 0.000111607142857142857*V01*V02*V05 - 
      3.33506192881192881e-6*V052 + 0.0000248015873015873016*V012*V06 - 5.11063011063011063e-6*V04*V06 - 
      3.56992544492544493e-6*V03*V07 - 1.25260541927208594e-6*V02*V08 - 4.69727032227032227e-7*V01*V09 + 
      1.80664243164243164e-9*V12) + delta6*eps3*
    (-3.15656565656565657e-6*V052 - 3.6075036075036075e-6*V04*V06 - 3.00625300625300625e-6*V03*V07 - 
      6.68056223611779167e-7*V02*V08 - 2.50521083854417188e-7*V01*V09 + 2.40885657552324219e-9*V12) + 
   delta2*eps5*(0.00020667989417989418*V02*V032 + 0.0000727513227513227513*V022*V04 + 
      0.000243055555555555556*V01*V03*V04 + 0.000124007936507936508*V01*V02*V05 - 6.57617845117845118e-6*V052 + 
      0.0000248015873015873016*V012*V06 - 9.16907166907166907e-6*V04*V06 - 6.95196007696007696e-6*V03*V07 - 
      2.0041686708353375e-6*V02*V08 - 7.51563251563251563e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   delta4*eps4*(0.000082671957671957672*V02*V032 + 0.0000198412698412698413*V022*V04 + 
      0.0000925925925925925926*V01*V03*V04 + 0.0000496031746031746032*V01*V02*V05 - 6.1377665544332211e-6*V052 + 
      8.2671957671957672e-6*V012*V06 - 7.56573673240339907e-6*V04*V06 - 6.0751362834696168e-6*V03*V07 - 
      1.50312650312650313e-6*V02*V08 - 5.63672438672438672e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   1.60590438368216146e-10*delta12*V12 + 4.81771315104648438e-10*delta10*eps*V12 + 
   delta10*eps2*(-1.3627245770102913e-8*V062 - 3.17969067969067969e-8*V05*V07 - 
      1.41319585764030208e-8*V04*V08 - 8.83247411025188803e-9*V03*V09 - 1.60590438368216146e-9*V02*V10 - 
      4.81771315104648438e-10*V01*V11 + 8.0295219184108073e-12*V14) + 
   delta8*eps3*(-6.81362288505145648e-8*V062 - 1.58984533984533985e-7*V05*V07 - 
      7.06597928820151042e-8*V04*V08 - 4.41623705512594401e-8*V03*V09 - 8.0295219184108073e-9*V02*V10 - 
      2.40885657552324219e-9*V01*V11 + 2.00738047960270182e-11*V14) + 
   eps7*(-0.0000132275132275132275*V024 - 0.000203373015873015873*V01*V022*V03 - 
      0.0000777116402116402116*V012*V032 - 0.000124007936507936508*V012*V02*V04 + 
      0.0000224842672759339426*V032*V04 + 0.000013452982202982203*V02*V042 - 
      0.0000165343915343915344*V013*V05 + 0.0000264299743466410133*V02*V03*V05 + 0.0000173485850569183903*V01*V04*V05 + 
      5.71188071188071188e-6*V022*V06 + 0.0000124383718133718134*V01*V03*V06 - 1.95667978406073644e-7*V062 + 
      5.44883357383357383e-6*V01*V02*V07 - 3.61569371986038653e-7*V05*V07 + 9.39454064454064454e-7*V012*V08 - 
      2.24023661523661524e-7*V04*V08 - 1.20442828776162109e-7*V03*V09 - 3.61328486328486328e-8*V02*V10 - 
      1.08398545898545899e-8*V01*V11 + 3.01107071940405274e-11*V14) + 
   delta6*eps4*(6.76406926406926407e-6*V032*V04 + 1.90396023729357063e-6*V02*V042 + 
      7.01459034792368126e-6*V02*V03*V05 + 4.05844155844155844e-6*V01*V04*V05 + 6.51354818021484688e-7*V022*V06 + 
      2.70562770562770563e-6*V01*V03*V06 - 1.88303759732331161e-7*V062 + 1.00208433541766875e-6*V01*V02*V07 - 
      4.20586358086358086e-7*V05*V07 + 1.25260541927208594e-7*V012*V08 - 1.99453324453324453e-7*V04*V08 - 
      1.22048733159844271e-7*V03*V09 - 2.40885657552324219e-8*V02*V10 - 7.22656972656972657e-9*V01*V11 + 
      4.01476095920540365e-11*V14) + delta2*eps6*
    (-1.65343915343915344e-6*V024 - 0.000133928571428571429*V01*V022*V03 - 
      0.0000562169312169312169*V012*V032 - 0.0000744047619047619048*V012*V02*V04 + 
      0.0000395197009780343114*V032*V04 + 0.0000179623617123617124*V02*V042 - 
      8.2671957671957672e-6*V013*V05 + 0.0000417743907327240661*V02*V03*V05 + 0.0000256408329324995992*V01*V04*V05 + 
      6.68891293891293891e-6*V022*V06 + 0.0000185636123136123136*V01*V03*V06 - 3.70998324867372486e-7*V062 + 
      6.95196007696007696e-6*V01*V02*V07 - 7.19525459108792442e-7*V05*V07 + 1.12734487734487734e-6*V012*V08 - 
      4.17213958880625547e-7*V04*V08 - 2.37272372689039356e-7*V03*V09 - 6.02214143880810547e-8*V02*V10 - 
      1.80664243164243164e-8*V01*V11 + 6.02214143880810547e-11*V14) + 
   delta4*eps5*(0.0000263047138047138047*V032*V04 + 9.11896745230078563e-6*V02*V042 + 
      0.0000267431257014590348*V02*V03*V05 + 0.0000157828282828282828*V01*V04*V05 + 3.20666987333654e-6*V022*V06 + 
      0.0000109352453102453102*V01*V03*V06 - 3.36345202416630988e-7*V062 + 3.82044652877986211e-6*V01*V02*V07 - 
      7.00254606504606505e-7*V05*V07 + 5.63672438672438672e-7*V012*V08 - 3.67591513424846758e-7*V04*V08 - 
      2.18001520084853418e-7*V03*V09 - 4.81771315104648438e-8*V02*V10 - 1.44531394531394531e-8*V01*V11 + 
      6.02214143880810547e-11*V14) + 7.64716373181981648e-13*delta14*V14 + 
   2.67650730613693577e-12*delta12*eps*V14 + 
   delta12*eps2*(-3.28063324095070127e-10*V072 - 4.37417765460093502e-10*V06*V08 - 
      3.82740544777581815e-10*V05*V09 - 1.3917837991912066e-10*V04*V10 - 6.95891899595603299e-11*V03*V11 - 
      1.07060292245477431e-11*V02*V12 - 2.67650730613693577e-12*V01*V13 + 3.93604015608372907e-14*V16) + 
   delta10*eps3*(-1.96837994457042076e-9*V072 - 2.62450659276056101e-9*V06*V08 - 
      2.29644326866549089e-9*V05*V09 - 8.35070279514723959e-10*V04*V10 - 4.1753513975736198e-10*V03*V11 - 
      6.42361753472864584e-11*V02*V12 - 1.60590438368216146e-11*V01*V13 + 1.18081204682511872e-13*V16) + 
   delta8*eps4*(5.93542260208926876e-8*V043 + 5.93542260208926876e-7*V03*V04*V05 + 
      1.51757964257964258e-7*V02*V052 + 2.04408686551543694e-7*V032*V06 + 1.2498524403286308e-7*V02*V04*V06 + 
      1.22645211930926217e-7*V01*V05*V06 + 1.44531394531394531e-7*V02*V03*V07 + 8.47917514584181251e-8*V01*V04*V07 - 
      6.52972193150764579e-9*V072 + 1.09201498090386979e-8*V022*V08 + 4.23958757292090625e-8*V01*V03*V08 - 
      9.08483051340194197e-9*V06*V08 + 1.20442828776162109e-8*V01*V02*V09 - 7.72841484647040203e-9*V05*V09 + 
      1.20442828776162109e-9*V012*V10 - 2.9709231098119987e-9*V04*V10 - 1.46538775010997233e-9*V03*V11 - 
      2.40885657552324219e-10*V02*V12 - 6.02214143880810547e-11*V01*V13 + 2.9520301170627968e-13*V16) + 
   eps8*(0.0000427138447971781305*V012*V023 + 0.0000454695767195767196*V013*V02*V03 - 
      0.0000265865500240500241*V022*V032 - 0.0000157201980118646785*V01*V033 + 
      4.1335978835978836e-6*V014*V04 - 0.0000100208433541766875*V023*V04 - 
      0.000068329625621292288*V01*V02*V03*V04 - 0.0000103840989257655924*V012*V042 + 
      8.50711788211788212e-7*V043 - 0.0000202922077922077922*V01*V022*V05 - 
      0.0000166283369408369408*V012*V03*V05 + 4.77122221913888581e-6*V03*V04*V05 + 
      1.40881976819476819e-6*V02*V052 - 8.83086820586820587e-6*V012*V02*V06 + 
      1.726031766954386e-6*V032*V06 + 2.18586528110337634e-6*V02*V04*V06 + 1.33467860402384212e-6*V01*V05*V06 - 
      9.39454064454064454e-7*V013*V07 + 1.49830878997545664e-6*V02*V03*V07 + 9.8088639755306422e-7*V01*V04*V07 - 
      1.13969026729443396e-8*V072 + 2.66580127691238802e-7*V022*V08 + 5.46810442643775977e-7*V01*V03*V08 - 
      1.96493872089110184e-8*V06*V08 + 1.92708526041859375e-7*V01*V02*V09 - 1.41821430883930884e-8*V05*V09 + 
      2.70996364746364746e-8*V012*V10 - 7.34701255534588868e-9*V04*V10 - 3.22184566976233643e-9*V03*V11 - 
      8.43099801433134766e-10*V02*V12 - 2.10774950358283692e-10*V01*V13 + 4.4280451755941952e-13*V16) + 
   delta6*eps5*(3.56125356125356125e-7*V043 + 3.07900047483380817e-6*V03*V04*V05 + 
      7.79024216524216524e-7*V02*V052 + 1.07882362346648061e-6*V032*V06 + 7.57069209450161831e-7*V02*V04*V06 + 
      6.47294174079888366e-7*V01*V05*V06 + 7.41927825261158594e-7*V02*V03*V07 + 4.39857210690544024e-7*V01*V04*V07 - 
      1.45735822819156152e-8*V072 + 6.83044664526146008e-8*V022*V08 + 2.31410821688599466e-7*V01*V03*V08 - 
      2.17026506709046392e-8*V06*V08 + 6.18273187717632162e-8*V01*V02*V09 - 1.76649482205037761e-8*V05*V09 + 
      7.22656972656972657e-9*V012*V10 - 7.38716016493794272e-9*V04*V10 - 3.57313725369280925e-9*V03*V11 - 
      6.42361753472864584e-10*V02*V12 - 1.60590438368216146e-10*V01*V13 + 5.9040602341255936e-13*V16) + 
   delta2*eps7*(-0.0000311898749398749399*V022*V032 - 
      0.0000202922077922077922*V01*V033 - 6.91438191438191438e-6*V023*V04 - 
      0.0000756072631072631073*V01*V02*V03*V04 - 0.0000108976671476671477*V012*V042 + 
      1.41486599819933153e-6*V043 - 0.0000187139249639249639*V01*V022*V05 - 
      0.0000174362674362674363*V012*V03*V05 + 8.83134997718331052e-6*V03*V04*V05 + 
      2.36067944401277735e-6*V02*V052 - 7.89141414141414141e-6*V012*V02*V06 + 
      3.2333737690880548e-6*V032*V06 + 3.3093559879274165e-6*V02*V04*V06 + 2.16549323692180835e-6*V01*V05*V06 - 
      7.51563251563251563e-7*V013*V07 + 2.48834884251550918e-6*V02*V03*V07 + 1.55419426252759586e-6*V01*V04*V07 - 
      2.27636946386946387e-8*V072 + 3.52656602656602657e-7*V022*V08 + 8.77305564805564806e-7*V01*V03*V08 - 
      3.81287583668536049e-8*V06*V08 + 2.67383079883079883e-7*V01*V02*V09 - 2.83040647623980957e-8*V05*V09 + 
      3.61328486328486328e-8*V012*V10 - 1.39713681380348047e-8*V04*V10 - 6.3834699251365918e-9*V03*V11 - 
      1.44531394531394531e-9*V02*V12 - 3.61328486328486328e-10*V01*V13 + 8.8560903511883904e-13*V16) + 
   delta4*eps6*(-0.0000102087341670675004*V022*V032 - 7.13985088985088985e-6*V01*V033 - 
      9.01875901875901876e-7*V023*V04 - 0.0000239999198332531666*V01*V02*V03*V04 - 
      3.34445646945646946e-6*V012*V042 + 9.90714532381199048e-7*V043 - 
      6.12524050024050024e-6*V01*V022*V05 - 5.59914622414622415e-6*V012*V03*V05 + 
      7.18272853689520356e-6*V03*V04*V05 + 1.84751269820714265e-6*V02*V052 - 
      2.31732002565335899e-6*V012*V02*V06 + 2.5855634114562686e-6*V032*V06 + 
      2.17219215235088251e-6*V02*V04*V06 + 1.60770529074100503e-6*V01*V05*V06 - 1.87890812890812891e-7*V013*V07 + 
      1.8291250930139819e-6*V02*V03*V07 + 1.10662871079537746e-6*V01*V04*V07 - 2.25830303955303955e-8*V072 + 
      2.09088750755417422e-7*V022*V08 + 6.12813112813112813e-7*V01*V03*V08 - 3.60296119224690653e-8*V06*V08 + 
      1.69824388574388574e-7*V01*V02*V09 - 2.79427362760696094e-8*V05*V09 + 2.16797091797091797e-8*V012*V10 - 
      1.27669398502731836e-8*V04*V10 - 6.02214143880810547e-9*V03*V11 - 1.20442828776162109e-9*V02*V12 - 
      3.01107071940405274e-10*V01*V13 + 8.8560903511883904e-13*V16) + 2.81145725434552076e-15*delta16*V16 + 
   1.12458290173820831e-14*delta14*eps*V16 + 
   delta14*eps2*(-3.57367455441252861e-12*V082 - 8.04076774742818938e-12*V07*V09 - 
      4.38587331677901239e-12*V06*V10 - 3.07011132174530867e-12*V05*V11 - 9.44649637460094976e-13*V04*V12 - 
      3.93604015608372907e-13*V03*V13 - 5.24805354144497209e-14*V02*V14 - 1.12458290173820831e-14*V01*V15 + 
      1.47971434439237935e-16*V18) + delta12*eps3*
    (-2.50157218808877003e-11*V082 - 5.62853742319973257e-11*V07*V09 - 3.07011132174530867e-11*V06*V10 - 
      2.14907792522171607e-11*V05*V11 - 6.61254746222066484e-12*V04*V12 - 2.75522810925861035e-12*V03*V13 - 
      3.67363747901148046e-13*V02*V14 - 7.87208031216745814e-14*V01*V15 + 5.17900020537332772e-16*V18) + 
   delta10*eps4*(1.31523569023569024e-8*V04*V052 + 5.84549195660306771e-9*V042*V06 + 
      1.83715461493239271e-8*V03*V05*V06 + 2.06932250583044234e-9*V02*V062 + 1.25260541927208594e-8*V03*V04*V07 + 
      6.35938135938135938e-9*V02*V05*V07 + 2.62450659276056101e-9*V01*V06*V07 + 3.28063324095070127e-9*V032*V08 + 
      2.11061718998226935e-9*V02*V04*V08 + 1.96837994457042076e-9*V01*V05*V08 - 1.03457878350242703e-10*V082 + 
      1.76649482205037761e-9*V02*V03*V09 + 1.04383784939340495e-9*V01*V04*V09 - 2.25945573702732122e-10*V07*V09 + 
      1.12413306857751302e-10*V022*V10 + 4.1753513975736198e-10*V01*V03*V10 - 1.28213696627173129e-10*V06*V10 + 
      9.63542630209296876e-11*V01*V02*V11 - 8.8009857890032182e-11*V05*V11 + 8.0295219184108073e-12*V012*V12 - 
      2.84182099269245239e-11*V04*V12 - 1.17293996651295126e-11*V03*V13 - 1.65313686555516621e-12*V02*V14 - 
      3.54243614047535616e-13*V01*V15 + 1.55370006161199832e-15*V18) + 
   delta8*eps5*(8.54903198653198653e-8*V04*V052 + 4.25885842552509219e-8*V042*V06 + 
      1.20563271604938272e-7*V03*V05*V06 + 1.51413841890032366e-8*V02*V062 + 8.1419352252685586e-8*V03*V04*V07 + 
      4.10710046126712793e-8*V02*V05*V07 + 1.72233245149911817e-8*V01*V06*V07 + 2.18708882730046751e-8*V032*V08 + 
      1.55696253579851463e-8*V02*V04*V08 + 1.31225329638028051e-8*V01*V05*V08 - 3.06889302360175895e-10*V082 + 
      1.14086123924086887e-8*V02*V03*V09 + 6.78494602105713217e-9*V01*V04*V09 - 6.39241035920541056e-10*V07*V09 + 
      8.56482337963819445e-10*V022*V10 + 2.87055408583186361e-9*V01*V03*V10 - 3.8595685187655309e-10*V06*V10 + 
      6.22287948676837566e-10*V01*V02*V11 - 2.57121823196169601e-10*V05*V11 + 6.02214143880810547e-11*V012*V12 - 
      8.91513095352964634e-11*V04*V12 - 3.63099704398724007e-11*V03*V13 - 5.5104562185172207e-12*V02*V14 - 
      1.18081204682511872e-12*V01*V15 + 3.88425015402999579e-15*V18) + 
   eps9*(1.06888995777884667e-6*V025 + 0.0000263923961840628507*V01*V023*V03 + 
      0.0000299748476831810165*V012*V02*V032 - 1.21518211175949271e-6*V034 + 
      0.0000238245550745550746*V012*V022*V04 + 0.0000102212602212602213*V013*V03*V04 - 
      0.0000101287830702513242*V02*V032*V04 - 3.09484386865339246e-6*V022*V042 - 
      6.45033978367311701e-6*V01*V03*V042 + 6.32565736732403399e-6*V013*V02*V05 - 
      5.97243869813314258e-6*V022*V03*V05 - 5.42102848650467698e-6*V01*V032*V05 - 
      7.74114737408388202e-6*V01*V02*V04*V05 - 9.78856075582266058e-7*V012*V052 + 
      2.90447881593714927e-7*V04*V052 + 4.69727032227032227e-7*V014*V06 - 
      8.74346112441350537e-7*V023*V06 - 5.52347371543800115e-6*V01*V02*V03*V06 - 
      1.67601358077548554e-6*V012*V04*V06 + 2.3201418290704005e-7*V042*V06 + 
      4.20311060192012573e-7*V03*V05*V06 + 1.000249016122032e-7*V02*V062 - 
      1.21213662880329547e-6*V01*V022*V07 - 1.0095517908017908e-6*V012*V03*V07 + 
      3.08183088131004798e-7*V03*V04*V07 + 1.83444465128492906e-7*V02*V05*V07 + 8.64564434132886514e-8*V01*V06*V07 - 
      4.09505617838951172e-7*V012*V02*V08 + 8.67546827988296242e-8*V032*V08 + 
      1.14248626153388058e-7*V02*V04*V08 + 6.72587168122882409e-8*V01*V05*V08 - 5.58025064485634825e-10*V082 - 
      3.61328486328486328e-8*V013*V09 + 6.05727059720115276e-8*V02*V03*V09 + 3.94450264241930909e-8*V01*V04*V09 - 
      1.01977880393934316e-9*V07*V09 + 9.15365498698832032e-9*V022*V10 + 1.79760921948421948e-8*V01*V03*V10 - 
      7.27717595714794594e-10*V06*V10 + 5.32959517334517335e-9*V01*V02*V11 - 4.32620013655552871e-10*V05*V11 + 
      6.32324851074851075e-10*V012*V12 - 1.92177160620788072e-10*V04*V12 - 7.12915273270665428e-11*V03*V13 - 
      1.65313686555516621e-11*V02*V14 - 3.54243614047535616e-12*V01*V15 + 5.82637523104499369e-15*V18) + 
   delta6*eps6*(-3.02827683780064732e-7*V034 - 1.85757254209635162e-6*V02*V032*V04 - 
      1.58222876476844731e-7*V022*V042 - 1.08321462488129155e-6*V01*V03*V042 - 
      9.25161515439293217e-7*V022*V03*V05 - 1.03112826327112041e-6*V01*V032*V05 - 
      1.11454352525781097e-6*V01*V02*V04*V05 - 1.39369559012416155e-7*V012*V052 + 
      2.68161943509165731e-7*V04*V052 - 3.51463645114438765e-8*V023*V06 - 
      7.62712816284244856e-7*V01*V02*V03*V06 - 2.12598798908322718e-7*V012*V04*V06 + 
      1.55031715051556321e-7*V042*V06 + 3.8440189109831967e-7*V03*V05*V06 + 5.61607704464847322e-8*V02*V062 - 
      1.32165930777041888e-7*V01*V022*V07 - 1.24296999296999297e-7*V012*V03*V07 + 
      2.6128064322508767e-7*V03*V04*V07 + 1.32968882968882969e-7*V02*V05*V07 + 5.73479926158497587e-8*V01*V06*V07 - 
      3.77387530165307943e-8*V012*V02*V08 + 7.26576144069530313e-8*V032*V08 + 
      5.89825738635262445e-8*V02*V04*V08 + 4.44778160551970076e-8*V01*V05*V08 - 6.7521831725198257e-10*V082 - 
      2.40885657552324219e-9*V013*V09 + 3.86086178910252984e-8*V02*V03*V09 + 2.32454659537992871e-8*V01*V04*V09 - 
      1.33786004905285951e-9*V07*V09 + 3.45269442491664714e-9*V022*V10 + 1.03580832747499414e-8*V01*V03*V10 - 
      8.61655419311815204e-10*V06*V10 + 2.28841374674708008e-9*V01*V02*V11 - 5.54981662007805799e-10*V05*V11 + 
      2.40885657552324219e-10*V012*V12 - 2.07822920241220895e-10*V04*V12 - 8.32472493011708698e-11*V03*V13 - 
      1.37761405462930517e-11*V02*V14 - 2.9520301170627968e-12*V01*V15 + 7.76850030805999158e-15*V18) + 
   delta2*eps8*(4.1753513975736198e-8*V025 + 0.0000140291806958473625*V01*V023*V03 + 
      0.0000188517115600448934*V012*V02*V032 - 2.104308279903518e-6*V034 + 
      0.0000125886844636844637*V012*V022*V04 + 5.82461519961519962e-6*V013*V03*V04 - 
      0.0000153405163325798246*V02*V032*V04 - 3.46221514376276281e-6*V022*V042 - 
      9.37767864851198185e-6*V01*V03*V042 + 2.94362273528940196e-6*V013*V02*V05 - 
      7.97973888251666029e-6*V022*V03*V05 - 8.09444633849395754e-6*V01*V032*V05 - 
      9.9663114296050804e-6*V01*V02*V04*V05 - 1.24727152256914162e-6*V012*V052 + 
      5.53495019640852974e-7*V04*V052 + 1.87890812890812891e-7*V014*V06 - 
      8.40346822489679633e-7*V023*V06 - 7.21314895422038279e-6*V01*V02*V03*V06 - 
      2.10547829595448643e-6*V012*V04*V06 + 4.143130073189597e-7*V042*V06 + 
      8.11973933253695158e-7*V03*V05*V06 + 1.64565051717829496e-7*V02*V062 - 
      1.3248711165377832e-6*V01*V022*V07 - 1.25380984755984756e-6*V012*V03*V07 + 
      5.84147719564386231e-7*V03*V04*V07 + 3.1668434446212224e-7*V02*V05*V07 + 1.46458479791813125e-7*V01*V06*V07 - 
      4.40820753320753321e-7*V012*V02*V08 + 1.6699971747094763e-7*V032*V08 + 
      1.84426647720298514e-7*V02*V04*V08 + 1.14231420034991464e-7*V01*V05*V08 - 1.09940630202554417e-9*V082 - 
      3.61328486328486328e-8*V013*V09 + 1.03781570795459684e-7*V02*V03*V09 + 6.52800131966798633e-8*V01*V04*V09 - 
      2.03867199884356747e-9*V07*V09 + 1.30479731174175619e-8*V022*V10 + 3.01107071940405274e-8*V01*V03*V10 - 
      1.42836085807024182e-9*V06*V10 + 7.82878387045053712e-9*V01*V02*V11 - 8.64354418275986903e-10*V05*V11 + 
      9.03321215821215821e-10*V012*V12 - 3.70184576679674719e-10*V04*V12 - 1.41697445619014246e-10*V03*V13 - 
      2.89298951472154087e-11*V02*V14 - 6.19926324583187328e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   delta4*eps7*(-1.3248711165377832e-6*V034 - 8.6670659587326254e-6*V02*V032*V04 - 
      1.31581381581381581e-6*V022*V042 - 5.14897910731244065e-6*V01*V03*V042 - 
      4.27957459207459207e-6*V022*V03*V05 - 4.63174942341609008e-6*V01*V032*V05 - 
      5.20023957523957524e-6*V01*V02*V04*V05 - 6.59063159063159063e-7*V012*V052 + 
      5.00520248784137673e-7*V04*V052 - 3.03928875357446786e-7*V023*V06 - 
      3.68334817739579644e-6*V01*V02*V03*V06 - 1.04922909982433792e-6*V012*V04*V06 + 
      3.34278174059920092e-7*V042*V06 + 7.29246916002868384e-7*V03*V05*V06 + 1.25604664295140486e-7*V02*V062 - 
      6.11367798867798868e-7*V01*V022*V07 - 6.07995399662066329e-7*V012*V03*V07 + 
      5.08188442216219994e-7*V03*V04*V07 + 2.63408466533466533e-7*V02*V05*V07 + 1.17724262069500165e-7*V01*V06*V07 - 
      1.95117382617382617e-7*V012*V02*V08 + 1.4478948630734345e-7*V032*V08 + 
      1.36065984280269995e-7*V02*V04*V08 + 9.21731762505572029e-8*V01*V05*V08 - 1.06818506921603716e-9*V082 - 
      1.44531394531394531e-8*V013*V09 + 8.19011235677902345e-8*V02*V03*V09 + 5.02246595996595997e-8*V01*V04*V09 - 
      2.03276793860944188e-9*V07*V09 + 8.67188367188367188e-9*V022*V10 + 2.30045802962469629e-8*V01*V03*V10 - 
      1.37834503351543501e-9*V06*V10 + 5.41992729492729493e-9*V01*V02*V11 - 8.5845035804186131e-10*V05*V11 + 
      6.02214143880810547e-10*V012*V12 - 3.45977929719759785e-10*V04*V12 - 1.35793385384888653e-10*V03*V13 - 
      2.47970529833274931e-11*V02*V14 - 5.31365421071303424e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   8.22063524662432972e-18*delta18*V18 + 3.69928586098094837e-17*delta16*eps*V18 + 
   delta16*eps2*(-4.99609107113593639e-14*V092 - 7.26704155801590747e-14*V08*V10 - 
      6.54033740221431672e-14*V07*V11 - 3.01861726256045387e-14*V06*V12 - 1.76086006982693143e-14*V05*V13 - 
      4.69562685287181713e-15*V04*V14 - 1.67700959031136326e-15*V03*V15 - 1.97295245918983913e-16*V02*V16 - 
      3.69928586098094837e-17*V01*V17 + 4.40391173926303378e-19*V20) + 
   delta14*eps3*(-3.99687285690874911e-13*V092 - 5.81363324641272598e-13*V08*V10 - 
      5.23226992177145338e-13*V07*V11 - 2.4148938100483631e-13*V06*V12 - 1.40868805586154514e-13*V05*V13 - 
      3.75650148229745371e-14*V04*V14 - 1.34160767224909061e-14*V03*V15 - 1.57836196735187131e-15*V02*V16 - 
      2.9594286887847587e-16*V01*V17 + 1.76156469570521351e-18*V20) + 
   delta12*eps4*(4.14465028435616671e-10*V052*V06 + 1.9311337588648513e-10*V04*V062 + 
      5.61121884651296416e-10*V04*V05*V07 + 3.94728598510111115e-10*V03*V06*V07 + 6.75424490783967908e-11*V02*V072 + 
      9.9293173004138872e-11*V042*V08 + 3.00188662570652404e-10*V03*V05*V08 + 7.05638284744001105e-11*V02*V06*V08 + 
      4.28840946529503434e-11*V01*V07*V08 + 1.55867190180915671e-10*V03*V04*V09 + 7.8799523924796256e-11*V02*V05*V09 + 
      3.28940498758425929e-11*V01*V06*V09 - 1.87500359022631024e-12*V092 + 3.28940498758425929e-11*V032*V10 + 
      2.19068749258602978e-11*V02*V04*V10 + 1.97364299255055558e-11*V01*V05*V10 - 2.808497825656736e-12*V08*V10 + 
      1.43271861681447738e-11*V02*V03*V11 + 8.50184673714085479e-12*V01*V04*V11 - 2.47282462663132475e-12*V07*V11 + 
      7.87208031216745814e-13*V022*V12 + 2.83394891238028493e-12*V01*V03*V12 - 1.183475532645025e-12*V06*V12 + 
      5.5104562185172207e-13*V01*V02*V13 - 6.80520626986055263e-13*V05*V13 + 3.93604015608372907e-14*V012*V14 - 
      1.89344247508448862e-13*V04*V14 - 6.71543693296741495e-14*V03*V15 - 8.28640032859732435e-15*V02*V16 - 
      1.55370006161199832e-15*V01*V17 + 6.16547643496824729e-18*V20) + 
   delta10*eps5*(3.26045822369351781e-9*V052*V06 + 1.65543101467471215e-9*V04*V062 + 
      4.38766140359277614e-9*V04*V05*V07 + 3.10519830827954077e-9*V03*V06*V07 + 5.25866210681803586e-10*V02*V072 + 
      8.54383116547241456e-10*V042*V08 + 2.38274750915455345e-9*V03*V05*V08 + 6.08564288665958964e-10*V02*V06*V08 + 
      3.40392501307793351e-10*V01*V07*V08 + 1.21879483433132671e-9*V03*V04*V09 + 6.1351057912877085e-10*V02*V05*V09 + 
      2.58766525689961731e-10*V01*V06*V09 - 6.38324106265132578e-12*V092 + 2.64979846222065332e-10*V032*V10 + 
      1.91044143347286827e-10*V02*V04*V10 + 1.58987907733239199e-10*V01*V05*V10 - 1.00156931590772184e-11*V08*V10 + 
      1.11547378023412882e-10*V02*V03*V11 + 6.6479718236254184e-11*V01*V04*V11 - 8.52071309503185762e-12*V07*V11 + 
      7.08487228095071232e-12*V022*V12 + 2.34981597318198625e-11*V01*V03*V12 - 4.3121835424282719e-12*V06*V12 + 
      4.29028377013126468e-12*V01*V02*V13 - 2.42687949623794137e-12*V05*V13 + 3.54243614047535616e-13*V012*V14 - 
      7.18016588472958155e-13*V04*V14 - 2.5221731000168106e-13*V03*V15 - 3.31456013143892974e-14*V02*V16 - 
      6.21480024644799327e-15*V01*V17 + 1.84964293049047419e-17*V20) + 
   delta8*eps6*(-8.45508658008658009e-8*V032*V042 - 1.14340392118169896e-8*V02*V043 - 
      5.74110817166372722e-8*V033*V05 - 1.70707635985413763e-7*V02*V03*V04*V05 - 
      5.07305194805194805e-8*V01*V042*V05 - 2.09931850556850557e-8*V022*V052 - 
      4.97910654160654161e-8*V01*V03*V052 - 5.99346457481378116e-8*V02*V032*V06 - 
      1.17185137026406868e-8*V022*V04*V06 - 6.97283683394794506e-8*V01*V03*V04*V06 - 
      3.5960787448882687e-8*V01*V02*V05*V06 + 1.29533113516637482e-8*V052*V06 - 
      3.43835599291948498e-9*V012*V062 + 7.392378229602008e-9*V04*V062 - 
      1.99935095768429102e-8*V022*V03*V07 - 2.28153129938844225e-8*V01*V032*V07 - 
      2.43868051407733947e-8*V01*V02*V04*V07 - 6.24582097796383511e-9*V012*V05*V07 + 
      1.75019961580419097e-8*V04*V05*V07 + 1.2518744403859561e-8*V03*V06*V07 + 2.14039052230578841e-9*V02*V072 - 
      6.57656080936504217e-10*V023*V08 - 1.26407616486981566e-8*V01*V02*V03*V08 - 
      3.52151889850302549e-9*V012*V04*V08 + 3.86929241225589394e-9*V042*V08 + 
      9.72664871847229976e-9*V03*V05*V08 + 2.79046504017974087e-9*V02*V06*V08 + 1.42857640312640831e-9*V01*V07*V08 - 
      1.66612579807024251e-9*V01*V022*V09 - 1.58583057888613444e-9*V012*V03*V09 + 
      5.00664307853850338e-9*V03*V04*V09 + 2.53392425148280268e-9*V02*V05*V09 + 1.08879305089038983e-9*V01*V06*V09 - 
      1.6748072821287926e-11*V092 - 3.81402291124513347e-10*V012*V02*V10 + 
      1.12917963434906323e-9*V032*V10 + 9.01690570613695419e-10*V02*V04*V10 + 6.8620642935438298e-10*V01*V05*V10 - 
      2.760150625644289e-11*V08*V10 - 2.00738047960270182e-11*V013*V11 + 4.80787305065627506e-10*V02*V03*V11 + 
      2.88905347456545714e-10*V01*V04*V11 - 2.26228347113945505e-11*V07*V11 + 3.54243614047535616e-11*V022*V12 + 
      1.07453896261085804e-10*V01*V03*V12 - 1.21478628817236775e-11*V06*V12 + 1.97786017843207386e-11*V01*V02*V13 - 
      6.6713291145516521e-12*V05*V13 + 1.77121807023767808e-12*V012*V14 - 2.11096048371016838e-12*V04*V14 - 
      7.32828529060325873e-13*V03*V15 - 1.03580004107466554e-13*V02*V16 - 1.9421250770149979e-14*V01*V17 + 
      4.62410732622618547e-17*V20) + eps10*(-4.32775172358505692e-6*V012*V024 - 
      9.24422799422799423e-6*V013*V022*V03 - 1.23068482443482443e-6*V014*V032 + 
      4.22450354245989167e-6*V023*V032 + 7.39166243258505163e-6*V01*V02*V033 - 
      1.69101731601731602e-6*V014*V02*V04 + 1.21747740795359843e-6*V024*V04 + 
      0.0000161214859875574161*V01*V022*V03*V04 + 6.33712696584720394e-6*V012*V032*V04 + 
      4.84675707889993604e-6*V012*V02*V042 - 1.07324812418438411e-6*V032*V042 - 
      4.62417873132158846e-7*V02*V043 - 9.39454064454064454e-8*V015*V05 + 
      3.19858299769014055e-6*V01*V023*V05 + 7.76295326146516623e-6*V012*V02*V03*V05 - 
      6.14896486982300474e-7*V033*V05 + 1.39724005051386004e-6*V013*V04*V05 - 
      2.56161679617780808e-6*V02*V03*V04*V05 - 8.20972733175114127e-7*V01*V042*V05 - 
      3.79289523169731503e-7*V022*V052 - 6.95468437903953777e-7*V01*V03*V052 + 
      2.05559775872275872e-6*V012*V022*V06 + 9.52221004304337638e-7*V013*V03*V06 - 
      9.2266376058538757e-7*V02*V032*V06 - 5.93101783577974054e-7*V022*V04*V06 - 
      1.16940150577303355e-6*V01*V03*V04*V06 - 7.07132752333645191e-7*V01*V02*V05*V06 + 
      2.89604486589270086e-8*V052*V06 - 7.63370950312914599e-8*V012*V062 + 
      2.35668492554580323e-8*V04*V062 + 4.33594183594183594e-7*V013*V02*V07 - 
      4.0140583760375427e-7*V022*V03*V07 - 3.62902846161774733e-7*V01*V032*V07 - 
      5.19422603685996543e-7*V01*V02*V04*V07 - 1.32534428479368956e-7*V012*V05*V07 + 
      4.25063111758883818e-8*V04*V05*V07 + 3.06977183828184645e-8*V03*V06*V07 + 6.76143520976766775e-9*V02*V072 + 
      2.70996364746364746e-8*V014*V08 - 4.80241882358284475e-8*V023*V08 - 
      2.87815345479035955e-7*V01*V02*V03*V08 - 8.72350202707345564e-8*V012*V04*V08 + 
      1.34766641195601669e-8*V042*V08 + 2.39151691290706619e-8*V03*V05*V08 + 1.16898143469883277e-8*V02*V06*V08 + 
      4.92813313471090471e-9*V01*V07*V08 - 5.07365416219582886e-8*V01*V022*V09 - 
      4.2305543607626941e-8*V012*V03*V09 + 1.39815526419386714e-8*V03*V04*V09 + 8.39144081076270619e-9*V02*V05*V09 + 
      3.92546204816425405e-9*V01*V06*V09 - 2.56298084717075669e-11*V092 - 1.40014788452288452e-8*V012*V02*V10 + 
      3.21391736030508206e-9*V032*V10 + 4.35416007894999492e-9*V02*V04*V10 + 2.49794462727031588e-9*V01*V05*V10 - 
      4.62118489039601052e-11*V08*V10 - 1.05387475179141846e-9*V013*V11 + 1.88841366588507111e-9*V02*V03*V11 + 
      1.22273087448741044e-9*V01*V04*V11 - 3.49496505466431814e-11*V07*V11 + 2.47970529833274931e-10*V022*V12 + 
      4.71144006683222369e-10*V01*V03*V12 - 2.1239079842236017e-11*V06*V12 + 1.20885633293721529e-10*V01*V02*V13 - 
      1.07535465514320433e-11*V05*V13 + 1.23985264916637466e-11*V012*V14 - 4.17634576561305147e-12*V04*V14 - 
      1.34395055329437854e-12*V03*V15 - 2.79666011090159697e-13*V02*V16 - 5.24373770794049432e-14*V01*V17 + 
      6.9361609893392782e-17*V20) + delta6*eps7*
    (-5.30269627491849714e-7*V032*V042 - 1.06760523427190094e-7*V02*V043 - 
      3.44466490299823633e-7*V033*V05 - 1.06134220717554051e-6*V02*V03*V04*V05 - 
      3.18161776495109828e-7*V01*V042*V05 - 1.30511849261849262e-7*V022*V052 - 
      3.03130511463844797e-7*V01*V03*V052 - 3.78534604725080916e-7*V02*V032*V06 - 
      1.11853534472582092e-7*V022*V04*V06 - 4.46345064400619956e-7*V01*V03*V04*V06 - 
      2.27120762835048549e-7*V01*V02*V05*V06 + 3.26639377224889207e-8*V052*V06 - 
      2.2585898081929828e-8*V012*V062 + 2.10193091164924343e-8*V04*V062 - 
      1.24296999296999297e-7*V022*V03*V07 - 1.41067229360880155e-7*V01*V032*V07 - 
      1.51620315310791501e-7*V01*V02*V04*V07 - 4.0124668100858577e-8*V012*V05*V07 + 4.4787492448848658e-8*V04*V05*V07 + 
      3.24298782831501475e-8*V03*V06*V07 + 5.68358575623981786e-9*V02*V072 - 6.5918551368286818e-9*V023*V08 - 
      8.25205438300676396e-8*V01*V02*V03*V08 - 2.34003210193686384e-8*V012*V04*V08 + 
      1.12529063924436888e-8*V042*V08 + 2.54356286410311724e-8*V03*V05*V08 + 8.30444495178907462e-9*V02*V06*V08 + 
      3.92657491666076582e-9*V01*V07*V08 - 1.03580832747499414e-8*V01*V022*V09 - 
      1.05989689323022656e-8*V012*V03*V09 + 1.3470310226165346e-8*V03*V04*V09 + 6.88846387716213424e-9*V02*V05*V09 + 
      3.03283139855268707e-9*V01*V06*V09 - 3.40039836055713167e-11*V092 - 2.64974223307556641e-9*V012*V02*V10 + 
      3.11981788600213748e-9*V032*V10 + 2.79278917817666651e-9*V02*V04*V10 + 1.94147992156084282e-9*V01*V05*V10 - 
      5.8329550274963918e-11*V08*V10 - 1.60590438368216146e-10*V013*V11 + 1.39296461123803172e-9*V02*V03*V11 + 
      8.47035841589218496e-10*V01*V04*V11 - 4.62613453487800303e-11*V07*V11 + 1.18081204682511872e-10*V022*V12 + 
      3.24723312876907648e-10*V01*V03*V12 - 2.6147736236888857e-11*V06*V12 + 6.25830384817312922e-11*V01*V02*V13 - 
      1.39998733551651795e-11*V05*V13 + 5.9040602341255936e-12*V012*V14 - 4.73567778779337087e-12*V04*V14 - 
      1.62102706428185158e-12*V03*V15 - 2.48592009857919731e-13*V02*V16 - 4.66110018483599495e-14*V01*V17 + 
      9.24821465245237093e-17*V20) + delta2*eps9*
    (4.15642466733736575e-6*V023*V032 + 8.35529109338633148e-6*V01*V02*V033 + 
      6.79829796893288957e-7*V024*V04 + 0.0000154207702570797809*V01*V022*V03*V04 + 
      6.74263732299446585e-6*V012*V032*V04 + 4.56072256667494763e-6*V012*V02*V042 - 
      1.91435273280511376e-6*V032*V042 - 6.72419695237155555e-7*V02*V043 + 
      2.49385480040241945e-6*V01*V023*V05 + 7.25582012784393737e-6*V012*V02*V03*V05 - 
      1.13434203215949248e-6*V033*V05 + 1.24703063691158929e-6*V013*V04*V05 - 
      4.15228372817658532e-6*V02*V03*V04*V05 - 1.29452411198442944e-6*V01*V042*V05 - 
      5.49420037267259489e-7*V022*V052 - 1.13306877939814448e-6*V01*V03*V052 + 
      1.63031413031413031e-6*V012*V022*V06 + 8.24792491459158126e-7*V013*V03*V06 - 
      1.51755096571564826e-6*V02*V032*V06 - 7.77042071684928828e-7*V022*V04*V06 - 
      1.86239140232195788e-6*V01*V03*V04*V06 - 1.01627938309485929e-6*V01*V02*V05*V06 + 
      5.68838491377298567e-8*V052*V06 - 1.07641476689095737e-7*V012*V062 + 
      4.41557917412842716e-8*V04*V062 + 3.20377924544591211e-7*V013*V02*V07 - 
      5.77443068762513207e-7*V022*V03*V07 - 5.83046527987004177e-7*V01*V032*V07 - 
      7.28552935894205735e-7*V01*V02*V04*V07 - 1.86531529537481918e-7*V012*V05*V07 + 
      8.20730498018079717e-8*V04*V05*V07 + 6.00686679154524626e-8*V03*V06*V07 + 1.19181468478999992e-8*V02*V072 + 
      1.80664243164243164e-8*V014*V08 - 5.42489795135297781e-8*V023*V08 - 
      4.0979812185169328e-7*V01*V02*V03*V08 - 1.20546065486541677e-7*V012*V04*V08 + 
      2.49040458005988663e-8*V042*V08 + 4.6958392905278604e-8*V03*V05*V08 + 2.00429912245193913e-8*V02*V06*V08 + 
      8.62016691568998603e-9*V01*V07*V08 - 6.16667283333950001e-8*V01*V022*V09 - 
      5.79330006413339747e-8*V012*V03*V09 + 2.68752821857397021e-8*V03*V04*V09 + 1.4780224390110011e-8*V02*V05*V09 + 
      6.83399189285918978e-9*V01*V06*V09 - 5.12537905681840888e-11*V092 - 1.68619960286626953e-8*V012*V02*V10 + 
      6.27264228017029137e-9*V032*V10 + 7.31125081907061366e-9*V02*V04*V10 + 4.36078106078397862e-9*V01*V05*V10 - 
      9.16586854918693502e-11*V08*V10 - 1.20442828776162109e-9*V013*V11 + 3.30686413713374498e-9*V02*V03*V11 + 
      2.08501887168145338e-9*V01*V04*V11 - 6.98876483428242728e-11*V07*V11 + 3.71955794749912397e-10*V022*V12 + 
      8.121034852039754e-10*V01*V03*V12 - 4.19521212350405431e-11*V06*V12 + 1.85092288339837359e-10*V01*V02*V13 - 
      2.14954403524019967e-11*V05*V13 + 1.85977897374956198e-11*V012*V14 - 8.11342172173785521e-12*V04*V14 - 
      2.6762483561266671e-12*V03*V15 - 4.97184019715839461e-13*V02*V16 - 9.3222003696719899e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + delta4*eps8*
    (1.12355953129762654e-6*V023*V032 + 2.5791971476495286e-6*V01*V02*V033 + 
      3.77616945077262538e-8*V024*V04 + 4.13625909657655689e-6*V01*V022*V03*V04 + 
      1.98785727059536583e-6*V012*V032*V04 + 1.22404326273373892e-6*V012*V02*V042 - 
      1.42409880133094419e-6*V032*V042 - 3.91505723846993688e-7*V02*V043 + 
      6.74135718778575921e-7*V01*V023*V05 + 2.06180916746392937e-6*V012*V02*V03*V05 - 
      8.81354738001563398e-7*V033*V05 + 3.3207808505427553e-7*V013*V04*V05 - 
      2.91372423688891943e-6*V02*V03*V04*V05 - 8.88464306123036282e-7*V01*V042*V05 - 
      3.66935769134843209e-7*V022*V052 - 8.12937475883904455e-7*V01*V03*V052 + 
      4.23557281196170085e-7*V012*V022*V06 + 2.13183806933806934e-7*V013*V03*V06 - 
      1.05803289707059548e-6*V02*V032*V06 - 4.22574620656631239e-7*V022*V04*V06 - 
      1.26838342984176318e-6*V01*V03*V04*V06 - 6.5878786116881355e-7*V01*V02*V05*V06 + 
      5.45632582627067921e-8*V052*V06 - 6.76716636538065109e-8*V012*V062 + 
      3.90218908615850726e-8*V04*V062 + 7.34701255534588868e-8*V013*V02*V07 - 
      3.63268954125435607e-7*V022*V03*V07 - 3.97088535729408745e-7*V01*V032*V07 - 
      4.49314840435872182e-7*V01*V02*V04*V07 - 1.17990956904647381e-7*V012*V05*V07 + 
      7.65859343014163276e-8*V04*V05*V07 + 5.59869380444485487e-8*V03*V06*V07 + 1.02824269600355035e-8*V02*V072 + 
      3.61328486328486328e-9*V014*V08 - 2.64209506934374659e-8*V023*V08 - 
      2.52155665102093674e-7*V01*V02*V03*V08 - 7.26442318704223466e-8*V012*V04*V08 + 
      2.14728983840795232e-8*V042*V08 + 4.39814532769423059e-8*V03*V05*V08 + 1.64109258267755e-8*V02*V06*V08 + 
      7.31276900598796024e-9*V01*V07*V08 - 3.37239920573253907e-8*V01*V022*V09 - 
      3.40250991292657959e-8*V012*V03*V09 + 2.42509274116708757e-8*V03*V04*V09 + 1.27037664057680398e-8*V02*V05*V09 + 
      5.74203595255766124e-9*V01*V06*V09 - 5.12110638164897588e-11*V092 - 9.03321215821215821e-9*V012*V02*V10 + 
      5.67822993017028965e-9*V032*V10 + 5.76472441260022959e-9*V02*V04*V10 + 3.68295277404754529e-9*V01*V05*V10 - 
      9.01908088622321099e-11*V08*V10 - 6.02214143880810547e-10*V013*V11 + 2.72767582816602424e-9*V02*V03*V11 + 
      1.68501879081944441e-9*V01*V04*V11 - 6.98021948394356129e-11*V07*V11 + 2.65682710535651712e-10*V022*V12 + 
      6.5535068598794089e-10*V01*V03*V12 - 4.09621923386420413e-11*V06*V12 + 1.35793385384888653e-10*V01*V02*V13 - 
      2.14099868490133368e-11*V05*V13 + 1.32841355267825856e-11*V012*V14 - 7.69703010522583966e-12*V04*V14 - 
      2.59079485273800719e-12*V03*V15 - 4.35036017251359529e-13*V02*V16 - 8.15692532346299116e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + 1.95729410633912612e-20*delta20*V20 + 
   9.78647053169563062e-20*delta18*eps*V20 + 
   delta18*eps2*(-3.73576270568999572e-16*V102 - 8.21867795251799059e-16*V09*V11 - 
      5.0576479707803019e-16*V08*V12 - 3.79323597808522643e-16*V07*V13 - 1.51729439123409057e-16*V06*V14 - 
      7.58647195617045285e-17*V05*V15 - 1.78505222498128302e-17*V04*V16 - 5.57828820306650945e-18*V03*V17 - 
      5.87188231901737837e-19*V02*V18 - 9.78647053169563062e-20*V01*V19 + 1.06374679692343811e-21*V22) + 
   delta16*eps3*(-3.36218643512099615e-15*V102 - 7.39681015726619153e-15*V09*V11 - 
      4.55188317370227171e-15*V08*V12 - 3.41391238027670378e-15*V07*V13 - 1.36556495211068151e-15*V06*V14 - 
      6.82782476055340757e-16*V05*V15 - 1.60654700248315472e-16*V04*V16 - 5.02045938275985851e-17*V03*V17 - 
      5.28469408711564053e-18*V02*V18 - 8.80782347852606755e-19*V01*V19 + 4.7868605861554715e-21*V22) + 
   delta14*eps4*(2.13459363566774952e-12*V063 + 1.7930586539609096e-11*V05*V06*V07 + 
      6.04327175964602865e-12*V04*V072 + 6.86735427232503256e-12*V052*V08 + 
      6.60875939349902034e-12*V04*V06*V08 + 6.54033740221431672e-12*V03*V07*V08 + 6.07011706610740506e-13*V02*V082 + 
      7.05048371958703343e-12*V04*V05*V09 + 4.98071848322474889e-12*V03*V06*V09 + 1.69279320998488198e-12*V02*V07*V09 + 
      5.4502811685119306e-13*V01*V08*V09 + 1.03773353448467159e-12*V042*V10 + 3.05215745436668114e-12*V03*V05*V10 + 
      7.38870695966594755e-13*V02*V06*V10 + 4.36022493480954448e-13*V01*V07*V10 - 1.85215182566314525e-14*V102 + 
      1.28190613083400608e-12*V03*V04*V11 + 6.463392256305913e-13*V02*V05*V11 + 2.71675553630440848e-13*V01*V06*V11 - 
      3.9838959969837207e-14*V09*V11 + 2.2639629469203404e-13*V032*V12 + 1.54600554702115794e-13*V02*V04*V12 + 
      1.35837776815220424e-13*V01*V05*V12 - 2.52150370543244262e-14*V08*V12 + 8.28640032859732435e-14*V02*V03*V13 + 
      4.93040819551540799e-14*V01*V04*V13 - 1.8596838492559939e-14*V07*V13 + 4.00509349215537344e-15*V022*V14 + 
      1.40868805586154514e-14*V01*V03*V14 - 7.6902868355706801e-15*V06*V14 + 2.36754295102780696e-15*V01*V02*V15 - 
      3.80321817802755597e-15*V05*V15 + 1.47971434439237935e-16*V012*V16 - 9.29401533454070648e-16*V04*V16 - 
      2.88896610095655016e-16*V03*V17 - 3.17081645226938432e-17*V02*V18 - 5.28469408711564053e-18*V01*V19 + 
      1.9147442344621886e-20*V22) + delta12*eps5*
    (2.10613238719217953e-11*V063 + 1.64612745870577951e-10*V05*V06*V07 + 5.52527703739065477e-11*V04*V072 + 
      6.34085711144678006e-11*V052*V08 + 6.53389768538752109e-11*V04*V06*V08 + 6.03891153471121911e-11*V03*V07*V08 + 
      6.02167012238729901e-12*V02*V082 + 6.44615654362243056e-11*V04*V05*V09 + 4.57257627418272085e-11*V03*V06*V09 + 
      1.54291047785080388e-11*V02*V07*V09 + 5.03242627892601592e-12*V01*V08*V09 + 1.03162921957593822e-11*V042*V10 + 
      2.84232162937897181e-11*V03*V05*V10 + 7.35516676785972028e-12*V02*V06*V10 + 4.0604594705413883e-12*V01*V07*V10 - 
      7.67994164653953858e-14*V102 + 1.17202846247680556e-11*V03*V04*V11 + 5.89111273361216028e-12*V02*V05*V11 + 
      2.49413251319057501e-12*V01*V06*V11 - 1.5942072417897397e-13*V09*V11 + 2.13818722764698816e-12*V032*V12 + 
      1.55808001607139976e-12*V02*V04*V12 + 1.2829123365881929e-12*V01*V05*V12 - 1.05441977990826965e-13*V08*V12 + 
      7.55270863283610293e-13*V02*V03*V13 + 4.50780177875694445e-13*V01*V04*V13 - 7.57798708621947274e-14*V07*V13 + 
      4.16161438725110068e-14*V022*V14 + 1.36760132089891674e-13*V01*V03*V14 - 3.29532384496182881e-14*V06*V14 + 
      2.15791675223888655e-14*V01*V02*V15 - 1.60364042073524112e-14*V05*V15 + 1.55370006161199832e-15*V012*V16 - 
      4.13580159257670028e-15*V04*V16 - 1.27625362203842719e-15*V03*V17 - 1.47971434439237935e-16*V02*V18 - 
      2.46619057398729892e-17*V01*V19 + 6.7016048206176601e-20*V22) + 
   delta10*eps6*(-2.95801289810004407e-10*V044 - 7.84358338143741194e-9*V03*V042*V05 - 
      4.09348176232707823e-9*V032*V052 - 3.92005983305002913e-9*V02*V04*V052 - 
      8.01299054975525564e-10*V01*V053 - 5.49887301462931715e-9*V032*V04*V06 - 
      1.23515189263710895e-9*V02*V042*V06 - 5.57736890117064409e-9*V02*V03*V05*V06 - 
      3.29932380877759029e-9*V01*V04*V05*V06 - 2.13153443195460002e-10*V022*V062 - 
      1.13590745155871206e-9*V01*V03*V062 + 1.11077632135397347e-10*V063 - 
      1.27190326186591359e-9*V033*V07 - 3.73339031719050393e-9*V02*V03*V04*V07 - 
      1.12051191163391599e-9*V01*V042*V07 - 9.11823062558356676e-10*V022*V05*V07 - 
      2.2213661141454481e-9*V01*V03*V05*V07 - 7.96766985881520584e-10*V01*V02*V06*V07 + 7.90818238274194341e-10*V05*V06*V07 - 
      7.07587561773680666e-11*V012*V072 + 2.66182291692605467e-10*V04*V072 - 
      1.0063142665720734e-9*V02*V032*V08 - 2.14750350915928258e-10*V022*V04*V08 - 
      1.16958121224642648e-9*V01*V03*V04*V08 - 6.03788559943244039e-10*V01*V02*V05*V08 + 
      3.07308867141893107e-10*V052*V08 - 1.15543395934255982e-10*V012*V06*V08 + 
      3.48020435329644263e-10*V04*V06*V08 + 2.95653173692384828e-10*V03*V07*V08 + 3.2678175994266238e-11*V02*V082 - 
      2.53284184043987966e-10*V022*V03*V09 - 2.92166637871586518e-10*V01*V032*V09 - 
      3.11115859765875328e-10*V01*V02*V04*V09 - 8.04807753628948774e-11*V012*V05*V09 + 
      3.13793240103475455e-10*V04*V05*V09 + 2.24240350892254344e-10*V03*V06*V09 + 7.61580611867156797e-11*V02*V07*V09 + 
      2.53822800065346792e-11*V01*V08*V09 - 7.30978886129835398e-12*V023*V10 - 
      1.29608179425328507e-10*V01*V02*V03*V10 - 3.60822424022704135e-11*V012*V04*V10 + 
      5.60804732543481649e-11*V042*V10 + 1.42000663750085985e-10*V03*V05*V10 + 4.03355333137918687e-11*V02*V06*V10 + 
      2.06774049390104097e-11*V01*V07*V10 - 2.53132042505487258e-13*V102 - 
      1.3815500947853889e-11*V01*V022*V11 - 1.32250949244413297e-11*V012*V03*V11 + 
      5.88245344526877608e-11*V03*V04*V11 + 2.96754985434489887e-11*V02*V05*V11 + 1.27296865619387611e-11*V01*V06*V11 - 
      5.05754031960445325e-13*V09*V11 - 2.63714690457609848e-12*V012*V02*V12 + 
      1.11352203701387527e-11*V032*V12 + 8.81730210584071817e-12*V02*V04*V12 + 6.74017282442450755e-12*V01*V05*V12 - 
      3.50568990092294541e-13*V08*V12 - 1.18081204682511872e-13*V013*V13 + 3.95761932360611793e-12*V02*V03*V13 + 
      2.37602171422117529e-12*V01*V04*V13 - 2.44874227567633878e-13*V07*V13 + 2.48384849849704798e-13*V022*V14 + 
      7.57584150042010379e-13*V01*V03*V14 - 1.12391703028323173e-13*V06*V14 + 1.1963490474412387e-13*V01*V02*V15 - 
      5.36951342721384656e-14*V05*V15 + 9.3222003696719899e-15*V012*V16 - 1.46935634398163269e-14*V04*V16 - 
      4.49463232109185227e-15*V03*V17 - 5.54892879147142256e-16*V02*V18 - 9.24821465245237093e-17*V01*V19 + 
      2.01048144618529803e-19*V22) + delta8*eps7*
    (-3.12288574815807931e-9*V044 - 6.13302756208529629e-8*V03*V042*V05 - 
      3.11053445414828857e-8*V032*V052 - 3.05407589414942356e-8*V02*V04*V052 - 
      6.13408242084712673e-9*V01*V053 - 4.34778369389713928e-8*V032*V04*V06 - 
      1.31957658023639972e-8*V02*V042*V06 - 4.3769553743682284e-8*V02*V03*V05*V06 - 
      2.60867021633828357e-8*V01*V04*V05*V06 - 2.31124277965236571e-9*V022*V062 - 
      9.11367606483152702e-9*V01*V03*V062 + 3.89361294085025683e-10*V063 - 
      9.73663876324940751e-9*V033*V07 - 2.90864370871373672e-8*V02*V03*V04*V07 - 
      8.76146794583613756e-9*V01*V042*V07 - 7.13092395077689195e-9*V022*V05*V07 - 
      1.71856509877829517e-8*V01*V03*V05*V07 - 6.252793391954612e-9*V01*V02*V06*V07 + 2.5282819527162001e-9*V05*V06*V07 - 
      5.70894510067401446e-10*V012*V072 + 8.58885837973415987e-10*V04*V072 - 
      8.03345795856689103e-9*V02*V032*V08 - 2.36162409365023744e-9*V022*V04*V08 - 
      9.43862429428878231e-9*V01*V03*V04*V08 - 4.82007477514013462e-9*V01*V02*V05*V08 + 
      9.90550771013638422e-10*V052*V08 - 9.52465488627175524e-10*V012*V06*V08 + 
      1.24013655702525207e-9*V04*V06*V08 + 9.70630955157051171e-10*V03*V07*V08 + 1.20233202577373189e-10*V02*V082 - 
      1.98081220854913665e-9*V022*V03*V09 - 2.30511380283789247e-9*V01*V032*V09 - 
      2.42386975726144727e-9*V01*V02*V04*V09 - 6.55688060858462352e-10*V012*V05*V09 + 
      1.03082561137740446e-9*V04*V05*V09 + 7.43326732405203706e-10*V03*V06*V09 + 2.56405271524897592e-10*V02*V07*V09 + 
      8.76982300491031469e-11*V01*V08*V09 - 8.45686342107132646e-11*V023*V10 - 1.06762277776516805e-9*V01*V02*V03*V10 - 
      3.02034852834339296e-10*V012*V04*V10 + 2.06123073726194409e-10*V042*V10 + 
      4.7748951503009169e-10*V03*V05*V10 + 1.50591515305042041e-10*V02*V06*V10 + 7.19068418752763738e-11*V01*V07*V10 - 
      6.67076525370678137e-13*V102 - 1.08044302284498363e-10*V01*V022*V11 - 
      1.12177144448386278e-10*V012*V03*V11 + 2.03127638655029436e-10*V03*V04*V11 + 
      1.03144968090215195e-10*V02*V05*V11 + 4.50206788567242398e-11*V01*V06*V11 - 1.29003346187058122e-12*V09*V11 - 
      2.30258349130898151e-11*V012*V02*V12 + 3.95028240664850572e-11*V032*V12 + 
      3.43243417611322668e-11*V02*V04*V12 + 2.42921004633035937e-11*V01*V05*V12 - 9.30432048801058198e-13*V08*V12 - 
      1.18081204682511872e-12*V013*V13 + 1.45685275777151709e-11*V02*V03*V13 + 8.81931944973023978e-12*V01*V04*V13 - 
      6.32855328667315743e-13*V07*V13 + 1.03165684091036688e-12*V022*V14 + 2.90075801502960086e-12*V01*V03*V14 - 
      3.05117097813708622e-13*V06*V14 + 4.73878518791659487e-13*V01*V02*V15 - 1.4295890209760875e-13*V05*V15 + 
      3.88425015402999579e-14*V012*V16 - 4.15429802188160502e-14*V04*V16 - 1.25775719273352245e-14*V03*V17 - 
      1.66467863744142677e-15*V02*V18 - 2.77446439573571128e-16*V01*V19 + 5.02620361546324507e-19*V22) + 
   eps11*(-9.01835117002665504e-8*V026 - 3.25916459348999032e-6*V01*V024*V03 - 
      7.35068548808628174e-6*V012*V022*V032 - 1.0854789500622834e-6*V013*V033 + 
      6.78100295225791258e-7*V02*V034 - 3.88445328921519398e-6*V012*V023*V04 - 
      4.99063464093225998e-6*V013*V02*V03*V04 + 2.84278006510562727e-6*V022*V032*V04 + 
      1.64707575731881287e-6*V01*V033*V04 - 2.84933320647606362e-7*V014*V042 + 
      5.87400058299529199e-7*V023*V042 + 3.58815504059799695e-6*V01*V02*V03*V042 + 
      3.5912954439740154e-7*V012*V043 - 2.81868399275952575e-8*V044 - 
      1.54110614180058625e-6*V013*V022*V05 - 4.60814262897596231e-7*V014*V03*V05 + 
      1.12000694579646299e-6*V023*V03*V05 + 3.00648528885136028e-6*V01*V02*V032*V05 + 
      2.15679602202006303e-6*V01*V022*V04*V05 + 1.75801937489685506e-6*V012*V03*V04*V05 - 
      3.02837308803974984e-7*V03*V042*V05 + 5.39000298734921751e-7*V012*V02*V052 - 
      1.30260107162109282e-7*V032*V052 - 1.81474604951678073e-7*V02*V04*V052 - 
      3.30907815972154207e-8*V01*V053 - 2.28841374674708008e-7*V014*V02*V06 + 
      1.2426335177657929e-7*V024*V06 + 1.53341242595954898e-6*V01*V022*V03*V06 + 
      6.11779025097477478e-7*V012*V032*V06 + 9.21724593289573448e-7*V012*V02*V04*V06 - 
      2.1732776138249265e-7*V032*V04*V06 - 1.45683102372722665e-7*V02*V042*V06 + 
      1.38048989425477521e-7*V013*V05*V06 - 2.61595716210939036e-7*V02*V03*V05*V06 - 
      1.66642922459441776e-7*V01*V04*V05*V06 - 3.13513920345541883e-8*V022*V062 - 
      5.92808427693683879e-8*V01*V03*V062 + 8.84509142307875836e-10*V063 - 
      1.08398545898545899e-8*V015*V07 + 2.24590985483015906e-7*V01*V023*V07 + 
      5.54011203192750812e-7*V012*V02*V03*V07 - 4.56228874516762589e-8*V033*V07 + 
      1.01933346911025482e-7*V013*V04*V07 - 1.91754429908024679e-7*V02*V03*V04*V07 - 
      6.13420781184067054e-8*V01*V042*V07 - 5.72043116871378037e-8*V022*V05*V07 - 
      1.03916952302356811e-7*V01*V03*V05*V07 - 5.3133259730785894e-8*V01*V02*V06*V07 + 4.73703555517935601e-9*V05*V06*V07 - 
      5.00584884186415077e-9*V012*V072 + 1.741265174578467e-9*V04*V072 + 
      1.12062015273820829e-7*V012*V022*V08 + 5.3898165877332544e-8*V013*V03*V08 - 
      5.36809105180029939e-8*V02*V032*V08 - 3.57374452845974788e-8*V022*V04*V08 - 
      6.77966188714758976e-8*V01*V03*V04*V08 - 4.12668507250089883e-8*V01*V02*V05*V08 + 
      1.84415328275492498e-9*V052*V08 - 8.89450891456902195e-9*V012*V06*V08 + 
      3.03796541544199087e-9*V04*V06*V08 + 1.95419862124377447e-9*V03*V07*V08 + 3.79246470634262349e-10*V02*V082 + 
      1.95719596761263428e-8*V013*V02*V09 - 1.87589213813852975e-8*V022*V03*V09 - 
      1.67786011778556713e-8*V01*V032*V09 - 2.41704845909809145e-8*V01*V02*V04*V09 - 
      6.17402338833098637e-9*V012*V05*V09 + 2.15772698503969466e-9*V04*V05*V09 + 1.55508035764887683e-9*V03*V06*V09 + 
      6.91653165373944804e-10*V02*V07*V09 + 2.50103168132130448e-10*V01*V08*V09 + 1.05387475179141846e-9*V014*V10 - 
      1.89829593813409562e-9*V023*V10 - 1.09471819705392301e-8*V01*V02*V03*V10 - 
      3.31517199332033599e-9*V012*V04*V10 + 5.66213951638936691e-10*V042*V10 + 
      9.90709445715168765e-10*V03*V05*V10 + 4.93857621869645393e-10*V02*V06*V10 + 2.04600194881280817e-10*V01*V07*V10 - 
      1.0592820988240287e-12*V102 - 1.62155014330259428e-9*V01*V022*V11 - 
      1.34701134241575418e-9*V012*V03*V11 + 4.83293552740012793e-10*V03*V04*V11 + 2.92311187466604348e-10*V02*V05*V11 + 
      1.35732624614622041e-10*V01*V06*V11 - 1.95010166215273807e-12*V09*V11 - 3.7815505799574427e-10*V012*V02*V12 + 
      9.37949305944393234e-11*V032*V12 + 1.29817854947928907e-10*V02*V04*V12 + 7.30666296474582508e-11*V01*V05*V12 - 
      1.49261560383255041e-12*V08*V12 - 2.47970529833274931e-11*V013*V13 + 4.77180131422584983e-11*V02*V03*V13 + 
      3.07298566685929087e-11*V01*V04*V13 - 9.64334462347839848e-13*V07*V13 + 5.53945861966731133e-12*V022*V14 + 
      1.02559741067008009e-11*V01*V03*V14 - 5.09835577360394305e-13*V06*V14 + 2.32278159210993748e-12*V01*V02*V15 - 
      2.25009062494166185e-13*V05*V15 + 2.09749508317619773e-13*V012*V16 - 7.75740245047704874e-14*V04*V16 - 
      2.20569919460989047e-14*V03*V17 - 4.16169659360356692e-15*V02*V18 - 6.9361609893392782e-16*V01*V19 + 
      7.53930542319486761e-19*V22) + delta6*eps8*
    (1.16714836456899949e-7*V02*V034 + 3.3167660895835499e-7*V022*V032*V04 + 
      2.55740273101384212e-7*V01*V033*V04 + 1.0639753805538638e-8*V023*V042 + 
      4.0211845767401323e-7*V01*V02*V03*V042 + 3.92643621810288477e-8*V012*V043 - 
      1.44647796358943781e-8*V044 + 1.06435773874045479e-7*V023*V03*V05 + 
      3.97805457329266853e-7*V01*V02*V032*V05 + 1.99005965375012994e-7*V01*V022*V04*V05 + 
      2.09450079241745908e-7*V012*V03*V04*V05 - 2.23205463736282545e-7*V03*V042*V05 + 
      5.46638381459810031e-8*V012*V02*V052 - 1.08785983451243074e-7*V032*V052 - 
      1.12518714013131224e-7*V02*V04*V052 - 2.20587498467400428e-8*V01*V053 + 
      1.74482785814355479e-9*V024*V06 + 1.40126628221866317e-7*V01*V022*V03*V06 + 
      6.90710946167295374e-8*V012*V032*V06 + 8.25320145756653693e-8*V012*V02*V04*V06 - 
      1.60306931018687944e-7*V032*V04*V06 - 6.23141806988030663e-8*V02*V042*V06 + 
      1.17976618472650219e-8*V013*V05*V06 - 1.63158892000544402e-7*V02*V03*V05*V06 - 
      9.83588207974490265e-8*V01*V04*V05*V06 - 1.11381689475890119e-8*V022*V062 - 
      3.48030855806882884e-8*V01*V03*V062 + 9.53886585144753617e-10*V063 + 
      1.52051105534350684e-8*V01*V023*V07 + 4.88653762463286273e-8*V012*V02*V03*V07 - 
      3.50760218509401516e-8*V033*V07 + 8.00084505441648299e-9*V013*V04*V07 - 
      1.0966831245289851e-7*V02*V03*V04*V07 - 3.33776917471737993e-8*V01*V042*V07 - 
      2.72838431539411932e-8*V022*V05*V07 - 6.36466502471469273e-8*V01*V03*V05*V07 - 
      2.43659066418494264e-8*V01*V02*V06*V07 + 5.73454430680343706e-9*V05*V06*V07 - 
      2.24285876770250149e-9*V012*V072 + 1.97943651812315506e-9*V04*V072 + 
      7.29348240922314996e-9*V012*V022*V08 + 3.81402291124513347e-9*V013*V03*V08 - 
      3.10448607244177324e-8*V02*V032*V08 - 1.1607382420290917e-8*V022*V04*V08 - 
      3.68885683428167088e-8*V01*V03*V04*V08 - 1.90217012623058375e-8*V01*V02*V05*V08 + 
      2.25567676854889474e-9*V052*V08 - 3.85231495904931946e-9*V012*V06*V08 + 
      3.10327793500338834e-9*V04*V06*V08 + 2.26552478541084656e-9*V03*V07*V08 + 3.14616699492002765e-10*V02*V082 + 
      1.00369023980135091e-9*V013*V02*V09 - 7.92456084758190786e-9*V022*V03*V09 - 
      9.03546132401563463e-9*V01*V032*V09 - 9.76593414783968783e-9*V01*V02*V04*V09 - 
      2.6475492964171769e-9*V012*V05*V09 + 2.41967965015243137e-9*V04*V05*V09 + 1.75967541052281089e-9*V03*V06*V09 + 
      6.25456165059616089e-10*V02*V07*V09 + 2.19248139960954814e-10*V01*V08*V09 + 4.01476095920540365e-11*V014*V10 - 
      4.41323816738797546e-10*V023*V10 - 4.45295468686769652e-9*V01*V02*V03*V10 - 
      1.27550192715147586e-9*V012*V04*V10 + 5.34938290003461784e-10*V042*V10 + 
      1.1361175216718043e-9*V03*V05*V10 + 4.00148693505997441e-10*V02*V06*V10 + 1.80018298529104411e-10*V01*V07*V10 - 
      1.37352914624220985e-12*V102 - 4.69963194636397251e-10*V01*V022*V11 - 
      4.90627405455836828e-10*V012*V03*V11 + 5.02893349542243018e-10*V03*V04*V11 + 
      2.59112630875115109e-10*V02*V05*V11 + 1.15332635287803027e-10*V01*V06*V11 - 2.59545595292284319e-12*V09*V11 - 
      1.05092272167435566e-10*V012*V02*V12 + 9.92078181483731716e-11*V032*V12 + 
      9.54439427562594958e-11*V02*V04*V12 + 6.26440027127202582e-11*V01*V05*V12 - 1.92513302396022541e-12*V08*V12 - 
      5.9040602341255936e-12*V013*V13 + 3.87855325380408513e-11*V02*V03*V13 + 2.3732250541102737e-11*V01*V04*V13 - 
      1.28109968651631223e-12*V07*V13 + 3.08841045580429443e-12*V022*V14 + 7.94458631504268473e-12*V01*V03*V14 - 
      6.42639939769610351e-13*V06*V14 + 1.37243505442393185e-12*V01*V02*V15 - 2.95332486711414013e-13*V05*V15 + 
      1.16527504620899874e-13*V012*V16 - 9.08914536043019015e-14*V04*V16 - 2.71897510782099705e-14*V03*V17 - 
      3.88425015402999579e-15*V02*V18 - 6.47375025671665965e-16*V01*V19 + 1.00524072309264901e-18*V22) + 
   delta2*eps10*(-1.05683802773749864e-9*V026 - 1.43624287969526065e-6*V01*V024*V03 - 
      4.03239837763647287e-6*V012*V022*V032 - 6.39695952195952196e-7*V013*V033 + 
      1.03731386283469617e-6*V02*V034 - 1.80719302743112267e-6*V012*V023*V04 - 
      2.58256954685526114e-6*V013*V02*V03*V04 + 3.76126895224117446e-6*V022*V032*V04 + 
      2.41349362443112443e-6*V01*V033*V04 - 1.39266322302036588e-7*V014*V042 + 
      5.67501373552960855e-7*V023*V042 + 4.64213503648027458e-6*V01*V02*V03*V042 + 
      4.56605646337789195e-7*V012*V043 - 4.8511255774108832e-8*V044 - 
      6.58099616432949766e-7*V013*V022*V05 - 2.11015836015836016e-7*V014*V03*V05 + 
      1.29053917496377814e-6*V023*V03*V05 + 3.9946842867229772e-6*V01*V02*V032*V05 + 
      2.44500548319992764e-6*V01*V022*V04*V05 + 2.24826843130414559e-6*V012*V03*V04*V05 - 
      5.60125414233724224e-7*V03*V042*V05 + 6.19076139909473243e-7*V012*V02*V052 - 
      2.49438911785360782e-7*V032*V052 - 3.07119530720429413e-7*V02*V04*V052 - 
      5.691691187504096e-8*V01*V053 - 8.67188367188367188e-8*V014*V02*V06 + 
      1.01721424886107426e-7*V024*V06 + 1.76647646885742124e-6*V01*V022*V03*V06 + 
      7.76630845455250217e-7*V012*V032*V06 + 1.04599434956577814e-6*V012*V02*V04*V06 - 
      4.0652457348302353e-7*V032*V04*V06 - 2.31405524903132279e-7*V02*V042*V06 + 
      1.52463415112224636e-7*V013*V05*V06 - 4.49494829929295382e-7*V02*V03*V05*V06 - 
      2.8006164438601997e-7*V01*V04*V05*V06 - 4.55565553349458578e-8*V022*V062 - 
      1.00457618621134027e-7*V01*V03*V062 + 1.71256554412201539e-9*V063 - 
      3.61328486328486328e-9*V015*V07 + 2.13711461231302501e-7*V01*V023*V07 + 
      6.20745133393942918e-7*V012*V02*V03*V07 - 8.67051308647217844e-8*V033*V07 + 
      1.10772990237275952e-7*V013*V04*V07 - 3.23151314667712894e-7*V02*V03*V04*V07 - 
      1.01333081107021933e-7*V01*V042*V07 - 8.70315157488360103e-8*V022*V05*V07 - 
      1.77061130153304523e-7*V01*V03*V05*V07 - 8.07420722001137501e-8*V01*V02*V06*V07 + 9.36414228087805413e-9*V05*V06*V07 - 
      7.52927932914510879e-9*V012*V072 + 3.39053821003755583e-9*V04*V072 + 
      1.08217881655381655e-7*V012*V022*V08 + 5.69694580111246778e-8*V013*V03*V08 - 
      9.20055009399080361e-8*V02*V032*V08 - 5.09313924784279593e-8*V022*V04*V08 - 
      1.13208170487071631e-7*V01*V03*V04*V08 - 6.28664755448281359e-8*V01*V02*V05*V08 + 
      3.65860240983193125e-9*V052*V08 - 1.33508092355693896e-8*V012*V06*V08 + 
      5.81472070492569043e-9*V04*V06*V08 + 3.86604911270109038e-9*V03*V07*V08 + 6.69355072471856466e-10*V02*V082 + 
      1.80664243164243164e-8*V013*V02*V09 - 2.83619245526925265e-8*V022*V03*V09 - 
      2.81638855036964281e-8*V01*V032*V09 - 3.58774136840050706e-8*V01*V02*V04*V09 - 
      9.23462495591347132e-9*V012*V05*V09 + 4.20004124525269606e-9*V04*V05*V09 + 3.06443310291299597e-9*V03*V06*V09 + 
      1.23744774342815094e-9*V02*V07*V09 + 4.45845885430025007e-10*V01*V08*V09 + 9.03321215821215821e-10*V014*V10 - 
      2.36809044533523214e-9*V023*V10 - 1.64647371186236732e-8*V01*V02*V03*V10 - 
      4.8689519595069315e-9*V012*V04*V10 + 1.06738757717012689e-9*V042*V10 + 
      1.95993066468536445e-9*V03*V05*V10 + 8.68331150576541423e-10*V02*V06*V10 + 3.64912169506311622e-10*V01*V07*V10 - 
      2.10980781986575818e-12*V102 - 2.1210336391096195e-9*V01*V022*V11 - 
      1.96605205796382267e-9*V012*V03*V11 + 9.3749562552640253e-10*V03*V04*V11 + 5.22594784223503694e-10*V02*V05*V11 + 
      2.40847369943663066e-10*V01*V06*V11 - 3.90006460108568935e-12*V09*V11 - 4.91513014490955667e-10*V012*V02*V12 + 
      1.84496333387633329e-10*V032*V12 + 2.23917921136611244e-10*V02*V04*V12 + 1.29959796546414746e-10*V01*V05*V12 - 
      2.97043406422117702e-12*V08*V12 - 3.09963162291593664e-11*V013*V13 + 8.4929129617865858e-11*V02*V03*V13 + 
      5.3556817973796388e-11*V01*V04*V13 - 1.92853020147589291e-12*V07*V13 + 8.62458904200820265e-12*V022*V14 + 
      1.80431188155001364e-11*V01*V03*V14 - 1.01084835794234905e-12*V06*V14 + 3.67061639555834602e-12*V01*V02*V15 - 
      4.49879401768545584e-13*V05*V15 + 3.26277012938519646e-13*V012*V16 - 1.51596734582999264e-13*V04*V16 - 
      4.39752606724110238e-14*V03*V17 - 7.49105386848642045e-15*V02*V18 - 1.24850897808107008e-15*V01*V19 + 
      1.50786108463897352e-18*V22) + delta4*eps9*
    (5.77265272205748396e-7*V02*V034 + 1.82975598402185704e-6*V022*V032*V04 + 
      1.29435893324782214e-6*V01*V033*V04 + 1.71045640622360199e-7*V023*V042 + 
      2.22836898184120406e-6*V01*V02*V03*V042 + 2.17760634427301094e-7*V012*V043 - 
      3.60906857706966639e-8*V044 + 5.88336453498490536e-7*V023*V03*V05 + 
      2.02834900255535176e-6*V01*V02*V032*V05 + 1.09785359041311422e-6*V01*V022*V04*V05 + 
      1.10349719724719725e-6*V012*V03*V04*V05 - 4.68083420578654783e-7*V03*V042*V05 + 
      2.91282378335949765e-7*V012*V02*V052 - 2.17885800504264557e-7*V032*V052 - 
      2.43074095879106772e-7*V02*V04*V052 - 4.63433304017454344e-8*V01*V053 + 
      2.92978136893480809e-8*V024*V06 + 7.90223105451280054e-7*V01*V022*V03*V06 + 
      3.71694599125154681e-7*V012*V032*V06 + 4.64519313725662932e-7*V012*V02*V04*V06 - 
      3.39387086707542668e-7*V032*V04*V06 - 1.61809756133596781e-7*V02*V042*V06 + 
      6.75684269434269434e-8*V013*V05*V06 - 3.55806643708089008e-7*V02*V03*V05*V06 - 
      2.17671871098866897e-7*V01*V04*V05*V06 - 3.00604608299908642e-8*V022*V062 - 
      7.77819282174149121e-8*V01*V03*V062 + 1.60833310225194172e-9*V063 + 
      8.40480647854986479e-8*V01*V023*V07 + 2.70296649264903233e-7*V012*V02*V03*V07 - 
      7.32294648124869102e-8*V033*V07 + 4.66974053283577093e-8*V013*V04*V07 - 
      2.46677484412856339e-7*V02*V03*V04*V07 - 7.61219370190736515e-8*V01*V042*V07 - 
      6.29359832025273202e-8*V022*V05*V07 - 1.38998120525801042e-7*V01*V03*V05*V07 - 
      5.7467395205441813e-8*V01*V02*V06*V07 + 9.13001277706507386e-9*V05*V06*V07 - 
      5.30907153538845104e-9*V012*V072 + 3.22444623072974743e-9*V04*V072 + 
      4.26367613867613868e-8*V012*V022*V08 + 2.3125023125023125e-8*V013*V03*V08 - 
      7.06136849830438377e-8*V02*V032*V08 - 3.23479074354424494e-8*V022*V04*V08 - 
      8.51545756400059232e-8*V01*V03*V04*V08 - 4.4997879418105842e-8*V01*V02*V05*V08 + 
      3.58588104686483122e-9*V052*V08 - 9.33831149945373413e-9*V012*V06*V08 + 
      5.35219682347953734e-9*V04*V06*V08 + 3.70330815615235731e-9*V03*V07*V08 + 5.74573573165675699e-10*V02*V082 + 
      6.62435558268891602e-9*V013*V02*V09 - 1.95347640966513516e-8*V022*V03*V09 - 
      2.10785071604399335e-8*V01*V032*V09 - 2.43510434044981197e-8*V01*V02*V04*V09 - 
      6.44571558874780163e-9*V012*V05*V09 + 3.98584660105880436e-9*V04*V05*V09 + 2.91333022299243766e-9*V03*V06*V09 + 
      1.09040704931153581e-9*V02*V07*V09 + 3.89198166147944597e-10*V01*V08*V09 + 3.01107071940405274e-10*V014*V10 - 
      1.34500115047889713e-9*V023*V10 - 1.12181361634267797e-8*V01*V02*V03*V10 - 
      3.25870387436680621e-9*V012*V04*V10 + 9.5573417761393829e-10*V042*V10 + 
      1.87501133817503019e-9*V03*V05*V10 + 7.39981468201118634e-10*V02*V06*V10 + 3.1894243886195272e-10*V01*V07*V10 - 
      2.09271123396052009e-12*V102 - 1.28944675513302964e-9*V01*V022*V11 - 
      1.29121797320326732e-9*V012*V03*V11 + 8.658560693855349e-10*V03*V04*V11 + 4.59043272703367589e-10*V02*V05*V11 + 
      2.08292359616979377e-10*V01*V06*V11 - 3.89895481532739506e-12*V09*V11 - 2.9520301170627968e-10*V012*V02*V12 + 
      1.71398086975365036e-10*V032*V12 + 1.84287767650791223e-10*V02*V04*V12 + 1.129495553361591e-10*V01*V05*V12 - 
      2.94167211665205015e-12*V08*V12 - 1.77121807023767808e-11*V013*V13 + 7.22146841136743384e-11*V02*V03*V13 + 
      4.47838505759042395e-11*V01*V04*V13 - 1.92742041571759863e-12*V07*V13 + 6.47582185679880898e-12*V022*V14 + 
      1.51042951489610416e-11*V01*V03*V14 - 9.94035103704190637e-13*V06*V14 + 2.80831286136368696e-12*V01*V02*V15 - 
      4.48769616010251299e-13*V05*V15 + 2.44707759703889735e-13*V012*V16 - 1.45326445048636557e-13*V04*V16 - 
      4.28654749141167393e-14*V03*V17 - 6.65871454976570707e-15*V02*V18 - 1.10978575829428451e-15*V01*V19 + 
      1.50786108463897352e-18*V22) + 3.86817017063068404e-23*delta22*V22 + 
   2.12749359384687622e-22*delta20*eps*V22 + 
   delta20*eps2*(-3.41091377476043088e-18*V112 - 5.24755965347758597e-18*V10*V12 - 
      4.81026301568778714e-18*V09*V13 - 2.56547360836681981e-18*V08*V14 - 1.64923303395009845e-18*V07*V15 - 
      5.82082247276505334e-19*V06*V16 - 2.54660983183471084e-19*V05*V17 - 5.36128385649412808e-20*V04*V18 - 
      1.48924551569281335e-20*V03*V19 - 1.41832906256458415e-21*V02*V20 - 2.12749359384687622e-22*V01*V21 + 
      2.12749359384687622e-24*V24) + delta18*eps3*
    (-3.41091377476043088e-17*V112 - 5.24755965347758597e-17*V10*V12 - 4.81026301568778714e-17*V09*V13 - 
      2.56547360836681981e-17*V08*V14 - 1.64923303395009845e-17*V07*V15 - 5.82082247276505334e-18*V06*V16 - 
      2.54660983183471084e-18*V05*V17 - 5.36128385649412808e-19*V04*V18 - 1.48924551569281335e-19*V03*V19 - 
      1.41832906256458415e-20*V02*V20 - 2.12749359384687622e-21*V01*V21 + 1.06374679692343811e-23*V24) + 
   delta16*eps4*(1.95275788151827456e-13*V06*V072 + 1.10155572803594975e-13*V062*V08 + 
      3.00424289464349933e-13*V05*V07*V08 + 5.69431659769029285e-14*V04*V082 + 2.27821752843798699e-13*V05*V06*V09 + 
      1.53157480903394083e-13*V04*V07*V09 + 8.34511915178749814e-14*V03*V08*V09 + 1.07059094381484351e-14*V02*V092 + 
      7.06059151375409192e-14*V052*V10 + 6.95537485590207015e-14*V04*V06*V10 + 6.7243728702419923e-14*V03*V07*V10 + 
      1.28135148350630137e-14*V02*V08*V10 + 5.60364405853499358e-15*V01*V09*V10 + 5.84783108903868319e-14*V04*V05*V11 + 
      4.14221368806906726e-14*V03*V06*V11 + 1.40150087190306787e-14*V02*V07*V11 + 4.55188317370227171e-15*V01*V08*V11 - 
      2.06888162885766611e-16*V112 + 7.37226568917269889e-15*V042*V12 + 2.1242121477277268e-14*V03*V05*V12 + 
      5.25463004964227156e-15*V02*V06*V12 + 3.03458878246818114e-15*V01*V07*V12 - 3.25473640412121701e-16*V10*V12 + 
      7.4972193449213887e-15*V03*V04*V13 + 3.77327157820056734e-15*V02*V05*V13 + 1.5931591107957951e-15*V01*V06*V13 - 
      2.93082453741548745e-16*V09*V13 + 1.13797079342556793e-15*V032*V14 + 7.91999487189063994e-16*V02*V04*V14 + 
      6.82782476055340757e-16*V01*V05*V14 - 1.60525348637809582e-16*V08*V14 + 3.59359197923863556e-16*V02*V03*V15 + 
      2.14206266997753963e-16*V01*V04*V15 - 1.01840139846418579e-16*V07*V15 + 1.55017693222058789e-17*V022*V16 + 
      5.35515667494384907e-17*V01*V03*V16 - 3.70592364099375063e-17*V06*V16 + 7.9270411306734608e-18*V01*V02*V17 - 
      1.60739587242709963e-17*V05*V17 + 4.40391173926303378e-19*V012*V18 - 3.50142895675318888e-18*V04*V18 - 
      9.68541458598790399e-19*V03*V19 - 9.57372117231094299e-20*V02*V20 - 1.43605817584664145e-20*V01*V21 + 
      4.7868605861554715e-23*V24) + delta14*eps5*
    (2.05039577559418829e-12*V06*V072 + 1.23173958680383473e-12*V062*V08 + 
      3.16697271810335554e-12*V05*V07*V08 + 6.37501651281648877e-13*V04*V082 + 2.39212840485988634e-12*V05*V06*V09 + 
      1.60336737820740681e-12*V04*V07*V09 + 8.79714643917598762e-13*V03*V08*V09 + 1.11817276353994767e-13*V02*V092 + 
      7.48422700457933743e-13*V052*V10 + 7.8015382937856978e-13*V04*V06*V10 + 7.12783524245651184e-13*V03*V07*V10 + 
      1.44021970804301276e-13*V02*V08*V10 + 5.9398627020470932e-14*V01*V09*V10 + 6.12194817133737146e-13*V04*V05*V11 + 
      4.34932437247252062e-13*V03*V06*V11 + 1.46378979954320422e-13*V02*V07*V11 + 4.79844351227781143e-14*V01*V08*V11 - 
      9.47746755987005437e-16*V112 + 8.32191347286274146e-14*V042*V12 + 2.27025173288400802e-13*V03*V05*V12 + 
      5.93661394970222595e-14*V02*V06*V12 + 3.24321676126286859e-14*V01*V07*V12 - 1.54428184088054673e-15*V10*V12 + 
      7.8486515017145788e-14*V03*V04*V13 + 3.94097253723170367e-14*V02*V05*V13 + 1.67281706633558485e-14*V01*V06*V13 - 
      1.35237108783908073e-15*V09*V13 + 1.23280169287769859e-14*V032*V14 + 9.06336779704970386e-15*V02*V04*V14 + 
      7.39681015726619153e-15*V01*V05*V14 - 7.71841059888646073e-16*V08*V14 + 3.75330717831590825e-15*V02*V03*V15 + 
      2.2424718576327368e-15*V01*V04*V15 - 4.79926812879478648e-16*V07*V15 + 1.82732977767820815e-16*V022*V16 + 
      5.95761180087503209e-16*V01*V03*V16 - 1.82773825644822675e-16*V06*V16 + 8.2793540698145035e-17*V01*V02*V17 - 
      7.82900622586899674e-17*V05*V17 + 5.28469408711564053e-18*V012*V18 - 1.78913701268146903e-17*V04*V18 - 
      4.9208926825678247e-18*V03*V19 - 5.10598462523250293e-19*V02*V20 - 7.65897693784875439e-20*V01*V21 + 
      1.9147442344621886e-22*V24) + delta12*eps6*
    (-1.81710194045720362e-10*V042*V052 - 1.29792995746943115e-10*V03*V053 - 
      4.18662090202051216e-11*V043*V06 - 5.14805050014601672e-10*V03*V04*V05*V06 - 
      1.29420107732156236e-10*V02*V052*V06 - 9.01865811069624174e-11*V032*V062 - 
      4.40269978275238859e-11*V02*V04*V062 - 5.41119486641774504e-11*V01*V05*V062 - 
      1.7305732766259082e-10*V03*V042*V07 - 1.82550878953343448e-10*V032*V05*V07 - 
      1.71981279391348682e-10*V02*V04*V05*V07 - 5.3904957766173305e-11*V01*V052*V07 - 
      1.23257245459196415e-10*V02*V03*V06*V07 - 7.35435785735145245e-11*V01*V04*V06*V07 - 
      9.95785605773606822e-12*V022*V072 - 2.49971695512631185e-11*V01*V03*V072 + 
      1.15250268045761243e-11*V06*V072 - 9.3124342549990002e-11*V032*V04*V08 - 
      2.23761745508195875e-11*V02*V042*V08 - 9.46468041976648278e-11*V02*V03*V05*V08 - 
      5.58746055299940012e-11*V01*V04*V05*V08 - 7.76241046146929228e-12*V022*V06*V08 - 
      3.85115190357462705e-11*V01*V03*V06*V08 + 7.53554676494466446e-12*V062*V08 - 
      1.35209720282378325e-11*V01*V02*V07*V08 + 1.79154934532962937e-11*V05*V07*V08 - 
      9.82119292914208671e-13*V012*V082 + 3.92859226055028743e-12*V04*V082 - 
      1.63718061254146838e-11*V033*V09 - 4.77725776087079673e-11*V02*V03*V04*V09 - 
      1.44214439718825684e-11*V01*V042*V09 - 1.16174987340254129e-11*V022*V05*V09 - 
      2.86854167432348997e-11*V01*V03*V05*V09 - 1.02714371215997013e-11*V01*V02*V06*V09 + 1.35496295737393273e-11*V05*V06*V09 - 
      1.84187443018241419e-12*V012*V07*V09 + 9.10052682992914154e-12*V04*V07*V09 + 
      5.05222430881163618e-12*V03*V08*V09 + 6.46063149296892166e-13*V02*V092 - 
      1.04307530326792808e-11*V02*V032*V10 - 2.36513594902759535e-12*V022*V04*V10 - 
      1.21170650938357241e-11*V01*V03*V04*V10 - 6.25845181960756846e-12*V01*V02*V05*V10 + 
      4.29758799138050964e-12*V052*V10 - 1.19770545225693172e-12*V012*V06*V10 + 
      4.84506694116438835e-12*V04*V06*V10 + 4.12322028399698023e-12*V03*V07*V10 + 9.06863113883747762e-13*V02*V08*V10 + 
      3.51171525289348256e-13*V01*V09*V10 - 2.11227249709552962e-12*V022*V03*V11 - 
      2.44960790856780832e-12*V01*V032*V11 - 2.60577696047498003e-12*V01*V02*V04*V11 - 
      6.77191269711172409e-13*V012*V05*V11 + 3.52815936324254369e-12*V04*V05*V11 + 
      2.52016808708015893e-12*V03*V06*V11 + 8.52167490935571267e-13*V02*V07*V11 + 2.83833873160198232e-13*V01*V08*V11 - 
      3.51413879689133865e-15*V112 - 5.41772745293529826e-14*V023*V12 - 
      9.0682813881742576e-13*V01*V02*V03*V12 - 2.52291295718900679e-13*V012*V04*V12 + 
      5.289041628784641e-13*V042*V12 + 1.34433281283334658e-12*V03*V05*V12 + 3.79763754107156185e-13*V02*V06*V12 + 
      1.94742738674907059e-13*V01*V07*V12 - 5.94631364944065399e-15*V10*V12 - 8.12412498882896009e-14*V01*V022*V13 - 
      7.79957430929223155e-14*V012*V03*V13 + 4.66023701813509939e-13*V03*V04*V13 + 
      2.34608709303411746e-13*V02*V05*V13 + 1.0055768755904512e-13*V01*V06*V13 - 5.05191543929168149e-15*V09*V13 - 
      1.32927671937915412e-14*V012*V02*V14 + 7.5919621661387341e-14*V032*V14 + 
      5.98495128495237701e-14*V02*V04*V14 + 4.58452496751368932e-14*V01*V05*V14 - 3.0134525591120312e-15*V08*V14 - 
      5.17900020537332772e-16*V013*V15 + 2.31657501249873611e-14*V02*V03*V15 + 1.3901916265566404e-14*V01*V04*V15 - 
      1.83240640289184556e-15*V07*V15 + 1.26762195502947164e-15*V022*V16 + 3.87685158230803389e-15*V01*V03*V16 - 
      7.33048341698442132e-16*V06*V16 + 5.36396449842237514e-16*V01*V02*V17 - 3.09533723454688484e-16*V05*V17 + 
      3.69928586098094837e-17*V012*V18 - 7.45754584438333215e-17*V04*V18 - 2.03728786546776867e-17*V03*V19 - 
      2.23386827353922003e-18*V02*V20 - 3.35080241030883005e-19*V01*V21 + 6.7016048206176601e-22*V24) + 
   delta10*eps7*(-1.70557610707464509e-9*V042*V052 - 1.19217270167562565e-9*V03*V053 - 
      5.01323905320006685e-10*V043*V06 - 4.86215725920891613e-9*V03*V04*V05*V06 - 
      1.21733642787349358e-9*V02*V052*V06 - 8.59173938356269183e-10*V032*V062 - 
      5.31289659696870534e-10*V02*V04*V062 - 5.1550436301376151e-10*V01*V05*V062 - 
      1.6243581972139477e-9*V03*V042*V07 - 1.68494184567353601e-9*V032*V05*V07 - 
      1.61287383824424957e-9*V02*V04*V05*V07 - 5.00033949543139184e-10*V01*V052*V07 - 
      1.15936802654618436e-9*V02*V03*V06*V07 - 6.94593894172702304e-10*V01*V04*V06*V07 - 
      9.39246312560111764e-11*V022*V072 - 2.33856304153575109e-10*V01*V03*V072 + 
      4.44102205900675288e-11*V06*V072 - 8.89988989578240483e-10*V032*V04*V08 - 
      2.7239765423050433e-10*V02*V042*V08 - 8.9868083163720132e-10*V02*V03*V05*V08 - 
      5.3399339374694429e-10*V01*V04*V05*V08 - 9.55675284983031473e-11*V022*V06*V08 - 
      3.723987620360497e-10*V01*V03*V06*V08 + 3.1674494679726012e-11*V062*V08 - 
      1.28382975948171617e-10*V01*V02*V07*V08 + 6.94986314416835163e-11*V05*V07*V08 - 
      9.71432467093597043e-12*V012*V082 + 1.67162671835187365e-11*V04*V082 - 
      1.52649797958091841e-10*V033*V09 - 4.48020510623402657e-10*V02*V03*V04*V09 - 
      1.35363183101162308e-10*V01*V042*V09 - 1.09578736465346372e-10*V022*V05*V09 - 
      2.69805352535325616e-10*V01*V03*V05*V09 - 9.66140022121820299e-11*V01*V02*V06*V09 + 5.29256680159109844e-11*V05*V06*V09 - 
      1.79602794741199031e-11*V012*V07*V09 + 3.57673098659722354e-11*V04*V07*V09 + 2.0127259476718193e-11*V03*V08*V09 + 
      2.61853949669536431e-12*V02*V092 - 1.00756215900251097e-10*V02*V032*V10 - 
      2.97018917149718008e-11*V022*V04*V10 - 1.18149015058534227e-10*V01*V03*V04*V10 - 
      6.04537295401506583e-11*V01*V02*V05*V10 + 1.69961237638805225e-11*V052*V10 - 
      1.19030688053496982e-11*V012*V06*V10 + 2.08588297254544514e-11*V04*V06*V10 + 
      1.65213712420960515e-11*V03*V07*V10 + 3.99657392471796277e-12*V02*V08*V10 + 1.46042761310808322e-12*V01*V09*V10 - 
      1.99234066300629768e-11*V022*V03*V11 - 2.35260967386419907e-11*V01*V032*V11 - 
      2.44374823976401449e-11*V01*V02*V04*V11 - 6.69245203681785332e-12*V012*V05*V11 + 
      1.42250735474288297e-11*V04*V05*V11 + 1.02303454542559249e-11*V03*V06*V11 + 3.49571416005116678e-12*V02*V07*V11 + 
      1.18753241613923411e-12*V01*V08*V11 - 1.07722042660262976e-14*V112 - 7.15353102653051873e-13*V023*V12 - 
      9.02525129503932721e-12*V01*V02*V03*V12 - 2.54954781538806962e-12*V012*V04*V12 + 
      2.35514294482179882e-12*V042*V12 + 5.54943436053908996e-12*V03*V05*V12 + 1.71018478591264041e-12*V02*V06*V12 + 
      8.23411708842879362e-13*V01*V07*V12 - 1.88276916619772124e-14*V10*V12 - 7.6628487038703757e-13*V01*V022*V13 - 
      8.02123551808220998e-13*V012*V03*V13 + 1.96948746143338698e-12*V03*V04*V13 + 
      9.95921739493290921e-13*V02*V05*V13 + 4.32416922861785017e-13*V01*V06*V13 - 1.55700618665683636e-14*V09*V13 - 
      1.39833005545079848e-13*V012*V02*V14 + 3.29532384496182881e-13*V032*V14 + 
      2.80820188278785753e-13*V02*V04*V14 + 2.01241150837363591e-13*V01*V05*V14 - 9.65495738769839211e-15*V08*V14 - 
      6.21480024644799327e-15*V013*V15 + 1.03543011248856745e-13*V02*V03*V15 + 6.25179310505780275e-14*V01*V04*V15 - 
      5.74558068332762718e-15*V07*V15 + 6.30358310711153603e-15*V022*V16 + 1.7985927856089371e-14*V01*V03*V16 - 
      2.40764535427438304e-15*V06*V16 + 2.55250724407685438e-15*V01*V02*V17 - 1.00124656661956089e-15*V05*V17 + 
      1.84964293049047419e-16*V012*V18 - 2.54660983183471084e-16*V04*V18 - 6.9026529652361899e-17*V03*V19 - 
      8.04192578474119211e-18*V02*V20 - 1.20628886771117882e-18*V01*V21 + 2.01048144618529803e-21*V24) + 
   delta8*eps8*(1.12851894189429203e-8*V034*V04 + 
      3.22772161542391857e-8*V02*V032*V042 + 1.32727772394750297e-9*V022*V043 + 
      1.28988759163051102e-8*V01*V03*V043 + 2.32560932622207132e-8*V02*V033*V05 + 
      3.15213839859809359e-8*V022*V03*V04*V05 + 3.88793049954736852e-8*V01*V032*V04*V05 + 
      1.93663296925435114e-8*V01*V02*V042*V05 + 2.50509275733948937e-9*V023*V052 + 
      2.01676793537496152e-8*V01*V02*V03*V052 + 5.42296366876198809e-9*V012*V04*V052 - 
      7.79716800769014296e-9*V042*V052 - 5.26980793180764275e-9*V03*V053 + 
      1.12944672278822606e-8*V022*V032*V06 + 8.727044463213931e-9*V01*V033*V06 + 
      8.90219825015965694e-10*V023*V04*V06 + 2.72517925412416542e-8*V01*V02*V03*V04*V06 + 
      3.97332007927635067e-9*V012*V042*V06 - 2.82619430165753763e-9*V043*V06 + 
      6.77668033672935634e-9*V01*V022*V05*V06 + 7.21389005435262827e-9*V012*V03*V05*V06 - 
      2.24289006366088539e-8*V03*V04*V05*V06 - 5.65439409962507944e-9*V02*V052*V06 + 
      1.39900924433487459e-9*V012*V02*V062 - 4.00160730277563195e-9*V032*V062 - 
      3.03640156876773161e-9*V02*V04*V062 - 2.43622427282075352e-9*V01*V05*V062 + 
      2.38580262603760892e-9*V023*V03*V07 + 9.24041655785742309e-9*V01*V02*V032*V07 + 
      4.5030548551401337e-9*V01*V022*V04*V07 + 4.91510203033701322e-9*V012*V03*V04*V07 - 
      7.54012879201343963e-9*V03*V042*V07 + 2.57138691939695675e-9*V012*V02*V05*V07 - 
      7.59338696663967903e-9*V032*V05*V07 - 7.5484574628484751e-9*V02*V04*V05*V07 - 
      2.29457182461032637e-9*V01*V052*V07 + 2.82523339489181381e-10*V013*V06*V07 - 
      5.4663977239129376e-9*V02*V03*V06*V07 - 3.30056967893175719e-9*V01*V04*V06*V07 - 
      4.51109044388735651e-10*V022*V072 - 1.09454741335667439e-9*V01*V03*V072 + 
      1.26631398443508704e-10*V06*V072 + 3.65989257687912458e-11*V024*V08 + 
      2.43314756620078749e-9*V01*V022*V03*V08 + 1.21284391647629535e-9*V012*V032*V08 + 
      1.42878257665839365e-9*V012*V02*V04*V08 - 4.21187584438707663e-9*V032*V04*V08 - 
      1.57900113818356684e-9*V02*V042*V08 + 2.09303621061842869e-10*V013*V05*V08 - 
      4.27845468704313461e-9*V02*V03*V05*V08 - 2.56344641051699639e-9*V01*V04*V05*V08 - 
      5.6232564871173011e-10*V022*V06*V08 - 1.80530156382735475e-9*V01*V03*V06*V08 + 
      9.74318743872451483e-11*V062*V08 - 6.28867334096473348e-10*V01*V02*V07*V08 + 
      1.99076135566589245e-10*V05*V07*V08 - 4.90493244688611919e-11*V012*V082 + 
      5.22622857692870916e-11*V04*V082 + 1.98816885503134077e-10*V01*V023*V09 + 
      6.53734098066692215e-10*V012*V02*V03*V09 - 7.14665652030552913e-10*V033*V09 + 
      1.07959958566867997e-10*V013*V04*V09 - 2.16039515045621509e-9*V02*V03*V04*V09 - 
      6.56907690744922031e-10*V01*V042*V09 - 5.34141365181383528e-10*V022*V05*V09 - 
      1.28674492004969786e-9*V01*V03*V05*V09 - 4.75848265203103142e-10*V01*V02*V06*V09 + 1.53293911446729409e-10*V05*V06*V09 - 
      8.93781990681032949e-11*V012*V07*V09 + 1.04748497532374607e-10*V04*V07*V09 + 
      5.96375848728657949e-11*V03*V08*V09 + 8.00285623282956963e-12*V02*V092 + 
      7.68511840475348101e-11*V012*V022*V10 + 4.10332186271728755e-11*V013*V03*V10 - 
      4.99307533109571225e-10*V02*V032*V10 - 1.79761814709409732e-10*V022*V04*V10 - 
      5.90560875518700023e-10*V01*V03*V04*V10 - 3.03615680992265154e-10*V01*V02*V05*V10 + 
      4.95593811626264585e-11*V052*V10 - 6.1010472062228291e-11*V012*V06*V10 + 
      6.60909927939994441e-11*V04*V06*V10 + 4.90642617367695468e-11*V03*V07*V10 + 1.30867700317987669e-11*V02*V08*V10 + 
      4.56632279958408988e-12*V01*V09*V10 + 8.75768934728629718e-12*V013*V02*V11 - 
      1.01397055520901697e-10*V022*V03*V11 - 1.18628329061350954e-10*V01*V032*V11 - 
      1.24778071200457163e-10*V01*V02*V04*V11 - 3.4528579333517025e-11*V012*V05*V11 + 
      4.27939492219946726e-11*V04*V05*V11 + 3.09900829324836135e-11*V03*V06*V11 + 1.08063045332860666e-11*V02*V07*V11 + 
      3.74521866042146181e-12*V01*V08*V11 - 2.71163685054242072e-14*V112 + 2.9520301170627968e-13*V014*V12 - 
      4.5881009438459709e-12*V023*V12 - 4.77907041094267739e-11*V01*V02*V03*V12 - 
      1.3647553369765354e-11*V012*V04*V12 + 7.75800666716767563e-12*V042*V12 + 
      1.69422051777957712e-11*V03*V05*V12 + 5.72886205574953589e-12*V02*V06*V12 + 2.60664012717587559e-12*V01*V07*V12 - 
      4.85079215546758719e-14*V10*V12 - 4.17427416553090214e-12*V01*V022*V13 - 
      4.44746642636434518e-12*V012*V03*V13 + 6.23590467228488958e-12*V03*V04*V13 + 
      3.18383353458829799e-12*V02*V05*V13 + 1.40300965206493938e-12*V01*V06*V13 - 3.92968703471378353e-14*V09*V13 - 
      8.00155531730179133e-13*V012*V02*V14 + 1.06004577715517818e-12*V032*V14 + 
      9.83467477094655061e-13*V02*V04*V14 + 6.59268229714719714e-13*V01*V05*V14 - 2.50933103808588833e-14*V08*V14 - 
      3.88425015402999579e-14*V013*V15 + 3.49335894805300891e-13*V02*V03*V15 + 2.12560965571965293e-13*V01*V04*V15 - 
      1.46526903520153798e-14*V07*V15 + 2.35521199815787046e-14*V022*V16 + 6.23329667575289801e-14*V01*V03*V16 - 
      6.38931003597687713e-15*V06*V16 + 9.24821465245237093e-15*V01*V02*V17 - 2.61613898184861906e-15*V05*V17 + 
      6.9361609893392782e-16*V012*V18 - 7.01658024718669012e-16*V04*V18 - 1.8848263557987169e-16*V03*V19 - 
      2.34556168721618103e-17*V02*V20 - 3.51834253082427155e-18*V01*V21 + 5.02620361546324507e-21*V24) + 
   eps12*(4.38492191964414187e-7*V012*V025 + 1.56443190297356964e-6*V013*V023*V03 + 
      6.26423152464819131e-7*V014*V02*V032 - 6.15952990446624706e-7*V024*V032 - 
      2.13342389991695547e-6*V01*V022*V033 - 4.02632490461111493e-7*V012*V034 + 
      4.3106488418988419e-7*V014*V022*V04 - 1.43889032777921667e-7*V025*V04 + 
      9.17774355274355274e-8*V015*V03*V04 - 3.11017509368203813e-6*V01*V023*V03*V04 - 
      3.63782652349120603e-6*V012*V02*V032*V04 + 1.63667367473803243e-7*V034*V04 - 
      1.39086131227128251e-6*V012*V022*V042 - 6.47181474004390671e-7*V013*V03*V042 + 
      6.94893262950216634e-7*V02*V032*V042 + 1.51283642180000723e-7*V022*V043 + 
      2.90338231387046747e-7*V01*V03*V043 + 4.81771315104648438e-8*V015*V02*V05 - 
      4.63494115837865838e-7*V01*V024*V05 - 2.22791129909185465e-6*V012*V022*V03*V05 - 
      5.21445756440796123e-7*V013*V032*V05 + 3.96565639823316158e-7*V02*V033*V05 - 
      7.97474910818164786e-7*V013*V02*V04*V05 + 8.3079202034726953e-7*V022*V03*V04*V05 + 
      7.30771143336125926e-7*V01*V032*V04*V05 + 5.27975212689593233e-7*V01*V02*V042*V05 - 
      3.96192383729586111e-8*V014*V052 + 8.21761150132950242e-8*V023*V052 + 
      4.45765187284624921e-7*V01*V02*V03*V052 + 1.3232200882651688e-7*V012*V04*V052 - 
      2.37469976794500349e-8*V042*V052 - 1.36096627499663723e-8*V03*V053 + 
      1.80664243164243164e-9*V016*V06 - 3.92472994469522247e-7*V012*V023*V06 - 
      5.43036567342122898e-7*V013*V02*V03*V06 + 2.9825624725585578e-7*V022*V032*V06 + 
      1.71632696794454206e-7*V01*V033*V06 - 6.66349950204116871e-8*V014*V04*V06 + 
      1.29177689090543121e-7*V023*V04*V06 + 7.4981900942536933e-7*V01*V02*V03*V04*V06 + 
      1.1252040651039834e-7*V012*V042*V06 - 1.29392157703847877e-8*V043*V06 + 
      2.26994879836485229e-7*V01*V022*V05*V06 + 1.8517650554189128e-7*V012*V03*V05*V06 - 
      6.81809509230165907e-8*V03*V04*V05*V06 - 2.05992629199890677e-8*V02*V052*V06 + 
      4.8446145797846895e-8*V012*V02*V062 - 1.22055305562127859e-8*V032*V062 - 
      1.68156090978436291e-8*V02*V04*V062 - 9.37819813764003117e-9*V01*V05*V062 - 
      1.2330334595959596e-7*V013*V022*V07 - 3.92944728882228882e-8*V014*V03*V07 + 
      8.66334246474497019e-8*V023*V03*V07 + 2.31846393732372082e-7*V01*V02*V032*V07 + 
      1.6665107427975075e-7*V01*V022*V04*V07 + 1.36708868964792167e-7*V012*V03*V04*V07 - 
      2.50571343461910233e-8*V03*V042*V07 + 8.40820834182762287e-8*V012*V02*V05*V07 - 
      2.14821947819303148e-8*V032*V05*V07 - 3.02261663079119173e-8*V02*V04*V05*V07 - 
      8.22752243934466367e-9*V01*V052*V07 + 1.09705030084640262e-8*V013*V06*V07 - 
      2.17543301382968463e-8*V02*V03*V06*V07 - 1.38315040954813512e-8*V01*V04*V06*V07 - 
      2.39937340072932961e-9*V022*V072 - 4.31306178988452739e-9*V01*V03*V072 + 
      2.14767307517493529e-10*V06*V072 - 1.5356460668960669e-8*V014*V02*V08 + 
      7.81750055533643043e-9*V024*V08 + 9.19141145218555349e-8*V01*V022*V03*V08 + 
      3.68678479028521823e-8*V012*V032*V08 + 5.52415504398901925e-8*V012*V02*V04*V08 - 
      1.39583195853626023e-8*V032*V04*V08 - 9.5986425764438334e-9*V02*V042*V08 + 
      8.45095936083720086e-9*V013*V05*V08 - 1.6922158316131765e-8*V02*V03*V05*V08 - 
      1.07323878817334722e-8*V01*V04*V05*V08 - 4.15583968693321596e-9*V022*V06*V08 - 
      7.63161126818879759e-9*V01*V03*V06*V08 + 1.88392481149618117e-10*V062*V08 - 
      3.44611396259379405e-9*V01*V02*V07*V08 + 3.34163144371482397e-10*V05*V07*V08 - 
      2.87881903030246724e-10*V012*V082 + 1.07955611905981345e-10*V04*V082 - 
      6.32324851074851075e-10*V015*V09 + 1.08012321958230183e-8*V01*V023*V09 + 
      2.67003744013037314e-8*V012*V02*V03*V09 - 2.32715627508698703e-9*V033*V09 + 
      4.97490875478007831e-9*V013*V04*V09 - 9.88389262871376166e-9*V02*V03*V04*V09 - 
      3.15013205391853196e-9*V01*V042*V09 - 2.97133665297839776e-9*V022*V05*V09 - 
      5.32644539790241181e-9*V01*V03*V05*V09 - 2.74320110204596492e-9*V01*V02*V06*V09 + 2.65885815201741545e-10*V05*V06*V09 - 
      5.17205072695488891e-10*V012*V07*V09 + 1.95841700939319757e-10*V04*V07*V09 + 1.096083942566415e-10*V03*V08*V09 + 
      1.95715989957548972e-11*V02*V092 + 4.40590494971622423e-9*V012*V022*V10 + 
      2.16310006827776436e-9*V013*V03*V10 - 2.25902809958179182e-9*V02*V032*V10 - 
      1.54286144998219302e-9*V022*V04*V10 - 2.84471333483214826e-9*V01*V03*V04*V10 - 
      1.74167770044125429e-9*V01*V02*V05*V10 + 8.46077491142124186e-11*V052*V10 - 
      3.74968030744362659e-10*V012*V06*V10 + 1.40534807154727983e-10*V04*V06*V10 + 
      8.96631141416310435e-11*V03*V07*V10 + 3.53068698438173758e-11*V02*V08*V10 + 1.14933982587741202e-11*V01*V09*V10 + 
      6.56088693517206589e-10*V013*V02*V11 - 6.63592935339787407e-10*V022*V03*V11 - 
      5.86501686136304238e-10*V01*V032*V11 - 8.50965315512898983e-10*V01*V02*V04*V11 - 
      2.17109607466627468e-10*V012*V05*V11 + 8.25656605053924563e-11*V04*V05*V11 + 
      5.93973291009376551e-11*V03*V06*V11 + 2.66550932927223941e-11*V02*V07*V11 + 9.56771272405064299e-12*V01*V08*V11 - 
      4.07749009133190344e-14*V112 + 3.09963162291593664e-11*V014*V12 - 
      5.82036759080676063e-11*V023*V12 - 3.25941413725211455e-10*V01*V02*V03*V12 - 
      9.86366484114377131e-11*V012*V04*V12 + 1.84687031573766897e-11*V042*V12 + 
      3.1993273768693732e-11*V03*V05*V12 + 1.61905904420380971e-11*V02*V06*V12 + 6.62190665544894663e-12*V01*V07*V12 - 
      7.51070723847808455e-14*V10*V12 - 4.17471438054835888e-11*V01*V022*V13 - 
      3.44956371929249896e-11*V012*V03*V13 + 1.34089170629807992e-11*V03*V04*V13 + 
      8.16679779260448407e-12*V02*V05*V13 + 3.76684869312443917e-12*V01*V06*V13 - 5.91460018310722003e-14*V09*V13 - 
      8.42882283424509087e-12*V012*V02*V14 + 2.25096920533364482e-12*V032*V14 + 
      3.16777246847520571e-12*V02*V04*V14 + 1.75706830181942595e-12*V01*V05*V14 - 3.93062525938867e-14*V08*V14 - 
      4.8941551940777947e-13*V013*V15 + 1.01138475439219129e-12*V02*V03*V15 + 6.48114882843862155e-13*V01*V04*V15 - 
      2.21797318383885171e-14*V07*V15 + 1.05207689886298172e-13*V022*V16 + 1.90772171850787508e-13*V01*V03*V16 - 
      1.03716716845807155e-14*V06*V16 + 3.87037783205131723e-14*V01*V02*V17 - 4.05901125373965282e-15*V05*V17 + 
      3.12127244520267519e-15*V012*V18 - 1.25755614458890392e-15*V04*V18 - 3.20420480485781873e-16*V03*V19 - 
      5.52882397700956958e-17*V02*V20 - 8.29323596551435437e-18*V01*V21 + 7.53930542319486761e-21*V24) + 
   delta6*eps9*(7.65183075086203004e-8*V034*V04 + 
      2.36200532725392669e-7*V02*V032*V042 + 2.10474956623416007e-8*V022*V043 + 
      9.48188609885232979e-8*V01*V03*V043 + 1.57752553415679777e-7*V02*V033*V05 + 
      2.30720518966025502e-7*V022*V03*V04*V05 + 2.68114688535634692e-7*V01*V032*V04*V05 + 
      1.41720319635235602e-7*V01*V02*V042*V05 + 1.84747491222164425e-8*V023*V052 + 
      1.39170980163627222e-7*V01*V02*V03*V052 + 3.83673161377993311e-8*V012*V04*V052 - 
      2.2023741600738457e-8*V042*V052 - 1.42734771738816095e-8*V03*V053 + 
      8.35556661619725734e-8*V022*V032*V06 + 6.10311140773325647e-8*V01*V033*V06 + 
      1.45381579205108617e-8*V023*V04*V06 + 2.02131518633813996e-7*V01*V02*V03*V04*V06 + 
      2.94928838394835905e-8*V012*V042*V06 - 9.41028310842586455e-9*V043*V06 + 
      5.01333996971835441e-8*V01*V022*V05*V06 + 5.18720048632708141e-8*V012*V03*V05*V06 - 
      6.38881832797249232e-8*V03*V04*V05*V06 - 1.63995054407892911e-8*V02*V052*V06 + 
      1.04752648131110627e-8*V012*V02*V062 - 1.14954440383213866e-8*V032*V062 - 
      1.0373940513735223e-8*V02*V04*V062 - 7.1995374382365363e-9*V01*V05*V062 + 
      1.75949991640156595e-8*V023*V03*V07 + 6.49355534538774501e-8*V01*V02*V032*V07 + 
      3.29600741380036431e-8*V01*V022*V04*V07 + 3.5490127012847212e-8*V012*V03*V04*V07 - 
      2.19073568194984549e-8*V03*V042*V07 + 1.86392868465697597e-8*V012*V02*V05*V07 - 
      2.1179389152059458e-8*V032*V05*V07 - 2.23122299449632283e-8*V02*V04*V05*V07 - 
      6.59696094049781919e-9*V01*V052*V07 + 2.17904805955303932e-9*V013*V06*V07 - 
      1.62855136239927535e-8*V02*V03*V06*V07 - 9.93213689609712688e-9*V01*V04*V06*V07 - 
      1.39055312077097546e-9*V022*V072 - 3.23282820827403963e-9*V01*V03*V072 + 
      2.70691673066425051e-10*V06*V072 + 6.3274781919956039e-10*V024*V08 + 
      1.84578803786903694e-8*V01*V022*V03*V08 + 9.01661706319217472e-9*V012*V032*V08 + 
      1.08198370142036497e-8*V012*V02*V04*V08 - 1.23996749144077e-8*V032*V04*V08 - 
      5.5206283010412297e-9*V02*V042*V08 + 1.63325049124276223e-9*V013*V05*V08 - 
      1.28086576834036954e-8*V02*V03*V05*V08 - 7.75394468687961361e-9*V01*V04*V05*V08 - 
      2.01580544695901625e-9*V022*V06*V08 - 5.50766241918738492e-9*V01*V03*V06*V08 + 
      2.20755502650434519e-10*V062*V08 - 1.97947906813119159e-9*V01*V02*V07*V08 + 4.2591718923221259e-10*V05*V07*V08 - 
      1.583082256110483e-10*V012*V082 + 1.20675045280608754e-10*V04*V082 + 
      1.46624993033463829e-9*V01*V023*V09 + 4.95485603591345888e-9*V012*V02*V03*V09 - 
      2.10097487807609381e-9*V033*V09 + 8.58787732912382772e-10*V013*V04*V09 - 
      6.70950969054189387e-9*V02*V03*V04*V09 - 2.05870427299032854e-9*V01*V042*V09 - 
      1.68483925214565814e-9*V022*V05*V09 - 3.89132664126299495e-9*V01*V03*V05*V09 - 
      1.52386038876203899e-9*V01*V02*V06*V09 + 3.32066820728828843e-10*V05*V06*V09 - 
      2.85511375988624393e-10*V012*V07*V09 + 2.30855487854577695e-10*V04*V07*V09 + 
      1.32285455360861002e-10*V03*V08*V09 + 1.86224886360941026e-11*V02*V092 + 
      6.04575767974460785e-10*V012*V022*V10 + 3.40073869485634192e-10*V013*V03*V10 - 
      1.57213310981915158e-9*V02*V032*V10 - 6.71181261929988321e-10*V022*V04*V10 - 
      1.87883873030537691e-9*V01*V03*V04*V10 - 9.79242152784242622e-10*V01*V02*V05*V10 + 
      1.07336839085989354e-10*V052*V10 - 2.00661102814361779e-10*V012*V06*V10 + 
      1.54495629503149789e-10*V04*V06*V10 + 1.08715403184487502e-10*V03*V07*V10 + 3.19419553321709642e-11*V02*V08*V10 + 
      1.07962929205513937e-11*V01*V09*V10 + 7.75399910748494626e-11*V013*V02*V11 - 
      3.40440197433494265e-10*V022*V03*V11 - 3.83107217992122246e-10*V01*V032*V11 - 
      4.21791587392818139e-10*V01*V02*V04*V11 - 1.14751107550456822e-10*V012*V05*V11 + 
      9.62065320400714134e-11*V04*V05*V11 + 7.0053450335113439e-11*V03*V06*V11 + 2.5310464537020169e-11*V02*V07*V11 + 
      8.92101281804860605e-12*V01*V08*V11 - 5.43372820460500498e-14*V112 + 2.9520301170627968e-12*V014*V12 - 
      1.849485094293739e-11*V023*V12 - 1.63911361271335963e-10*V01*V02*V03*V12 - 
      4.73197850193238992e-11*V012*V04*V12 + 1.88537309952640217e-11*V042*V12 + 
      3.82877627980636899e-11*V03*V05*V12 + 1.42638050703933002e-11*V02*V06*V12 + 6.20117454352671344e-12*V01*V07*V12 - 
      9.861716111939824e-14*V10*V12 - 1.52801222059334661e-11*V01*V022*V13 - 
      1.59005664305371908e-11*V012*V03*V13 + 1.46902340825414441e-11*V03*V04*V13 + 
      7.63906846126070317e-12*V02*V05*V13 + 3.41839908555666496e-12*V01*V06*V13 - 7.88028307646789415e-14*V09*V13 - 
      3.00382011911653008e-12*V012*V02*V14 + 2.51465121876614934e-12*V032*V14 + 
      2.55827813001998466e-12*V02*V04*V14 + 1.60913386023879783e-12*V01*V05*V14 - 5.13051632836443249e-14*V08*V14 - 
      1.55370006161199832e-13*V013*V15 + 8.81293201614361267e-13*V02*V03*V15 + 5.4133499646664708e-13*V01*V04*V15 - 
      2.95144707744340306e-14*V07*V15 + 6.57733026082412621e-14*V022*V16 + 1.60419531361438826e-13*V01*V03*V16 - 
      1.32723943151368635e-14*V06*V16 + 2.52476260011949726e-14*V01*V02*V17 - 5.35350999490221159e-15*V05*V17 + 
      1.9421250770149979e-15*V012*V18 - 1.50866527721744764e-15*V04*V18 - 4.01091048513966957e-16*V03*V19 - 
      5.36128385649412808e-17*V02*V20 - 8.04192578474119211e-18*V01*V21 + 1.00524072309264901e-20*V24) + 
   delta2*eps11*(-5.19942132872027052e-7*V024*V032 - 
      2.12909656114021193e-6*V01*V022*V033 - 4.30973118225102352e-7*V012*V034 - 
      6.80612866459427306e-8*V025*V04 - 2.60643787429501715e-6*V01*V023*V03*V04 - 
      3.48396023619237905e-6*V012*V02*V032*V04 + 2.92634394072278254e-7*V034*V04 - 
      1.17616437060881505e-6*V012*V022*V042 - 5.9607155961322628e-7*V013*V03*V042 + 
      1.1082481523457393e-6*V02*V032*V042 + 1.95584655809718057e-7*V022*V043 + 
      4.54467079326658575e-7*V01*V03*V043 - 3.11965279723216231e-7*V01*V024*V05 - 
      1.86285023214586707e-6*V012*V022*V03*V05 - 4.72547688569513966e-7*V013*V032*V05 + 
      6.54479977676270082e-7*V02*V033*V05 - 6.53448229093070363e-7*V013*V02*V04*V05 + 
      1.19518228764965654e-6*V022*V03*V04*V05 + 1.16986246668154153e-6*V01*V032*V04*V05 + 
      7.49205341404634316e-7*V01*V02*V042*V05 - 3.07473335747145271e-8*V014*V052 + 
      1.0472435081384564e-7*V023*V052 + 6.53677756463315131e-7*V01*V02*V03*V052 + 
      1.8926780842484624e-7*V012*V04*V052 - 4.49111369355517819e-8*V042*V052 - 
      2.66308862018481758e-8*V03*V053 - 2.7752321899147296e-7*V012*V023*V06 - 
      4.30835469277929595e-7*V013*V02*V03*V06 + 4.35860386828621345e-7*V022*V032*V06 + 
      2.74950060854005765e-7*V01*V033*V06 - 5.11709961114723019e-8*V014*V04*V06 + 
      1.49373083789906074e-7*V023*V04*V06 + 1.07553785650458347e-6*V01*V02*V03*V04*V06 + 
      1.58959003141207273e-7*V012*V042*V06 - 2.34589188319894784e-8*V043*V06 + 
      2.91743367359030291e-7*V01*V022*V05*V06 + 2.64325940625106125e-7*V012*V03*V05*V06 - 
      1.30477649586021645e-7*V03*V04*V05*V06 - 3.63982154243717568e-8*V02*V052*V06 + 
      6.21909667103265376e-8*V012*V02*V062 - 2.35866641208131788e-8*V032*V062 - 
      2.83830922891645865e-8*V02*V04*V062 - 1.64809807039780169e-8*V01*V05*V062 - 
      8.3627470780248558e-8*V013*V022*V07 - 2.86653932487265821e-8*V014*V03*V07 + 
      1.09769440570337318e-7*V023*V03*V07 + 3.35492824806258513e-7*V01*V02*V032*V07 + 
      2.09044847038933562e-7*V01*V022*V04*V07 + 1.92355750008498608e-7*V012*V03*V04*V07 - 
      4.72618338936615608e-8*V03*V042*V07 + 1.07650164092011664e-7*V012*V02*V05*V07 - 
      4.18304532027872241e-8*V032*V05*V07 - 5.2495110872022949e-8*V02*V04*V05*V07 - 
      1.45549356985976133e-8*V01*V052*V07 + 1.36847681855268223e-8*V013*V06*V07 - 
      3.83220680268478737e-8*V02*V03*V06*V07 - 2.39667134245575088e-8*V01*V04*V06*V07 - 
      3.78370234356419949e-9*V022*V072 - 7.57514185448521646e-9*V01*V03*V072 + 
      4.26147160475657499e-10*V06*V072 - 9.63542630209296876e-9*V014*V02*V08 + 
      7.72535223236800164e-9*V024*V08 + 1.17120217666946775e-7*V01*V022*V03*V08 + 
      5.1466665825082803e-8*V012*V032*V08 + 6.95025549042676727e-8*V012*V02*V04*V08 - 
      2.66734083953653464e-8*V032*V04*V08 - 1.59763800882102491e-8*V02*V042*V08 + 
      1.04776967236360716e-8*V013*V05*V08 - 2.9909484601287233e-8*V02*V03*V05*V08 - 
      1.86295937434687129e-8*V01*V04*V05*V08 - 6.38461798617259437e-9*V022*V06*V08 - 
      1.33424917612395601e-8*V01*V03*V06*V08 + 3.69473760663051925e-10*V062*V08 - 
      5.46385122184290841e-9*V01*V02*V07*V08 + 6.65193360464561812e-10*V05*V07*V08 - 
      4.51929472006984006e-10*V012*V082 + 2.09622080250661849e-10*V04*V082 - 
      3.61328486328486328e-10*V015*V09 + 1.16554442820539537e-8*V01*V023*V09 + 
      3.32813562272012319e-8*V012*V02*V03*V09 - 4.49623559158400142e-9*V033*V09 + 
      6.05996959616532446e-9*V013*V04*V09 - 1.71008894358145883e-8*V02*V03*V04*V09 - 
      5.36744415768178965e-9*V01*V042*V09 - 4.68188403056017865e-9*V022*V05*V09 - 
      9.32814612085776875e-9*V01*V03*V05*V09 - 4.32938137442453789e-9*V01*V02*V06*V09 + 5.27480366322598665e-10*V05*V06*V09 - 
      8.11379645939557258e-10*V012*V07*V09 + 3.83426984261945439e-10*V04*V07*V09 + 2.1768055216367305e-10*V03*V08*V09 + 
      3.5427496549520743e-11*V02*V092 + 4.80738104563676459e-9*V012*V022*V10 + 
      2.57712229219582161e-9*V013*V03*V10 - 3.97089667710882205e-9*V02*V032*V10 - 
      2.32086891334837589e-9*V022*V04*V10 - 4.89421578838019756e-9*V01*V03*V04*V10 - 
      2.7556254125600797e-9*V01*V02*V05*V10 + 1.68525837843121799e-10*V052*V10 - 
      5.86367513038126459e-10*V012*V06*V10 + 2.72167713347360047e-10*V04*V06*V10 + 
      1.78212007585668558e-10*V03*V07*V10 + 6.34254219220624266e-11*V02*V08*V10 + 2.07887313037605561e-11*V01*V09*V10 + 
      6.93727077509757248e-10*V013*V02*V11 - 1.04023300630045484e-9*V022*V03*V11 - 
      1.01343227212338563e-9*V01*V032*V11 - 1.31535377883894447e-9*V01*V02*V04*V11 - 
      3.38479662243844452e-10*V012*V05*V11 + 1.61601702895817855e-10*V04*V05*V11 + 
      1.17549811516796611e-10*V03*V06*V11 + 4.82422574380474134e-11*V02*V07*V11 + 1.72881408123471871e-11*V01*V08*V11 - 
      8.15490478960957494e-14*V112 + 3.09963162291593664e-11*V014*V12 - 
      7.7737976854129163e-11*V023*V12 - 5.09456252588209318e-10*V01*V02*V03*V12 - 
      1.51223846568212385e-10*V012*V04*V12 + 3.5268177555702946e-11*V042*V12 + 
      6.35409685554323088e-11*V03*V05*V12 + 2.89625228485092606e-11*V02*V06*V12 + 1.19713052157937093e-11*V01*V07*V12 - 
      1.49876201115561999e-13*V10*V12 - 5.76407185857435255e-11*V01*V022*V13 - 
      5.26657709884619069e-11*V012*V03*V13 + 2.61749907254696341e-11*V03*V04*V13 + 
      1.47714796482632382e-11*V02*V05*V13 + 6.77909855989667958e-12*V01*V06*V13 - 1.18290495801059762e-13*V09*V13 - 
      1.15828339593174474e-11*V012*V02*V14 + 4.4488998996354753e-12*V032*V14 + 
      5.57193834952672406e-12*V02*V04*V14 + 3.16827187206643814e-12*V01*V05*V14 - 7.8365081937796196e-14*V08*V14 - 
      6.52554025877039293e-13*V013*V15 + 1.82291559014488683e-12*V02*V03*V15 + 1.14846179197084033e-12*V01*V04*V15 - 
      4.43579558156923953e-14*V07*V15 + 1.68539463826292008e-13*V022*V16 + 3.40815206372174774e-13*V01*V03*V16 - 
      2.06130641714486236e-14*V06*V16 + 6.27028953436270749e-14*V01*V02*V17 - 8.11651464639466667e-15*V05*V17 + 
      4.9940359123242803e-15*V012*V18 - 2.46806702333707186e-15*V04*V18 - 6.39333099886924773e-16*V03*V19 - 
      1.00524072309264901e-16*V02*V20 - 1.50786108463897352e-17*V01*V21 + 1.50786108463897352e-20*V24) + 
   delta4*eps10*(-1.17745291769762669e-7*V024*V032 - 
      5.79433243123719314e-7*V01*V022*V033 - 1.24555091072948216e-7*V012*V034 - 
      1.48202033122668043e-9*V025*V04 - 5.98870803897258924e-7*V01*V023*V03*V04 - 
      9.19068255377779187e-7*V012*V02*V032*V04 + 2.14311482438524922e-7*V034*V04 - 
      2.78216052025575835e-7*V012*V022*V042 - 1.52528798362131695e-7*V013*V03*V042 + 
      7.28419279216334149e-7*V02*V032*V042 + 9.77137892841674354e-8*V022*V043 + 
      2.94835574485628952e-7*V01*V03*V043 - 7.06471750618576015e-8*V01*V024*V05 - 
      4.70752516883469264e-7*V012*V022*V03*V05 - 1.22944598391026962e-7*V013*V032*V05 + 
      4.53829576895904121e-7*V02*V033*V05 - 1.57814517933565553e-7*V013*V02*V04*V05 + 
      7.3417265658745584e-7*V022*V03*V04*V05 + 7.89349551944867849e-7*V01*V032*V04*V05 + 
      4.54844988100998839e-7*V01*V02*V042*V05 - 7.17495137137994281e-9*V014*V052 + 
      6.06452340719542971e-8*V023*V052 + 4.1961331835354361e-7*V01*V02*V03*V052 + 
      1.18468274871461146e-7*V012*V04*V052 - 4.026399605523601e-8*V042*V052 - 
      2.49344252732416599e-8*V03*V053 - 6.40105840171977738e-8*V012*V023*V06 - 
      1.01929045381426334e-7*V013*V02*V03*V06 + 2.68121481016361191e-7*V022*V032*V06 + 
      1.83131423420507804e-7*V01*V033*V06 - 1.15108932073217788e-8*V014*V04*V06 + 
      6.94660406346006512e-8*V023*V04*V06 + 6.53241508264072845e-7*V01*V02*V03*V04*V06 + 
      9.57025503606288698e-8*V012*V042*V06 - 1.94107261144450045e-8*V043*V06 + 
      1.67111827140421912e-7*V01*V022*V05*V06 + 1.63286817054226796e-7*V012*V03*V05*V06 - 
      1.17292675685637981e-7*V03*V04*V05*V06 - 3.1097029829286499e-8*V02*V052*V06 + 
      3.52784186586804856e-8*V012*V02*V062 - 2.12175240295383638e-8*V032*V062 - 
      2.22496709765014992e-8*V02*V04*V062 - 1.3892605532982901e-8*V01*V05*V062 - 
      1.7584653001319668e-8*V013*V022*V07 - 6.08236285319618653e-9*V014*V03*V07 + 
      6.00239001444391008e-8*V023*V03*V07 + 2.05120027408751926e-7*V01*V02*V032*V07 + 
      1.13262007082035093e-7*V01*V022*V04*V07 + 1.1481891901160303e-7*V012*V03*V04*V07 - 
      4.13685034628376481e-8*V03*V042*V07 + 6.13554156716213205e-8*V012*V02*V05*V07 - 
      3.81989797524358541e-8*V032*V05*V07 - 4.35034561212444647e-8*V02*V04*V05*V07 - 
      1.24465574767207969e-8*V01*V052*V07 + 7.51825841670807435e-9*V013*V06*V07 - 
      3.18774024187369472e-8*V02*V03*V06*V07 - 1.9667871997796414e-8*V01*V04*V06*V07 - 
      2.88384332637313435e-9*V022*V072 - 6.2963852833022967e-9*V01*V03*V072 + 
      4.1939913591699306e-10*V06*V072 - 1.80664243164243164e-9*V014*V02*V08 + 
      3.19339934526286845e-9*V024*V08 + 6.40864146422619812e-8*V01*V022*V03*V08 + 
      3.00955337592388246e-8*V012*V032*V08 + 3.77117630268890773e-8*V012*V02*V04*V08 - 
      2.34923487086251406e-8*V032*V04*V08 - 1.21932300356941412e-8*V02*V042*V08 + 
      5.71217827651651181e-9*V013*V05*V08 - 2.5025281349342178e-8*V02*V03*V05*V08 - 
      1.53470257143579543e-8*V01*V04*V05*V08 - 4.61685998131022047e-9*V022*V06*V08 - 
      1.09728674070220722e-8*V01*V03*V06*V08 + 3.55652899273829005e-10*V062*V08 - 
      4.15881740242510684e-9*V01*V02*V07*V08 + 6.57949166107055085e-10*V05*V07*V08 - 
      3.39306748576642572e-10*V012*V082 + 1.98294607994327916e-10*V04*V082 - 
      6.02214143880810547e-11*V015*V09 + 5.56862526910962952e-9*V01*V023*V09 + 
      1.77171569817169724e-8*V012*V02*V03*V09 - 3.97927241519096207e-9*V033*V09 + 
      3.15622625744591197e-9*V013*V04*V09 - 1.37407137803524885e-8*V02*V03*V04*V09 - 
      4.2604639747773317e-9*V01*V042*V09 - 3.55753189027397834e-9*V022*V05*V09 - 
      7.70861279121372267e-9*V01*V03*V05*V09 - 3.26262256487220193e-9*V01*V02*V06*V09 + 5.18422609402698898e-10*V05*V06*V09 - 
      6.09370338393160972e-10*V012*V07*V09 + 3.68525742913893642e-10*V04*V07*V09 + 
      2.10984752273151009e-10*V03*V08*V09 + 3.17026393750257638e-11*V02*V092 + 
      2.31409640876552641e-9*V012*V022*V10 + 1.29948365753104315e-9*V013*V03*V10 - 
      3.22012106269394711e-9*V02*V032*V10 - 1.61126775629484608e-9*V022*V04*V10 - 
      3.90065748563062876e-9*V01*V03*V04*V10 - 2.08963724511459505e-9*V01*V02*V05*V10 + 
      1.66708646337348923e-10*V052*V10 - 4.36754705462371277e-10*V012*V06*V10 + 
      2.56156280440564972e-10*V04*V06*V10 + 1.72991833207666797e-10*V03*V07*V10 + 5.59156137952565482e-11*V02*V08*V10 + 
      1.85371567607405689e-11*V01*V09*V10 + 3.18819252642782055e-10*V013*V02*V11 - 
      7.60905183923706026e-10*V022*V03*V11 - 8.04406011184446243e-10*V01*V032*V11 - 
      9.51332212403664011e-10*V01*V02*V04*V11 - 2.51421963541570156e-10*V012*V05*V11 + 
      1.55046124435856297e-10*V04*V05*V11 + 1.13147716831517197e-10*V03*V06*V11 + 4.31537972541215944e-11*V02*V07*V11 + 
      1.53827773885756874e-11*V01*V08*V11 - 8.15425138313956472e-14*V112 + 1.32841355267825856e-11*V014*V12 - 
      4.86248930710779778e-11*V023*V12 - 3.70489767763205647e-10*V01*V02*V03*V12 - 
      1.0830510193769752e-10*V012*V04*V12 + 3.23502918471370033e-11*V042*V12 + 
      6.15313315114544086e-11*V03*V05*V12 + 2.53281964472471377e-11*V02*V06*V12 + 1.06661509229663684e-11*V01*V07*V12 - 
      1.4921036621479354e-13*V10*V12 - 3.77044162451691691e-11*V01*V022*V13 - 
      3.72150007257613897e-11*V012*V03*V13 + 2.45643216615985292e-11*V03*V04*V13 + 
      1.31821739602392982e-11*V02*V05*V13 + 5.98357638370737909e-12*V01*V06*V13 - 1.18277427671659557e-13*V09*V13 - 
      7.51602404804804186e-12*V012*V02*V14 + 4.20331355953960259e-12*V032*V14 + 
      4.72524580166540459e-12*V02*V04*V14 + 2.80845158458347374e-12*V01*V05*V14 - 7.78802878450727144e-14*V08*V14 - 
      4.07846266173149558e-13*V013*V15 + 1.58477406284423828e-12*V02*V03*V15 + 9.84657414046603933e-13*V01*V04*V15 - 
      4.43448876862921908e-14*V07*V15 + 1.31287655206213858e-13*V022*V16 + 2.92872461613861683e-13*V01*V03*V16 - 
      2.03625581832539355e-14*V06*V16 + 4.95241894638824463e-14*V01*V02*V17 - 8.10344651699446223e-15*V05*V17 + 
      3.88425015402999579e-15*V012*V18 - 2.3840288988865264e-15*V04*V18 - 6.26264970486720336e-16*V03*V19 - 
      9.04716650783384113e-17*V02*V20 - 1.35707497617507617e-17*V01*V21 + 1.50786108463897352e-20*V24) + 
   6.4469502843844734e-26*delta24*V24 + 3.86817017063068404e-25*delta22*eps*V24 + 
   delta22*eps2*(-1.85682880046129965e-20*V122 - 4.02312906766614924e-20*V11*V13 - 
      2.68208604511076616e-20*V10*V14 - 2.10735332115845913e-20*V09*V15 - 9.91695680545157236e-21*V08*V16 - 
      5.57828820306650945e-21*V07*V17 - 1.76156469570521351e-21*V06*V18 - 6.85052937218694143e-22*V05*V19 - 
      1.30486273755941742e-22*V04*V20 - 3.26215684389854354e-23*V03*V21 - 2.83665812512916829e-24*V02*V22 - 
      3.86817017063068404e-25*V01*V23 + 3.581639046880263e-27*V26) + 
   delta20*eps3*(-2.04251168050742961e-19*V122 - 4.42544197443276416e-19*V11*V13 - 
      2.95029464962184278e-19*V10*V14 - 2.31808865327430504e-19*V09*V15 - 1.09086524859967296e-19*V08*V16 - 
      6.1361170233731604e-20*V07*V17 - 1.93772116527573486e-20*V06*V18 - 7.53558230940563557e-21*V05*V19 - 
      1.43534901131535916e-21*V04*V20 - 3.58837252828839789e-22*V03*V21 - 3.12032393764208512e-23*V02*V22 - 
      4.25498718769375244e-24*V01*V23 + 1.96990147578414465e-26*V26) + 
   delta18*eps4*(3.30176453396809709e-15*V072*V08 + 1.9052198711412549e-15*V06*V082 + 
      4.99426568163241577e-15*V06*V07*V09 + 3.85205862296277994e-15*V05*V08*V09 + 9.77496079135291902e-16*V04*V092 + 
      1.16561970017120193e-15*V062*V10 + 3.11705043416568606e-15*V05*V07*V10 + 1.2063126956394299e-15*V04*V08*V10 + 
      8.65847342823801684e-16*V03*V09*V10 + 6.80933335986972465e-17*V02*V102 + 1.90690144207783147e-15*V05*V06*V11 + 
      1.27963123086801849e-15*V04*V07*V11 + 7.00374295084141807e-16*V03*V08*V11 + 1.78666912011260665e-16*V02*V09*V11 + 
      4.72280368812982737e-17*V01*V10*V11 + 4.95894387253631874e-16*V052*V12 + 4.97254203795415384e-16*V04*V06*V12 + 
      4.72280368812982737e-16*V03*V07*V12 + 9.17573287979509317e-17*V02*V08*V12 + 3.93566974010818947e-17*V01*V09*V12 - 
      1.4057404994796687e-18*V122 + 3.4451610061831267e-16*V04*V05*V13 + 2.4447454385613224e-16*V03*V06*V13 + 
      8.24616516975049223e-17*V02*V07*V13 + 2.6937472887851608e-17*V01*V08*V13 - 2.991109002482224e-18*V11*V13 + 
      3.79960143891801628e-17*V042*V14 + 1.07749891551406432e-16*V03*V05*V14 + 2.70991624009839705e-17*V02*V06*V14 + 
      1.53928416502009188e-17*V01*V07*V14 - 2.03780233210046255e-18*V10*V14 + 3.28110572017440638e-17*V03*V04*V15 + 
      1.64923303395009845e-17*V02*V05*V15 + 6.98498696731806401e-18*V01*V06*V15 - 1.57822438943280254e-18*V09*V15 + 
      4.36561685457379e-18*V032*V16 + 3.08401471364043177e-18*V02*V04*V16 + 2.619370112744274e-18*V01*V05*V16 - 
      7.61557606853427812e-19*V08*V16 + 1.21267134849271945e-18*V02*V03*V17 + 7.2377332062670729e-19*V01*V04*V17 - 
      4.23828636298205446e-19*V07*V17 + 4.72303577834006521e-20*V022*V18 + 1.60838515694823842e-19*V01*V03*V18 - 
      1.3767011045783136e-19*V06*V18 + 2.12749359384687622e-20*V01*V02*V19 - 5.31660649102334368e-20*V05*V19 + 
      1.06374679692343811e-21*V012*V20 - 1.04459935457881622e-20*V04*V20 - 2.60263382980601191e-21*V03*V21 - 
      2.34024295323156384e-22*V02*V22 - 3.19124039077031433e-23*V01*V23 + 9.84950737892072324e-26*V26) + 
   delta16*eps5*(3.91494937599074369e-14*V072*V08 + 2.38059997491145151e-14*V06*V082 + 
      5.90467869651332489e-14*V06*V07*V09 + 4.56744093865586764e-14*V05*V08*V09 + 1.15308333779477952e-14*V04*V092 + 
      1.45811602942764586e-14*V062*V10 + 3.71015586399999022e-14*V05*V07*V10 + 1.51019979579681752e-14*V04*V08*V10 + 
      1.03059885111110839e-14*V03*V09*V10 + 8.54602572137778286e-16*V02*V102 + 2.2545136841232695e-14*V05*V06*V11 + 
      1.50949091493134774e-14*V04*V07*V11 + 8.30443807028339571e-15*V03*V08*V11 + 2.10380288893259433e-15*V02*V09*V11 + 
      5.62144827878786397e-16*V01*V10*V11 + 5.93420283413512809e-15*V052*V12 + 6.24345874560816188e-15*V04*V06*V12 + 
      5.65162174679536008e-15*V03*V07*V12 + 1.15366349562739614e-15*V02*V08*V12 + 4.7096847889961334e-16*V01*V09*V12 - 
      7.4883685401212359e-18*V122 + 4.06401400173824391e-15*V04*V05*V13 + 2.8904021591323968e-15*V03*V06*V13 + 
      9.7098594873812046e-16*V02*V07*V13 + 3.19401464241669066e-16*V01*V08*V13 - 1.54868604273257256e-17*V11*V13 + 
      4.80337674442322357e-16*V042*V14 + 1.29973306683884008e-15*V03*V05*V14 + 3.42781767840608697e-16*V02*V06*V14 + 
      1.85676152405548583e-16*V01*V07*V14 - 1.09149240792333788e-17*V10*V14 + 3.8704895254649942e-16*V03*V04*V15 + 
      1.94197189747624092e-16*V02*V05*V15 + 8.25829188323541943e-17*V01*V06*V15 - 8.26678058267486846e-18*V09*V15 + 
      5.33575393336796556e-17*V032*V16 + 3.95203209992995727e-17*V02*V04*V16 + 3.20145236002077934e-17*V01*V05*V16 - 
      4.14491066914811507e-18*V08*V16 + 1.42792051285017715e-17*V02*V03*V17 + 8.53784454146689896e-18*V01*V04*V17 - 
      2.2701207643783708e-18*V07*V17 + 6.22930124278365357e-19*V022*V18 + 2.01718305100591569e-18*V01*V03*V18 - 
      7.68578335713122504e-19*V06*V18 + 2.50512370675469675e-19*V01*V02*V19 - 2.93865371384084395e-19*V05*V19 + 
      1.43605817584664145e-20*V012*V20 - 6.02825309816512377e-20*V04*V20 - 1.49509612307589226e-20*V03*V21 - 
      1.40414577193893831e-21*V02*V22 - 1.9147442344621886e-22*V01*V23 + 4.43227832051432546e-25*V26) + 
   delta14*eps6*(-1.54203318660389367e-12*V054 - 1.20222768349253792e-11*V04*V052*V06 - 
      2.20810148842809719e-12*V042*V062 - 8.49950385609556685e-12*V03*V05*V062 - 
      5.19154254600674884e-13*V02*V063 - 8.03458254146862924e-12*V042*V05*V07 - 
      8.72037364191043845e-12*V03*V052*V07 - 1.14497874618336945e-11*V03*V04*V06*V07 - 
      5.72782625570846122e-12*V02*V05*V06*V07 - 1.21421483658508098e-12*V01*V062*V07 - 
      2.04958885084975925e-12*V032*V072 - 1.89411468817236972e-12*V02*V04*V072 - 
      1.21671837233061723e-12*V01*V05*V072 - 7.53220636853102185e-13*V043*V08 - 
      8.7898649136415848e-12*V03*V04*V05*V08 - 2.21582514890753923e-12*V02*V052*V08 - 
      3.07934896700958681e-12*V032*V06*V08 - 1.58993354704801313e-12*V02*V04*V06*V08 - 
      1.84760938020575209e-12*V01*V05*V06*V08 - 2.11030966562622784e-12*V02*V03*V07*V08 - 
      1.25569498766308354e-12*V01*V04*V07*V08 + 2.52902464207594821e-13*V072*V08 - 
      7.05860041184046148e-14*V022*V082 - 3.2938676181467125e-13*V01*V03*V082 + 
      1.65322644154544154e-13*V06*V082 - 2.2318284837412859e-12*V03*V042*V09 - 
      2.36584127953175572e-12*V032*V05*V09 - 2.20980046953443135e-12*V02*V04*V05*V09 - 
      7.00410678164405918e-13*V01*V052*V09 - 1.5910628488079059e-12*V02*V03*V06*V09 - 
      9.54148955152807872e-13*V01*V04*V06*V09 - 2.55178500255161524e-13*V022*V07*V09 - 
      6.50858439786300493e-13*V01*V03*V07*V09 + 3.8183588904119501e-13*V06*V07*V09 - 1.75859138802185653e-13*V01*V02*V08*V09 + 
      2.96791441398816354e-13*V05*V08*V09 - 1.20920740210491967e-14*V012*V092 + 
      7.51242092489750279e-14*V04*V092 - 9.72977199189485451e-13*V032*V04*V10 - 
      2.45301962166125281e-13*V02*V042*V10 - 9.89880319917499004e-13*V02*V03*V05*V10 - 
      5.8378631951369127e-13*V01*V04*V05*V10 - 8.53406564866380643e-14*V022*V06*V10 - 
      4.02592159254841163e-13*V01*V03*V06*V10 + 1.01860733210772983e-13*V062*V10 - 
      1.41411474273928429e-13*V01*V02*V07*V10 + 2.42414016797913357e-13*V05*V07*V10 - 
      2.05587945175887093e-14*V012*V08*V10 + 1.06087349072260034e-13*V04*V08*V10 + 
      6.81155107853280148e-14*V03*V09*V10 + 6.10328012679467652e-15*V02*V102 - 
      1.38073789602302242e-13*V033*V11 - 4.0178190355171479e-13*V02*V03*V04*V11 - 
      1.21736099113161049e-13*V01*V042*V11 - 9.74317910065162182e-14*V022*V05*V11 - 
      2.4234761532458389e-13*V01*V03*V05*V11 - 8.67852462986130488e-14*V01*V02*V06*V11 + 1.47517807276666873e-13*V05*V06*V11 - 
      1.56321251096880647e-14*V012*V07*V11 + 9.89245613535953171e-14*V04*V07*V11 + 
      5.49103892488515527e-14*V03*V08*V11 + 1.39755139279545053e-14*V02*V09*V11 + 3.80029519523811889e-15*V01*V10*V11 - 
      7.36486711745073699e-14*V02*V032*V12 - 1.74606292638300763e-14*V022*V04*V12 - 
      8.55307773599781761e-14*V01*V03*V04*V12 - 4.4189202704704422e-14*V01*V02*V05*V12 + 
      3.94736305220268869e-14*V052*V12 - 8.45492335115312311e-15*V012*V06*V12 + 
      4.4391093491512922e-14*V04*V06*V12 + 3.7804669162617643e-14*V03*V07*V12 + 8.28983170499228742e-15*V02*V08*V12 + 
      3.20307292991376506e-15*V01*V09*V12 - 3.2885668253304498e-17*V122 - 1.2491255257245669e-14*V022*V03*V13 - 
      1.45258624807851906e-14*V01*V032*V13 - 1.5453150136604415e-14*V01*V02*V04*V13 - 
      4.02482301674727183e-15*V012*V05*V13 + 2.71021119581024799e-14*V04*V05*V13 + 
      1.93550835918877473e-14*V03*V06*V13 + 6.52510369708493555e-15*V02*V07*V13 + 2.17272708614309219e-15*V01*V08*V13 - 
      6.59474565261144479e-17*V11*V13 - 2.87957108924612235e-16*V023*V14 - 4.61600412862594148e-15*V01*V02*V03*V14 - 
      1.28347603729081856e-15*V012*V04*V14 + 3.49836247258676175e-15*V042*V14 + 
      8.9090194133122693e-15*V03*V05*V14 + 2.5090229770134993e-15*V02*V06*V14 + 1.28626433039491428e-15*V01*V07*V14 - 
      4.82088307689125368e-17*V10*V14 - 3.56893007349876257e-16*V01*V022*V15 - 
      3.43152802723375592e-16*V012*V03*V15 + 2.65553069586017059e-15*V03*V04*V15 + 
      1.33496733924397574e-15*V02*V05*V15 + 5.71968568230076054e-16*V01*V06*V15 - 3.56303053376302519e-17*V09*V15 - 
      5.10853761754511918e-17*V012*V02*V16 + 3.79444864943371915e-16*V032*V16 + 
      2.98429483390964099e-16*V02*V04*V16 + 2.28782576606636451e-16*V01*V05*V16 - 1.86185474371915526e-17*V08*V16 - 
      1.76156469570521351e-18*V013*V17 + 1.01462296984151374e-16*V02*V03*V17 + 6.08748251981782081e-17*V01*V04*V17 - 
      1.00166653385498626e-17*V07*V17 + 4.92472217103674908e-18*V022*V18 + 1.50805255906241974e-17*V01*V03*V18 - 
      3.54738281838028141e-18*V06*V18 + 1.85730190742832294e-18*V01*V02*V19 - 1.34095921220168608e-18*V05*V19 + 
      1.14884654067731316e-19*V012*V20 - 2.88488131325636416e-19*V04*V20 - 7.11646607141780096e-20*V03*V21 - 
      7.02072885969469153e-21*V02*V22 - 9.57372117231094299e-22*V01*V23 + 1.77291132820573018e-24*V26) + 
   delta12*eps7*(-1.66065112403496242e-11*V054 - 1.32286910338566607e-10*V04*V052*V06 - 
      2.9624444362982876e-11*V042*V062 - 9.40202849236138478e-11*V03*V05*V062 - 
      6.99935888436239844e-12*V02*V063 - 8.81082588939342752e-11*V042*V05*V07 - 
      9.41948082625692053e-11*V03*V052*V07 - 1.25987533655777721e-10*V03*V04*V06*V07 - 
      6.28954061798325235e-11*V02*V05*V06*V07 - 1.34314692748019783e-11*V01*V062*V07 - 
      2.22227074615757362e-11*V032*V072 - 2.07868960496107846e-11*V02*V04*V072 - 
      1.32336899509046145e-11*V01*V05*V072 - 1.0160231656237466e-11*V043*V08 - 
      9.74169938630722944e-11*V03*V04*V05*V08 - 2.44607475427185688e-11*V02*V052*V08 - 
      3.43735457862127048e-11*V032*V06*V08 - 2.15689127816977362e-11*V02*V04*V06*V08 - 
      2.06241274717276229e-11*V01*V05*V06*V08 - 2.32959500406843512e-11*V02*V03*V07*V08 - 
      1.39167134090103278e-11*V01*V04*V07*V08 + 1.14358065959054919e-12*V072*V08 - 
      9.72492181709934615e-13*V022*V082 - 3.72143225233535432e-12*V01*V03*V082 + 
      8.06832513790939047e-13*V06*V082 - 2.44745163594261876e-11*V03*V042*V09 - 
      2.57321749045367505e-11*V032*V05*V09 - 2.42513787245459154e-11*V02*V04*V05*V09 - 
      7.64803272769843236e-12*V01*V052*V09 - 1.74709461610645899e-11*V02*V03*V06*V09 - 
      1.04989611379814768e-11*V01*V04*V06*V09 - 2.81955869038106904e-12*V022*V07*V09 - 
      7.15964568449305329e-12*V01*V03*V07*V09 + 1.73526454756329624e-12*V06*V07*V09 - 1.94132917005702927e-12*V01*V02*V08*V09 + 
      1.35608337396241624e-12*V05*V08*V09 - 1.37908629566892789e-13*V012*V092 + 
      3.46474443578993563e-13*V04*V092 - 1.09131825067883835e-11*V032*V04*V10 - 
      3.37043773226947542e-12*V02*V042*V10 - 1.10387250589529224e-11*V02*V03*V05*V10 - 
      6.54790950407303009e-12*V01*V04*V05*V10 - 1.18352037247364295e-12*V022*V06*V10 - 
      4.56141900382685922e-12*V01*V03*V06*V10 + 5.0179374673263931e-13*V062*V10 - 
      1.57696072270756034e-12*V01*V02*V07*V10 + 1.11318188386107411e-12*V05*V07*V10 - 
      2.37735166353798372e-13*V012*V08*V10 + 5.27507721727871024e-13*V04*V08*V10 + 
      3.19132526809428339e-13*V03*V09*V10 + 3.11787899621623516e-14*V02*V102 - 
      1.51881168562532466e-12*V033*V11 - 4.40934158628107553e-12*V02*V03*V04*V11 - 
      1.33497361960506478e-12*V01*V042*V11 - 1.07655877269095363e-12*V022*V05*V11 - 
      2.68644112176895661e-12*V01*V03*V05*V11 - 9.52960699694432174e-13*V01*V02*V06*V11 + 6.84129584149527379e-13*V05*V06*V11 - 
      1.79020773765738028e-13*V012*V07*V11 + 4.60774808337594117e-13*V04*V07*V11 + 
      2.58509306778680506e-13*V03*V08*V11 + 6.66112563825561374e-14*V02*V09*V11 + 1.84889018457526946e-14*V01*V10*V11 - 
      8.35290526774251518e-13*V02*V032*V12 - 2.47605533628324811e-13*V022*V04*V12 - 
      9.78324647684366881e-13*V01*V03*V04*V12 - 5.01174316064550911e-13*V01*V02*V05*V12 + 
      1.85755303096988537e-13*V052*V12 - 9.84544380311962849e-14*V012*V06*V12 + 
      2.24702992214237174e-13*V04*V06*V12 + 1.79638835024222621e-13*V03*V07*V12 + 4.27110664190148531e-14*V02*V08*V12 + 
      1.56521585564102695e-14*V01*V09*V12 - 1.21283886108971637e-16*V122 - 
      1.38020355473199184e-13*V022*V03*V13 - 1.64470249379212965e-13*V01*V032*V13 - 
      1.69590061010810597e-13*V01*V02*V04*V13 - 4.6788567569687035e-14*V012*V05*V13 + 
      1.2987681548843124e-13*V04*V05*V13 + 9.32407235128521577e-14*V03*V06*V13 + 3.16695058366000516e-14*V02*V07*V13 + 
      1.07086075255241517e-14*V01*V08*V13 - 2.36726161901129699e-16*V11*V13 - 4.28788334463925038e-15*V023*V14 - 
      5.38763992793265321e-14*V01*V02*V03*V14 - 1.52040648886316978e-14*V012*V04*V14 + 
      1.83220005303319117e-14*V042*V14 + 4.36973912871109959e-14*V03*V05*V14 + 1.32520690923386879e-14*V02*V06*V14 + 
      6.42266317854633338e-15*V01*V07*V14 - 1.7866191433540021e-16*V10*V14 - 3.94343872780569097e-15*V01*V022*V15 - 
      4.14813254544663678e-15*V012*V03*V15 + 1.32933569350157555e-14*V03*V04*V15 + 
      6.70424078518043637e-15*V02*V05*V15 + 2.90109792042610258e-15*V01*V06*V15 - 1.29107459341060207e-16*V09*V15 - 
      6.28878596366761223e-16*V012*V02*V16 + 1.9498542612414436e-15*V032*V16 + 
      1.63958782899303425e-15*V02*V04*V16 + 1.18553176371345238e-15*V01*V05*V16 - 7.00374295084141807e-17*V08*V16 - 
      2.46619057398729892e-17*V013*V17 + 5.33805162644932019e-16*V02*V03*V17 + 3.2177532159368341e-16*V01*V04*V17 - 
      3.70192182554372465e-17*V07*V17 + 2.85220301165487614e-17*V022*V18 + 8.2215287939337454e-17*V01*V03*V18 - 
      1.36918254221765874e-17*V06*V18 + 1.03204714237511965e-17*V01*V02*V19 - 5.11287770447656681e-18*V05*V19 + 
      6.7016048206176601e-19*V012*V20 - 1.1553566710744846e-18*V04*V20 - 2.832544970847731e-19*V03*V21 - 
      2.94870612107177044e-20*V02*V22 - 4.02096289237059606e-21*V01*V23 + 6.20518964872005564e-24*V26) + 
   delta10*eps8*(1.03644223710013184e-9*V032*V043 + 7.69281785172546935e-11*V02*V044 + 
      2.23576403065925483e-9*V033*V04*V05 + 3.0758151273048265e-9*V02*V03*V042*V05 + 
      6.21865342260079102e-10*V01*V043*V05 + 1.72425317004195095e-9*V02*V032*V052 + 
      7.44933924140365489e-10*V022*V04*V052 + 1.95196621320524829e-9*V01*V03*V04*V052 + 
      3.37044154365490795e-10*V01*V02*V053 - 8.86044777363391133e-11*V054 + 
      3.8244802639047179e-10*V034*V06 + 2.19627954448125206e-9*V02*V032*V04*V06 + 
      1.57554740974366134e-10*V022*V042*V06 + 1.3106433671735816e-9*V01*V03*V042*V06 + 
      1.07889346598353593e-9*V022*V03*V05*V06 + 1.32380166356476179e-9*V01*V032*V05*V06 + 
      1.31776772668875124e-9*V01*V02*V04*V05*V06 + 1.85737232406228952e-10*V012*V052*V06 - 
      7.31437823120934984e-10*V04*V052*V06 + 1.78028801454292508e-11*V023*V062 + 
      4.63481031146693903e-10*V01*V02*V03*V062 + 1.3454676832729077e-10*V012*V04*V062 - 
      1.95663925615815219e-10*V042*V062 - 5.235117843415e-10*V03*V05*V062 - 
      4.66936333251060897e-11*V02*V063 + 5.34990721215064754e-10*V02*V033*V07 + 
      7.09460880133681418e-10*V022*V03*V04*V07 + 9.00830856579603447e-10*V01*V032*V04*V07 + 
      4.39402161043546643e-10*V01*V02*V042*V07 + 1.12101974959691146e-10*V023*V05*V07 + 
      9.34561339650519572e-10*V01*V02*V03*V05*V07 + 2.53549200883068641e-10*V012*V04*V05*V07 - 
      4.89345958036449584e-10*V042*V05*V07 - 5.0936164839679545e-10*V03*V052*V07 + 
      1.5412763799764799e-10*V01*V022*V06*V07 + 1.6931956922865567e-10*V012*V03*V06*V07 - 
      7.04068186757063522e-10*V03*V04*V06*V07 - 3.53228899935868542e-10*V02*V05*V06*V07 - 
      7.6362931160826196e-11*V01*V062*V07 + 3.02631670953244222e-11*V012*V02*V072 - 
      1.21809194119213621e-10*V032*V072 - 1.17419159346054373e-10*V02*V04*V072 - 
      7.34560746088200637e-11*V01*V05*V072 + 1.9730626157021439e-10*V022*V032*V08 + 
      1.52448556807254477e-10*V01*V033*V08 + 1.77815628638582902e-11*V023*V04*V08 + 
      4.7487650391059968e-10*V01*V02*V03*V04*V08 + 6.90528428335295722e-11*V012*V042*V08 - 
      6.78083241517972135e-11*V043*V08 + 1.18383756942128634e-10*V01*V022*V05*V08 + 
      1.26591387143792804e-10*V012*V03*V05*V08 - 5.48630925336919625e-10*V03*V04*V05*V08 - 
      1.38327168512975287e-10*V02*V052*V08 + 4.8745308936170531e-11*V012*V02*V06*V08 - 
      1.95031783256437153e-10*V032*V06*V08 - 1.4543219266699888e-10*V02*V04*V06*V08 - 
      1.18210669118258031e-10*V01*V05*V06*V08 + 5.01746472277715964e-12*V013*V07*V08 - 
      1.33112230181405307e-10*V02*V03*V07*V08 - 8.00030249249020578e-11*V01*V04*V07*V08 + 
      3.92990368802391292e-12*V072*V08 - 6.70541348750019e-12*V022*V082 - 
      2.17404810478333747e-11*V01*V03*V082 + 2.97203456063187927e-12*V06*V082 + 
      3.1139437488803096e-11*V023*V03*V09 + 1.22754882439275202e-10*V01*V02*V032*V09 + 
      5.91217400111401182e-11*V01*V022*V04*V09 + 6.56508562462427927e-11*V012*V03*V04*V09 - 
      1.38854417015004065e-10*V03*V042*V09 + 3.43776854632476121e-11*V012*V02*V05*V09 - 
      1.42941449688980166e-10*V032*V05*V09 - 1.38448103897304411e-10*V02*V04*V05*V09 - 
      4.30276258233606887e-11*V01*V052*V09 + 3.81396372267135777e-12*V013*V06*V09 - 
      1.00202658874331531e-10*V02*V03*V06*V09 - 6.05375329378461776e-11*V01*V04*V06*V09 - 
      1.64118652809714842e-11*V022*V07*V09 - 4.08646481491317894e-11*V01*V03*V07*V09 + 
      6.01397796505936062e-12*V06*V07*V09 - 1.14357032716647961e-11*V01*V02*V08*V09 + 4.72038477027008684e-12*V05*V08*V09 - 
      8.2482864742720661e-13*V012*V092 + 1.22588102727520073e-12*V04*V092 + 
      4.41628966719152241e-13*V024*V10 + 2.58472555773542445e-11*V01*V022*V03*V10 + 
      1.29549237470610211e-11*V012*V032*V10 + 1.51456161720281988e-11*V012*V02*V04*V10 - 
      6.3325802769482879e-11*V032*V04*V10 - 2.32112737609917358e-11*V02*V042*V10 + 
      2.24854925583291979e-12*V013*V05*V10 - 6.42691019807710967e-11*V02*V03*V05*V10 - 
      3.83706426821222986e-11*V01*V04*V05*V10 - 8.24636658227674083e-12*V022*V06*V10 - 
      2.69448662011830399e-11*V01*V03*V06*V10 + 1.86934827302314237e-12*V062*V10 - 
      9.3636809477959793e-12*V01*V02*V07*V10 + 3.88547034161994706e-12*V05*V07*V10 - 
      1.44871320788164355e-12*V012*V08*V10 + 1.99004986634628615e-12*V04*V08*V10 + 
      1.14387030318298649e-12*V03*V09*V10 + 1.21953854967834181e-13*V02*V102 + 
      1.69851477211653251e-12*V01*V023*V11 + 5.6508811098000575e-12*V012*V02*V03*V11 - 
      8.77872595288240884e-12*V033*V11 + 9.38064908627548888e-13*V013*V04*V11 - 
      2.59682468869140614e-11*V02*V03*V04*V11 - 7.89296648013855657e-12*V01*V042*V11 - 
      6.39681333144350255e-12*V022*V05*V11 - 1.57396968193959993e-11*V01*V03*V05*V11 - 
      5.69289266622793113e-12*V01*V02*V06*V11 + 2.42670699692985867e-12*V05*V06*V11 - 
      1.08447647752873986e-12*V012*V07*V11 + 1.64742693740948427e-12*V04*V07*V11 + 
      9.33604454491042186e-13*V03*V08*V11 + 2.46029316174515537e-13*V02*V09*V11 + 6.96299380888316339e-14*V01*V10*V11 + 
      5.48801388429393628e-13*V012*V022*V12 + 2.96756711767891678e-13*V013*V03*V12 - 
      5.06091900069081585e-12*V02*V032*V12 - 1.78082799284098192e-12*V022*V04*V12 - 
      5.96983353673383486e-12*V01*V03*V04*V12 - 3.06467337152966668e-12*V01*V02*V05*V12 + 
      6.64541833429161692e-13*V052*V12 - 6.12971667164543145e-13*V012*V06*V12 + 
      8.64904687778891982e-13*V04*V06*V12 + 6.515886536102613e-13*V03*V07*V12 + 1.6855302949908041e-13*V02*V08*V12 + 
      5.90505816400706376e-14*V01*V09*V12 - 3.74596196056266142e-16*V122 + 
      5.33437021153452755e-14*V013*V02*V13 - 8.53556778292250779e-13*V022*V03*V13 - 
      1.01555261646222982e-12*V01*V032*V13 - 1.04979567258204347e-12*V01*V02*V04*V13 - 
      2.945001473926933e-13*V012*V05*V13 + 4.78694801337721704e-13*V04*V05*V13 + 3.45583666266237063e-13*V03*V06*V13 + 
      1.1908242444271215e-13*V02*V07*V13 + 4.09234391918326829e-14*V01*V08*V13 - 7.16541842251606127e-16*V11*V13 + 
      1.55370006161199832e-15*V014*V14 - 3.25948187528654673e-14*V023*V14 - 
      3.46142178011987339e-13*V01*V02*V03*V14 - 9.8667352484083855e-14*V012*V04*V14 + 
      7.33058474524930906e-14*V042*V14 + 1.6352256203831978e-13*V03*V05*V14 + 5.36870923463537244e-14*V02*V06*V14 + 
      2.46884977078012e-14*V01*V07*V14 - 5.53761160863980495e-16*V10*V14 - 2.58210153096470196e-14*V01*V022*V15 - 
      2.7874118962491446e-14*V012*V03*V15 + 5.13986819450477708e-14*V03*V04*V15 + 2.60977111694806816e-14*V02*V05*V15 + 
      1.14235555772248634e-14*V01*V06*V15 - 3.92931397871210248e-16*V09*V15 - 4.3281644573477096e-15*V012*V02*V16 + 
      7.66455841729221167e-15*V032*V16 + 6.93053164128995936e-15*V02*V04*V16 + 4.72235285289644036e-15*V01*V05*V16 - 
      2.19634375428030821e-16*V08*V16 - 1.84964293049047419e-16*V013*V17 + 2.18324881846082131e-15*V02*V03*V17 + 
      1.32375459700696516e-15*V01*V04*V17 - 1.14226173525499769e-16*V07*V17 + 1.27732587880972601e-16*V022*V18 + 
      3.44998616165397142e-16*V01*V03*V18 - 4.39182970314357737e-17*V06*V18 + 4.49007522981383226e-17*V01*V02*V19 - 
      1.61950982095046374e-17*V05*V19 + 3.01572216927794704e-18*V012*V20 - 3.8427002041421663e-18*V04*V20 - 
      9.35544032958225349e-19*V03*V21 - 1.03204714237511965e-19*V02*V22 - 1.40733701232970862e-20*V01*V23 + 
      1.86155689461601669e-23*V26) + delta8*eps9*
    (9.45532553415107021e-9*V032*V043 + 1.26121885620031857e-9*V02*V044 + 
      1.9236691918831295e-8*V033*V04*V05 + 2.80143356086422153e-8*V02*V03*V042*V05 + 
      5.67319532049064213e-9*V01*V043*V05 + 1.48129746610753902e-8*V02*V032*V052 + 
      6.81024771582047124e-9*V022*V04*V052 + 1.69721695215116268e-8*V01*V03*V04*V052 + 
      2.92333949172506964e-9*V01*V02*V053 - 3.01794207563108192e-10*V054 + 
      3.32166487416964801e-9*V034*V06 + 2.01536861179702234e-8*V02*V032*V04*V06 + 
      2.63380560248332698e-9*V022*V042*V06 + 1.20713226448484733e-8*V01*V03*V042*V06 + 
      9.90150503351099135e-9*V022*V03*V05*V06 + 1.16365122459848362e-8*V01*V032*V05*V06 + 
      1.20922116707821341e-8*V01*V02*V04*V05*V06 + 1.66451337448793449e-9*V012*V052*V06 - 
      2.60533004952591578e-9*V04*V052*V06 + 3.04152605911516103e-10*V023*V062 + 
      4.29268672053267617e-9*V01*V02*V03*V062 + 1.24788195969702198e-9*V012*V04*V062 - 
      8.06569167406602239e-10*V042*V062 - 1.87772943073893864e-9*V03*V05*V062 - 
      1.96002792948003781e-10*V02*V063 + 4.64022141543661848e-9*V02*V033*V07 + 
      6.48595020554330594e-9*V022*V03*V04*V07 + 7.91967443622623238e-9*V01*V032*V04*V07 + 
      4.00204794409174504e-9*V01*V02*V042*V07 + 1.03563623669674131e-9*V023*V05*V07 + 
      8.20429847684633615e-9*V01*V02*V03*V05*V07 + 2.27371485633562394e-9*V012*V04*V05*V07 - 
      1.76603097599484093e-9*V042*V05*V07 - 1.7725841772712883e-9*V03*V052*V07 + 
      1.41450071907299876e-9*V01*V022*V06*V07 + 1.53932493269909523e-9*V012*V03*V06*V07 - 
      2.55804468490423388e-9*V03*V04*V06*V07 - 1.29848555321289188e-9*V02*V05*V06*V07 - 
      2.84730444412418445e-10*V01*V062*V07 + 2.75556597736724661e-10*V012*V02*V072 - 
      4.32782883923761649e-10*V032*V072 - 4.37045606733090645e-10*V02*V04*V072 - 
      2.66544802682082887e-10*V01*V05*V072 + 1.83748806362752038e-9*V022*V032*V08 + 
      1.36783610224156033e-9*V01*V033*V08 + 3.09244777418661657e-10*V023*V04*V08 + 
      4.4295562598826887e-9*V01*V02*V03*V04*V08 + 6.4469062655569227e-10*V012*V042*V08 - 
      2.84375948424868838e-10*V043*V08 + 1.10249283817651223e-9*V01*V022*V05*V08 + 
      1.16187002620730595e-9*V012*V03*V05*V08 - 2.00379019114445587e-9*V03*V04*V05*V08 - 
      5.11059549984255632e-10*V02*V052*V08 + 4.57908455110747334e-10*V012*V02*V06*V08 - 
      7.17308210461874218e-10*V032*V06*V08 - 6.20926322796909474e-10*V02*V04*V06*V08 - 
      4.43164997112489852e-10*V01*V05*V06*V08 + 4.87383378374813935e-11*V013*V07*V08 - 
      5.00958232930441006e-10*V02*V03*V07*V08 - 3.03361359199640337e-10*V01*V04*V07*V08 + 
      1.05185172877049743e-11*V072*V08 - 2.96368428745279302e-11*V022*V082 - 
      8.34852942360073705e-11*V01*V03*V082 + 8.42135875274038724e-12*V06*V082 + 
      2.87676732415761474e-10*V023*V03*V09 + 1.10333888951482431e-9*V01*V02*V032*V09 + 
      5.40495850461942162e-10*V01*V022*V04*V09 + 6.04535618391916272e-10*V012*V03*V04*V09 - 
      5.20240032580919634e-10*V03*V042*V09 + 3.16809430634511105e-10*V012*V02*V05*V09 - 
      5.17637658963436757e-10*V032*V05*V09 - 5.24562163091996322e-10*V02*V04*V05*V09 - 
      1.59044648426037593e-10*V01*V052*V09 + 3.71995253799096194e-11*V013*V06*V09 - 
      3.81897553570740288e-10*V02*V03*V06*V09 - 2.3236488317619325e-10*V01*V04*V06*V09 - 
      6.40105065788137506e-11*V022*V07*V09 - 1.53992753440856139e-10*V01*V03*V07*V09 + 
      1.62711915862272012e-11*V06*V07*V09 - 4.53052324091337561e-11*V01*V02*V08*V09 + 1.27970839761365963e-11*V05*V08*V09 - 
      3.29435978864654287e-12*V012*V092 + 3.40283698966436004e-12*V04*V092 + 
      8.1607890220289046e-12*V024*V10 + 2.46944717864024914e-10*V01*V022*V03*V10 + 
      1.23282523912579785e-10*V012*V032*V10 + 1.44532282360001167e-10*V012*V02*V04*V10 - 
      2.40824437360646892e-10*V032*V04*V10 - 1.02282749004364433e-10*V02*V042*V10 + 
      2.23117494323917926e-11*V013*V05*V10 - 2.46940637439620681e-10*V02*V03*V05*V10 - 
      1.48568020885695002e-10*V01*V04*V05*V10 - 3.69865033114333662e-11*V022*V06*V10 - 
      1.05079828554496227e-10*V01*V03*V06*V10 + 5.3573388311976452e-12*V062*V10 - 
      3.7225474562396066e-11*V01*V02*V07*V10 + 1.05331784243999658e-11*V05*V07*V10 - 
      5.88727892826532548e-12*V012*V08*V10 + 5.79164320309262717e-12*V04*V08*V10 + 
      3.19802563074875501e-12*V03*V09*V10 + 3.7107362635932425e-13*V02*V102 + 
      1.56914581317688077e-11*V01*V023*V11 + 5.45080893329476388e-11*V012*V02*V03*V11 - 
      3.35412399372212098e-11*V033*V11 + 9.46750831829132155e-12*V013*V04*V11 - 
      1.03379823418576005e-10*V02*V03*V04*V11 - 3.16140969679431848e-11*V01*V042*V11 - 
      2.57464068793074689e-11*V022*V05*V11 - 6.13166742838945541e-11*V01*V03*V05*V11 - 
      2.314427988088199e-11*V01*V02*V06*V11 + 6.70145101878702692e-12*V05*V06*V11 - 
      4.39712531127282944e-12*V012*V07*V11 + 4.60832450404364041e-12*V04*V07*V11 + 
      2.63025586772588469e-12*V03*V08*V11 + 7.18500274567017961e-13*V02*V09*V11 + 2.0643658012849413e-13*V01*V10*V11 + 
      5.43484281551877011e-12*V012*V022*V12 + 3.12397292388119128e-12*V013*V03*V12 - 
      2.04535364896567126e-11*V02*V032*V12 - 8.33434307335563745e-12*V022*V04*V12 - 
      2.43186859976911768e-11*V01*V03*V04*V12 - 1.25867461562704572e-11*V01*V02*V05*V12 + 
      1.83811761205944291e-12*V052*V12 - 2.55921528243809983e-12*V012*V06*V12 + 
      2.56527370540687419e-12*V04*V06*V12 + 1.83501369778612031e-12*V03*V07*V12 + 5.16770641723490209e-13*V02*V08*V12 + 
      1.7500680491185295e-13*V01*V09*V12 - 9.51467811463379367e-16*V122 + 
      5.92995523515246024e-13*V013*V02*V13 - 3.63570130250712084e-12*V022*V03*V13 - 
      4.20778969543138954e-12*V01*V032*V13 - 4.48928068754629983e-12*V01*V02*V04*V13 - 
      1.24654835657475017e-12*V012*V05*V13 + 1.37299761393899378e-12*V04*V05*V13 + 
      9.96161857994013652e-13*V03*V06*V13 + 3.52057919143315269e-13*V02*V07*V13 + 1.22784748364545112e-13*V01*V08*V13 - 
      1.79621550299223666e-15*V11*V13 + 1.9421250770149979e-14*V014*V14 - 1.63228933456972691e-13*V023*V14 - 
      1.50547987041411165e-12*V01*V02*V03*V14 - 4.33112388603649435e-13*V012*V04*V14 + 
      2.26134324491859549e-13*V042*V14 + 4.72403651941420687e-13*V03*V05*V14 + 1.68587357962076689e-13*V02*V06*V14 + 
      7.409507624095008e-14*V01*V07*V14 - 1.40971547280422602e-15*V10*V14 - 1.1822917611695111e-13*V01*V022*V15 - 
      1.26164144288755244e-13*V012*V03*V15 + 1.54348581062465391e-13*V03*V04*V15 + 
      7.93638556122369489e-14*V02*V05*V15 + 3.51664367400224497e-14*V01*V06*V15 - 9.87189392041246962e-16*V09*V15 - 
      2.0346072235395216e-14*V012*V02*V16 + 2.32222334842838003e-14*V032*V16 + 
      2.27093261593378277e-14*V02*V04*V16 + 1.45999822301012219e-14*V01*V05*V16 - 5.63749049917588494e-16*V08*V16 - 
      9.24821465245237093e-16*V013*V17 + 6.96548051042948046e-15*V02*V03*V17 + 4.25303946730858563e-15*V01*V04*V17 - 
      2.89206080632549967e-16*V07*V17 + 4.45522688474662043e-16*V022*V18 + 1.12194917104370556e-15*V01*V03*V18 - 
      1.14825296996462988e-16*V06*V18 + 1.53299210271628975e-16*V01*V02*V19 - 4.18163386794490446e-17*V05*V19 + 
      1.05550275924728147e-17*V012*V20 - 1.03975398791882996e-17*V04*V20 - 2.51142640652646812e-18*V03*V21 - 
      2.94870612107177044e-19*V02*V22 - 4.02096289237059606e-20*V01*V23 + 4.65389223654004173e-23*V26) + 
   eps13*(7.83069566138349207e-9*V027 + 3.89470526809316492e-7*V01*V025*V03 + 
      1.4560094596883618e-6*V012*V023*V032 + 6.43388385203861394e-7*V013*V02*V033 - 
      2.25963672458806971e-7*V022*V034 - 7.40421868182868416e-8*V01*V035 + 
      5.75913158068416005e-7*V012*V024*V04 + 1.47733453165000784e-6*V013*V022*V03*V04 + 
      2.2660888081274986e-7*V014*V032*V04 - 6.34316323392156272e-7*V023*V032*V04 - 
      1.09169531821405071e-6*V01*V02*V033*V04 + 1.68546834283441426e-7*V014*V02*V042 - 
      9.93094869534334209e-8*V024*V042 - 1.19255469126537345e-6*V01*V022*V03*V042 - 
      4.7194417974956753e-7*V012*V032*V042 - 2.36977895033304697e-7*V012*V02*V043 + 
      6.15396422160911125e-8*V032*V043 + 2.08755249185163841e-8*V02*V044 + 
      3.0365453335856775e-7*V013*V023*V05 + 2.72437377162079543e-7*V014*V02*V03*V05 - 
      1.87735168274331277e-7*V024*V03*V05 - 9.9695598435458963e-7*V01*V022*V032*V05 - 
      2.57829614588594222e-7*V012*V033*V05 + 2.32669736017950304e-8*V015*V04*V05 - 
      4.78481933545874632e-7*V01*V023*V04*V05 - 1.15909676568249893e-6*V012*V02*V03*V04*V05 + 
      1.04774569359265628e-7*V033*V04*V05 - 1.06365326721047134e-7*V013*V042*V05 + 
      2.22867743488102149e-7*V02*V03*V042*V05 + 4.68070079918040045e-8*V01*V043*V05 - 
      1.77712107617533329e-7*V012*V022*V052 - 8.62823368941701691e-8*V013*V03*V052 + 
      9.55102875060511121e-8*V02*V032*V052 + 6.68835757659441601e-8*V022*V04*V052 + 
      1.18262788679119731e-7*V01*V03*V04*V052 + 2.4114996135405519e-8*V01*V02*V053 - 
      5.87971432306545918e-10*V054 + 6.7598537650620984e-8*V014*V022*V06 - 
      1.67841748918624113e-8*V025*V06 + 1.55672356193189527e-8*V015*V03*V06 - 
      3.39250098452824682e-7*V01*V023*V03*V06 - 4.02710445142131358e-7*V012*V02*V032*V06 + 
      1.85997849341130047e-8*V034*V06 - 3.03600293319488289e-7*V012*V022*V04*V06 - 
      1.4652365639961199e-7*V013*V03*V04*V06 + 1.59493451267026331e-7*V02*V032*V04*V06 + 
      5.38775891387696344e-8*V022*V042*V06 + 9.95998783780060399e-8*V01*V03*V042*V06 - 
      9.0371657699760816e-8*V013*V02*V05*V06 + 9.61234477073195602e-8*V022*V03*V05*V06 + 
      8.35480469489877804e-8*V01*V032*V05*V06 + 1.21508776031097569e-7*V01*V02*V04*V05*V06 + 
      1.52399636306011813e-8*V012*V052*V06 - 5.89896157218003488e-9*V04*V052*V06 - 
      3.96868820344981643e-9*V014*V062 + 7.7188754804050435e-9*V023*V062 + 
      4.31138384904303964e-8*V01*V02*V03*V062 + 1.29330943052344899e-8*V012*V04*V062 - 
      2.43809977936439083e-9*V042*V062 - 4.2243022736965277e-9*V03*V05*V062 - 
      7.07716085533879318e-10*V02*V063 + 6.41358063233063233e-9*V015*V02*V07 - 
      3.72903536990352272e-8*V01*V024*V07 - 1.82159404246676656e-7*V012*V022*V03*V07 - 
      4.37857125942516349e-8*V013*V032*V07 + 3.33510664947870221e-8*V02*V033*V07 - 
      6.66512522719849401e-8*V013*V02*V04*V07 + 7.0436522298911306e-8*V022*V03*V04*V07 + 
      6.1629967050080088e-8*V01*V032*V04*V07 + 4.47039502924786497e-8*V01*V02*V042*V07 - 
      6.89687013435262735e-9*V014*V05*V07 + 1.40319220319051179e-8*V023*V05*V07 + 
      7.55002763583002605e-8*V01*V02*V03*V05*V07 + 2.25165618306410122e-8*V012*V04*V05*V07 - 
      4.3390872573251391e-9*V042*V05*V07 - 3.71581570466195363e-9*V03*V052*V07 + 
      1.93279029537411271e-8*V01*V022*V06*V07 + 1.57967461763094828e-8*V012*V03*V06*V07 - 
      6.22175490190489495e-9*V03*V04*V06*V07 - 3.78129113979179746e-9*V02*V05*V06*V07 - 
      8.58084901628134437e-10*V01*V062*V07 + 3.60138821890595882e-9*V012*V02*V072 - 
      9.78266741482981504e-10*V032*V072 - 1.38948128968561484e-9*V02*V04*V072 - 
      7.52394819580870262e-10*V01*V05*V072 + 2.10774950358283692e-10*V016*V08 - 
      2.45112683534232709e-8*V012*V023*V08 - 3.51761800156262108e-8*V013*V02*V03*V08 + 
      1.96330626303350956e-8*V022*V032*V08 + 1.1216843817911246e-8*V01*V033*V08 - 
      4.47633195393757952e-9*V014*V04*V08 + 8.78358434831316382e-9*V023*V04*V08 + 
      4.92151309619481556e-8*V01*V02*V03*V04*V08 + 7.3841526455329652e-9*V012*V042*V08 - 
      9.28787617588229207e-10*V043*V08 + 1.49915135042101125e-8*V01*V022*V05*V08 + 
      1.22042032643364276e-8*V012*V03*V05*V08 - 4.83269600788884407e-9*V03*V04*V05*V08 - 
      1.47011713658956168e-9*V02*V052*V08 + 6.3955703261807191e-9*V012*V02*V06*V08 - 
      1.72787802715219131e-9*V032*V06*V08 - 2.42668113764751516e-9*V02*V04*V06*V08 - 
      1.33087411285108721e-9*V01*V05*V06*V08 + 7.34425621745087177e-10*V013*V07*V08 - 
      1.55259713298449543e-9*V02*V03*V07*V08 - 9.82807179230375702e-10*V01*V04*V07*V08 + 
      1.66409833207679984e-11*V072*V08 - 1.50941041769118968e-10*V022*V082 - 
      2.70912027194210816e-10*V01*V03*V082 + 1.46477147933849181e-11*V06*V082 - 
      6.3675289625044527e-9*V013*V022*V09 - 2.10996352617063401e-9*V014*V03*V09 + 
      4.57593414678611544e-9*V023*V03*V09 + 1.21308679000675984e-8*V01*V02*V032*V09 + 
      8.77025813340971257e-9*V01*V022*V04*V09 + 7.1834582491458546e-9*V012*V03*V04*V09 - 
      1.4153130144278294e-9*V03*V042*V09 + 4.43374919694538825e-9*V012*V02*V05*V09 - 
      1.2085493846929004e-9*V032*V05*V09 - 1.71860988325774967e-9*V02*V04*V05*V09 - 
      4.64537966320880956e-10*V01*V052*V09 + 5.85119928881510634e-10*V013*V06*V09 - 
      1.23485121005822109e-9*V02*V03*V06*V09 - 7.82527221124742941e-10*V01*V04*V06*V09 - 
      2.74866492876620447e-10*V022*V07*V09 - 4.87679733209617839e-10*V01*V03*V07*V09 + 
      2.64872102510882816e-11*V06*V07*V09 - 1.96132737209951713e-10*V01*V02*V08*V09 + 2.05915231695656882e-11*V05*V08*V09 - 
      1.47194794595128582e-11*V012*V092 + 6.04604398570575428e-12*V04*V092 - 
      6.81918957041506061e-10*V014*V02*V10 + 3.48265568096190404e-10*V024*V10 + 
      3.9527475182641169e-9*V01*V022*V03*V10 + 1.58723639999545373e-9*V012*V032*V10 + 
      2.37547505225306883e-9*V012*V02*V04*V10 - 6.43522757525397723e-10*V032*V04*V10 - 
      4.50952228298101522e-10*V02*V042*V10 + 3.68274912836089829e-10*V013*V05*V10 - 
      7.85069953286181082e-10*V02*V03*V05*V10 - 4.96120765508822204e-10*V01*V04*V05*V10 - 
      1.96309128408017937e-10*V022*V06*V10 - 3.52688219460775253e-10*V01*V03*V06*V10 + 
      9.5316233966908681e-12*V062*V10 - 1.60333731470374093e-10*V01*V02*V07*V10 + 1.68369529618378081e-11*V05*V07*V10 - 
      2.67557676759354174e-11*V012*V08*V10 + 1.0935460066826233e-11*V04*V08*V10 + 5.52161429611184481e-12*V03*V09*V10 + 
      8.9919967036980298e-13*V02*V102 - 2.47970529833274931e-11*V015*V11 + 
      3.89954577624368677e-10*V01*V023*V11 + 9.61437921518691765e-10*V012*V02*V03*V11 - 
      8.91464542226039259e-11*V033*V11 + 1.80678947825540564e-10*V013*V04*V11 - 
      3.82417051477253683e-10*V02*V03*V04*V11 - 1.21402737967798751e-10*V01*V042*V11 - 
      1.1579794533571919e-10*V022*V05*V11 - 2.04845647122264229e-10*V01*V03*V05*V11 - 
      1.06250624924977204e-10*V01*V02*V06*V11 + 1.11490964617701429e-11*V05*V06*V11 - 
      2.0020992866254189e-11*V012*V07*V11 + 8.22649391242126872e-12*V04*V07*V11 + 4.59415296211132609e-12*V03*V08*V11 + 
      1.65438981434644094e-12*V02*V09*V11 + 4.82472259286606351e-13*V01*V10*V11 + 
      1.34548483210522039e-10*V012*V022*V12 + 6.68595979013183176e-11*V013*V03*V12 - 
      7.38062556142881292e-11*V02*V032*V12 - 5.13963980381249043e-11*V022*V04*V12 - 
      9.27015141760798796e-11*V01*V03*V04*V12 - 5.70547794500081007e-11*V01*V02*V05*V12 + 
      2.99860569026803575e-12*V052*V12 - 1.2273583111709115e-11*V012*V06*V12 + 
      5.01003651777715458e-12*V04*V06*V12 + 3.17860203949389117e-12*V03*V07*V12 + 1.2659976078683143e-12*V02*V08*V12 + 
      4.08194929348678229e-13*V01*V09*V12 - 1.4504663090396124e-15*V122 + 
      1.74558201922108011e-11*V013*V02*V13 - 1.87565584625415959e-11*V022*V03*V13 - 
      1.63891079936603135e-11*V01*V032*V13 - 2.39430034807101478e-11*V01*V02*V04*V13 - 
      6.09778721055783964e-12*V012*V05*V13 + 2.51300746588976029e-12*V04*V05*V13 + 
      1.80512891105252166e-12*V03*V06*V13 + 8.16578853091849905e-13*V02*V07*V13 + 2.91207984024564874e-13*V01*V08*V13 - 
      2.69675342393643147e-15*V11*V13 + 7.34123279111669205e-13*V014*V14 - 1.4520930099637216e-12*V023*V14 - 
      7.94578858294750353e-12*V01*V02*V03*V14 - 2.40313008101044368e-12*V012*V04*V14 + 
      4.89671735163281324e-13*V042*V14 + 8.42069244727671752e-13*V03*V05*V14 + 4.31272395984100651e-13*V02*V06*V14 + 
      1.74658263583684653e-13*V01*V07*V14 - 2.15457447914380396e-15*V10*V14 - 8.9781667846007617e-13*V01*V022*V15 - 
      7.37730082826125629e-13*V012*V03*V15 + 3.09546490011871761e-13*V03*V04*V15 + 
      1.89703701486212331e-13*V02*V05*V15 + 8.69839823895684655e-14*V01*V06*V15 - 1.48321425750994692e-15*V09*V15 - 
      1.5980914919437697e-13*V012*V02*V16 + 4.57771546685545971e-14*V032*V16 + 
      6.52843535205289976e-14*V02*V04*V16 + 3.57966221493292314e-14*V01*V05*V16 - 8.70649042677774238e-16*V08*V16 - 
      8.32339318720713384e-15*V013*V17 + 1.84343556902537708e-14*V02*V03*V17 + 1.17610148879670657e-14*V01*V04*V17 - 
      4.36239290396901429e-16*V07*V17 + 1.7370559695040975e-15*V022*V18 + 3.09639273730613213e-15*V01*V03*V18 - 
      1.8281307790162915e-16*V06*V18 + 5.69217559451212504e-16*V01*V02*V19 - 6.42876573435826361e-17*V05*V19 + 
      4.14661798275717718e-17*V012*V20 - 1.80792544048212925e-17*V04*V20 - 4.17426210264222503e-18*V03*V21 - 
      6.63458877241148349e-19*V02*V22 - 9.04716650783384113e-20*V01*V23 + 6.9808383548100626e-23*V26) + 
   delta6*eps10*(-2.74769340381696435e-8*V022*V034 - 1.07639452439872608e-8*V01*V035 - 
      4.89821079515290533e-8*V023*V032*V04 - 1.22930855987967722e-7*V01*V02*V033*V04 - 
      6.21784885258793341e-10*V024*V042 - 9.20991292139751524e-8*V01*V022*V03*V042 - 
      4.92875941492888272e-8*V012*V032*V042 - 1.87580428009933145e-8*V012*V02*V043 + 
      3.8824614260066828e-8*V032*V043 + 7.35917308458240036e-9*V02*V044 - 
      1.14557399132108646e-8*V024*V03*V05 - 9.39409530971155621e-8*V01*V022*V032*V05 - 
      2.85950056049067876e-8*V012*V033*V05 - 2.9389264770917432e-8*V01*V023*V04*V05 - 
      1.01809884577158153e-7*V012*V02*V03*V04*V05 + 7.44574559481591069e-8*V033*V04*V05 - 
      8.71032191546508384e-9*V013*V042*V05 + 1.17074384057691148e-7*V02*V03*V042*V05 + 
      2.38540431258448046e-8*V01*V043*V05 - 1.30756378568003218e-8*V012*V022*V052 - 
      7.29685615792836459e-9*V013*V03*V052 + 5.81283378552467414e-8*V02*V032*V052 + 
      2.89942622476878869e-8*V022*V04*V052 + 6.76905840804596579e-8*V01*V03*V04*V052 + 
      1.18056790875543742e-8*V01*V02*V053 - 7.06794045525907851e-10*V054 - 
      8.08275217575974916e-11*V025*V06 - 2.12515129940433395e-8*V01*V023*V03*V06 - 
      3.38762155989046745e-8*V012*V02*V032*V06 + 1.30392731897766477e-8*V034*V06 - 
      1.95949349048088544e-8*V012*V022*V04*V06 - 1.13983674421738536e-8*V013*V03*V04*V06 + 
      8.48076389399461026e-8*V02*V032*V04*V06 + 1.56786788592745625e-8*V022*V042*V06 + 
      5.10787322326783384e-8*V01*V03*V042*V06 - 5.92992564086557239e-9*V013*V02*V05*V06 + 
      4.24257291634024247e-8*V022*V03*V05*V06 + 4.70787089119660635e-8*V01*V032*V05*V06 + 
      5.20706209726761905e-8*V01*V02*V04*V05*V06 + 6.94713693255276068e-9*V012*V052*V06 - 
      6.40105790975212439e-9*V04*V052*V06 - 2.24298059751685646e-10*V014*V062 + 
      1.84866682635380758e-9*V023*V062 + 1.85948157653287073e-8*V01*V02*V03*V062 + 
      5.42265501444226541e-9*V012*V04*V062 - 2.22130745594143576e-9*V042*V062 - 
      4.63736991429361019e-9*V03*V05*V062 - 5.54580846146333209e-10*V02*V063 - 
      1.63653427331583779e-9*V01*V024*V07 - 1.17421299435771891e-8*V012*V022*V03*V07 - 
      3.20093405070451445e-9*V013*V032*V07 + 1.87592204069923935e-8*V02*V033*V07 - 
      4.00733871205393148e-9*V013*V02*V04*V07 + 2.82652039123999253e-8*V022*V03*V04*V07 + 
      3.2547018463495343e-8*V01*V032*V04*V07 + 1.75210095995387451e-8*V01*V02*V042*V07 - 
      3.83623342355446308e-10*V014*V05*V07 + 4.60317291956745984e-9*V023*V05*V07 + 
      3.41071335553664913e-8*V01*V02*V03*V05*V07 + 9.62912321222397202e-9*V012*V04*V05*V07 - 
      4.42951313977359782e-9*V042*V05*V07 - 4.25973443487603526e-9*V03*V052*V07 + 
      6.34079407561570895e-9*V01*V022*V06*V07 + 6.61773317046439941e-9*V012*V03*V06*V07 - 
      6.44617457894883118e-9*V03*V04*V06*V07 - 3.34149468111654351e-9*V02*V05*V06*V07 - 
      7.42741450773490953e-10*V01*V062*V07 + 1.21142067789604728e-9*V012*V02*V072 - 
      1.06680612584732195e-9*V032*V072 - 1.14702018027081605e-9*V02*V04*V072 - 
      6.77478100005880002e-10*V01*V05*V072 - 1.14891137851247821e-9*V012*V023*V08 - 
      1.92910950964172253e-9*V013*V02*V03*V08 + 8.11039841871320418e-9*V022*V032*V08 + 
      5.76365642877216439e-9*V01*V033*V08 - 2.22498727108904513e-10*V014*V04*V08 + 
      1.91415314893434211e-9*V023*V04*V08 + 1.96330381410626959e-8*V01*V02*V03*V04*V08 + 
      2.86591172869538992e-9*V012*V042*V08 - 8.01282368730101966e-10*V043*V08 + 
      4.97306318106403491e-9*V01*V022*V05*V08 + 5.05041475517903175e-9*V012*V03*V05*V08 - 
      5.05492119438749656e-9*V03*V04*V05*V08 - 1.31604917227658524e-9*V02*V052*V08 + 
      2.08191788365372175e-9*V012*V02*V06*V08 - 1.82019520578530927e-9*V032*V06*V08 - 
      1.79627438518836763e-9*V02*V04*V06*V08 - 1.15840113098896455e-9*V01*V05*V06*V08 + 
      2.25606373851185909e-10*V013*V07*V08 - 1.32165695838759844e-9*V02*V03*V07*V08 - 
      8.07434980281941008e-10*V01*V04*V07*V08 + 2.17051692867928172e-11*V072*V08 - 
      8.98487444929676867e-11*V022*V082 - 2.24134068354309549e-10*V01*V03*V082 + 
      1.81331803232160107e-11*V06*V082 - 2.52693778020575406e-10*V013*V022*V09 - 
      9.09225276055341415e-11*V014*V03*V09 + 1.3370593591798383e-9*V023*V03*V09 + 
      4.85068722880645286e-9*V01*V02*V032*V09 + 2.51833886420762107e-9*V01*V022*V04*V09 + 
      2.70947346742516175e-9*V012*V03*V04*V09 - 1.36161805484418992e-9*V03*V042*V09 + 
      1.43096367560202802e-9*V012*V02*V05*V09 - 1.29851267719888812e-9*V032*V05*V09 - 
      1.40116539159537664e-9*V02*V04*V05*V09 - 4.11291740294556219e-10*V01*V052*V09 + 
      1.74891630887711094e-10*V013*V06*V09 - 1.02452104590438096e-9*V02*V03*V06*V09 - 
      6.28379847623859237e-10*V01*V04*V06*V09 - 1.78484697920670409e-10*V022*V07*V09 - 
      4.08092701013585716e-10*V01*V03*V07*V09 + 3.3953132833433193e-11*V06*V07*V09 - 1.27888002532006643e-10*V01*V02*V08*V09 + 
      2.6678956657570525e-11*V05*V08*V09 - 9.36810066023675533e-12*V012*V092 + 
      7.3042193898542391e-12*V04*V092 - 2.1254616842852137e-11*V014*V02*V10 + 
      5.34565056721994546e-11*V024*V10 + 1.16830609307205209e-9*V01*V022*V03*V10 + 
      5.7084323796536825e-10*V012*V032*V10 + 6.85449851410095157e-10*V012*V02*V04*V10 - 
      6.33606321810949201e-10*V032*V04*V10 - 3.07470334617415872e-10*V02*V042*V10 + 
      1.06936736097720667e-10*V013*V05*V10 - 6.62203685910129601e-10*V02*V03*V05*V10 - 
      4.02223295614672744e-10*V01*V04*V05*V10 - 1.13976288763887216e-10*V022*V06*V10 - 
      2.86328062844170295e-10*V01*V03*V06*V10 + 1.16480856420793068e-11*V062*V10 - 
      1.04988399583446367e-10*V01*V02*V07*V10 + 2.19163995634344966e-11*V05*V07*V10 - 
      1.69271171359636885e-11*V012*V08*V10 + 1.28132665874286097e-11*V04*V08*V10 + 
      6.86706159496541213e-12*V03*V09*V10 + 8.64949181561006468e-13*V02*V102 - 
      5.9040602341255936e-13*V015*V11 + 7.9301443030414151e-11*V01*V023*V11 + 
      2.6594713548899463e-10*V012*V02*V03*V11 - 8.87299917031129082e-11*V033*V11 + 
      4.73697993641643616e-11*V013*V04*V11 - 2.90710931892431905e-10*V02*V03*V04*V11 - 
      8.95415287043420387e-11*V01*V042*V11 - 7.38304027027456823e-11*V022*V05*V11 - 
      1.6709053987121586e-10*V01*V03*V05*V11 - 6.70736015883760654e-11*V01*V02*V06*V11 + 1.41806766887971536e-11*V05*V06*V11 - 
      1.26383881868897513e-11*V012*V07*V11 + 9.92787536971747346e-12*V04*V07*V11 + 
      5.68022819682475523e-12*V03*V08*V11 + 1.63246143178152037e-12*V02*V09*V11 + 4.7344232554941086e-13*V01*V10*V11 + 
      2.78562884046415178e-11*V012*V022*V12 + 1.62444520441739797e-11*V013*V03*V12 - 
      5.77149632529734132e-11*V02*V032*V12 - 2.6944414439909714e-11*V022*V04*V12 - 
      6.92962743396114235e-11*V01*V03*V04*V12 - 3.64699830497891316e-11*V01*V02*V05*V12 + 
      3.87536377323733394e-12*V052*V12 - 7.53905826800908323e-12*V012*V06*V12 + 
      5.76198889094579598e-12*V04*V06*V12 + 3.95150326642972839e-12*V03*V07*V12 + 1.21099716344026668e-12*V02*V08*V12 + 
      4.00943552284233181e-13*V01*V09*V12 - 1.91905668480552483e-15*V122 + 
      3.26277012938519646e-12*V013*V02*V13 - 1.10242787871679341e-11*V022*V03*V13 - 
      1.21615132465506972e-11*V01*V032*V13 - 1.36914823893645027e-11*V01*V02*V04*V13 - 
      3.70892250064880374e-12*V012*V05*V13 + 3.00593384548658181e-12*V04*V05*V13 + 
      2.18822945116350435e-12*V03*V06*V13 + 8.0426113589143413e-13*V02*V07*V13 + 2.83733661829447263e-13*V01*V08*V13 - 
      3.5950044222355905e-15*V11*V13 + 1.16527504620899874e-13*V014*V14 - 5.70142157529630388e-13*V023*V14 - 
      4.61744861167641976e-12*V01*V02*V03*V14 - 1.3414535353382164e-12*V012*V04*V14 + 
      5.26901714422590449e-13*V042*V14 + 1.03479343769192604e-12*V03*V05*V14 + 4.02694965934368117e-13*V02*V06*V14 + 
      1.70833668881899522e-13*V01*V07*V14 - 2.84703099736483097e-15*V10*V14 - 3.89072390428671245e-13*V01*V022*V15 - 
      4.00077765865089566e-13*V012*V03*V15 + 3.51758725996098794e-13*V03*V04*V15 + 
      1.84741598720858294e-13*V02*V05*V15 + 8.28519403972961318e-14*V01*V06*V15 - 1.97695220033361111e-15*V09*V15 - 
      6.79743776955249263e-14*V012*V02*V16 + 5.30733593768815591e-14*V032*V16 + 
      5.64663818975602804e-14*V02*V04*V16 + 3.43795678100096272e-14*V01*V05*V16 - 1.14444869229479259e-15*V08*V16 - 
      3.23687512835832983e-15*V013*V17 + 1.69279186966391785e-14*V02*V03*V17 + 1.04222688009763788e-14*V01*V04*V17 - 
      5.80985577516217115e-16*V07*V17 + 1.18497776438161466e-15*V022*V18 + 2.76682456624020715e-15*V01*V03*V18 - 
      2.36325392394261166e-16*V06*V18 + 4.01091048513966957e-16*V01*V02*V19 - 8.50500667784587243e-17*V05*V19 + 
      2.81467402465941724e-17*V012*V20 - 2.20750862791145724e-17*V04*V20 - 5.28421540105702499e-18*V03*V21 - 
      6.63458877241148349e-19*V02*V22 - 9.04716650783384113e-20*V01*V23 + 9.30778447308008347e-23*V26) + 
   delta2*eps12*(2.67650730613693577e-11*V027 + 1.45976708476708477e-7*V01*V025*V03 + 
      7.0347310654023617e-7*V012*V023*V032 + 3.42178076553076553e-7*V013*V02*V033 - 
      3.084430776406004e-7*V022*V034 - 1.08118735615307161e-7*V01*V035 + 
      2.37633701175367842e-7*V012*V024*V04 + 6.93810915165081832e-7*V013*V022*V03*V04 + 
      1.13156037635204302e-7*V014*V032*V04 - 7.43688622196506832e-7*V023*V032*V04 - 
      1.44359805672247316e-6*V01*V02*V033*V04 + 7.64811962728629395e-8*V014*V02*V042 - 
      8.46192910475220622e-8*V024*V042 - 1.38524165905300651e-6*V01*V022*V03*V042 - 
      6.05303266276509741e-7*V012*V032*V042 - 2.74664734491634001e-7*V012*V02*V043 + 
      1.11694089518080728e-7*V032*V043 + 3.25142589196534057e-8*V02*V044 + 
      1.18629495076254336e-7*V013*V023*V05 + 1.16106886940220274e-7*V014*V02*V03*V05 - 
      1.89987803884635766e-7*V024*V03*V05 - 1.18823842681875478e-6*V01*V022*V032*V05 - 
      3.31736914716460702e-7*V012*V033*V05 + 9.63542630209296876e-9*V015*V04*V05 - 
      4.83504726572034514e-7*V01*V023*V04*V05 - 1.34919420843425862e-6*V012*V02*V03*V04*V05 + 
      1.95378476733736308e-7*V033*V04*V05 - 1.21287286511449093e-7*V013*V042*V05 + 
      3.72522518500135835e-7*V02*V03*V042*V05 + 7.73089389403570869e-8*V01*V043*V05 - 
      1.8487438634533931e-7*V012*V022*V052 - 9.78097825560769072e-8*V013*V03*V052 + 
      1.65316922135894928e-7*V02*V032*V052 + 1.01740062258203634e-7*V022*V04*V052 + 
      2.00321126014137137e-7*V01*V03*V04*V052 + 3.76852254599081583e-8*V01*V02*V053 - 
      1.16437164809287144e-9*V054 + 2.40283443408443408e-8*V014*V022*V06 - 
      1.2002167247946115e-8*V025*V06 + 5.90169861003194337e-9*V015*V03*V06 - 
      3.48537536633261034e-7*V01*V023*V03*V06 - 4.65194063466705857e-7*V012*V02*V032*V06 + 
      3.48391497335826987e-8*V034*V06 - 3.12553644628662136e-7*V012*V022*V04*V06 - 
      1.64529391194015377e-7*V013*V03*V04*V06 + 2.69770771364478109e-7*V02*V032*V04*V06 + 
      7.7090098636797543e-8*V022*V042*V06 + 1.65806390843634817e-7*V01*V03*V042*V06 - 
      9.2022791402022261e-8*V013*V02*V05*V06 + 1.48557661675356213e-7*V022*V03*V05*V06 + 
      1.41952602899461084e-7*V01*V032*V05*V06 + 1.85640328809827055e-7*V01*V02*V04*V05*V06 + 
      2.34643216241922976e-8*V012*V052*V06 - 1.14432768100795188e-8*V04*V052*V06 - 
      3.87938929240866683e-9*V014*V062 + 1.00510417097837275e-8*V023*V062 + 
      6.64465440764529479e-8*V01*V02*V03*V062 + 1.96674517835845123e-8*V012*V04*V062 - 
      4.58348028122747872e-9*V042*V062 - 8.278219783333639e-9*V03*V05*V062 - 
      1.24683518334632837e-9*V02*V063 + 2.04752808919475586e-9*V015*V02*V07 - 
      3.13823433674672781e-8*V01*V024*V07 - 1.84926089044246724e-7*V012*V022*V03*V07 - 
      4.810012569626832e-8*V013*V032*V07 + 5.73194526254322907e-8*V02*V033*V07 - 
      6.68356487246543269e-8*V013*V02*V04*V07 + 1.0676507036741326e-7*V022*V03*V04*V07 + 
      1.03432916432419505e-7*V01*V032*V04*V07 + 6.71412123632643145e-8*V01*V02*V042*V07 - 
      6.69646946126287863e-9*V014*V05*V07 + 1.90859584989206258e-8*V023*V05*V07 + 
      1.16939449769792707e-7*V01*V02*V03*V05*V07 + 3.4238071677382654e-8*V012*V04*V05*V07 - 
      8.30823257228058229e-9*V042*V05*V07 - 7.33675818986803955e-9*V03*V052*V07 + 
      2.65804099641751113e-8*V01*V022*V06*V07 + 2.40101095250355247e-8*V012*V03*V06*V07 - 
      1.20455061030964279e-8*V03*V04*V06*V07 - 6.79398788954425902e-9*V02*V05*V06*V07 - 
      1.53869034002724677e-9*V01*V062*V07 + 4.96562880025493872e-9*V012*V02*V072 - 
      1.92466642630860559e-9*V032*V072 - 2.45920200644826241e-9*V02*V04*V072 - 
      1.35724029323924052e-9*V01*V05*V072 + 6.02214143880810547e-11*V016*V08 - 
      2.13611851300781039e-8*V012*V023*V08 - 3.42695272229585955e-8*V013*V02*V03*V08 + 
      3.02792194681157412e-8*V022*V032*V08 + 1.88389345300225058e-8*V01*V033*V08 - 
      4.26361709807379742e-9*V014*V04*V08 + 1.12167139606465727e-8*V023*V04*V08 + 
      7.47344361790665714e-8*V01*V02*V03*V04*V08 + 1.10687472366313311e-8*V012*V042*V08 - 
      1.72772347997289948e-9*V043*V08 + 2.06640487907188666e-8*V01*V022*V05*V08 + 
      1.85082141198720689e-8*V012*V03*V05*V08 - 9.37950419429437389e-9*V03*V04*V05*V08 - 
      2.65050454855617483e-9*V02*V052*V08 + 8.80299398332571031e-9*V012*V02*V06*V08 - 
      3.38269656824215663e-9*V032*V06*V08 - 4.22589433929602085e-9*V02*V04*V06*V08 - 
      2.38981532068142626e-9*V01*V05*V06*V08 + 9.90515159221750045e-10*V013*V07*V08 - 
      2.79267731905870259e-9*V02*V03*V07*V08 - 1.74370892281823102e-9*V01*V04*V07*V08 + 
      3.31867925608791034e-11*V072*V08 - 2.41409229250683865e-10*V022*V082 - 
      4.84349766673563639e-10*V01*V03*V082 + 2.89712894379706975e-11*V06*V082 - 
      5.41549924975170073e-9*V013*V022*V09 - 1.93062769655906911e-9*V014*V03*V09 + 
      6.18950644102830038e-9*V023*V03*V09 + 1.85179574839370135e-8*V01*V02*V032*V09 + 
      1.17828203493836249e-8*V01*V022*V04*V09 + 1.07257156401284082e-8*V012*V03*V04*V09 - 
      2.70359820304872567e-9*V03*V042*V09 + 6.07914170003273737e-9*V012*V02*V05*V09 - 
      2.37460104972733882e-9*V032*V05*V09 - 3.04046225768207461e-9*V02*V04*V05*V09 - 
      8.36430987272470724e-10*V01*V052*V09 + 7.86772810235201405e-10*V013*V06*V09 - 
      2.21263297880806407e-9*V02*V03*V06*V09 - 1.38398602015655266e-9*V01*V04*V06*V09 - 
      4.4520846148331938e-10*V022*V07*V09 - 8.72931442629041828e-10*V01*V03*V07*V09 + 
      5.26721248135003586e-11*V06*V07*V09 - 3.19721355448360149e-10*V01*V02*V08*V09 + 4.10606581135547258e-11*V05*V08*V09 - 
      2.38199168900336927e-11*V012*V092 + 1.18839211140883258e-11*V04*V092 - 
      5.49077601773680205e-10*V014*V02*V10 + 3.86984390179204898e-10*V024*V10 + 
      5.38127123739438841e-9*V01*V022*V03*V10 + 2.35425271167935375e-9*V012*V032*V10 + 
      3.1997553842434887e-9*V012*V02*V04*V10 - 1.24450308167573351e-9*V032*V04*V10 - 
      7.73375929443341844e-10*V02*V042*V10 + 4.92008163903447967e-10*V013*V05*V10 - 
      1.41186771676983161e-9*V02*V03*V05*V10 - 8.79027095323632989e-10*V01*V04*V05*V10 - 
      3.12777136181320367e-10*V022*V06*V10 - 6.28829694329919415e-10*V01*V03*V06*V10 + 
      1.88137017465615999e-11*V062*V10 - 2.61467955813591311e-10*V01*V02*V07*V10 + 
      3.36011857984340028e-11*V05*V07*V10 - 4.32819850759256635e-11*V012*V08*V10 + 
      2.13961039994227219e-11*V04*V08*V10 + 1.09996421190625787e-11*V03*V09*V10 + 1.63674936427126164e-12*V02*V102 - 
      1.85977897374956198e-11*V015*V11 + 4.59321643964406406e-10*V01*V023*V11 + 
      1.28685984453044567e-9*V012*V02*V03*V11 - 1.73965530086105601e-10*V033*V11 + 
      2.37428674915237523e-10*V013*V04*V11 - 6.74434524894710797e-10*V02*V03*V04*V11 - 
      2.11500334074548793e-10*V01*V042*V11 - 1.87388333343387057e-10*V022*V05*V11 - 
      3.65495445156227141e-10*V01*V03*V05*V11 - 1.72407649831470694e-10*V01*V02*V06*V11 + 2.21675458077228265e-11*V05*V06*V11 - 
      3.23547309901701805e-11*V012*V07*V11 + 1.61689362500497414e-11*V04*V07*V11 + 
      9.14425764956572053e-12*V03*V08*V11 + 3.02273164582402388e-12*V02*V09*V11 + 8.81698213101695296e-13*V01*V10*V11 + 
      1.59805819837102087e-10*V012*V022*V12 + 8.63507651742408364e-11*V013*V03*V12 - 
      1.32009755806277339e-10*V02*V032*V12 - 8.03257382924611658e-11*V022*V04*V12 - 
      1.62859423095692768e-10*V01*V03*V04*V12 - 9.27706260841776561e-11*V01*V02*V05*V12 + 
      5.98372199130302705e-12*V052*V12 - 1.97702321500602692e-11*V012*V06*V12 + 
      9.77437966473708316e-12*V04*V06*V12 + 6.3322572941193529e-12*V03*V07*V12 + 2.30242322547588044e-12*V02*V08*V12 + 
      7.46025996387384221e-13*V01*V09*V12 - 2.89767620050883711e-15*V122 + 
      2.02563645532664281e-11*V013*V02*V13 - 3.02249688860715764e-11*V022*V03*V13 - 
      2.89074219856099494e-11*V01*V032*V13 - 3.81567556720352671e-11*V01*V02*V04*V13 - 
      9.79910305465500131e-12*V012*V05*V13 + 4.93805918318293845e-12*V04*V05*V13 + 
      3.58232318765102169e-12*V03*V06*V13 + 1.49168263991744812e-12*V02*V07*V13 + 5.31637941831333841e-13*V01*V08*V13 - 
      5.39349176926201655e-15*V11*V13 + 8.15692532346299116e-13*V014*V14 - 2.0394039642059269e-12*V023*V14 - 
      1.27822904068819101e-11*V01*V02*V03*V14 - 3.80462302587238088e-12*V012*V04*V14 + 
      9.43493087903362422e-13*V042*V14 + 1.6761637137509049e-12*V03*V05*V14 + 7.81357932304635833e-13*V02*V06*V14 + 
      3.18991229225688745e-13*V01*V07*V14 - 4.30350651164704879e-15*V10*V14 - 1.2922900262457796e-12*V01*V022*V15 - 
      1.16469240868589424e-12*V012*V03*V15 + 6.0699923045643279e-13*V03*V04*V15 + 3.46354183280487579e-13*V02*V05*V15 + 
      1.58266004160357444e-13*V01*V06*V15 - 2.96641343640904745e-15*V09*V15 - 2.29170759087769752e-13*V012*V02*V16 + 
      9.0756148202973631e-14*V032*V16 + 1.1655806393888189e-13*V02*V04*V16 + 6.52324830992174169e-14*V01*V05*V16 - 
      1.73765241233313247e-15*V08*V16 - 1.16527504620899874e-14*V013*V17 + 3.35629772626173653e-14*V02*V03*V17 + 
      2.11142771959826184e-14*V01*V04*V17 - 8.72463502182956469e-16*V07*V17 + 2.84623858336452642e-15*V022*V18 + 
      5.59838663504758089e-15*V01*V03*V18 - 3.6390719416676987e-16*V06*V18 + 9.40905316814719477e-16*V01*V02*V19 - 
      1.28560236076318882e-16*V05*V19 + 6.78537488087538085e-17*V012*V20 - 3.55955740047107016e-17*V04*V20 - 
      8.33344559443806033e-18*V03*V21 - 1.21634127494210531e-18*V02*V22 - 1.65864719310287087e-19*V01*V23 + 
      1.39616767096201252e-22*V26) + delta4*eps11*
    (-1.52806918959560572e-7*V022*V034 - 5.68856203558000944e-8*V01*V035 - 
      3.15876669022093859e-7*V023*V032*V04 - 6.958119979804348e-7*V01*V02*V033*V04 - 
      2.12135350797297057e-8*V024*V042 - 5.88091694777424625e-7*V01*V022*V03*V042 - 
      2.84453623063372519e-7*V012*V032*V042 - 1.17619271009793886e-7*V012*V02*V043 + 
      8.86966561558005104e-8*V032*V043 + 2.14460056215349951e-8*V02*V044 - 
      7.48091926548262786e-8*V024*V03*V05 - 5.39058962601990924e-7*V01*V022*V032*V05 - 
      1.58909001373938738e-7*V012*V033*V05 - 1.89526001413256315e-7*V01*V023*V04*V05 - 
      5.98055205770687797e-7*V012*V02*V03*V04*V05 + 1.61506258237866329e-7*V033*V04*V05 - 
      5.25955727480781947e-8*V013*V042*V05 + 2.7817888422773766e-7*V02*V03*V042*V05 + 
      5.71626170411310686e-8*V01*V043*V05 - 7.79750415933013972e-8*V012*V022*V052 - 
      4.30718512656148822e-8*V013*V03*V052 + 1.29951972063580657e-7*V02*V032*V052 + 
      7.14529200788832413e-8*V022*V04*V052 + 1.54251296369004045e-7*V01*V03*V04*V052 + 
      2.7666147109001462e-8*V01*V02*V053 - 1.13709972354473621e-9*V054 - 
      2.88534984820906597e-9*V025*V06 - 1.37982768361308666e-7*V01*V023*V03*V06 - 
      2.02380681221523114e-7*V012*V02*V032*V06 + 2.86427995168255253e-8*V034*V06 - 
      1.2455520353123839e-7*V012*V022*V04*V06 - 6.98371886039661483e-8*V013*V03*V04*V06 + 
      2.02138696129166647e-7*V02*V032*V04*V06 + 4.76440170839494897e-8*V022*V042*V06 + 
      1.22766511580894927e-7*V01*V03*V042*V06 - 3.73179340947003568e-8*V013*V02*V05*V06 + 
      1.04883064752468015e-7*V022*V03*V05*V06 + 1.08613935887695355e-7*V01*V032*V05*V06 + 
      1.29739082094093604e-7*V01*V02*V04*V05*V06 + 1.67949996998712611e-8*V012*V052*V06 - 
      1.07734910420858212e-8*V04*V052*V06 - 1.49676361306846834e-9*V014*V062 + 
      5.84866874828278493e-9*V023*V062 + 4.6490749479958687e-8*V01*V02*V03*V062 + 
      1.36335308620654137e-8*V012*V04*V062 - 4.07075243007609874e-9*V042*V062 - 
      7.81909983324219675e-9*V03*V05*V062 - 1.05468946841692334e-9*V02*V063 - 
      1.06870275221180398e-8*V01*V024*V07 - 7.26839521385117401e-8*V012*V022*V03*V07 - 
      1.97934519015381916e-8*V013*V032*V07 + 4.36427528289873252e-8*V02*V033*V07 - 
      2.5795429568918131e-8*V013*V02*V04*V07 + 7.24637097784827881e-8*V022*V03*V04*V07 + 
      7.71187361798493556e-8*V01*V032*V04*V07 + 4.5233620195199384e-8*V01*V02*V042*V07 - 
      2.55167860404399464e-9*V014*V05*V07 + 1.21804939863605216e-8*V023*V05*V07 + 
      8.29641982955464781e-8*V01*V02*V03*V05*V07 + 2.38538285080762939e-8*V012*V04*V05*V07 - 
      7.64283130640170456e-9*V042*V05*V07 - 7.0292409799740354e-9*V03*V052*V07 + 
      1.69392668103744883e-8*V01*V022*V06*V07 + 1.6595678076758996e-8*V012*V03*V06*V07 - 
      1.11310141599262844e-8*V03*V04*V06*V07 - 5.96678959169407956e-9*V02*V05*V06*V07 - 
      1.34126360695585486e-9*V01*V062*V07 + 3.18336816442698659e-9*V012*V02*V072 - 
      1.80743274343053554e-9*V032*V072 - 2.10266307800613464e-9*V02*V04*V072 - 
      1.19842672976589113e-9*V01*V05*V072 - 7.53560510796738621e-9*V012*V023*V08 - 
      1.27980626820787885e-8*V013*V02*V03*V08 + 2.07894937321814828e-8*V022*V032*V08 + 
      1.3921933471288758e-8*V01*V033*V08 - 1.54652640647038406e-9*V014*V04*V08 + 
      6.26249873969185865e-9*V023*V04*V08 + 5.07187641611914184e-8*V01*V02*V03*V04*V08 + 
      7.44622710619452884e-9*V012*V042*V08 - 1.50432993014089171e-9*V043*V08 + 
      1.32561219817359938e-8*V01*V022*V05*V08 + 1.27619496246252961e-8*V012*V03*V05*V08 - 
      8.70482219950651634e-9*V03*V04*V05*V08 - 2.34132189036775429e-9*V02*V052*V08 + 
      5.60267195480498943e-9*V012*V02*V06*V08 - 3.14457965704656587e-9*V032*V06*V08 - 
      3.49886763160363477e-9*V02*V04*V06*V08 - 2.08946769759537164e-9*V01*V05*V06*V08 + 
      6.17035147718537668e-10*V013*V07*V08 - 2.4147989327076599e-9*V02*V03*V07*V08 - 
      1.49030395092540559e-9*V01*V04*V07*V08 + 3.29892849746113782e-11*V072*V08 - 
      1.85769012528000428e-10*V022*V082 - 4.15060292854459985e-10*V01*V03*V082 + 
      2.8347059314050546e-11*V06*V082 - 1.82258339427457075e-9*V013*V022*V09 - 
      6.67749212479604636e-10*V014*V03*V09 + 3.77339507269355975e-9*V023*V03*V09 + 
      1.25618347953540254e-8*V01*V02*V032*V09 + 7.14196990737920524e-9*V01*V022*V04*V09 + 
      7.14037566314455689e-9*V012*V03*V04*V09 - 2.43543286477891104e-9*V03*V042*V09 + 
      3.85955520133643137e-9*V012*V02*V05*V09 - 2.22293375126654135e-9*V032*V05*V09 - 
      2.59506546555557269e-9*V02*V04*V05*V09 - 7.3581687943856921e-10*V01*V052*V09 + 
      4.8665825669129732e-10*V013*V06*V09 - 1.89847107157496911e-9*V02*V03*V06*V09 - 
      1.17490485564995988e-9*V01*V04*V06*V09 - 3.51426447562011315e-10*V022*V07*V09 - 
      7.50335709632982461e-10*V01*V03*V07*V09 + 5.20763182348270563e-11*V06*V07*V09 - 2.5303234703178275e-10*V01*V02*V08*V09 + 
      4.07778441576321774e-11*V05*V08*V09 - 1.8695582881471011e-11*V012*V092 + 
      1.15072965190096386e-11*V04*V092 - 1.71217746789642214e-10*V014*V02*V10 + 
      1.92113878170659558e-10*V024*V10 + 3.29879529180663194e-9*V01*V022*V03*V10 + 
      1.54202785290627957e-9*V012*V032*V10 + 1.94591185098659104e-9*V012*V02*V04*V10 - 
      1.13024061335515152e-9*V032*V04*V10 - 6.21893994910565973e-10*V02*V042*V10 + 
      3.01718378928932375e-10*V013*V05*V10 - 1.21968969858732122e-9*V02*V03*V05*V10 - 
      7.49404778180590171e-10*V01*V04*V05*V10 - 2.38893190799719848e-10*V022*V06*V10 - 
      5.35874668934533298e-10*V01*V03*V06*V10 + 1.83359842204111559e-11*V062*V10 - 
      2.0718693649376069e-10*V01*V02*V07*V10 + 3.34199798567538781e-11*V05*V07*V10 - 
      3.3924902962824983e-11*V012*V08*V10 + 2.05328632884404755e-11*V04*V08*V10 + 1.07581102072366036e-11*V03*V09*V10 + 
      1.47070404889579494e-12*V02*V102 - 5.31365421071303424e-12*V015*V11 + 
      2.48358769884384882e-10*V01*V023*V11 + 7.71874861251565881e-10*V012*V02*V03*V11 - 
      1.58559391707317819e-10*V033*V11 + 1.40032212088693673e-10*V013*V04*V11 - 
      5.61357991571373525e-10*V02*V03*V04*V11 - 1.7433030741664228e-10*V01*V042*V11 - 
      1.47512793895455299e-10*V022*V05*V11 - 3.12222269925821467e-10*V01*V03*V05*V11 - 
      1.35159910425839623e-10*V01*V02*V06*V11 + 2.18922952159847789e-11*V05*V06*V11 - 
      2.5333763872467914e-11*V012*V07*V11 + 1.56536001965007288e-11*V04*V07*V11 + 8.92813645643280211e-12*V03*V08*V11 + 
      2.73641576630246169e-12*V02*V09*V11 + 7.97100635634540666e-13*V01*V10*V11 + 
      8.70369827014528024e-11*V012*V022*V12 + 4.96329484681952862e-11*V013*V03*V12 - 
      1.1096220648949361e-10*V02*V032*V12 - 5.91343175830674534e-11*V022*V04*V12 - 
      1.34862071672957394e-10*V01*V03*V04*V12 - 7.31229327782623809e-11*V01*V02*V05*V12 + 
      5.9457389675347873e-12*V052*V12 - 1.53633191449469276e-11*V012*V06*V12 + 
      9.3275632375441689e-12*V04*V06*V12 + 6.19310925351062037e-12*V03*V07*V12 + 2.06544449972002528e-12*V02*V08*V12 + 
      6.74624177338058683e-13*V01*V09*V12 - 2.89121865360783184e-15*V122 + 
      1.06816879235824884e-11*V013*V02*V13 - 2.30842065612378769e-11*V022*V03*V13 - 
      2.38773642772143671e-11*V01*V032*V13 - 2.88804264470394409e-11*V01*V02*V04*V13 - 
      7.59812044951786155e-12*V012*V05*V13 + 4.77430004109124123e-12*V04*V05*V13 + 
      3.47710866212780649e-12*V03*V06*V13 + 1.34988740448089142e-12*V02*V07*V13 + 4.7964793038172923e-13*V01*V08*V13 - 
      5.39335103556078358e-15*V11*V13 + 4.07846266173149558e-13*V014*V14 - 1.36409933028385478e-12*V023*V14 - 
      9.72954723225390703e-12*V01*V02*V03*V14 - 2.85819773119901505e-12*V012*V04*V14 + 
      8.79942667404491114e-13*V042*V14 + 1.63558710494722192e-12*V03*V05*V14 + 6.95851218173700222e-13*V02*V06*V14 + 
      2.88122330608983782e-13*V01*V07*V14 - 4.29233219484547072e-15*V10*V14 - 8.92212260380690033e-13*V01*V022*V15 - 
      8.66576209364092061e-13*V012*V03*V15 + 5.76254546085077975e-13*V03*V04*V15 + 
      3.12876249383043852e-13*V02*V05*V15 + 1.418321277710942e-13*V01*V06*V15 - 2.96627270270781448e-15*V09*V15 - 
      1.5731213123821483e-13*V012*V02*V16 + 8.6747750819641693e-14*V032*V16 + 
      1.01055643603636294e-13*V02*V04*V16 + 5.86680601292778003e-14*V01*V05*V16 - 1.73047164276784065e-15*V08*V16 - 
      7.76850030805999158e-15*V013*V17 + 2.96757113864180916e-14*V02*V03*V17 + 1.84515955686548097e-14*V01*V04*V17 - 
      8.72322768481723498e-16*V07*V17 + 2.28069015255260208e-15*V022*V18 + 4.90597682498136425e-15*V01*V03*V18 - 
      3.60579847373333201e-16*V06*V18 + 7.61972468104227953e-16*V01*V02*V19 - 1.28419502375085912e-16*V05*V19 + 
      5.42829990470030468e-17*V012*V20 - 3.45802808743871261e-17*V04*V20 - 8.19271189320508947e-18*V03*V21 - 
      1.10576479540191392e-18*V02*V22 - 1.50786108463897352e-19*V01*V23 + 1.39616767096201252e-22*V26) + 
   9.18368986379554615e-29*delta26*V26 + 5.969398411467105e-28*delta24*eps*V26 + 
   delta24*eps2*(-1.19394855996739947e-22*V132 - 1.91031769594783915e-22*V12*V14 - 
      1.77386643195156492e-22*V11*V15 - 1.04345084232444995e-22*V10*V16 - 7.17372454098059343e-23*V09*V17 - 
      3.02051559620235513e-23*V08*V18 - 1.51025779810117756e-23*V07*V19 - 4.31502228028907875e-24*V06*V20 - 
      1.51025779810117756e-24*V05*V21 - 2.6265353010455262e-25*V04*V22 - 5.969398411467105e-26*V03*V23 - 
      4.775518729173684e-27*V02*V24 - 5.969398411467105e-28*V01*V25 + 5.1460331133337112e-30*V28) + 
   delta22*eps3*(-1.43273827196087936e-21*V132 - 2.29238123513740697e-21*V12*V14 - 
      2.1286397183418779e-21*V11*V15 - 1.25214101078933994e-21*V10*V16 - 8.60846944917671212e-22*V09*V17 - 
      3.62461871544282615e-22*V08*V18 - 1.81230935772141308e-22*V07*V19 - 5.17802673634689451e-23*V06*V20 - 
      1.81230935772141308e-23*V05*V21 - 3.15184236125463144e-24*V04*V22 - 7.163278093760526e-25*V03*V23 - 
      5.7306224750084208e-26*V02*V24 - 7.163278093760526e-27*V01*V25 + 3.08761986800022672e-29*V28) + 
   delta20*eps4*(1.10298597358411377e-17*V083 + 8.50874893907744908e-17*V07*V08*V09 + 
      3.21177283144453053e-17*V06*V092 + 3.45184474005755605e-17*V072*V10 + 
      4.05285146835004812e-17*V06*V08*V10 + 4.02715219673381539e-17*V05*V09*V10 + 6.42551185378679264e-18*V04*V102 + 
      4.20450261570920361e-17*V06*V07*V11 + 3.2487950494659351e-17*V05*V08*V11 + 1.64373559050359812e-17*V04*V09*V11 + 
      7.32209490315239162e-18*V03*V10*V11 + 7.50401030447294793e-19*V02*V112 + 
      8.37583361314851212e-18*V062*V12 + 2.20591261494802398e-17*V05*V07*V12 + 8.6735229906141829e-18*V04*V08*V12 + 
      6.12753504152228884e-18*V03*V09*V12 + 9.81159102388680945e-19*V02*V10*V12 + 3.34229184083033937e-19*V01*V11*V12 + 
      1.1319814734601702e-17*V05*V06*V13 + 7.58647195617045285e-18*V04*V07*V13 + 4.16512185828966039e-18*V03*V08*V13 + 
      1.05825786345131317e-18*V02*V09*V13 + 2.81619034736630447e-19*V01*V10*V13 - 1.06595727433889424e-20*V132 + 
      2.53457131262967402e-18*V052*V14 + 2.57722253056508207e-18*V04*V06*V14 + 2.41387744059968954e-18*V03*V07*V14 + 
      4.76053124119404531e-19*V02*V08*V14 + 2.01156453383307462e-19*V01*V09*V14 - 1.73647878561658578e-20*V12*V14 + 
      1.51729439123409057e-18*V04*V05*V15 + 1.07807759377159067e-18*V03*V06*V15 + 3.62831267469021658e-19*V02*V07*V15 + 
      1.19003481665418868e-19*V01*V08*V15 - 1.58849738981262639e-20*V11*V15 + 1.48754352081773585e-19*V042*V16 + 
      4.16512185828966039e-19*V03*V05*V16 + 1.06136400409832961e-19*V02*V06*V16 + 5.95017408327094341e-20*V01*V07*V16 - 
      9.54131450221477037e-21*V10*V16 + 1.11565764061330189e-19*V03*V04*V17 + 5.60254163003636384e-20*V02*V05*V17 + 
      2.37811233920203824e-20*V01*V06*V17 - 6.48217749523006422e-21*V09*V17 + 1.32117352177891013e-20*V032*V18 + 
      9.44607155668013042e-21*V02*V04*V18 + 7.9270411306734608e-21*V01*V05*V18 - 2.79458102960641896e-21*V08*V18 + 
      3.27634013452418938e-21*V02*V03*V19 + 1.95729410633912612e-21*V01*V04*V19 - 1.38505742663858994e-21*V07*V19 + 
      1.163029831302959e-22*V022*V20 + 3.91458821267825225e-22*V01*V03*V20 - 4.06216197466413874e-22*V06*V20 + 
      4.68048590646312769e-23*V01*V02*V21 - 1.4136012990227022e-22*V05*V21 + 2.12749359384687622e-24*V012*V22 - 
      2.52935349490684173e-23*V04*V22 - 5.73241329453186093e-24*V03*V23 - 4.72776354188194716e-25*V02*V24 - 
      5.90970442735243395e-26*V01*V25 + 1.6981909274001247e-28*V28) + 
   delta18*eps5*(1.52317110637806187e-16*V083 + 1.12120493832635136e-15*V07*V08*V09 + 
      4.22288650060299385e-16*V06*V092 + 4.56136626364748478e-16*V072*V10 + 
      5.60091452293578975e-16*V06*V08*V10 + 5.32159397425539891e-16*V05*V09*V10 + 8.89111523954218982e-17*V04*V102 + 
      5.52814232806210104e-16*V06*V07*V11 + 4.28096430997334157e-16*V05*V08*V11 + 2.15740296253597253e-16*V04*V09*V11 + 
      9.67562540773708892e-17*V03*V10*V11 + 9.8348013838925757e-18*V02*V112 + 
      1.15962448868508278e-16*V062*V12 + 2.92589798232689292e-16*V05*V07*V12 + 1.20147745912201742e-16*V04*V08*V12 + 
      8.12749439535248034e-17*V03*V09*V12 + 1.36140534804836448e-17*V02*V10*V12 + 4.43317876110135291e-18*V01*V11*V12 + 
      1.4883460114013349e-16*V05*V06*V13 + 9.95724444247371937e-17*V04*V07*V13 + 5.48841578201710458e-17*V03*V08*V13 + 
      1.38695916952331196e-17*V02*V09*V13 + 3.72139438759118805e-18*V01*V10*V13 - 6.13928349535236805e-20*V132 + 
      3.37942841683956536e-17*V052*V14 + 3.58270230657427606e-17*V04*V06*V14 + 3.21850325413291939e-17*V03*V07*V14 + 
      6.62404371072965862e-18*V02*V08*V14 + 2.68208604511076616e-18*V01*V09*V14 - 1.02870607926791138e-19*V12*V14 + 
      1.99144888849474387e-17*V04*V05*V15 + 1.41747239181079514e-17*V03*V06*V15 + 4.75528858122278385e-18*V02*V07*V15 + 
      1.56811879486202988e-18*V01*V08*V15 - 9.1930627835889852e-20*V11*V15 + 2.08256092914483019e-18*V042*V16 + 
      5.59688249707673115e-18*V03*V05*V16 + 1.48652232389268935e-18*V02*V06*V16 + 7.99554642439533021e-19*V01*V07*V16 - 
      5.70350230414544345e-20*V10*V16 + 1.46430065330495873e-18*V03*V04*V17 + 7.34272501512341624e-19*V02*V05*V17 + 
      3.12677733487675398e-19*V01*V06*V17 - 3.80494349653610676e-20*V09*V17 + 1.79826396019907213e-19*V032*V18 + 
      1.34032096412353202e-19*V02*V04*V18 + 1.07895837611944328e-19*V01*V05*V18 - 1.69994617754268547e-20*V08*V18 + 
      4.29399123691427851e-20*V02*V03*V19 + 2.56894851457010304e-20*V01*V04*V19 - 8.31623456524413426e-21*V07*V19 + 
      1.69726711153561903e-21*V022*V20 + 5.46411271353006043e-21*V01*V03*V20 - 2.53334958075771814e-21*V06*V20 + 
      6.13427319559182644e-22*V01*V02*V21 - 8.7443926510058181e-22*V05*V21 + 3.19124039077031433e-23*V012*V22 - 
      1.62713861899770348e-22*V04*V22 - 3.67386625233742977e-23*V03*V23 - 3.15184236125463144e-24*V02*V24 - 
      3.9398029515682893e-25*V01*V25 + 8.49095463700062349e-28*V28) + 
   delta16*eps6*(-1.9971583877377173e-13*V052*V062 - 5.15012279872686278e-14*V04*V063 - 
      1.38552891798664746e-13*V053*V07 - 5.35296957748947698e-13*V04*V05*V06*V07 - 
      1.90205560736925457e-13*V03*V062*V07 - 8.90955092929180725e-14*V042*V072 - 
      1.9633954345872527e-13*V03*V05*V072 - 6.35520307987724906e-14*V02*V06*V072 - 
      9.19777263033969904e-15*V01*V073 - 2.06722420226566058e-13*V04*V052*V08 - 
      7.93140422857561947e-14*V042*V06*V08 - 2.92044310053531097e-13*V03*V05*V06*V08 - 
      2.8054165341348957e-14*V02*V062*V08 - 1.96878495453872436e-13*V03*V04*V07*V08 - 
      9.88055510639503979e-14*V02*V05*V07*V08 - 4.17206157219330139e-14*V01*V06*V07*V08 - 
      2.64742324327273891e-14*V032*V082 - 1.43533312602985843e-14*V02*V04*V082 - 
      1.58845394596364335e-14*V01*V05*V082 + 1.1820275926538449e-15*V083 - 
      1.03944760841737751e-13*V042*V05*V09 - 1.13602057536292194e-13*V03*V052*V09 - 
      1.48693599374707694e-13*V03*V04*V06*V09 - 7.41440359319012391e-14*V02*V05*V06*V09 - 
      1.58504633947437881e-14*V01*V062*V09 - 5.34751684544834494e-14*V032*V07*V09 - 
      4.88875816832892394e-14*V02*V04*V07*V09 - 3.18195745542241038e-14*V01*V05*V07*V09 - 
      2.74459864066528883e-14*V02*V03*V08*V09 - 1.6406541287822703e-14*V01*V04*V08*V09 + 8.17560521363213863e-15*V07*V08*V09 - 
      1.643382958440418e-15*V022*V092 - 4.26733622425923663e-15*V01*V03*V092 + 
      3.08192679142743045e-15*V06*V092 - 8.23776276145120962e-15*V043*V10 - 
      9.24961930882277239e-14*V03*V04*V05*V10 - 2.33503285680618882e-14*V02*V052*V10 - 
      3.24037911030739563e-14*V032*V06*V10 - 1.74238643178067204e-14*V02*V04*V06*V10 - 
      1.94422746618443738e-14*V01*V05*V06*V10 - 2.22384081600589411e-14*V02*V03*V07*V10 - 
      1.32137418697468177e-14*V01*V04*V07*V10 + 3.34029474072375626e-15*V072*V10 - 
      1.55351438944380804e-15*V022*V08*V10 - 6.93994367294913794e-15*V01*V03*V08*V10 + 
      4.36673324974551584e-15*V06*V08*V10 - 1.85320068000491176e-15*V01*V02*V09*V10 + 3.91504901715321151e-15*V05*V09*V10 - 
      1.08465183908934031e-16*V012*V102 + 6.99478132891690773e-16*V04*V102 - 
      1.88990474257705002e-14*V03*V042*V11 - 2.0079848750027906e-14*V032*V05*V11 - 
      1.8666167551801346e-14*V02*V04*V05*V11 - 5.9528162369059927e-15*V01*V052*V11 - 
      1.34807338058002253e-14*V02*V03*V06*V11 - 8.11055996589314694e-15*V01*V04*V06*V11 - 
      2.15133769104927447e-15*V022*V07*V11 - 5.5380535084000978e-15*V01*V03*V07*V11 + 
      4.05344001817784992e-15*V06*V07*V11 - 1.49705380399924845e-15*V01*V02*V08*V11 + 3.15077698022744369e-15*V05*V08*V11 - 
      2.06810074200447004e-16*V012*V09*V11 + 1.59121692189397229e-15*V04*V09*V11 + 
      7.21666268378127112e-16*V03*V10*V11 + 7.36581415510666222e-17*V02*V112 - 
      6.9185418610290725e-15*V032*V04*V12 - 1.80834826436122564e-15*V02*V042*V12 - 
      7.0425748922771522e-15*V02*V03*V05*V12 - 4.1511251166174435e-15*V01*V04*V05*V12 - 
      6.30237871364720846e-16*V022*V06*V12 - 2.86359817679713366e-15*V01*V03*V06*V12 + 
      9.12710887385849357e-16*V062*V12 - 1.0060821274681646e-15*V01*V02*V07*V12 + 2.17298619641462655e-15*V05*V07*V12 - 
      1.46306960814815552e-16*V012*V08*V12 + 9.49799932113489445e-16*V04*V08*V12 + 
      6.09073484754213193e-16*V03*V09*V12 + 1.09033397228799142e-16*V02*V10*V12 + 3.38185036744886271e-17*V01*V11*V12 - 
      8.23403845626556504e-16*V033*V13 - 2.39309840407709564e-15*V02*V03*V04*V13 - 
      7.26886439452711547e-16*V01*V042*V13 - 5.79206301436343127e-16*V022*V05*V13 - 
      1.44677819056731709e-15*V01*V03*V05*V13 - 5.18489761761547126e-16*V01*V02*V06*V13 + 1.10659043311581401e-15*V05*V06*V13 - 
      9.35939746766680868e-17*V012*V07*V13 + 7.41243447021940299e-16*V04*V07*V13 + 
      4.11428398053562672e-16*V03*V08*V13 + 1.04354074922474458e-16*V02*V09*V13 + 2.83871112421247911e-17*V01*V10*V13 - 
      2.94467426655281363e-19*V132 - 3.77787547433765198e-16*V02*V032*V14 - 
      9.26777057356701142e-17*V022*V04*V14 - 4.38655479552699342e-16*V01*V03*V04*V14 - 
      2.26672528460259119e-16*V01*V02*V05*V14 + 2.55854974493514799e-16*V052*V14 - 
      4.33570429464430293e-17*V012*V06*V14 + 2.8735149788757784e-16*V04*V06*V14 + 2.44740351616357412e-16*V03*V07*V14 + 
      5.35741052876326988e-17*V02*V08*V14 + 2.06622661355679947e-17*V01*V09*V14 - 5.08721755295465973e-19*V12*V14 - 
      5.51625048986993454e-17*V022*V03*V15 - 6.42358395777375031e-17*V01*V032*V15 - 
      6.83742401164884467e-17*V01*V02*V04*V15 - 1.78262688228429759e-17*V012*V05*V15 + 
      1.50982944171200065e-16*V04*V05*V15 + 1.07814907755634392e-16*V03*V06*V15 + 3.6269383138285915e-17*V02*V07*V15 + 
      1.20757812882905002e-17*V01*V08*V15 - 4.43179318750542553e-19*V11*V15 - 1.15395252530254566e-18*V023*V16 - 
      1.78862641421894578e-17*V01*V02*V03*V16 - 4.9706760326638416e-18*V012*V04*V16 + 
      1.71110905763354099e-17*V042*V16 + 4.3613320824757824e-17*V03*V05*V16 + 1.22621922769833635e-17*V02*V06*V16 + 
      6.28244603275794854e-18*V01*V07*V16 - 2.8474503199052279e-19*V10*V16 - 1.21681996100072085e-18*V01*V022*V17 - 
      1.17086609937362833e-18*V012*V03*V17 + 1.14032592883395642e-17*V03*V04*V17 + 
      5.72673938731115986e-18*V02*V05*V17 + 2.45317031319295603e-18*V01*V06*V17 - 1.86187158637677321e-19*V09*V17 - 
      1.54775158952360245e-19*V012*V02*V18 + 1.45049853861487712e-18*V032*V18 + 
      1.1394855688643869e-18*V02*V04*V18 + 8.73649925579235103e-19*V01*V05*V18 - 8.64577938312806382e-20*V08*V18 - 
      4.7868605861554715e-21*V013*V19 + 3.45239022941501839e-19*V02*V03*V19 + 2.071115013609934e-19*V01*V04*V19 - 
      4.16838046931090252e-20*V07*V19 + 1.50626546444358836e-20*V022*V20 + 4.61453360505387452e-20*V01*V03*V20 - 
      1.32340232459151162e-20*V06*V20 + 5.1219408271863545e-21*V01*V02*V21 - 4.52579939307717773e-21*V05*V21 + 
      2.8721163516932829e-22*V012*V22 - 8.79364018790042171e-22*V04*V22 - 1.97679613094938916e-22*V03*V23 - 
      1.77291132820573018e-23*V02*V24 - 2.21613916025716273e-24*V01*V25 + 3.82092958665028057e-27*V28) + 
   delta14*eps7*(-2.51986024216111903e-12*V052*V062 - 
      7.66374204694040638e-13*V04*V063 - 1.71500114887796047e-12*V053*V07 - 
      6.73187355701465464e-12*V04*V05*V06*V07 - 2.39986689729630384e-12*V03*V062*V07 - 
      1.11856831327609723e-12*V042*V072 - 2.43566320925706709e-12*V03*V05*V072 - 
      7.98583082493023281e-13*V02*V06*V072 - 1.14618397393463942e-13*V01*V073 - 
      2.61143204268681004e-12*V04*V052*V08 - 1.18471866425539801e-12*V042*V06*V08 - 
      3.70632780010077628e-12*V03*V05*V06*V08 - 4.20522991215922173e-13*V02*V062*V08 - 
      2.48707813589220004e-12*V03*V04*V07*V08 - 1.24518743296266383e-12*V02*V05*V07*V08 - 
      5.29475400014396611e-13*V01*V06*V07*V08 - 3.38500229532863735e-13*V032*V082 - 
      2.1618555087787909e-13*V02*V04*V082 - 2.03100137719718241e-13*V01*V05*V082 + 
      6.55112010707955772e-15*V083 - 1.3049963654887801e-12*V042*V05*V09 - 
      1.41243945340161121e-12*V03*V052*V09 - 1.86996487694851518e-12*V03*V04*V06*V09 - 
      9.31680262908527161e-13*V02*V05*V06*V09 - 1.9998890810802532e-13*V01*V062*V09 - 
      6.67000771126056506e-13*V032*V07*V09 - 6.14853248028864449e-13*V02*V04*V07*V09 - 
      3.97810724009440211e-13*V01*V05*V07*V09 - 3.45885398045184397e-13*V02*V03*V08*V09 - 
      2.07256511324350003e-13*V01*V04*V08*V09 + 4.25003916946786307e-14*V07*V08*V09 - 
      2.082221806665971e-14*V022*V092 - 5.38830472713085848e-14*V01*V03*V092 + 
      1.60812251786407803e-14*V06*V092 - 1.24056419875980856e-13*V043*V10 - 
      1.17736463407971587e-12*V03*V04*V05*V10 - 2.96119791245740176e-13*V02*V052*V10 - 
      4.15039194364330216e-13*V032*V06*V10 - 2.63587490168626055e-13*V02*V04*V06*V10 - 
      2.49023516618598129e-13*V01*V05*V06*V10 - 2.82018848805466834e-13*V02*V03*V07*V10 - 
      1.68194947725673695e-13*V01*V04*V07*V10 + 1.74383716386006097e-14*V072*V10 - 
      2.38053768189902368e-14*V022*V08*V10 - 8.98202690897743747e-14*V01*V03*V08*V10 + 
      2.43846652416793024e-14*V06*V08*V10 - 2.35015707337889029e-14*V01*V02*V09*V10 + 2.06057236803017738e-14*V05*V09*V10 - 
      1.43370826246798331e-15*V012*V102 + 3.96428932547644154e-15*V04*V102 - 
      2.37272066452505473e-13*V03*V042*V11 - 2.51631536127520512e-13*V032*V05*V11 - 
      2.34762149247384608e-13*V02*V04*V05*V11 - 7.48492153453347417e-14*V01*V052*V11 - 
      1.69396411437914029e-13*V02*V03*V06*V11 - 1.01998084197191737e-13*V01*V04*V06*V11 - 
      2.72581763781727113e-14*V022*V07*V11 - 7.01033093976778396e-14*V01*V03*V07*V11 + 
      2.13218354709983197e-14*V06*V07*V11 - 1.8866476257010058e-14*V01*V02*V08*V11 + 1.66463961920891562e-14*V05*V08*V11 - 
      2.70549182705722968e-15*V012*V09*V11 + 8.46519127348510629e-15*V04*V09*V11 + 
      3.88883527020090202e-15*V03*V10*V11 + 4.02081764258068888e-16*V02*V112 - 
      8.9119744245507192e-14*V032*V04*V12 - 2.77615388249572503e-14*V02*V042*V12 - 
      9.02401843369926548e-14*V02*V03*V05*V12 - 5.34718465473043152e-14*V01*V04*V05*V12 - 
      9.75373498117561726e-15*V022*V06*V12 - 3.72237934749807608e-14*V01*V03*V06*V12 + 
      5.17221526231414158e-15*V062*V12 - 1.2891454905284665e-14*V01*V02*V07*V12 + 1.15738056510318501e-14*V05*V07*V12 - 
      1.9385984662704339e-15*V012*V08*V12 + 5.42172521751850093e-15*V04*V08*V12 + 3.29486197473159965e-15*V03*V09*V12 + 
      6.35760112757530432e-16*V02*V10*V12 + 1.88437848864205698e-16*V01*V11*V12 - 1.04411003105223144e-14*V033*V13 - 
      3.00977114419723856e-14*V02*V03*V04*V13 - 9.12584870971174895e-15*V01*V042*V13 - 
      7.33873979412342228e-15*V022*V05*V13 - 1.84758419748958044e-14*V01*V03*V05*V13 - 
      6.5152465937659242e-15*V01*V02*V06*V13 + 5.95861129736542136e-15*V05*V06*V13 - 
      1.23197707636072354e-15*V012*V07*V13 + 4.0041533527362525e-15*V04*V07*V13 + 2.2415825653105088e-15*V03*V08*V13 + 
      5.73795659728471751e-16*V02*V09*V13 + 1.58694949853917996e-16*V01*V10*V13 - 1.2092933945033283e-18*V132 - 
      4.9215054007228526e-15*V02*V032*V14 - 1.46814009844390231e-15*V022*V04*V14 - 
      5.7597988081150496e-15*V01*V03*V04*V14 - 2.95290324043371156e-15*V01*V02*V05*V14 + 
      1.39952415958247218e-15*V052*V14 - 5.79171836040122807e-16*V012*V06*V14 + 
      1.6750370091965098e-15*V04*V06*V14 + 1.34875401993507653e-15*V03*V07*V14 + 3.16627754139116627e-16*V02*V08*V14 + 
      1.16364635315865469e-16*V01*V09*V14 - 2.14611734546070503e-18*V12*V14 - 6.98927599440325931e-16*V022*V03*V15 - 
      8.37876759046778033e-16*V01*V032*V15 - 8.59934612627782446e-16*V01*V02*V04*V15 - 
      2.38362680259728934e-16*V012*V05*V15 + 8.3968746884450111e-16*V04*V05*V15 + 6.02108557224745365e-16*V03*V06*V15 + 
      2.03680279692837158e-16*V02*V07*V15 + 6.86493250381728478e-17*V01*V08*V15 - 1.82727523647880226e-18*V11*V15 - 
      1.9167866283122816e-17*V023*V16 - 2.3955748066203334e-16*V01*V02*V03*V16 - 
      6.75521765918260138e-17*V012*V04*V16 + 1.03124890677870831e-16*V042*V16 + 
      2.48128726852923635e-16*V03*V05*V16 + 7.43882390075747964e-17*V02*V06*V16 + 3.62386621307907661e-17*V01*V07*V16 - 
      1.21120144382787979e-18*V10*V16 - 1.54175205758895426e-17*V01*V022*V17 - 
      1.62676670159907543e-17*V012*V03*V17 + 6.60274019331159576e-17*V03*V04*V17 + 3.323932166218544e-17*V02*V05*V17 + 
      1.43510080372941035e-17*V01*V06*V17 - 7.77120222492417712e-19*V09*V17 - 2.182808427286895e-18*V012*V02*V18 + 
      8.61634905507984869e-18*V032*V18 + 7.17646139076428287e-18*V02*V04*V18 + 5.2234222716128505e-18*V01*V05*V18 - 
      3.7401337379828084e-19*V08*V18 - 7.65897693784875439e-20*V013*V19 + 2.09026245595455589e-18*V02*V03*V19 + 
      1.25862521011981197e-18*V01*V04*V19 - 1.77698902426060336e-19*V07*V19 + 9.95667001920338071e-20*V022*V20 + 
      2.89126379403790478e-19*V01*V03*V20 - 5.87492159558001676e-20*V06*V20 + 3.25506519858572062e-20*V01*V02*V21 - 
      1.98920651024682927e-20*V05*V21 + 1.9147442344621886e-21*V012*V22 - 4.04223782830906482e-21*V04*V22 - 
      9.04184777384922394e-22*V03*V23 - 8.50997437538750488e-23*V02*V24 - 1.06374679692343811e-23*V01*V25 + 
      1.52837183466011223e-26*V28) + delta12*eps8*
    (1.69722051530330397e-12*V045 + 9.90045300593593985e-11*V03*V043*V05 + 
      1.65145212109441825e-10*V032*V04*V052 + 7.29432517380202435e-11*V02*V042*V052 + 
      5.64335642606010761e-11*V02*V03*V053 + 3.24106070216067245e-11*V01*V04*V053 + 
      1.05663509164113951e-10*V032*V042*V06 + 1.17532365180228153e-11*V02*V043*V06 + 
      7.57945446961099518e-11*V033*V05*V06 + 2.10162034740904921e-10*V02*V03*V04*V05*V06 + 
      6.33981054984683709e-11*V01*V042*V05*V06 + 2.56238332842952961e-11*V022*V052*V06 + 
      6.63802309875038209e-11*V01*V03*V052*V06 + 3.74575065295956479e-11*V02*V032*V062 + 
      6.06698639197789842e-12*V022*V04*V062 + 4.45126951642857669e-11*V01*V03*V04*V062 + 
      2.24745039177573887e-11*V01*V02*V05*V062 - 1.63160233770679799e-11*V052*V062 + 
      1.52221561580565904e-12*V012*V063 - 5.78540684073728724e-12*V04*V063 + 
      5.14454079708043246e-11*V033*V04*V07 + 6.94697635600192795e-11*V02*V03*V042*V07 + 
      1.41435042941941998e-11*V01*V043*V07 + 7.92724339032897677e-11*V02*V032*V05*V07 + 
      3.34782410990087043e-11*V022*V04*V05*V07 + 9.03276914070541286e-11*V01*V03*V04*V05*V07 + 
      2.33776470874305423e-11*V01*V02*V052*V07 - 1.08185146013897752e-11*V053*V07 + 
      2.4403650746947901e-11*V022*V03*V06*V07 + 3.07358913088136596e-11*V01*V032*V06*V07 + 
      3.00231478201292744e-11*V01*V02*V04*V06*V07 + 8.68957492519746369e-12*V012*V05*V06*V07 - 
      4.37093686329841425e-11*V04*V05*V06*V07 - 1.566181267711276e-11*V03*V062*V07 + 
      1.25464861823383465e-12*V023*V072 + 1.08474889550181841e-11*V01*V02*V03*V072 + 
      2.96769747346639897e-12*V012*V04*V072 - 7.28858817233331817e-12*V042*V072 - 
      1.55159626435125332e-11*V03*V05*V072 - 5.24660148877228691e-12*V02*V06*V072 - 
      7.44212283487397049e-13*V01*V073 + 6.67609532142999851e-12*V034*V08 + 
      3.84582775897924735e-11*V02*V032*V04*V08 + 3.05603303904589489e-12*V022*V042*V08 + 
      2.28990069525048949e-11*V01*V03*V042*V08 + 1.89494560578382592e-11*V022*V03*V05*V08 + 
      2.31650689866383551e-11*V01*V032*V05*V08 + 2.30749665538754841e-11*V01*V02*V04*V05*V08 + 
      3.25981262240335248e-12*V012*V052*V08 - 1.70529257356118519e-11*V04*V052*V08 + 
      6.94763678262057234e-13*V023*V06*V08 + 1.62296042957806157e-11*V01*V02*V03*V06*V08 + 
      4.69918606764911534e-12*V012*V04*V06*V08 - 9.01512332233048342e-12*V042*V06*V08 - 
      2.43390798066278307e-11*V03*V05*V06*V08 - 3.22453879873185615e-12*V02*V062*V08 + 
      2.70706515111975132e-12*V01*V022*V07*V08 + 2.98045856840657767e-12*V012*V03*V07*V08 - 
      1.63678310962694555e-11*V03*V04*V07*V08 - 8.22054068494952146e-12*V02*V05*V07*V08 - 
      3.5306585954940383e-12*V01*V06*V07*V08 + 4.27227659317861358e-13*V012*V02*V082 - 
      2.25523495409310078e-12*V032*V082 - 1.67159794752105173e-12*V02*V04*V082 - 
      1.36330647299124867e-12*V01*V05*V082 + 2.80098426526990846e-14*V083 + 
      7.09060617403523279e-12*V02*V033*V09 + 9.29951141639130675e-12*V022*V03*V04*V09 + 
      1.19842625250196528e-11*V01*V032*V04*V09 + 5.78914696333493996e-12*V01*V02*V042*V09 + 
      1.46375672127280709e-12*V023*V05*V09 + 1.2430913178878777e-11*V01*V02*V03*V05*V09 + 
      3.3886904571058416e-12*V012*V04*V05*V09 - 8.57100355790489362e-12*V042*V05*V09 - 
      9.08705561862994056e-12*V03*V052*V09 + 2.03363756224565842e-12*V01*V022*V06*V09 + 
      2.26814706342825295e-12*V012*V03*V06*V09 - 1.23340808419557285e-11*V03*V04*V06*V09 - 
      6.1692665648056855e-12*V02*V05*V06*V09 - 1.33583675497378195e-12*V01*V062*V09 + 
      8.11760639874362548e-13*V012*V02*V07*V09 - 4.33464495272616129e-12*V032*V07*V09 - 
      4.09110037577523526e-12*V02*V04*V07*V09 - 2.60926157468941e-12*V01*V05*V07*V09 + 
      6.79697068800438898e-14*V013*V08*V09 - 2.31898587308895023e-12*V02*V03*V08*V09 - 
      1.39572328551556802e-12*V01*V04*V08*V09 + 1.71686331083175458e-13*V07*V08*V09 - 
      1.41825665686594023e-13*V022*V092 - 3.61035387268690237e-13*V01*V03*V092 + 
      6.53857258245341292e-14*V06*V092 + 2.10846776290424879e-12*V022*V032*V10 + 
      1.62762786071965243e-12*V01*V033*V10 + 2.0882306763634111e-13*V023*V04*V10 + 
      5.06712184364963239e-12*V01*V02*V03*V04*V10 + 7.35486409901654912e-13*V012*V042*V10 - 
      9.59305627506322286e-13*V043*V10 + 1.26508065774254928e-12*V01*V022*V05*V10 + 
      1.35509493219951251e-12*V012*V03*V05*V10 - 7.86276590867499058e-12*V03*V04*V05*V10 - 
      1.98258060474281681e-12*V02*V052*V10 + 5.19864378696037504e-13*V012*V02*V06*V10 - 
      2.78858403478309586e-12*V032*V06*V10 - 2.05469609340393125e-12*V02*V04*V06*V10 - 
      1.68557798488720377e-12*V01*V05*V06*V10 + 5.40740308239601506e-14*V013*V07*V10 - 
      1.90247352254040442e-12*V02*V03*V07*V10 - 1.14020824033674051e-12*V01*V04*V07*V10 + 
      7.06450656808127573e-14*V072*V10 - 1.88915965409151507e-13*V022*V08*V10 - 
      6.17169857042578985e-13*V01*V03*V08*V10 + 1.05241906443131414e-13*V06*V08*V10 - 1.62114839717559375e-13*V01*V02*V09*V10 + 
      8.43512198400368814e-14*V05*V09*V10 - 1.01879759579391264e-14*V012*V102 + 
      1.74429213223327529e-14*V04*V102 + 2.66137585685964925e-13*V023*V03*V11 + 
      1.05906854914023571e-12*V01*V02*V032*V11 + 5.07246077257707641e-13*V01*V022*V04*V11 + 
      5.68284293963893289e-13*V012*V03*V04*V11 - 1.59526465971872016e-12*V03*V042*V11 + 
      2.9770002966244182e-13*V012*V02*V05*V11 - 1.66744937872337325e-12*V032*V05*V11 - 
      1.58652933824338137e-12*V02*V04*V05*V11 - 5.007211389248975e-13*V01*V052*V11 + 
      3.32257525080438846e-14*V013*V06*V11 - 1.1479929179126796e-12*V02*V03*V06*V11 - 
      6.93777815562933079e-13*V01*V04*V06*V11 - 1.87092052579593526e-13*V022*V07*V11 - 
      4.74251271528799159e-13*V01*V03*V07*V11 + 8.74934122198606157e-14*V06*V07*V11 - 1.30363122113054841e-13*V01*V02*V08*V11 + 
      6.8574529490516731e-14*V05*V08*V11 - 1.90080765250655044e-14*V012*V09*V11 + 3.53027384466007188e-14*V04*V09*V11 + 
      1.64052489611799716e-14*V03*V10*V11 + 1.73546694453885326e-15*V02*V112 + 
      3.48280913281984102e-15*V024*V12 + 1.85950769278642338e-13*V01*V022*V03*V12 + 
      9.34645124364953167e-14*V012*V032*V12 + 1.08783666218579755e-13*V012*V02*V04*V12 - 
      6.13856704112766429e-13*V032*V04*V12 - 2.21778759541654563e-13*V02*V042*V12 + 
      1.6280968105939485e-14*V013*V05*V12 - 6.22704221012906932e-13*V02*V03*V05*V12 - 
      3.70956271646512361e-13*V01*V04*V05*V12 - 7.86666000003416018e-14*V022*V06*V12 - 
      2.60023262126741606e-13*V01*V03*V06*V12 + 2.27134927216431786e-14*V062*V12 - 
      9.02421222515664391e-14*V01*V02*V07*V12 + 4.79014585663032558e-14*V05*V07*V12 - 
      1.38882189976287973e-14*V012*V08*V12 + 2.40467287854516429e-14*V04*V08*V12 + 
      1.39260898601988465e-14*V03*V09*V12 + 2.9018707451200084e-15*V02*V10*V12 + 8.28596396924692205e-16*V01*V11*V12 + 
      1.02360609879217279e-14*V01*V023*V13 + 3.42738835019884867e-14*V012*V02*V03*V13 - 
      7.19332390498911321e-14*V033*V13 + 5.70923117878059699e-15*V013*V04*V13 - 
      2.09676282115613157e-13*V02*V03*V04*V13 - 6.37217418137510935e-14*V01*V042*V13 - 
      5.1525422695415292e-14*V022*V05*V13 - 1.28648176024020543e-13*V01*V03*V05*V13 - 
      4.58399896599754662e-14*V01*V02*V06*V13 + 2.51117911730858733e-14*V05*V06*V13 - 
      8.82037675447656105e-15*V012*V07*V13 + 1.69741932779255435e-14*V04*V07*V13 + 
      9.58338797132798474e-15*V03*V08*V13 + 2.49469101004387013e-15*V02*V09*V13 + 7.01380077351058344e-16*V01*V10*V13 - 
      4.27353345192435548e-18*V132 + 2.83817431889704983e-15*V012*V022*V14 + 
      1.54753458517703007e-15*V013*V03*V14 - 3.52847386806752976e-14*V02*V032*V14 - 
      1.22374878213716136e-14*V022*V04*V14 - 4.15516029503519116e-14*V01*V03*V04*V14 - 
      2.13136767458152763e-14*V01*V02*V05*V14 + 5.95542265348387808e-15*V052*V14 - 
      4.25021139007428497e-15*V012*V06*V14 + 7.60517821823443363e-15*V04*V06*V14 + 
      5.80084922444112894e-15*V03*V07*V14 + 1.46578502492623655e-15*V02*V08*V14 + 5.160537622557416e-16*V01*V09*V14 - 
      7.73886903353060472e-18*V12*V14 + 2.40453580963761644e-16*V013*V02*V15 - 
      5.09043477455507611e-15*V022*V03*V15 - 6.12709857802884349e-15*V01*V032*V15 - 
      6.25968312779994327e-15*V01*V02*V04*V15 - 1.77277552319798963e-15*V012*V05*V15 + 
      3.67333501324724325e-15*V04*V05*V15 + 2.64593878461763225e-15*V03*V06*V15 + 9.04658570208272093e-16*V02*V07*V15 + 
      3.08960363931146751e-16*V01*V08*V15 - 6.47264097833335275e-18*V11*V15 + 6.16547643496824729e-18*V014*V16 - 
      1.68403882914543334e-16*V023*V16 - 1.81046088097259627e-15*V01*V02*V03*V16 - 
      5.15451700909533787e-16*V012*V04*V16 + 4.86090927718546833e-16*V042*V16 + 
      1.10218688305046193e-15*V03*V05*V16 + 3.54020465499464205e-16*V02*V06*V16 + 1.64312925482935176e-16*V01*V07*V16 - 
      4.39498432485673238e-18*V10*V16 - 1.17948244842870818e-16*V01*V022*V17 - 
      1.28469764411240544e-16*V012*V03*V17 + 3.01963143875664068e-16*V03*V04*V17 + 
      1.52772017359073719e-16*V02*V05*V17 + 6.65625729466481393e-17*V01*V06*V17 - 2.77491205584608323e-18*V09*V17 - 
      1.75582046300182694e-17*V012*V02*V18 + 4.00700121566097593e-17*V032*V18 + 
      3.5554247441650226e-17*V02*V04*V18 + 2.45368091165547928e-17*V01*V05*V18 - 1.3760805856134416e-18*V08*V18 - 
      6.7016048206176601e-19*V013*V19 + 1.00524072309264901e-17*V02*V03*V19 + 6.08058944057375693e-18*V01*V04*V19 - 
      6.44825579181706125e-19*V07*V19 + 5.19746684976791861e-19*V022*V20 + 1.42520795851802238e-18*V01*V03*V20 - 
      2.21277062873357184e-19*V06*V20 + 1.65306252241902282e-19*V01*V02*V21 - 7.41520163022046649e-20*V05*V21 + 
      1.00524072309264901e-20*V012*V22 - 1.57611817077489413e-20*V04*V22 - 3.50593215152683144e-21*V03*V23 - 
      3.47490620328323116e-22*V02*V24 - 4.34363275410403895e-23*V01*V25 + 5.3493014213103928e-26*V28) + 
   delta10*eps9*(2.94346529368315861e-11*V045 + 1.07985655286172715e-9*V03*V043*V05 + 
      1.71897339904773307e-9*V032*V04*V052 + 7.96266008412303666e-10*V02*V042*V052 + 
      5.8607426055896506e-10*V02*V03*V053 + 3.39463604350525028e-10*V01*V04*V053 + 
      1.15932748685713087e-9*V032*V042*V06 + 2.06411599190622904e-10*V02*V043*V06 + 
      7.94747422420482385e-10*V033*V05*V06 + 2.30172081336221789e-9*V02*V03*V04*V05*V06 + 
      6.95596492114278522e-10*V01*V042*V05*V06 + 2.81347387631380162e-10*V022*V052*V06 + 
      7.01468961792346197e-10*V01*V03*V052*V06 + 4.12513514218773564e-10*V02*V032*V062 + 
      1.08095995688749874e-10*V022*V04*V062 + 4.91928317844827125e-10*V01*V03*V04*V062 + 
      2.47508108531264139e-10*V01*V02*V05*V062 - 6.99871235822987974e-11*V052*V062 + 
      1.69186310382554962e-11*V012*V063 - 2.82711509161556807e-11*V04*V063 + 
      5.38831118016706393e-10*V033*V04*V07 + 7.58348579440289206e-10*V02*V03*V042*V07 + 
      1.54265221837389593e-10*V01*V043*V07 + 8.28508293443252896e-10*V02*V032*V05*V07 + 
      3.67630249386954262e-10*V022*V04*V05*V07 + 9.535216764415262e-10*V01*V03*V04*V05*V07 + 
      2.45930292969252426e-10*V01*V02*V052*V07 - 4.50648873161857779e-11*V053*V07 + 
      2.67949892982266821e-10*V022*V03*V06*V07 + 3.27459639717265832e-10*V01*V032*V06*V07 + 
      3.28817259051745412e-10*V01*V02*V04*V06*V07 + 9.4048614407050179e-11*V012*V05*V06*V07 - 
      1.89215565149637133e-10*V04*V05*V06*V07 - 6.81763445170203853e-11*V03*V062*V07 + 
      1.39444848287510596e-11*V023*V072 + 1.15182666174941962e-10*V01*V02*V03*V072 + 
      3.21017537411587722e-11*V012*V04*V072 - 3.18406426463850054e-11*V042*V072 - 
      6.56634174168191508e-11*V03*V05*V072 - 2.32359443397106751e-11*V02*V06*V072 - 
      3.24855532859376506e-12*V01*V073 + 7.09335127901937342e-11*V034*V08 + 
      4.255771685715893e-10*V02*V032*V04*V08 + 5.51372149754177856e-11*V022*V042*V08 + 
      2.54174166457058009e-10*V01*V03*V042*V08 + 2.09757140803781025e-10*V022*V03*V05*V08 + 
      2.48540229250877708e-10*V01*V032*V05*V08 + 2.5534630114295358e-10*V01*V02*V04*V05*V08 + 
      3.55537576199033233e-11*V012*V052*V08 - 7.41718453423337579e-11*V04*V052*V08 + 
      1.27541569802581361e-11*V023*V06*V08 + 1.8086421825184335e-10*V01*V02*V03*V06*V08 + 
      5.24600512141898831e-11*V012*V04*V06*V08 - 4.4634629696567675e-11*V042*V06*V08 - 
      1.06465580947736599e-10*V03*V05*V06*V08 - 1.61793688506655506e-11*V02*V062*V08 + 
      2.9965305829111575e-11*V01*V022*V07*V08 + 3.28863762865051076e-11*V012*V03*V07*V08 - 
      7.22184165366019031e-11*V03*V04*V07*V08 - 3.65672326448746265e-11*V02*V05*V07*V08 - 
      1.58851445341324774e-11*V01*V06*V07*V08 + 4.81429545930922416e-12*V012*V02*V082 - 
      1.00567311914564964e-11*V032*V082 - 8.49608394495698954e-12*V02*V04*V082 - 
      6.1646152851312787e-12*V01*V05*V082 + 9.4887905784810694e-14*V083 + 
      7.50950919461509207e-11*V02*V033*V09 + 1.02119513718598406e-10*V022*V03*V04*V09 + 
      1.28440672102984811e-10*V01*V032*V04*V09 + 6.31957149533574338e-11*V01*V02*V042*V09 + 
      1.62685656335429029e-11*V023*V05*V09 + 1.32923002168697043e-10*V01*V02*V03*V05*V09 + 
      3.69364418100398072e-11*V012*V04*V05*V09 - 3.79694474739357151e-11*V042*V05*V09 - 
      3.9034308676048156e-11*V03*V052*V09 + 2.23291577485222351e-11*V01*V022*V06*V09 + 
      2.50290819078244188e-11*V012*V03*V06*V09 - 5.49219470293534729e-11*V03*V04*V06*V09 - 
      2.76958345878698167e-11*V02*V05*V06*V09 - 6.06184731941184335e-12*V01*V062*V09 + 
      8.94597365597926538e-12*V012*V02*V07*V09 - 1.89037760065707799e-11*V032*V07*V09 - 
      1.85289155193646286e-11*V02*V04*V07*V09 - 1.15536048336506895e-11*V01*V05*V07*V09 + 
      7.95055001224887219e-13*V013*V08*V09 - 1.05951063776393714e-11*V02*V03*V08*V09 - 
      6.41284233545450153e-12*V01*V04*V08*V09 + 5.55883324588347876e-13*V07*V08*V09 - 
      6.65118998787311756e-13*V022*V092 - 1.64515184248772008e-12*V01*V03*V092 + 
      2.13608060848841071e-13*V06*V092 + 2.37158096442747268e-11*V022*V032*V10 + 
      1.78646809595064318e-11*V01*V033*V10 + 3.93339699765279626e-12*V023*V04*V10 + 
      5.70557438613053632e-11*V01*V02*V03*V04*V10 + 8.29135109407503231e-12*V012*V042*V10 - 
      4.86945810336921357e-12*V043*V10 + 1.42294857865648361e-11*V01*V022*V05*V10 + 
      1.51736511538758572e-11*V012*V03*V05*V10 - 3.53050072330784785e-11*V03*V04*V05*V10 - 
      8.97064762190009636e-12*V02*V052*V10 + 5.88941853542087871e-12*V012*V02*V06*V10 - 
      1.25932366524160681e-11*V032*V06*V10 - 1.05676700348517258e-11*V02*V04*V06*V10 - 
      7.71623126310894452e-12*V01*V05*V06*V10 + 6.36406082595999729e-13*V013*V07*V10 - 
      8.72294959529437055e-12*V02*V03*V07*V10 - 5.25867723896048924e-12*V01*V04*V07*V10 + 
      2.28898431203407425e-13*V072*V10 - 9.97338905526024202e-13*V022*V08*V10 - 
      2.8782774654125242e-12*V01*V03*V08*V10 + 3.60135174475426985e-13*V06*V08*V10 - 7.71781383693338668e-13*V01*V02*V09*V10 + 
      2.76443023372544839e-13*V05*V09*V10 - 4.96460571321507087e-14*V012*V102 + 
      6.10495166679236661e-14*V04*V102 + 2.9579210242805278e-12*V023*V03*V11 + 
      1.16146626148653275e-11*V01*V02*V032*V11 + 5.57015529374173124e-12*V01*V022*V04*V11 + 
      6.37387447085132202e-12*V012*V03*V04*V11 - 7.35191647879915301e-12*V03*V042*V11 + 
      3.33627493944288791e-12*V012*V02*V05*V11 - 7.47447845867108231e-12*V032*V05*V11 - 
      7.3704400826648317e-12*V02*V04*V05*V11 - 2.27772842501028492e-12*V01*V052*V11 + 
      3.92839496530436844e-13*V013*V06*V11 - 5.35591512045307342e-12*V02*V03*V06*V11 - 
      3.2534226911779279e-12*V01*V04*V06*V11 - 8.87941756531218918e-13*V022*V07*V11 - 
      2.18868978399247471e-12*V01*V03*V07*V11 + 2.88103562668946431e-13*V06*V07*V11 - 6.25646721041756942e-13*V01*V02*V08*V11 + 
      2.26356906084163136e-13*V05*V08*V11 - 9.17518543701169467e-14*V012*V09*V11 + 
      1.18720485286494369e-13*V04*V09*V11 + 5.55963333795981137e-14*V03*V10*V11 + 6.08766127182957582e-15*V02*V112 + 
      6.97126310184236409e-14*V024*V12 + 2.14508023030128266e-12*V01*V022*V03*V12 + 
      1.08549131494993563e-12*V012*V032*V12 + 1.25421574306927669e-12*V012*V02*V04*V12 - 
      2.87395694078467199e-12*V032*V04*V12 - 1.18073000878447294e-12*V02*V042*V12 + 
      1.96419748265218422e-13*V013*V05*V12 - 2.93488217411979218e-12*V02*V03*V05*V12 - 
      1.75892385028531593e-12*V01*V04*V05*V12 - 4.24427157495073098e-13*V022*V06*V12 - 
      1.24049252083159444e-12*V01*V03*V06*V12 + 7.90915954466652055e-14*V062*V12 - 
      4.35830349941432114e-13*V01*V02*V07*V12 + 1.58221233806604946e-13*V05*V07*V12 - 
      6.83918592447986524e-14*V012*V08*V12 + 8.47838077594851237e-14*V04*V08*V12 + 
      4.71921138034589144e-14*V03*V09*V12 + 1.06064692652075795e-14*V02*V10*V12 + 2.94712436112520976e-15*V01*V11*V12 + 
      1.13766193241558761e-13*V01*V023*V13 + 4.018188964103246e-13*V012*V02*V03*V13 - 
      3.39446113184688056e-13*V033*V13 + 6.98943070573740386e-14*V013*V04*V13 - 
      1.02076494598224435e-12*V02*V03*V04*V13 - 3.115083629311985e-13*V01*V042*V13 - 
      2.52986278945218013e-13*V022*V05*V13 - 6.15808787097615085e-13*V01*V03*V05*V13 - 
      2.26529352821879131e-13*V01*V02*V06*V13 + 8.4727092316375805e-14*V05*V06*V13 - 
      4.35519694409946241e-14*V012*V07*V13 + 5.78301316721366918e-14*V04*V07*V13 + 
      3.28743702409754702e-14*V03*V08*V13 + 8.79555959489167708e-15*V02*V09*V13 + 2.50710033784371886e-15*V01*V10*V13 - 
      1.28605817626567052e-17*V132 + 3.39150527734733347e-14*V012*V022*V14 + 
      1.97689836410821881e-14*V013*V03*V14 - 1.74504919696047553e-13*V02*V032*V14 - 
      6.88531028421720269e-14*V022*V04*V14 - 2.06827059977782492e-13*V01*V03*V04*V14 - 
      1.06625347370051632e-13*V01*V02*V05*V14 + 2.01573940483405383e-14*V052*V14 - 
      2.15718046925592802e-14*V012*V06*V14 + 2.74241246925085559e-14*V04*V06*V14 + 1.9914991776080897e-14*V03*V07*V14 + 
      5.42456758466606654e-15*V02*V08*V14 + 1.84487798792354805e-15*V01*V09*V14 - 2.36008514869398616e-17*V12*V14 + 
      3.21837869905342508e-15*V013*V02*V15 - 2.63042546300521179e-14*V022*V03*V15 - 
      3.10484279082444893e-14*V01*V032*V15 - 3.24148583247491478e-14*V01*V02*V04*V15 - 
      9.13844236549065366e-15*V012*V05*V15 + 1.28653803882824346e-14*V04*V05*V15 + 
      9.30702659603714739e-15*V03*V06*V15 + 3.24213499459520527e-15*V02*V07*V15 + 1.12131899680374015e-15*V01*V08*V15 - 
      1.94978857487673357e-17*V11*V15 + 9.24821465245237093e-17*V014*V16 - 1.00713504338861027e-15*V023*V16 - 
      9.5489022575438441e-15*V01*V02*V03*V16 - 2.74127804866401263e-15*V012*V04*V16 + 
      1.82135143557975467e-15*V042*V16 + 3.8926459245492656e-15*V03*V05*V16 + 1.34458139769482602e-15*V02*V06*V16 + 
      5.97447399597582336e-16*V01*V07*V16 - 1.34599721373616975e-17*V10*V16 - 6.48500895281529732e-16*V01*V022*V17 - 
      7.04231440969786193e-16*V012*V03*V17 + 1.10490698998487486e-15*V03*V04*V17 + 
      5.64120095437823358e-16*V02*V05*V17 + 2.48213369185554833e-16*V01*V06*V17 - 8.39360579453806537e-18*V09*V17 - 
      9.91837513451413694e-17*V012*V02*V18 + 1.48092063326009053e-16*V032*V18 + 
      1.40635411028935136e-16*V02*V04*V18 + 9.20552542974503644e-17*V01*V05*V18 - 4.25846563971969208e-18*V08*V18 - 
      4.02096289237059606e-18*V013*V19 + 3.88268644623851834e-17*V02*V03*V19 + 2.36131045854463253e-17*V01*V04*V19 - 
      1.97123450811280778e-18*V07*V19 + 2.17400060380836893e-18*V022*V20 + 5.6072327534107962e-18*V01*V03*V20 - 
      6.98636983815406448e-19*V06*V20 + 6.77532247364445436e-19*V01*V02*V21 - 2.31689371103909438e-19*V05*V21 + 
      4.22201103698912586e-20*V012*V22 - 5.14534325671867014e-20*V04*V22 - 1.1374112626103862e-20*V03*V23 - 
      1.19139641255425068e-21*V02*V24 - 1.48924551569281335e-22*V01*V25 + 1.60479042639311784e-25*V28) + 
   delta8*eps10*(-3.48353822487445235e-10*V036 - 5.63618331860497148e-9*V02*V034*V04 - 
      7.52142487857241595e-9*V022*V032*V042 - 6.31557116084406533e-9*V01*V033*V042 - 
      1.18235613578975095e-10*V023*V043 - 6.20497920477853972e-9*V01*V02*V03*V043 - 
      4.68244180888229736e-10*V012*V044 + 2.04522364126337295e-10*V045 - 
      5.69957259001663313e-9*V022*V033*V05 - 2.91870821835366133e-9*V01*V034*V05 - 
      4.75996246502304676e-9*V023*V03*V04*V05 - 1.94477609941236912e-8*V01*V02*V032*V04*V05 - 
      4.51285492714344957e-9*V01*V022*V042*V05 - 5.29793573792971798e-9*V012*V03*V042*V05 + 
      5.59571374853810928e-9*V03*V043*V05 - 2.76558300226923378e-10*V024*V052 - 
      4.94975404004256773e-9*V01*V022*V03*V052 - 2.375237797497436e-9*V012*V032*V052 - 
      2.73842679842908882e-9*V012*V02*V04*V052 + 8.44899434558817426e-9*V032*V04*V052 + 
      4.17434942425085623e-9*V02*V042*V052 - 1.38131989351095415e-10*V013*V053 + 
      2.90352382085443044e-9*V02*V03*V053 + 1.70184735404769042e-9*V01*V04*V053 - 
      1.73954584163477662e-9*V023*V032*V06 - 4.40434437955229898e-9*V01*V02*V033*V06 - 
      5.87254203673968461e-11*V024*V04*V06 - 6.49781876600089265e-9*V01*V022*V03*V04*V06 - 
      3.5490267205211955e-9*V012*V032*V04*V06 - 1.97199129312179211e-9*V012*V02*V042*V06 + 
      6.04178321890165732e-9*V032*V042*V06 + 1.45494291493694489e-9*V02*V043*V06 - 
      1.04372750498086597e-9*V01*V023*V05*V06 - 3.67813736079536552e-9*V012*V02*V03*V05*V06 + 
      3.94832555048672289e-9*V033*V05*V06 - 6.34555710698009723e-10*V013*V04*V05*V06 + 
      1.21278448455036406e-8*V02*V03*V04*V05*V06 + 3.68117797660595973e-9*V01*V042*V05*V06 + 
      1.50086149642047213e-9*V022*V052*V06 + 3.55613591527038345e-9*V01*V03*V052*V06 - 
      3.44719728612722945e-10*V012*V022*V062 - 2.08773784678927438e-10*V013*V03*V062 + 
      2.18499743603896193e-9*V02*V032*V062 + 7.73560057249388023e-10*V022*V04*V062 + 
      2.61697161424435874e-9*V01*V03*V04*V062 + 1.33089573649811817e-9*V01*V02*V05*V062 - 
      2.15515965268820468e-10*V052*V062 + 9.16959769356950817e-11*V012*V063 - 
      9.67413716629006364e-11*V04*V063 - 2.63388857358974646e-10*V024*V03*V07 - 
      2.27137749955722174e-9*V01*V022*V032*V07 - 7.11282704434497315e-10*V012*V033*V07 - 
      6.79994637860435252e-10*V01*V023*V04*V07 - 2.48766852904853134e-9*V012*V02*V03*V04*V07 + 
      2.70257970473577217e-9*V033*V04*V07 - 2.15513291631896969e-10*V013*V042*V07 + 
      4.03779812962716808e-9*V02*V03*V042*V07 + 8.24512636044631884e-10*V01*V043*V07 - 
      6.39821675829280626e-10*V012*V022*V05*V07 - 3.68508356270347032e-10*V013*V03*V05*V07 + 
      4.1867374435375795e-9*V02*V032*V05*V07 + 1.98341983515254212e-9*V022*V04*V05*V07 + 
      4.87810293002306012e-9*V01*V03*V04*V05*V07 + 1.26645435615914452e-9*V01*V02*V052*V07 - 
      1.34822783062642816e-10*V053*V07 - 1.47932961866283733e-10*V013*V02*V06*V07 + 
      1.45131577655238092e-9*V022*V03*V06*V07 + 1.69420034313961507e-9*V01*V032*V06*V07 + 
      1.78593788867828818e-9*V01*V02*V04*V06*V07 + 4.97484348880810243e-10*V012*V05*V06*V07 - 
      5.91527317494421009e-10*V04*V05*V06*V07 - 2.14111837640765805e-10*V03*V062*V07 - 
      4.98460273337877888e-12*V014*V072 + 7.75456826903812862e-11*V023*V072 + 
      6.04883423727214372e-10*V01*V02*V03*V072 + 1.71199337557789747e-10*V012*V04*V072 - 
      1.01035142618061238e-10*V042*V072 - 2.00437065382737022e-10*V03*V05*V072 - 
      7.51436497578171893e-11*V02*V06*V072 - 1.034089196038987e-11*V01*V073 - 
      1.90317570721649182e-12*V025*V08 - 3.82821435828408598e-10*V01*V023*V03*V08 - 
      6.21948995444348751e-10*V012*V02*V032*V08 + 3.62822522193854791e-10*V034*V08 - 
      3.51341006389575525e-10*V012*V022*V04*V08 - 2.10733814299509583e-10*V013*V03*V04*V08 + 
      2.29129168331781158e-9*V02*V032*V04*V08 + 4.00038718360123285e-10*V022*V042*V08 + 
      1.37391448269021764e-9*V01*V03*V042*V08 - 1.09914167977695533e-10*V013*V02*V05*V08 + 
      1.14273217810063096e-9*V022*V03*V05*V08 + 1.29747898633794244e-9*V01*V032*V05*V08 + 
      1.39521690195051682e-9*V01*V02*V04*V05*V08 + 1.89817244764465933e-10*V012*V052*V08 - 
      2.32345054050319718e-10*V04*V052*V08 - 8.4691450501297832e-12*V014*V06*V08 + 
      9.40480899945783424e-11*V023*V06*V08 + 9.92961990520016034e-10*V01*V02*V03*V06*V08 + 
      2.88801564071787016e-10*V012*V04*V06*V08 - 1.55454334755832098e-10*V042*V06*V08 - 
      3.35167087204343158e-10*V03*V05*V06*V08 - 5.74591434619374414e-11*V02*V062*V08 + 
      1.68078190530655331e-10*V01*V022*V07*V08 + 1.7922784297330001e-10*V012*V03*V07*V08 - 
      2.30627741795751109e-10*V03*V04*V07*V08 - 1.1847375577040188e-10*V02*V05*V07*V08 - 
      5.20635310606352351e-11*V01*V06*V07*V08 + 2.73302791010986286e-11*V012*V02*V082 - 
      3.23689884485910393e-11*V032*V082 - 3.0687952430678249e-11*V02*V04*V082 - 
      2.02660877457561619e-11*V01*V05*V082 + 2.5478272581313858e-13*V083 - 
      2.19490714465812205e-11*V01*V024*V09 - 1.63453537653180961e-10*V012*V022*V03*V09 - 
      4.5621590851981985e-11*V013*V032*V09 + 3.9451350045098616e-10*V02*V033*V09 - 
      5.63016510897856419e-11*V013*V02*V04*V09 + 5.67847963196590586e-10*V022*V03*V04*V09 + 
      6.83497674924997587e-10*V01*V032*V04*V09 + 3.52039989815995021e-10*V01*V02*V042*V09 - 
      5.54652425566178494e-12*V014*V05*V09 + 9.18275435053114489e-11*V023*V05*V09 + 
      7.11472707603287305e-10*V01*V02*V03*V05*V09 + 2.00808560272265483e-10*V012*V04*V05*V09 - 
      1.22379251573796394e-10*V042*V05*V09 - 1.2104186629599732e-10*V03*V052*V09 + 
      1.26423950179252656e-10*V01*V022*V06*V09 + 1.3777207229766087e-10*V012*V03*V06*V09 - 
      1.77770794499627443e-10*V03*V04*V06*V09 - 9.09454281396483529e-11*V02*V05*V06*V09 - 
      2.01178788126795057e-11*V01*V062*V09 + 4.98127842058461555e-11*V012*V02*V07*V09 - 
      5.97734920434934253e-11*V032*V07*V09 - 6.17065865165672288e-11*V02*V04*V07*V09 - 
      3.73422990754700221e-11*V01*V05*V07*V09 + 4.6326605235350596e-12*V013*V08*V09 - 
      3.54902394595375172e-11*V02*V03*V08*V09 - 2.16182468692036307e-11*V01*V04*V08*V09 + 1.44416410754209022e-12*V07*V08*V09 - 
      2.31982052822957649e-12*V022*V092 - 5.50043602650990372e-12*V01*V03*V092 + 
      5.60756891947137004e-13*V06*V092 - 1.25177421440102926e-11*V012*V023*V10 - 
      2.16603545160845274e-11*V013*V02*V03*V10 + 1.33909625510296353e-10*V022*V032*V10 + 
      9.76607742790705792e-11*V01*V033*V10 - 2.52831391454603897e-12*V014*V04*V10 + 
      2.97886436303311412e-11*V023*V04*V10 + 3.23010487473487697e-10*V01*V02*V03*V04*V10 + 
      4.70550540341506635e-11*V012*V042*V10 - 1.75022677593823745e-11*V043*V10 + 
      8.14695838240757881e-11*V01*V022*V05*V10 + 8.48788142856757976e-11*V012*V03*V05*V10 - 
      1.14552171393243433e-10*V03*V04*V05*V10 - 2.95108352868355473e-11*V02*V052*V10 + 
      3.39326742656223317e-11*V012*V02*V06*V10 - 4.10807357303802357e-11*V032*V06*V10 - 
      3.87061693537785587e-11*V02*V04*V06*V10 - 2.57011365522157467e-11*V01*V05*V06*V10 + 
      3.73548841761136647e-12*V013*V07*V10 - 2.92217665576245852e-11*V02*V03*V07*V10 - 
      1.77384521140662386e-11*V01*V04*V07*V10 + 5.93962491830135727e-13*V072*V10 - 
      3.78246057178661458e-12*V022*V08*V10 - 9.79616287622452431e-12*V01*V03*V08*V10 + 
      9.76297712086681666e-13*V06*V08*V10 - 2.72121658140061301e-12*V01*V02*V09*V10 + 7.25084909932484695e-13*V05*V09*V10 - 
      1.78323033133655411e-13*V012*V102 + 1.69575297984627578e-13*V04*V102 - 
      2.29222549089823485e-12*V013*V022*V11 - 8.44435983486121085e-13*V014*V03*V11 + 
      1.74364153827111444e-11*V023*V03*V11 + 6.5728760123736834e-11*V01*V02*V032*V11 + 
      3.281694442754688e-11*V01*V022*V04*V11 + 3.66814218986499327e-11*V012*V03*V04*V11 - 
      2.47814438354677427e-11*V03*V042*V11 + 1.92631247960223483e-11*V012*V02*V05*V11 - 
      2.4270321576788209e-11*V032*V05*V11 - 2.51925693621858727e-11*V02*V04*V05*V11 - 
      7.5569455661131593e-12*V01*V052*V11 + 2.35164218730202385e-12*V013*V06*V11 - 
      1.83757610573746442e-11*V02*V03*V06*V11 - 1.12271506506756399e-11*V01*V04*V06*V11 - 
      3.13110455057833352e-12*V022*V07*V11 - 7.39832471867915497e-12*V01*V03*V07*V11 + 
      7.60245426486413122e-13*V06*V07*V11 - 2.22886744666734419e-12*V01*V02*V08*V11 + 5.97517127561872589e-13*V05*V08*V11 - 
      3.27626045988909981e-13*V012*V09*V11 + 3.21185006823789825e-13*V04*V09*V11 + 
      1.50808308443720851e-13*V03*V10*V11 + 1.72946818913936683e-14*V02*V112 - 
      1.63138506469259823e-13*V014*V02*V12 + 5.58419531667944093e-13*V024*V12 + 
      1.28764372320438753e-11*V01*V022*V03*V12 + 6.45396832557506403e-12*V012*V032*V12 + 
      7.54254792767127526e-12*V012*V02*V04*V12 - 9.75145473881211404e-12*V032*V04*V12 - 
      4.50376637938931664e-12*V02*V042*V12 + 1.20158353693452675e-12*V013*V05*V12 - 
      1.00839260572710666e-11*V02*V03*V05*V12 - 6.08782612914198772e-12*V01*V04*V05*V12 - 
      1.6484320757807942e-12*V022*V06*V12 - 4.31836552247896612e-12*V01*V03*V06*V12 + 
      2.17717556668614242e-13*V062*V12 - 1.55274369081896802e-12*V01*V02*V07*V12 + 
      4.16717345659387109e-13*V05*V07*V12 - 2.47998588843422056e-13*V012*V08*V12 + 
      2.36849734453498605e-13*V04*V08*V12 + 1.27868089741642656e-13*V03*V09*V12 + 3.09373294846011127e-14*V02*V10*V12 + 
      8.44356355298828722e-15*V01*V11*V12 - 3.88425015402999579e-15*V015*V13 + 
      7.1809920585718673e-13*V01*V023*V13 + 2.48945291657643411e-12*V012*V02*V03*V13 - 
      1.16160373954814387e-12*V033*V13 + 4.43525878302310805e-13*V013*V04*V13 - 
      3.66707114608416697e-12*V02*V03*V04*V13 - 1.12477065389886273e-12*V01*V042*V13 - 
      9.21441289700999496e-13*V022*V05*V13 - 2.15189828220726337e-12*V01*V03*V05*V13 - 
      8.31430815663206351e-13*V01*V02*V06*V13 + 2.27749640225126443e-13*V05*V06*V13 - 
      1.58376245559656605e-13*V012*V07*V13 + 1.57655305342467814e-13*V04*V07*V13 + 
      8.99693016116435438e-14*V03*V08*V13 + 2.50465583102290494e-14*V02*V09*V13 + 7.20849329211898222e-15*V01*V10*V13 - 
      3.21803883195180805e-17*V132 + 2.18045156860869549e-13*V012*V022*V14 + 
      1.30270351594444097e-13*V013*V03*V14 - 6.30326478088255669e-13*V02*V032*V14 - 
      2.80122041894993088e-13*V022*V04*V14 - 7.52745557853500325e-13*V01*V03*V04*V14 - 
      3.92273981607649023e-13*V01*V02*V05*V14 + 5.40803287586297931e-14*V052*V14 - 
      8.04948184417643853e-14*V012*V06*V14 + 7.80891139128618399e-14*V04*V06*V14 + 
      5.43740781719425874e-14*V03*V07*V14 + 1.597202818528769e-14*V02*V08*V14 + 5.29724316851910525e-15*V01*V09*V14 - 
      5.95245198917411751e-17*V12*V14 + 2.21957151658856902e-14*V013*V02*V15 - 
      1.00947915306144865e-13*V022*V03*V15 - 1.14771751173946253e-13*V01*V032*V15 - 
      1.24857632920951728e-13*V01*V02*V04*V15 - 3.4513834462590702e-14*V012*V05*V15 + 
      3.58028429140039697e-14*V04*V05*V15 + 2.59899778457856372e-14*V03*V06*V15 + 9.32107114925971582e-15*V02*V07*V15 + 
      3.25854476754579703e-15*V01*V08*V15 - 4.88025821976709744e-17*V11*V15 + 6.9361609893392782e-16*V014*V16 - 
      4.38463664730278108e-15*V023*V16 - 3.70702621454876177e-14*V01*V02*V03*V16 - 
      1.07299394782909356e-14*V012*V04*V16 + 5.38104465524185602e-15*V042*V16 + 
      1.08618951941430341e-14*V03*V05*V16 + 4.04737615083692379e-15*V02*V06*V16 + 1.73388722735808211e-15*V01*V07*V16 - 
      3.40357899883500811e-17*V10*V16 - 2.66841149944943681e-15*V01*V022*V17 - 
      2.82321857080570476e-15*V012*V03*V17 + 3.20146552388739126e-15*V03*V04*V17 + 
      1.65932740599216357e-15*V02*V05*V17 + 7.37439568257151854e-16*V01*V06*V17 - 2.10418823120977985e-17*V09*V17 - 
      4.14661798275717718e-16*V012*V02*V18 + 4.31147746134437162e-16*V032*V18 + 
      4.40295436714580268e-16*V02*V04*V18 + 2.73892913617438614e-16*V01*V05*V18 - 1.08451911250036055e-17*V08*V18 - 
      1.75917126541213578e-17*V013*V19 + 1.19137779698530452e-16*V02*V03*V19 + 7.29134604483201418e-17*V01*V04*V19 - 
      4.96989816781859134e-18*V07*V19 + 7.22432999662583758e-18*V022*V20 + 1.74509789528883869e-17*V01*V03*V20 - 
      1.80799724339092158e-18*V06*V20 + 2.21655579441929108e-18*V01*V02*V21 - 5.93510876925951522e-19*V05*V21 + 
      1.40733701232970862e-19*V012*V22 - 1.37382898822662032e-19*V04*V22 - 3.01572216927794704e-20*V03*V23 - 
      3.35080241030883005e-21*V02*V24 - 4.18850301288603756e-22*V01*V25 + 4.0119760659827946e-25*V28) + 
   eps14*(-4.44285396439000936e-8*V012*V026 - 2.38124362318310731e-7*V013*V024*V03 - 
      1.91046128236108395e-7*V014*V022*V032 + 8.47814123243652694e-8*V025*V032 - 
      1.35979953688287022e-8*V015*V033 + 4.85554468215240858e-7*V01*V023*V033 + 
      2.73534843558599589e-7*V012*V02*V034 - 5.66691941869923714e-9*V036 - 
      8.77483361362329616e-8*V014*V023*V04 + 1.66609565924847593e-8*V026*V04 - 
      5.61693735056830295e-8*V015*V02*V03*V04 + 5.31943375712827938e-7*V01*V024*V03*V04 + 
      1.23637235775819508e-6*V012*V022*V032*V04 + 
      1.92166939849085624e-7*V013*V033*V04 - 1.23357570532137392e-7*V02*V034*V04 - 
      1.71415954526073574e-9*V016*V042 + 3.15099921017591905e-7*V012*V023*V042 + 
      4.38158827637666048e-7*V013*V02*V03*V042 - 2.6288958283670669e-7*V022*V032*V042 - 
      1.49320092000854684e-7*V01*V033*V042 + 1.81036536333863598e-8*V014*V043 - 
      3.84541066603365207e-8*V023*V043 - 2.18275281392033712e-7*V01*V02*V03*V043 - 
      1.62557222292894705e-8*V012*V044 + 1.23616495716322489e-9*V045 - 
      1.47743203298758854e-8*V015*V022*V05 + 6.3486237399161944e-8*V01*V025*V05 - 
      2.61963152588152588e-9*V016*V03*V05 + 5.04749092373161098e-7*V012*V023*V03*V05 + 
      3.52991140766754484e-7*V013*V02*V032*V05 - 1.49577749258686372e-7*V022*V033*V05 - 
      6.20592452742179181e-8*V01*V034*V05 + 2.69761723133219301e-7*V013*V022*V04*V05 + 
      8.77107272725415816e-8*V014*V03*V04*V05 - 2.09818162328113677e-7*V023*V03*V04*V05 - 
      5.48198735129195742e-7*V01*V02*V032*V04*V05 - 1.98662769889577042e-7*V01*V022*V042*V05 - 
      1.6042882424496805e-7*V012*V03*V042*V05 + 2.15636899144237912e-8*V03*V043*V05 + 
      2.67278282813924154e-8*V014*V02*V052 - 1.55886771333317162e-8*V024*V052 - 
      1.67299596589608388e-7*V01*V022*V03*V052 - 
      6.60736192207424135e-8*V012*V032*V052 - 
      9.87358270157971727e-8*V012*V02*V04*V052 + 2.75385910139636236e-8*V032*V04*V052 + 
      1.95974610187973338e-8*V02*V042*V052 - 5.0322316333669934e-9*V013*V053 + 
      1.11939649437148335e-8*V02*V03*V053 + 6.96824490892339008e-9*V01*V04*V053 - 
      1.11409616617949951e-9*V016*V02*V06 + 6.65795095057685511e-8*V012*V024*V06 + 
      1.83568097555524123e-7*V013*V022*V03*V06 + 2.97925711255105513e-8*V014*V032*V06 - 
      7.51309637948993831e-8*V023*V032*V06 - 1.2851692907095802e-7*V01*V02*V033*V06 + 
      4.49398509403761505e-8*V014*V02*V04*V06 - 2.45969778812155529e-8*V024*V04*V06 - 
      2.81476680443194741e-7*V01*V022*V03*V04*V06 - 1.11990144232753333e-7*V012*V032*V04*V06 - 
      8.39195240244391173e-8*V012*V02*V042*V06 + 2.30850772817083477e-8*V032*V042*V06 + 
      1.07019465801876516e-8*V02*V043*V06 + 3.34093899905641269e-9*V015*V05*V06 - 
      5.68612789544256521e-8*V01*V023*V05*V06 - 1.37946216092929594e-7*V012*V02*V03*V05*V06 + 
      1.30513790433038994e-8*V033*V05*V06 - 2.5648829174374078e-8*V013*V04*V05*V06 + 
      5.61239769146853626e-8*V02*V03*V04*V05*V06 + 1.76001840353159858e-8*V01*V042*V05*V06 + 
      8.48834586634070483e-9*V022*V052*V06 + 1.47938814807311634e-8*V01*V03*V052*V06 - 
      1.80369720913617452e-8*V012*V022*V062 - 8.88476205467893865e-9*V013*V03*V062 + 
      1.00226471812315941e-8*V02*V032*V062 + 6.94477230572795859e-9*V022*V04*V062 + 
      1.24772222583550127e-8*V01*V03*V04*V062 + 7.65341039943219654e-9*V01*V02*V05*V062 - 
      4.00421842173653072e-10*V052*V062 + 5.42508390784734171e-10*V012*V063 - 
      2.22402533455576898e-10*V04*V063 - 3.01107071940405274e-11*V017*V07 + 
      2.77283134599238124e-8*V013*V023*V07 + 2.64719083561724785e-8*V014*V02*V03*V07 - 
      1.63832980432584913e-8*V024*V03*V07 - 8.67821980500707419e-8*V01*V022*V032*V07 - 
      2.26562275544794585e-8*V012*V033*V07 + 2.42602052206102159e-9*V015*V04*V07 - 
      4.17244583788554264e-8*V01*V023*V04*V07 - 1.01754981256123818e-7*V012*V02*V03*V04*V07 + 
      9.61933163483392822e-9*V033*V04*V07 - 9.46603145239704213e-9*V013*V042*V07 + 
      2.06181050369082218e-8*V02*V03*V042*V07 + 4.32428629621820677e-9*V01*V043*V07 - 
      3.12950296226941361e-8*V012*V022*V05*V07 - 1.54385614355878046e-8*V013*V03*V05*V07 + 
      1.76198113679567036e-8*V02*V032*V05*V07 + 1.24514430520378678e-8*V022*V04*V05*V07 + 
      2.18382321119836989e-8*V01*V03*V04*V05*V07 + 6.7076755062824439e-9*V01*V02*V052*V07 - 
      2.34661747410824179e-10*V053*V07 - 8.10809190164792969e-9*V013*V02*V06*V07 + 
      8.93730376339007827e-9*V022*V03*V06*V07 + 7.72142743457785924e-9*V01*V032*V06*V07 + 
      1.12813037607382006e-8*V01*V02*V04*V06*V07 + 2.83745875649115152e-9*V012*V05*V06*V07 - 
      1.18025293159619893e-9*V04*V05*V06*V07 - 4.22181735978734033e-10*V03*V062*V07 - 
      3.18691793748441956e-10*V014*V072 + 6.57786841443475241e-10*V023*V072 + 
      3.50638547974525262e-9*V01*V02*V03*V072 + 1.04890139026294974e-9*V012*V04*V072 - 
      2.17336706555266237e-10*V042*V072 - 3.70918013728160585e-10*V03*V05*V072 - 
      1.90194226432363861e-10*V02*V06*V072 - 2.51314251998090779e-11*V01*V073 + 
      5.16310067474283161e-9*V014*V022*V08 - 1.18730700632077167e-9*V025*V08 + 
      1.25136556662291956e-9*V015*V03*V08 - 2.29279375669576944e-8*V01*V023*V03*V08 - 
      2.73729662872491818e-8*V012*V02*V032*V08 + 1.32330997386533185e-9*V034*V08 - 
      2.05293337471624539e-8*V012*V022*V04*V08 - 1.00946782145188957e-8*V013*V03*V04*V08 + 
      1.14433490804597708e-8*V02*V032*V04*V08 + 3.9580363656136679e-9*V022*V042*V08 + 
      7.12851884157794588e-9*V01*V03*V042*V08 - 6.24094168156796559e-9*V013*V02*V05*V08 + 
      6.94356978258042249e-9*V022*V03*V05*V08 + 5.97551640081225015e-9*V01*V032*V05*V08 + 
      8.74380863198565107e-9*V01*V02*V04*V05*V08 + 1.09674986486655438e-9*V012*V052*V08 - 
      4.581985947432085e-10*V04*V052*V08 - 5.64122782334582771e-10*V014*V06*V08 + 
      1.14077085538480067e-9*V023*V06*V08 + 6.2033225723360664e-9*V01*V02*V03*V06*V08 + 
      1.86052874460750999e-9*V012*V04*V06*V08 - 3.81590377099588795e-10*V042*V06*V08 - 
      6.55281918259906118e-10*V03*V05*V06*V08 - 1.66926781546952041e-10*V02*V062*V08 + 
      1.4005434568201366e-9*V01*V022*V07*V08 + 1.13979684147809739e-9*V012*V03*V07*V08 - 
      4.83322804309876299e-10*V03*V04*V07*V08 - 2.95582748451497857e-10*V02*V05*V07*V08 - 
      1.33409947208532761e-10*V01*V06*V07*V08 + 2.31526965969625083e-10*V012*V02*V082 - 
      6.69929031241200044e-11*V032*V082 - 9.55031661992683771e-11*V02*V04*V082 - 
      5.17126889322778945e-11*V01*V05*V082 + 4.13107977656135402e-13*V083 + 
      4.2464953233948332e-10*V015*V02*V09 - 2.02019027419996013e-9*V01*V024*V09 - 
      9.89520180800151304e-9*V012*V022*V03*V09 - 2.41562895063108654e-9*V013*V032*V09 + 
      1.90018113274307923e-9*V02*V033*V09 - 3.66727316596148449e-9*V013*V02*V04*V09 + 
      4.05192218156296103e-9*V022*V03*V04*V09 + 3.51340513992207514e-9*V01*V032*V04*V09 + 
      2.56351206321914891e-9*V01*V02*V042*V09 - 3.89765451634726026e-10*V014*V05*V09 + 
      8.1311449232293595e-10*V023*V05*V09 + 4.32302295795212964e-9*V01*V02*V03*V05*V09 + 
      1.29182440988578419e-9*V012*V04*V05*V09 - 2.68529095864056996e-10*V042*V05*V09 - 
      2.29028113383650342e-10*V03*V052*V09 + 1.1142292397210049e-9*V01*V022*V06*V09 + 
      9.07931717762568069e-10*V012*V03*V06*V09 - 3.84555435601096485e-10*V03*V04*V06*V09 - 
      2.35077579863707066e-10*V02*V05*V06*V09 - 5.31194531671469679e-11*V01*V062*V09 + 
      4.15842572147764832e-10*V012*V02*V07*V09 - 1.20677033057322425e-10*V032*V07*V09 - 
      1.7307782150521251e-10*V02*V04*V07*V09 - 9.30875921523964184e-11*V01*V05*V07*V09 + 
      4.27915270305025167e-11*V013*V08*V09 - 9.64922137274363018e-11*V02*V03*V08*V09 - 
      6.0897977955022888e-11*V01*V04*V08*V09 + 2.23672006049290896e-12*V07*V08*V09 - 
      8.61435126001093185e-12*V022*V092 - 1.5101570440934915e-11*V01*V03*V092 + 
      8.90312494831359498e-13*V06*V092 + 1.23985264916637466e-11*V016*V10 - 
      1.08597003336772874e-9*V012*V023*V10 - 1.59037792603074527e-9*V013*V02*V03*V10 + 
      9.21839305565832322e-10*V022*V032*V10 + 5.2290045243083601e-10*V01*V033*V10 - 
      2.07045792763975322e-10*V014*V04*V10 + 4.223102586584077e-10*V023*V04*V10 + 
      2.30531604195516552e-9*V01*V02*V03*V04*V10 + 3.45866196153316002e-10*V012*V042*V10 - 
      4.730140076757285e-11*V043*V10 + 7.06111048292429286e-10*V01*V022*V05*V10 + 
      5.72957043956577621e-10*V012*V03*V05*V10 - 2.43995573875325085e-10*V03*V04*V05*V10 - 
      7.46676721210225473e-11*V02*V052*V10 + 3.01169854286320233e-10*V012*V02*V06*V10 - 
      8.71561659032362657e-11*V032*V06*V10 - 1.24184781432973377e-10*V02*V04*V06*V10 - 
      6.72932958419904147e-11*V01*V05*V06*V10 + 3.49217470015431594e-11*V013*V07*V10 - 
      7.88821815003766501e-11*V02*V03*V07*V10 - 4.97562731181520737e-11*V01*V04*V07*V10 + 
      9.14063254057000579e-13*V072*V10 - 1.55453703275504475e-11*V022*V08*V10 - 
      2.74200591514209273e-11*V01*V03*V08*V10 + 1.61275026622152242e-12*V06*V08*V10 - 9.98822615803830342e-12*V01*V02*V09*V10 + 
      1.13079968870586721e-12*V05*V09*V10 - 6.80460290457835636e-13*V012*V102 + 
      3.01293286387371767e-13*V04*V102 - 2.40416310658712261e-10*V013*V022*V11 - 
      8.17459866166382764e-11*V014*V03*V11 + 1.80452585440968922e-10*V023*V03*V11 + 
      4.7330571674483787e-10*V01*V02*V032*V11 + 3.44422568062248563e-10*V01*V022*V04*V11 + 
      2.81012315314083125e-10*V012*V03*V04*V11 - 5.95582892105503442e-11*V03*V042*V11 + 
      1.74071537746559336e-10*V012*V02*V05*V11 - 5.06728075205236914e-11*V032*V05*V11 - 
      7.27687542032896293e-11*V02*V04*V05*V11 - 1.95355626099852823e-11*V01*V052*V11 + 
      2.31618530300907583e-11*V013*V06*V11 - 5.2207755670901011e-11*V02*V03*V06*V11 - 
      3.297199918412495e-11*V01*V04*V06*V11 - 1.1719434646825447e-11*V022*V07*V11 - 
      2.05337843265451811e-11*V01*V03*V07*V11 + 1.2105816634917136e-12*V06*V07*V11 - 8.31119230639439751e-12*V01*V02*V08*V11 + 
      9.40616387175285778e-13*V05*V08*V11 - 1.24684884587326264e-12*V012*V09*V11 + 
      5.53411506155556774e-13*V04*V09*V11 + 2.5217127119503702e-13*V03*V10*V11 + 3.80558411977371771e-14*V02*V112 - 
      2.25674933949142755e-11*V014*V02*V12 + 1.18826980712085631e-11*V024*V12 + 
      1.31282476206008484e-10*V01*V022*V03*V12 + 5.26689431260876981e-11*V012*V032*V12 + 
      7.88924869784827072e-11*V012*V02*V04*V12 - 2.28704609621203231e-11*V032*V04*V12 - 
      1.62613938571251225e-11*V02*V042*V12 + 1.2343499614481655e-11*V013*V05*V12 - 
      2.8057126377794321e-11*V02*V03*V05*V12 - 1.76754020392417743e-11*V01*V04*V05*V12 - 
      7.11446422836924071e-12*V022*V06*V12 - 1.25639885755102269e-11*V01*V03*V06*V12 + 
      3.69165227756859453e-13*V062*V12 - 5.7461886803326097e-12*V01*V02*V07*V12 + 6.50304802067189682e-13*V05*V07*V12 - 
      9.58157148441811182e-13*V012*V08*V12 + 4.23974042778759694e-13*V04*V08*V12 + 
      2.13299545045710937e-13*V03*V09*V12 + 7.01010201669626122e-14*V02*V10*V12 + 1.86645558392741721e-14*V01*V11*V12 - 
      7.34123279111669205e-13*V015*V13 + 1.11917223375579105e-11*V01*V023*V13 + 
      2.74773798021158917e-11*V012*V02*V03*V13 - 2.71184870502481249e-12*V033*V13 + 
      5.19683538733058212e-12*V013*V04*V13 - 1.17379576815014896e-11*V02*V03*V04*V13 - 
      3.7125710821677119e-12*V01*V042*V13 - 3.57769544470418032e-12*V022*V05*V13 - 
      6.25241942029032562e-12*V01*V03*V05*V13 - 3.26429884921483961e-12*V01*V02*V06*V13 + 3.69055431492914755e-13*V05*V06*V13 - 
      6.14606188580291793e-13*V012*V07*V13 + 2.72738495171039016e-13*V04*V07*V13 + 
      1.52048984007312621e-13*V03*V08*V13 + 5.51653449031946066e-14*V02*V09*V13 + 1.59933365724365125e-14*V01*V10*V13 - 
      4.82840505109887935e-17*V132 + 3.34634624519940854e-12*V012*V022*V14 + 
      1.67527709143313718e-12*V013*V03*V14 - 1.96009308477979693e-12*V02*V032*V14 - 
      1.38589788154165138e-12*V022*V04*V14 - 2.45614126959940437e-12*V01*V03*V04*V14 - 
      1.5188247425853835e-12*V01*V02*V05*V14 + 8.59482153995903017e-14*V052*V14 - 
      3.26537068713583715e-13*V012*V06*V14 + 1.44221830492316582e-13*V04*V06*V14 + 
      9.11392462040902418e-14*V03*V07*V14 + 3.66389488900220047e-14*V02*V08*V14 + 1.17260332723494438e-14*V01*V09*V14 - 
      9.00758329931411365e-17*V12*V14 + 3.84540765248969583e-13*V013*V02*V15 - 
      4.39666189529948373e-13*V022*V03*V15 - 3.80178623655181342e-13*V01*V032*V15 - 
      5.58897255567581823e-13*V01*V02*V04*V15 - 1.42081226422276558e-13*V012*V05*V15 + 
      6.31543037165354444e-14*V04*V05*V15 + 4.53093106098236628e-14*V03*V06*V15 + 2.06422463096400032e-14*V02*V07*V15 + 
      7.32019980438718352e-15*V01*V08*V15 - 7.32308093599298073e-17*V11*V15 + 1.45659380776124842e-14*V014*V16 - 
      3.04692484132274287e-14*V023*V16 - 1.63637306916058396e-13*V01*V02*V03*V16 - 
      4.94650813093645986e-14*V012*V04*V16 + 1.08989807582861954e-14*V042*V16 + 
      1.86396459507237516e-14*V03*V05*V16 + 9.64001727668496181e-15*V02*V06*V16 + 3.8737051788447539e-15*V01*V07*V16 - 
      5.16507406747715027e-17*V10*V16 - 1.6556767067661321e-14*V01*V022*V17 - 
      1.35313945874416845e-14*V012*V03*V17 + 6.10374627756433287e-15*V03*V04*V17 + 
      3.76127654327226431e-15*V02*V05*V17 + 1.71578004959984158e-15*V01*V06*V17 - 3.15897595315700434e-17*V09*V17 - 
      2.63498724540660623e-15*V012*V02*V18 + 8.06592590700502911e-16*V032*V18 + 
      1.16286246847357638e-15*V02*V04*V18 + 6.31725940714921152e-16*V01*V05*V18 - 1.66021090089434833e-17*V08*V18 - 
      1.24398539482715316e-16*V013*V19 + 2.94460138811914213e-16*V02*V03*V19 + 1.87125560603696614e-16*V01*V04*V19 - 
      7.48178331515123269e-18*V07*V19 + 2.53588726412172258e-17*V022*V20 + 4.45623212546971308e-17*V01*V03*V20 - 
      2.83988482374650272e-18*V06*V20 + 7.49155648884796678e-18*V01*V02*V21 - 9.06880710673375232e-19*V05*V21 + 
      4.97594157930861262e-19*V012*V22 - 2.33439234584848493e-19*V04*V22 - 4.9284718784959042e-20*V03*V23 - 
      7.2600718890024651e-21*V02*V24 - 9.07508986125308138e-22*V01*V25 + 6.0179640989741919e-25*V28) + 
   delta6*eps11*(-2.49661808097621507e-9*V036 - 4.26038561333340795e-8*V02*V034*V04 - 
      6.35525387519264992e-8*V022*V032*V042 - 4.83292346032964941e-8*V01*V033*V042 - 
      3.48009271425128996e-9*V023*V043 - 5.21007542194428255e-8*V01*V02*V03*V043 - 
      3.88562403920447723e-9*V012*V044 + 7.74456172615070677e-10*V045 - 
      4.33178344404360152e-8*V022*V033*V05 - 2.14585667164907926e-8*V01*V034*V05 - 
      4.05750607908712866e-8*V023*V03*V04*V05 - 1.49701349905328914e-7*V01*V02*V032*V04*V05 - 
      3.81315232511558995e-8*V01*V022*V042*V05 - 4.14542305333481087e-8*V012*V03*V042*V05 + 
      1.74757770810771918e-8*V03*V043*V05 - 2.39083324048852658e-9*V024*V052 - 
      3.83066196167295525e-8*V01*V022*V03*V052 - 
      1.80376103167323091e-8*V012*V032*V052 - 
      2.15672748820465144e-8*V012*V02*V04*V052 + 2.50208225944889591e-8*V032*V04*V052 + 
      1.33552205247362602e-8*V02*V042*V052 - 1.0931822218562792e-9*V013*V053 + 
      8.75985166357305396e-9*V02*V03*V053 + 5.20810599820024563e-9*V01*V04*V053 - 
      1.48779795339320709e-8*V023*V032*V06 - 3.43121584273838304e-8*V01*V02*V033*V06 - 
      1.78831917683038053e-9*V024*V04*V06 - 5.51184596961167823e-8*V01*V022*V03*V04*V06 - 
      2.80922928946639527e-8*V012*V032*V04*V06 - 1.64962882079455804e-8*V012*V02*V042*V06 + 
      1.8942406412571866e-8*V032*V042*V06 + 5.66450426445252467e-9*V02*V043*V06 - 
      8.92678772035924254e-9*V01*V023*V05*V06 - 2.93794851767513907e-8*V012*V02*V03*V05*V06 + 
      1.18176763577933914e-8*V033*V05*V06 - 5.18481639171417276e-9*V013*V04*V05*V06 + 
      3.89480165738484644e-8*V02*V03*V04*V05*V06 + 1.18938744327780421e-8*V01*V042*V05*V06 + 
      4.93394369258030515e-9*V022*V052*V06 + 1.09980585927146159e-8*V01*V03*V052*V06 - 
      2.90935693102773385e-9*V012*V022*V062 - 1.72637399528795707e-9*V013*V03*V062 + 
      7.0439280037250256e-9*V02*V032*V062 + 3.09503195995822463e-9*V022*V04*V062 + 
      8.48663599829213159e-9*V01*V03*V04*V062 + 4.41494802311360294e-9*V01*V02*V05*V062 - 
      4.84192342238050314e-10*V052*V062 + 3.06606269118169895e-10*V012*V063 - 
      2.3609905663751539e-10*V04*V063 - 2.2769840385605015e-9*V024*V03*V07 - 
      1.79177086843174721e-8*V01*V022*V032*V07 - 5.54028518810008891e-9*V012*V033*V07 - 
      5.79643725583875523e-9*V01*V023*V04*V07 - 2.00156143389004272e-8*V012*V02*V03*V04*V07 + 
      8.24612384933782233e-9*V033*V04*V07 - 1.77952711019574461e-9*V013*V042*V07 + 
      1.32850691831887295e-8*V02*V03*V042*V07 + 2.72810098339074092e-9*V01*V043*V07 - 
      5.17986347072184624e-9*V012*V022*V05*V07 - 3.00001458976562176e-9*V013*V03*V05*V07 + 
      1.30002531630843894e-8*V02*V032*V05*V07 + 6.67320638621514296e-9*V022*V04*V05*V07 + 
      1.5359262313915318e-8*V01*V03*V04*V05*V07 + 4.05369906224963899e-9*V01*V02*V052*V07 - 
      2.95320892275880125e-10*V053*V07 - 1.25602716004587036e-9*V013*V02*V06*V07 + 
      4.89987598832738015e-9*V022*V03*V06*V07 + 5.39008937563491906e-9*V01*V032*V06*V07 + 
      6.05928022089994357e-9*V01*V02*V04*V06*V07 + 1.63292218138416486e-9*V012*V05*V06*V07 - 
      1.35522339946117897e-9*V04*V05*V06*V07 - 4.9177054136235004e-10*V03*V062*V07 - 
      4.42819314702863444e-11*V014*V072 + 2.73300107347243502e-10*V023*V072 + 
      1.98787540226761154e-9*V01*V02*V03*V072 + 5.70839279729497001e-10*V012*V04*V072 - 
      2.36194080412229453e-10*V042*V072 - 4.48932968279637233e-10*V03*V05*V072 - 
      1.80111790128789343e-10*V02*V06*V072 - 2.44145584190784027e-11*V01*V073 - 
      6.1591651792682389e-11*V025*V08 - 3.3205120028876497e-9*V01*V023*V03*V08 - 
      5.12971004917428142e-9*V012*V02*V032*V08 + 1.12654005149410709e-9*V034*V08 - 
      2.99579217556008662e-9*V012*V022*V04*V08 - 1.77931999951134116e-9*V013*V03*V04*V08 + 
      7.57072442063727112e-9*V02*V032*V04*V08 + 1.63909310102557311e-9*V022*V042*V08 + 
      4.56593896082372445e-9*V01*V03*V042*V08 - 9.42611166537989541e-10*V013*V02*V05*V08 + 
      3.86025914024896609e-9*V022*V03*V05*V08 + 4.15757927376058933e-9*V01*V032*V05*V08 + 
      4.73780983192891003e-9*V01*V02*V04*V05*V08 + 6.27676099485222348e-10*V012*V052*V08 - 
      5.31670146918461443e-10*V04*V052*V08 - 7.66171425620634154e-11*V014*V06*V08 + 
      3.95636370021983198e-10*V023*V06*V08 + 3.38492848473740677e-9*V01*V02*V03*V06*V08 + 
      9.88657452675484232e-10*V012*V04*V06*V08 - 3.87119861701422049e-10*V042*V06*V08 - 
      7.695276814491008e-10*V03*V05*V06*V08 - 1.46948279806190887e-10*V02*V062*V08 + 
      5.9700727167391108e-10*V01*V022*V07*V08 + 6.08501502443267155e-10*V012*V03*V07*V08 - 
      5.39598172457962928e-10*V03*V04*V07*V08 - 2.83515124264387506e-10*V02*V05*V07*V08 - 
      1.25932010249151538e-10*V01*V06*V07*V08 + 9.79822849116433203e-11*V012*V02*V082 - 
      7.60321202835209672e-11*V032*V082 - 8.00438662894526186e-11*V02*V04*V082 - 
      4.90581509132273981e-11*V01*V05*V082 + 5.30370390189967646e-13*V083 - 
      1.89748669880041792e-10*V01*V024*V09 - 1.38492783871933339e-9*V012*V022*V03*V09 - 
      3.92619956245540495e-10*V013*V032*V09 + 1.28926976485616982e-9*V02*V033*V09 - 
      4.94435450321130617e-10*V013*V02*V04*V09 + 2.00577754615659779e-9*V022*V03*V04*V09 + 
      2.26381328315603608e-9*V01*V032*V04*V09 + 1.24854198374475265e-9*V01*V02*V042*V09 - 
      5.06266999599834683e-11*V014*V05*V09 + 3.30997431172136471e-10*V023*V05*V09 + 
      2.39176482559352055e-9*V01*V02*V03*V05*V09 + 6.84796104831609499e-10*V012*V04*V05*V09 - 
      2.8964693312899592e-10*V042*V05*V09 - 2.7452581036405451e-10*V03*V052*V09 + 
      4.58543497875720728e-10*V01*V022*V06*V09 + 4.74776799562345758e-10*V012*V03*V06*V09 - 
      4.21594857816365011e-10*V03*V04*V06*V09 - 2.20749527071950243e-10*V02*V05*V06*V09 - 
      4.92822244041278936e-11*V01*V062*V09 + 1.76500396127192128e-10*V012*V02*V07*V09 - 
      1.38689184975927788e-10*V032*V07*V09 - 1.52857352811459595e-10*V02*V04*V07*V09 - 
      8.93272283859778263e-11*V01*V05*V07*V09 + 1.70090809796901564e-11*V013*V08*V09 - 
      8.79396612859014719e-11*V02*V03*V08*V09 - 5.39460898133261518e-11*V01*V04*V08*V09 + 2.94106739734106171e-12*V07*V08*V09 - 
      6.08730636079525797e-12*V022*V092 - 1.3637441496554828e-11*V01*V03*V092 + 
      1.15356416762231491e-12*V06*V092 - 1.10290212716417116e-10*V012*V023*V10 - 
      1.96961668981946391e-10*V013*V02*V03*V10 + 4.73736502833791189e-10*V022*V032*V10 + 
      3.30526268265465486e-10*V01*V033*V10 - 2.40308568958011191e-11*V014*V04*V10 + 
      1.306858449197228e-10*V023*V04*V10 + 1.14855445011369218e-9*V01*V02*V03*V04*V10 + 
      1.68032962650687216e-10*V012*V042*V10 - 4.50591365188107947e-11*V043*V10 + 
      2.95281792295839512e-10*V01*V022*V05*V10 + 2.96087417912995843e-10*V012*V03*V05*V10 - 
      2.70958150839110306e-10*V03*V04*V05*V10 - 7.13538949593980984e-11*V02*V052*V10 + 
      1.23973004586497602e-10*V012*V02*V06*V10 - 9.75850911950480834e-11*V032*V06*V10 - 
      1.02290832413024991e-10*V02*V04*V06*V10 - 6.29210003101351228e-11*V01*V05*V06*V10 + 
      1.37901305728218524e-11*V013*V07*V10 - 7.22394463607154801e-11*V02*V03*V07*V10 - 
      4.42014311579501796e-11*V01*V04*V07*V10 + 1.20693083515099705e-12*V072*V10 - 
      1.04548365252086475e-11*V022*V08*V10 - 2.45525098402197856e-11*V01*V03*V08*V10 + 
      2.04868873712807041e-12*V06*V08*V10 - 7.16738347520472014e-12*V01*V02*V09*V10 + 1.48553413763209583e-12*V05*V09*V10 - 
      4.76362356925007745e-13*V012*V102 + 3.64596047658544612e-13*V04*V102 - 
      2.2225852014699815e-11*V013*V022*V11 - 8.46041473549786817e-12*V014*V03*V11 + 
      6.68071543587624776e-11*V023*V03*V11 + 2.35400430463378888e-10*V01*V02*V032*V11 + 
      1.25999768576681367e-10*V01*V022*V04*V11 + 1.33242160559910272e-10*V012*V03*V04*V11 - 
      6.1093208918199871e-11*V03*V042*V11 + 7.08712637913533671e-11*V012*V02*V05*V11 - 
      5.73967385086297412e-11*V032*V05*V11 - 6.35821678907591332e-11*V02*V04*V05*V11 - 
      1.84336694398277715e-11*V01*V052*V11 + 8.89175146688824675e-12*V013*V06*V11 - 
      4.64625183219576854e-11*V02*V03*V06*V11 - 2.85686697464344414e-11*V01*V04*V06*V11 - 
      8.26546389412233474e-12*V022*V07*V11 - 1.84599259550681866e-11*V01*V03*V07*V11 + 
      1.56758121391240015e-12*V06*V07*V11 - 5.91926806409766088e-12*V01*V02*V08*V11 + 1.22978944900088456e-12*V05*V08*V11 - 
      8.73047668890433673e-13*V012*V09*V11 + 6.79875661187316609e-13*V04*V09*V11 + 
      3.18472665746274171e-13*V03*V10*V11 + 3.86507060780704276e-14*V02*V112 - 
      1.76086006982693143e-12*V014*V02*V12 + 2.65284831789715095e-12*V024*V12 + 
      4.94243888968296153e-11*V01*V022*V03*V12 + 2.4059427713600762e-11*V012*V032*V12 + 
      2.90634455322732559e-11*V012*V02*V04*V12 - 2.40332415562754902e-11*V032*V04*V12 - 
      1.24004736709692699e-11*V02*V042*V12 + 4.62159797731715339e-12*V013*V05*V12 - 
      2.53817340430362582e-11*V02*V03*V05*V12 - 1.54582452810502205e-11*V01*V04*V05*V12 - 
      4.65443001013582812e-12*V022*V06*V12 - 1.10195143774801306e-11*V01*V03*V06*V12 + 
      4.62275445114552831e-13*V062*V12 - 4.11091841812275455e-12*V01*V02*V07*V12 + 
      8.54827264660022273e-13*V05*V07*V12 - 6.6677690271151634e-13*V012*V08*V12 + 5.11140088822477658e-13*V04*V08*V12 + 
      2.69716890703278048e-13*V03*V09*V12 + 7.01887047142654836e-14*V02*V10*V12 + 1.89467326589422553e-14*V01*V11*V12 - 
      4.66110018483599495e-14*V015*V13 + 2.99423691357777777e-12*V01*V023*V13 + 
      9.82167794662163755e-12*V012*V02*V03*V13 - 2.87880905295321031e-12*V033*V13 + 
      1.77930100984392145e-12*V013*V04*V13 - 9.67816167205109803e-12*V02*V03*V04*V13 - 
      2.98580071451049345e-12*V01*V042*V13 - 2.48794034649747452e-12*V022*V05*V13 - 
      5.49948735789160165e-12*V01*V03*V05*V13 - 2.26100990709481797e-12*V01*V02*V06*V13 + 4.7500858695694337e-13*V05*V06*V13 - 
      4.26483138776411711e-13*V012*V07*V13 + 3.34748910337749257e-13*V04*V07*V13 + 
      1.91031803190879603e-13*V03*V08*V13 + 5.60095614202921938e-14*V02*V09*V13 + 1.62074470333207622e-14*V01*V10*V13 - 
      6.43752435954743197e-17*V132 + 9.10425077769586236e-13*V012*V022*V14 + 
      5.39910771410169415e-13*V013*V03*V14 - 1.66140669058117387e-12*V02*V032*V14 - 
      8.28263992410037937e-13*V022*V04*V14 - 2.00219641298408411e-12*V01*V03*V04*V14 - 
      1.06363153783049786e-12*V01*V02*V05*V14 + 1.12234590097211278e-13*V052*V14 - 
      2.21355079481772612e-13*V012*V06*V14 + 1.70954099969788965e-13*V04*V06*V14 + 
      1.15073071065298605e-13*V03*V07*V14 + 3.64577550958467795e-14*V02*V08*V14 + 1.18950180456313298e-14*V01*V09*V14 - 
      1.19600364870750189e-16*V12*V14 + 9.71062538507498948e-14*V013*V02*V15 - 
      2.85947268917745482e-13*V022*V03*V15 - 3.0871699887519981e-13*V01*V032*V15 - 
      3.55411636751721068e-13*V01*V02*V04*V15 - 9.56295552285267934e-14*V012*V05*V15 + 
      7.69887767065883574e-14*V04*V05*V15 + 5.59914492163303378e-14*V03*V06*V15 + 2.09270410588993816e-14*V02*V07*V15 + 
      7.37375232850873924e-15*V01*V08*V15 - 9.76340983082182663e-17*V11*V15 + 3.23687512835832983e-15*V014*V16 - 
      1.39609618717725926e-14*V023*V16 - 1.05698917519649446e-13*V01*V02*V03*V16 - 
      3.08646430976438706e-14*V012*V04*V16 + 1.21795591493021946e-14*V042*V16 + 
      2.33127207864400535e-14*V03*V05*V16 + 9.39590908722569e-15*V02*V06*V16 + 3.91432583953079108e-15*V01*V07*V16 - 
      6.8486373534522317e-17*V10*V16 - 8.15973999748765058e-15*V01*V022*V17 - 
      8.26669761042470843e-15*V012*V03*V17 + 7.12626876408814967e-15*V03*V04*V17 + 
      3.78036522690319113e-15*V02*V05*V17 + 1.69613932127181637e-15*V01*V06*V17 - 4.21126985370719144e-17*V09*V17 - 
      1.28067668122003484e-15*V012*V02*V18 + 9.60189184686046794e-16*V032*V18 + 
      1.05979178633247677e-15*V02*V04*V18 + 6.29005926858352959e-16*V01*V05*V18 - 2.19183431885879037e-17*V08*V18 - 
      5.62934804931883448e-17*V013*V19 + 2.81701958634663342e-16*V02*V03*V19 + 1.73672088926306661e-16*V01*V04*V19 - 
      9.96873024851350019e-18*V07*V19 + 1.85321711972813694e-17*V022*V20 + 4.17241916131655518e-17*V01*V03*V20 - 
      3.6971583673871015e-18*V06*V20 + 5.61594483967759916e-18*V01*V02*V21 - 1.20219344254302358e-18*V05*V21 + 
      3.61886660313353645e-19*V012*V22 - 2.88913630044405791e-19*V04*V22 - 6.29206230380213642e-20*V03*V23 - 
      7.44622757846406677e-21*V02*V24 - 9.30778447308008347e-22*V01*V25 + 8.02395213196558919e-25*V28) + 
   delta2*eps13*(6.26037729789820904e-8*V025*V032 + 
      4.32286855970912927e-7*V01*V023*V033 + 2.65611018375665901e-7*V012*V02*V034 - 
      1.0056479547259229e-8*V036 + 6.86627585651083939e-9*V026*V04 + 
      3.95802566746899341e-7*V01*V024*V03*V04 + 1.07162878384648343e-6*V012*V022*V032*V04 + 
      1.78563679745402434e-7*V013*V033*V04 - 2.00100852048114414e-7*V02*V034*V04 + 
      2.40940930801944652e-7*V012*V023*V042 + 
      3.71028688605719418e-7*V013*V02*V03*V042 - 3.786789464730803e-7*V022*V032*V042 - 
      2.36280973326511114e-7*V01*V033*V042 + 1.49288633236900044e-8*V014*V043 - 
      4.47785160224899766e-8*V023*V043 - 3.11478549885343524e-7*V01*V02*V03*V043 - 
      2.30545145737442503e-8*V012*V044 + 2.19249275444418889e-9*V045 + 
      3.75622637873892542e-8*V01*V025*V05 + 3.80256762866230264e-7*V012*V023*V03*V05 + 
      2.93511920167790849e-7*V013*V02*V032*V05 - 2.22910418782730152e-7*V022*V033*V05 - 
      9.93600987223710436e-8*V01*V034*V05 + 2.03066187598021165e-7*V013*V022*V04*V05 + 
      7.068880712087995e-8*V014*V03*V04*V05 - 2.71181513017230613e-7*V023*V03*V04*V05 - 
      7.99658959096722232e-7*V01*V02*V032*V04*V05 - 2.55860711226782637e-7*V01*V022*V042*V05 - 
      2.29459772380387721e-7*V012*V03*V042*V05 + 4.01679166923128863e-8*V03*V043*V05 + 
      1.93668779267081088e-8*V014*V02*V052 - 1.77379742813162922e-8*V024*V052 - 
      2.22534401542033469e-7*V01*V022*V03*V052 - 9.521874323339043e-8*V012*V032*V052 - 
      1.29568314594432361e-7*V012*V02*V04*V052 + 5.27035762312654575e-8*V032*V04*V052 + 
      3.38001761885005644e-8*V02*V042*V052 - 6.53865642029561654e-9*V013*V053 + 
      1.99735057415167033e-8*V02*V03*V053 + 1.22479913352590455e-8*V01*V04*V053 + 
      4.23093812467791226e-8*V012*V024*V06 + 1.33534491939312201e-7*V013*V022*V03*V06 + 
      2.31786657294360376e-8*V014*V032*V06 - 9.86821340376802218e-8*V023*V032*V06 - 
      1.87628983514970859e-7*V01*V02*V033*V06 + 3.22085884826606115e-8*V014*V02*V04*V06 - 
      2.54812550973248439e-8*V024*V04*V06 - 3.66514117038712385e-7*V01*V022*V03*V04*V06 - 
      1.5958495148039661e-7*V012*V032*V04*V06 - 1.08852043899466103e-7*V012*V02*V042*V06 + 
      4.34041600832955616e-8*V032*V042*V06 + 1.77200747105181666e-8*V02*V043*V06 + 
      2.28056978100745608e-9*V015*V05*V06 - 6.60077636103449389e-8*V01*V023*V05*V06 - 
      1.80647912983891509e-7*V012*V02*V03*V05*V06 + 2.51194422978490909e-8*V033*V05*V06 - 
      3.3036760746107917e-8*V013*V04*V05*V06 + 9.79806517215620028e-8*V02*V03*V04*V05*V06 + 
      3.04115383559460582e-8*V01*V042*V05*V06 + 1.36283104170069822e-8*V022*V052*V06 + 
      2.61204247533627771e-8*V01*V03*V052*V06 - 2.11807889001744888e-8*V012*V022*V062 - 
      1.1333556656753781e-8*V013*V03*V062 + 1.76746991456447859e-8*V02*V032*V062 + 
      1.06677036842741399e-8*V022*V04*V062 + 2.1702681959296302e-8*V01*V03*V04*V062 + 
      1.23289861151022954e-8*V01*V02*V05*V062 - 7.90901730498100935e-10*V052*V062 + 
      8.69955863714949038e-10*V012*V063 - 4.28930339326720835e-10*V04*V063 + 
      1.7269235611954644e-8*V013*V023*V07 + 1.80196135531394635e-8*V014*V02*V03*V07 - 
      1.8548270418758121e-8*V024*V03*V07 - 1.13948565609417724e-7*V01*V022*V032*V07 - 
      3.20680607512308394e-8*V012*V033*V07 + 1.61914634735012886e-9*V015*V04*V07 - 
      4.7288839506620564e-8*V01*V023*V04*V07 - 1.31384056746108091e-7*V012*V02*V03*V04*V07 + 
      1.83196164302877053e-8*V033*V04*V07 - 1.2047569175203672e-8*V013*V042*V07 + 
      3.54792234131722972e-8*V02*V03*V042*V07 + 7.37777134042991446e-9*V01*V043*V07 - 
      3.66318637990656579e-8*V012*V022*V05*V07 - 1.96262914574951561e-8*V013*V03*V05*V07 + 
      3.1297380532310738e-8*V02*V032*V05*V07 + 1.96511394126519307e-8*V022*V04*V05*V07 + 
      3.81400923195861699e-8*V01*V03*V04*V05*V07 + 1.08726304366174659e-8*V01*V02*V052*V07 - 
      4.66805721270364971e-10*V053*V07 - 9.37224948779954554e-9*V013*V02*V06*V07 + 
      1.43114854589958633e-8*V022*V03*V06*V07 + 1.35332733566607584e-8*V01*V032*V06*V07 + 
      1.79211033285429649e-8*V01*V02*V04*V06*V07 + 4.55414833979787922e-9*V012*V05*V06*V07 - 
      2.30576331233322882e-9*V04*V05*V06*V07 - 8.32632663866097855e-10*V03*V062*V07 - 
      3.56422123491067297e-10*V014*V072 + 9.38987455031989622e-10*V023*V072 + 
      5.64466615821918792e-9*V01*V02*V03*V072 + 1.66530240177509072e-9*V012*V04*V072 - 
      4.19734176015411067e-10*V042*V072 - 7.36328011081932439e-10*V03*V05*V072 - 
      3.45983715856640743e-10*V02*V06*V072 - 4.59703508778850503e-11*V01*V073 + 
      3.03321094528202371e-9*V014*V022*V08 - 1.04471088085659645e-9*V025*V08 + 
      7.83763996080172551e-10*V015*V03*V08 - 2.63937953457177631e-8*V01*V023*V03*V08 - 
      3.50566928973522331e-8*V012*V02*V032*V08 + 2.53313431522826346e-9*V034*V08 - 
      2.36319893513054495e-8*V012*V022*V04*V08 - 1.26474364551414176e-8*V013*V03*V04*V08 + 
      1.9953363374100479e-8*V02*V032*V04*V08 + 5.99519201575933914e-9*V022*V042*V08 + 
      1.22625520447323922e-8*V01*V03*V042*V08 - 7.16912037204157159e-9*V013*V02*V05*V08 + 
      1.11541958989999938e-8*V022*V03*V05*V08 + 1.04698608963253418e-8*V01*V032*V05*V08 + 
      1.39123975502834464e-8*V01*V02*V04*V05*V08 + 1.75830385152653858e-9*V012*V052*V08 - 
      8.97418632544638092e-10*V04*V052*V08 - 6.29395016672954164e-10*V014*V06*V08 + 
      1.5886748524893385e-9*V023*V06*V08 + 9.94336310560763942e-9*V01*V02*V03*V06*V08 + 
      2.94820165189933703e-9*V012*V04*V06*V08 - 7.29384657133766073e-10*V042*V06*V08 - 
      1.29495456392085736e-9*V03*V05*V06*V08 - 3.00324904831965124e-10*V02*V062*V08 + 
      2.02862826846065116e-9*V01*V022*V07*V08 + 1.80786199791238447e-9*V012*V03*V07*V08 - 
      9.45167289704024987e-10*V03*V04*V07*V08 - 5.39343867628521465e-10*V02*V05*V07*V08 - 
      2.43084042759038705e-10*V01*V06*V07*V08 + 3.35452430689708632e-10*V012*V02*V082 - 
      1.32292084412831336e-10*V032*V082 - 1.70110732268529292e-10*V02*V04*V082 - 
      9.43311982681580721e-11*V01*V05*V082 + 8.21637941907666639e-13*V083 + 
      2.3114395816601699e-10*V015*V02*V09 - 1.95942959641549458e-9*V01*V024*V09 - 
      1.1279391898141591e-8*V012*V022*V03*V09 - 2.96983274530447457e-9*V013*V032*V09 + 
      3.3499775104416207e-9*V02*V033*V09 - 4.14151236512458962e-9*V013*V02*V04*V09 + 
      6.37297699327406587e-9*V022*V03*V04*V09 + 6.07421868620520999e-9*V01*V032*V04*V09 + 
      4.0048526338949564e-9*V01*V02*V042*V09 - 4.30909278909142232e-10*V014*V05*V09 + 
      1.1596879253737509e-9*V023*V05*V09 + 6.93903765995887209e-9*V01*V02*V03*V05*V09 + 
      2.04341393515044019e-9*V012*V04*V05*V09 - 5.1850245911125742e-10*V042*V05*V09 - 
      4.54321365784394465e-10*V03*V052*V09 + 1.6067111920432139e-9*V01*V022*V06*V09 + 
      1.43643437206426077e-9*V012*V03*V06*V09 - 7.49981534908386298e-10*V03*V04*V06*V09 - 
      4.27517072375866469e-10*V02*V05*V06*V09 - 9.65503667363073166e-11*V01*V062*V09 + 
      6.02020936065519019e-10*V012*V02*V07*V09 - 2.38718295375480113e-10*V032*V07*V09 - 
      3.10667159008854608e-10*V02*V04*V07*V09 - 1.70043575180262805e-10*V01*V05*V07*V09 + 
      6.09077193529588257e-11*V013*V08*V09 - 1.75696170557529793e-10*V02*V03*V08*V09 - 
      1.09663819995065411e-10*V01*V04*V08*V09 + 4.46497234172275058e-12*V07*V08*V09 - 
      1.42528415799870108e-11*V022*V092 - 2.74113180136972269e-11*V01*V03*V092 + 
      1.77303866649813176e-12*V06*V092 + 6.19926324583187328e-12*V016*V10 - 
      1.08013598211852221e-9*V012*V023*V10 - 1.75570881426551545e-9*V013*V02*V03*V10 + 
      1.47307460970132083e-9*V022*V032*V10 + 9.04896052257042606e-10*V01*V033*V10 - 
      2.24642833193929071e-10*V014*V04*V10 + 5.75877358442485548e-10*V023*V04*V10 + 
      3.63624248841115733e-9*V01*V02*V03*V04*V10 + 5.39568743006184196e-10*V012*V042*V10 - 
      8.93783511579785148e-11*V043*V10 + 1.02043843621241647e-9*V01*V022*V05*V10 + 
      9.04205048358374603e-10*V012*V03*V05*V10 - 4.77151607123061347e-10*V03*V04*V05*V10 - 
      1.36304962154936436e-10*V02*V052*V10 + 4.34684552305441662e-10*V012*V02*V06*V10 - 
      1.71766859580324334e-10*V032*V06*V10 - 2.20617707752033349e-10*V02*V04*V06*V10 - 
      1.22486998470881226e-10*V01*V05*V06*V10 + 4.96346324840088191e-11*V013*V07*V10 - 
      1.4373321721592951e-10*V02*V03*V07*V10 - 8.96259820389039816e-11*V01*V04*V07*V10 + 
      1.82594934724659227e-12*V072*V10 - 2.55378844470172402e-11*V022*V08*V10 - 
      4.97209607691980023e-11*V01*V03*V08*V10 + 3.20226136731066484e-12*V06*V08*V10 - 1.66424128279075483e-11*V01*V02*V09*V10 + 
      2.25874092088892671e-12*V05*V09*V10 - 1.12653412881304331e-12*V012*V102 + 
      5.92609032826688976e-13*V04*V102 - 2.35307874331137145e-10*V013*V022*V11 - 
      8.59390346579136569e-11*V014*V03*V11 + 2.56122800222029521e-10*V023*V03*V11 + 
      7.49755212651196611e-10*V01*V02*V032*V11 + 4.86471165308878208e-10*V01*V022*V04*V11 + 
      4.3713910750440046e-10*V012*V03*V04*V11 - 1.14780689171311559e-10*V03*V042*V11 + 
      2.50421907850127219e-10*V012*V02*V05*V11 - 1.00095716619238854e-10*V032*V05*V11 - 
      1.30555855138937328e-10*V02*V04*V05*V11 - 3.56124023162364183e-11*V01*V052*V11 + 
      3.28078102742084746e-11*V013*V06*V11 - 9.47291834291967603e-11*V02*V03*V06*V11 - 
      5.91897930748147892e-11*V01*V04*V06*V11 - 1.93856434348288081e-11*V022*V07*V11 - 
      3.72456668581856948e-11*V01*V03*V07*V11 + 2.41080199563574167e-12*V06*V07*V11 - 1.38343978742014259e-11*V01*V02*V08*V11 + 
      1.87750330278607734e-12*V05*V08*V11 - 2.06379980709586934e-12*V012*V09*V11 + 
      1.09092874076500041e-12*V04*V09*V11 + 5.0298800777905358e-13*V03*V10*V11 + 7.0070765338504517e-14*V02*V112 - 
      2.1208005841003777e-11*V014*V02*V12 + 1.43260393895278697e-11*V024*V12 + 
      1.87465703907169474e-10*V01*V022*V03*V12 + 8.15053018303082035e-11*V012*V032*V12 + 
      1.11649857489976707e-10*V012*V02*V04*V12 - 4.4564767919231618e-11*V032*V04*V12 - 
      2.84835600049112391e-11*V02*V042*V12 + 1.73871521984163422e-11*V013*V05*V12 - 
      5.10750075917268583e-11*V02*V03*V05*V12 - 3.17784325607582635e-11*V01*V04*V05*V12 - 
      1.16381576566694122e-11*V022*V06*V12 - 2.27141689369831666e-11*V01*V03*V06*V12 + 
      7.31381556139377256e-13*V062*V12 - 9.56832624987960252e-12*V01*V02*V07*V12 + 
      1.29918256119366774e-12*V05*V07*V12 - 1.58491086696809916e-12*V012*V08*V12 + 
      8.33446556463244752e-13*V04*V08*V12 + 4.25530730443919345e-13*V03*V09*V12 + 1.28805732732071082e-13*V02*V10*V12 + 
      3.43922679955297765e-14*V01*V11*V12 - 6.52554025877039293e-13*V015*V13 + 
      1.40670431381859411e-11*V01*V023*V13 + 3.87184829818105716e-11*V012*V02*V03*V13 - 
      5.32620413852048442e-12*V033*V13 + 7.21263636637434183e-12*V013*V04*V13 - 
      2.10052472792949051e-11*V02*V03*V04*V13 - 6.57704165621252631e-12*V01*V042*V13 - 
      5.91280120430917342e-12*V022*V05*V13 - 1.13084914015245695e-11*V01*V03*V05*V13 - 
      5.41157832841609232e-12*V01*V02*V06*V13 + 7.34867886046282007e-13*V05*V06*V13 - 
      1.01573925615648402e-12*V012*V07*V13 + 5.37612816248197697e-13*V04*V07*V13 + 
      3.03057183654965243e-13*V03*V08*V13 + 1.01567905899118282e-13*V02*V09*V13 + 2.94634403383630342e-14*V01*V10*V13 - 
      9.6568031213594039e-17*V132 + 4.23286160535418791e-12*V012*V022*V14 + 
      2.29364971595471251e-12*V013*V03*V14 - 3.55109930502696861e-12*V02*V032*V14 - 
      2.22905375128135736e-12*V022*V04*V14 - 4.3827866246146841e-12*V01*V03*V04*V14 - 
      2.52199778603470324e-12*V01*V02*V05*V14 + 1.71668370770168171e-13*V052*V14 - 
      5.38067360972162115e-13*V012*V06*V14 + 2.8277801582513226e-13*V04*V06*V14 + 1.81793451574552243e-13*V03*V07*V14 + 
      6.72568307750133747e-14*V02*V08*V14 + 2.16039025365449634e-14*V01*V09*V14 - 1.8004300704052234e-16*V12*V14 + 
      4.77762768945689482e-13*V013*V02*V15 - 7.24117615574366523e-13*V022*V03*V15 - 
      6.80930463628860136e-13*V01*V032*V15 - 9.12230925712573974e-13*V01*V02*V04*V15 - 
      2.33698865924940589e-13*V012*V05*V15 + 1.24464156570915188e-13*V04*V05*V15 + 
      9.00859793439058392e-14*V03*V06*V15 + 3.79980993329021327e-14*V02*V07*V15 + 1.3473894818080785e-14*V01*V08*V15 - 
      1.46461479103092518e-16*V11*V15 + 1.74791256931349811e-14*V014*V16 - 4.44825721573317806e-14*V023*V16 - 
      2.69225580940119444e-13*V01*V02*V03*V16 - 8.02978247680623291e-14*V012*V04*V16 + 
      2.11371564748402071e-14*V042*V16 + 3.71537976495766168e-14*V03*V05*V16 + 1.76383558236728567e-14*V02*V06*V16 + 
      7.13233371645080865e-15*V01*V07*V16 - 1.03218422065554138e-16*V10*V16 - 2.46324186786622714e-14*V01*V022*V17 - 
      2.1924300170650675e-14*V012*V03*V17 + 1.20094852636974912e-14*V03*V04*V17 + 6.92055462711326482e-15*V02*V05*V17 + 
      3.1493186613769601e-15*V01*V06*V17 - 6.31793794463729905e-17*V09*V17 - 3.90837593138421937e-15*V012*V02*V18 + 
      1.60247936770006911e-15*V032*V18 + 2.10075206311901791e-15*V02*V04*V18 + 1.16097764211777766e-15*V01*V05*V18 - 
      3.31561898500058733e-17*V08*V18 - 1.80943330156676823e-16*V013*V19 + 5.40568198843072007e-16*V02*V03*V19 + 
      3.39494923206464888e-16*V01*V04*V19 - 1.49634270135353692e-17*V07*V19 + 4.23206344422005235e-17*V022*V20 + 
      8.13491055162726215e-17*V01*V03*V20 - 5.65926592798230618e-18*V06*V20 + 1.25906400567354289e-17*V01*V02*V21 - 
      1.81362180457965426e-18*V05*V21 + 8.29323596551435437e-19*V012*V22 - 4.60735331417464132e-19*V04*V22 - 
      9.84298208028218827e-20*V03*V23 - 1.34032096412353202e-20*V02*V24 - 1.67540120515441502e-21*V01*V25 + 
      1.20359281979483838e-24*V28) + delta4*eps12*
    (1.20882353260258126e-8*V025*V032 + 1.04426097371018395e-7*V01*V023*V033 + 
      6.9719079284711093e-8*V012*V02*V034 - 7.23344550992912055e-9*V036 + 
      5.52620037914155561e-11*V026*V04 + 7.90326424631072416e-8*V01*V024*V03*V04 + 
      2.54323416726398753e-7*V012*V022*V032*V04 + 
      4.51281960847592656e-8*V013*V033*V04 - 1.324883216725678e-7*V02*V034*V04 + 
      5.06434542722669084e-8*V012*V023*V042 + 
      8.66226005370204717e-8*V013*V02*V03*V042 - 
      2.22409766088872341e-7*V022*V032*V042 - 1.53016681070112025e-7*V01*V033*V042 + 
      3.41313722134800566e-9*V014*V043 - 1.96395897468419557e-8*V023*V043 - 
      1.82156807683404165e-7*V01*V02*V03*V043 - 1.34927607259456209e-8*V012*V044 + 
      1.73105497543500998e-9*V045 + 7.25294119561548755e-9*V01*V025*V05 + 
      8.59807307885671175e-8*V012*V023*V03*V05 + 6.99591777342322005e-8*V013*V02*V032*V05 - 
      1.39049724059185477e-7*V022*V033*V05 - 6.57865723958235981e-8*V01*V034*V05 + 
      4.46305625278255997e-8*V013*V022*V04*V05 + 1.61950340242143074e-8*V014*V03*V04*V05 - 
      1.47756732055728671e-7*V023*V03*V04*V05 - 4.89030123593119722e-7*V01*V02*V032*V04*V05 - 
      1.38963331863418844e-7*V01*V022*V042*V05 - 1.37800085223021031e-7*V012*V03*V042*V05 + 
      3.44050669150184239e-8*V03*V043*V05 + 4.18302667587798307e-9*V014*V02*V052 - 
      9.04196340258141116e-9*V024*V052 - 1.28790956572407237e-7*V01*V022*V03*V052 - 
      5.83555802365083814e-8*V012*V032*V052 - 
      7.37360574267513578e-8*V012*V02*V04*V052 + 4.69398212292297161e-8*V032*V04*V052 + 
      2.73458931028917595e-8*V02*V042*V052 - 3.72952775189787807e-9*V013*V053 + 
      1.6958793336841598e-8*V02*V03*V053 + 1.02386762080878323e-8*V01*V04*V053 + 
      8.71170327812938561e-9*V012*V024*V06 + 2.89591202453743303e-8*V013*V022*V03*V06 + 
      5.14017324083364388e-9*V014*V032*V06 - 5.41574870492825955e-8*V023*V032*V06 - 
      1.13699493062326463e-7*V01*V02*V033*V06 + 6.72413420064563855e-9*V014*V02*V04*V06 - 
      1.03756170676674664e-8*V024*V04*V06 - 2.00346967720785699e-7*V01*V022*V03*V04*V06 - 
      9.4732859862585303e-8*V012*V032*V04*V06 - 5.95676145783665186e-8*V012*V02*V042*V06 + 
      3.73178531516166455e-8*V032*V042*V06 + 1.32159742949447015e-8*V02*V043*V06 + 
      4.60713500269600487e-10*V015*V05*V06 - 3.37780054041672907e-8*V01*V023*V05*V06 - 
      1.01912862830765567e-7*V012*V02*V03*V05*V06 + 2.23348100714193579e-8*V033*V05*V06 - 
      1.83126783282942847e-8*V013*V04*V05*V06 + 7.97301498466301465e-8*V02*V03*V04*V05*V06 + 
      2.45304974411087697e-8*V01*V042*V05*V06 + 1.04873740107954018e-8*V022*V052*V06 + 
      2.17844261436320787e-8*V01*V03*V052*V06 - 1.0911096004189193e-8*V012*V022*V062 - 
      6.19369308313955983e-9*V013*V03*V062 + 1.44345788288939075e-8*V02*V032*V062 + 
      7.52095144554799776e-9*V022*V04*V062 + 1.75328066449056264e-8*V01*V03*V04*V062 + 
      9.45427784090595249e-9*V01*V02*V05*V062 - 7.70529739619229361e-10*V052*V062 + 
      6.62001241850818438e-10*V012*V063 - 3.99981412133341695e-10*V04*V063 + 
      3.33215319513658294e-9*V013*V023*V07 + 3.57136603562257157e-9*V014*V02*V03*V07 - 
      8.94594528544603356e-9*V024*V03*V07 - 6.29789259431921199e-8*V01*V022*V032*V07 - 
      1.87936322738569965e-8*V012*V033*V07 + 3.09963162291593664e-10*V015*V04*V07 - 
      2.27966376917771864e-8*V01*V023*V04*V07 - 7.15304904904188209e-8*V012*V02*V03*V04*V07 + 
      1.59574377651104258e-8*V033*V04*V07 - 6.47274061062662212e-9*V013*V042*V07 + 
      2.80661408894938849e-8*V02*V03*V042*V07 + 5.79788133003006763e-9*V01*V043*V07 - 
      1.89350223704757276e-8*V012*V022*V05*V07 - 1.07012255785477306e-8*V013*V03*V05*V07 + 
      2.59524523300590123e-8*V02*V032*V05*V07 + 1.46388001108568292e-8*V022*V04*V05*V07 + 
      3.1127191581057809e-8*V01*V03*V04*V05*V07 + 8.45935591506244628e-9*V01*V02*V052*V07 - 
      4.60775985578051114e-10*V053*V07 - 4.74234229789098545e-9*V013*V02*V06*V07 + 
      1.07393279794729315e-8*V022*V03*V06*V07 + 1.10090898685328405e-8*V01*V032*V06*V07 + 
      1.33582456330230875e-8*V01*V02*V04*V06*V07 + 3.48362573500462324e-9*V012*V05*V06*V07 - 
      2.2032984342683328e-9*V04*V05*V06*V07 - 7.99139107397828057e-10*V03*V062*V07 - 
      1.73530910238513601e-10*V014*V072 + 6.40666703698504504e-10*V023*V072 + 
      4.27646404882137475e-9*V01*V02*V03*V072 + 1.2450965718386082e-9*V012*V04*V072 - 
      3.92905777070812353e-10*V042*V072 - 7.15578374379870009e-10*V03*V05*V072 - 
      3.09694258732338897e-10*V02*V06*V072 - 4.14768341729476862e-11*V01*V073 + 
      5.32251030106422263e-10*V014*V022*V08 - 3.7599196224330001e-10*V025*V08 + 
      1.39926227548776568e-10*V015*V03*V08 - 1.29607199114575347e-8*V01*V023*V03*V08 - 
      1.87787565822432913e-8*V012*V02*V032*V08 + 2.20249261839429827e-9*V034*V08 - 
      1.16240437448587649e-8*V012*V022*V04*V08 - 6.6443470413816776e-9*V013*V03*V04*V08 + 
      1.59373880158148374e-8*V02*V032*V04*V08 + 4.10863213632520728e-9*V022*V042*V08 + 
      9.69019621454820376e-9*V01*V03*V042*V08 - 3.59849807784135024e-9*V013*V02*V05*V08 + 
      8.42325230947116132e-9*V022*V03*V05*V08 + 8.51769281088870386e-9*V01*V032*V05*V08 + 
      1.04141439935135217e-8*V01*V02*V04*V05*V08 + 1.34401063281953465e-9*V012*V052*V08 - 
      8.61241971193464998e-10*V04*V052*V08 - 3.05016292273996891e-10*V014*V06*V08 + 
      1.02953600221241218e-9*V023*V06*V08 + 7.45566703073174797e-9*V01*V02*V03*V06*V08 + 
      2.19130998543030349e-9*V012*V04*V06*V08 - 6.6905946103917063e-10*V042*V06*V08 - 
      1.24720512530691495e-9*V03*V05*V06*V08 - 2.63072992129871742e-10*V02*V062*V08 + 
      1.39859646064307274e-9*V01*V022*V07*V08 + 1.34354140443118404e-9*V012*V03*V07*V08 - 
      8.93225254027936508e-10*V03*V04*V07*V08 - 4.85337063910672764e-10*V02*V05*V07*V08 - 
      2.17489322951947217e-10*V01*V06*V07*V08 + 2.30893271575664754e-10*V012*V02*V082 - 
      1.25747164684605609e-10*V032*V082 - 1.46299824985844711e-10*V02*V04*V082 - 
      8.46083818310006371e-11*V01*V05*V082 + 8.12672495620012848e-13*V083 + 
      3.66051734515786803e-11*V015*V02*V09 - 8.29133332629294245e-10*V01*V024*V09 - 
      5.47087570944765504e-9*V012*V022*V03*V09 - 1.51631914791537193e-9*V013*V032*V09 + 
      2.69669756136912825e-9*V02*V033*V09 - 1.98663118520845969e-9*V013*V02*V04*V09 + 
      4.61220388749224967e-9*V022*V03*V04*V09 + 4.80632079808038063e-9*V01*V032*V04*V09 + 
      2.88370634770292973e-9*V01*V02*V042*V09 - 2.05719876229253226e-10*V014*V05*V09 + 
      7.89190574074530246e-10*V023*V05*V09 + 5.22812950672100975e-9*V01*V02*V03*V05*V09 + 
      1.51791882925948914e-9*V012*V04*V05*V09 - 4.84854684995298139e-10*V042*V05*V09 - 
      4.40672046256432976e-10*V03*V052*V09 + 1.09662515229161045e-9*V01*V022*V06*V09 + 
      1.0613831516673568e-9*V012*V03*V06*V09 - 7.04914834356448994e-10*V03*V04*V06*V09 - 
      3.82230795717939654e-10*V02*V05*V06*V09 - 8.5942197180477207e-11*V01*V062*V09 + 
      4.14350377197574503e-10*V012*V02*V07*V09 - 2.27728148229236456e-10*V032*V07*V09 - 
      2.71296133326879144e-10*V02*V04*V07*V09 - 1.53009091405004201e-10*V01*V05*V07*V09 + 
      4.10498544838390642e-11*V013*V08*V09 - 1.55152746080081988e-10*V02*V03*V08*V09 - 
      9.59423029015289857e-11*V01*V04*V08*V09 + 4.44773535618112588e-12*V07*V08*V09 - 
      1.15555001237355942e-11*V022*V092 - 2.41257779299523541e-11*V01*V03*V092 + 
      1.75819821034290929e-12*V06*V092 + 8.8560903511883904e-13*V016*V10 - 
      4.7028558739918174e-10*V012*V023*V10 - 8.1843740245514698e-10*V013*V02*V03*V10 + 
      1.08025794505111839e-9*V022*V032*V10 + 7.1154440620899848e-10*V01*V033*V10 - 
      1.02649078820550699e-10*V014*V04*V10 + 3.57535624229162578e-10*V023*V04*V10 + 
      2.63925751474864757e-9*V01*V02*V03*V04*V10 + 3.88468872118375081e-10*V012*V042*V10 - 
      8.02194685956035236e-11*V043*V10 + 7.01148303994630507e-10*V01*V022*V05*V10 + 
      6.66210883791491801e-10*V012*V03*V05*V10 - 4.50711553031096479e-10*V03*V04*V05*V10 - 
      1.22690085869169305e-10*V02*V052*V10 + 2.96824185621000256e-10*V012*V02*V06*V10 - 
      1.62614166065059905e-10*V032*V06*V10 - 1.88755241645819331e-10*V02*V04*V06*V10 - 
      1.09389510016645682e-10*V01*V05*V06*V10 + 3.33774532149794918e-11*V013*V07*V10 - 
      1.27115440921079826e-10*V02*V03*V07*V10 - 7.84755984592965309e-11*V01*V04*V07*V10 + 
      1.82130306750850787e-12*V072*V10 - 2.04109508615751688e-11*V022*V08*V10 - 
      4.3660858041144564e-11*V01*V03*V08*V10 + 3.15711796440761009e-12*V06*V08*V10 - 1.35716438685426404e-11*V01*V02*V09*V10 + 
      2.25146259575764275e-12*V05*V09*V10 - 9.11392969230539979e-13*V012*V102 + 
      5.74360148619121813e-13*V04*V102 - 9.9642669201331482e-11*V013*V022*V11 - 
      3.77898697485578291e-11*V014*V03*V11 + 1.68168394627053444e-10*V023*V03*V11 + 
      5.43769172804245806e-10*V01*V02*V032*V11 + 3.18163757684645535e-10*V01*V022*V04*V11 + 
      3.12142097152999357e-10*V012*V03*V04*V11 - 1.05468421638837286e-10*V03*V042*V11 + 
      1.70517703181524832e-10*V012*V02*V05*V11 - 9.51761282987384297e-11*V032*V05*V11 - 
      1.13828360332427639e-10*V02*V04*V05*V11 - 3.19184559893581372e-11*V01*V052*V11 + 
      2.1895471877193824e-11*V013*V06*V11 - 8.30677175300375597e-11*V02*V03*V06*V11 - 
      5.1450365942944162e-11*V01*V04*V06*V11 - 1.57105521096675428e-11*V022*V07*V11 - 
      3.27396475996945943e-11*V01*V03*V07*V11 + 2.39040097981453856e-12*V06*V07*V11 - 1.12578722185719423e-11*V01*V02*V08*V11 + 
      1.8688161409045364e-12*V05*V08*V11 - 1.66948591790450449e-12*V012*V09*V11 + 1.06199280278071825e-12*V04*V09*V11 + 
      4.9427418823354929e-13*V03*V10*V11 + 6.40281712049283203e-14*V02*V112 - 
      8.50650783732569078e-12*V014*V02*V12 + 7.98040773312985024e-12*V024*V12 + 
      1.23857732036580147e-10*V01*V022*V03*V12 + 5.74712727968812932e-11*V012*V032*V12 + 
      7.32396637436056347e-11*V012*V02*V04*V12 - 4.12875645130824172e-11*V032*V04*V12 - 
      2.37244082451593395e-11*V02*V042*V12 + 1.15172641174315601e-11*V013*V05*V12 - 
      4.50673354173006439e-11*V02*V03*V05*V12 - 2.77261980520601875e-11*V01*V04*V05*V12 - 
      9.22551319763251332e-12*V022*V06*V12 - 1.98248863022593421e-11*V01*V03*V06*V12 + 
      7.17967666041412286e-13*V062*V12 - 7.79601827328047531e-12*V01*V02*V07*V12 + 
      1.29534634912714369e-12*V05*V07*V12 - 1.28004691923030537e-12*V012*V08*V12 + 
      8.06898150216084409e-13*V04*V08*V12 + 4.18311280199754674e-13*V03*V09*V12 + 1.17212660295230542e-13*V02*V10*V12 + 
      3.14292422906541054e-14*V01*V11*V12 - 2.44707759703889735e-13*V015*V13 + 
      8.29470830809344407e-12*V01*V023*V13 + 2.51527855599340736e-11*V012*V02*V03*V13 - 
      4.95163469108411185e-12*V033*V13 + 4.62128662075718749e-12*V013*V04*V13 - 
      1.79399282081407719e-11*V02*V03*V04*V13 - 5.57203912826001651e-12*V01*V042*V13 - 
      4.78132194911426031e-12*V022*V05*V13 - 9.8862445917739025e-12*V01*V03*V05*V13 - 
      4.36794692598014939e-12*V01*V02*V06*V13 + 7.28040642889289817e-13*V05*V06*V13 - 
      8.19479307658213228e-13*V012*V07*V13 + 5.23260039465917009e-13*V04*V07*V13 + 
      2.97359507159829527e-13*V03*V08*V13 + 9.28014863712321666e-14*V02*V09*V13 + 2.69121310061478652e-14*V01*V10*V13 - 
      9.65673331297585579e-17*V132 + 2.51116772458039228e-12*V012*V022*V14 + 
      1.44008574460662094e-12*V013*V03*V14 - 3.06151557533819164e-12*V02*V032*V14 - 
      1.7112000522365447e-12*V022*V04*V14 - 3.72993907514810658e-12*V01*V03*V04*V14 - 
      2.0446358065653108e-12*V01*V02*V05*V14 + 1.70985078442690671e-13*V052*V14 - 
      4.31254469191205498e-13*V012*V06*V14 + 2.72387093882243787e-13*V04*V06*V14 + 1.7864407249719243e-13*V03*V07*V14 + 
      6.10919899771084163e-14*V02*V08*V14 + 1.97384141183837402e-14*V01*V09*V14 - 1.79826806083139243e-16*V12*V14 + 
      2.767528234746372e-13*V013*V02*V15 - 5.713527912711336e-13*V022*V03*V15 - 
      5.7875508238377094e-13*V01*V032*V15 - 7.14478161232486493e-13*V01*V02*V04*V15 - 
      1.87009153727962485e-13*V012*V05*V15 + 1.21020252115635927e-13*V04*V05*V15 + 
      8.79582868294079383e-14*V03*V06*V15 + 3.47072260237016761e-14*V02*V07*V15 + 1.22859180855419439e-14*V01*V08*V15 - 
      1.46460082935421556e-16*V11*V15 + 9.71062538507498948e-15*V014*V16 - 3.12672755152665796e-14*V023*V16 - 
      2.11989988841248669e-13*V01*V02*V03*V16 - 6.25139100876856569e-14*V012*V04*V16 + 
      1.99525674035381883e-14*V042*V16 + 3.64406463725905885e-14*V03*V05*V16 + 1.59224099093537048e-14*V02*V06*V16 + 
      6.50930227029003634e-15*V01*V07*V16 - 1.03053420431713173e-16*V10*V16 - 1.77282243443173395e-14*V01*V022*V17 - 
      1.69492633079928458e-14*V012*V03*V17 + 1.14998784791256728e-14*V03*V04*V17 + 
      6.31266880784708842e-15*V02*V05*V17 + 2.85571297717967464e-15*V01*V06*V17 - 6.31779832787020285e-17*V09*V17 - 
      2.80060065453612015e-15*V012*V02*V18 + 1.54455237103185521e-15*V032*V18 + 
      1.85252462056333978e-15*V02*V04*V18 + 1.05585459350036389e-15*V01*V05*V18 - 3.30612504483804565e-17*V08*V18 - 
      1.26660331109673776e-16*V013*V19 + 4.84358488410141383e-16*V02*V03*V19 + 3.01170120638557645e-16*V01*V04*V19 - 
      1.49620308458644072e-17*V07*V19 + 3.4680804946696391e-17*V022*V20 + 7.2377332062670729e-17*V01*V03*V20 - 
      5.61937542309767725e-18*V06*V20 + 1.04042414840089173e-17*V01*V02*V21 - 1.81222563690869225e-18*V05*V21 + 
      6.78537488087538085e-19*V012*V22 - 4.49565990049768031e-19*V04*V22 - 9.70336531318598701e-20*V03*V23 - 
      1.22862755044657102e-20*V02*V24 - 1.53578443805821377e-21*V01*V25 + 1.20359281979483838e-24*V28) + 
   1.13099628864477169e-31*delta28*V28 + 7.91697402051340185e-31*delta26*eps*V28;
}
#endif


#ifdef p16 /* Uses: V00 - V30. */
double Vp(void)
{

   V012 = V01 * V01;
   V013 = V01 * V012;
   V014 = V01 * V013;
   V015 = V01 * V014;
   V016 = V01 * V015;
   V017 = V01 * V016;
   V022 = V02 * V02;
   V023 = V02 * V022;
   V024 = V02 * V023;
   V025 = V02 * V024;
   V026 = V02 * V025;
   V027 = V02 * V026;
   V028 = V02 * V027;
   V032 = V03 * V03;
   V033 = V03 * V032;
   V034 = V03 * V033;
   V035 = V03 * V034;
   V036 = V03 * V035;
   V042 = V04 * V04;
   V043 = V04 * V042;
   V044 = V04 * V043;
   V045 = V04 * V044;
   V052 = V05 * V05;
   V053 = V05 * V052;
   V054 = V05 * V053;
   V062 = V06 * V06;
   V063 = V06 * V062;
   V064 = V06 * V063;
   V072 = V07 * V07;
   V073 = V07 * V072;
   V082 = V08 * V08;
   V083 = V08 * V082;
   V092 = V09 * V09;
   V102 = V10 * V10;
   V112 = V11 * V11;
   V122 = V12 * V12;
   V132 = V13 * V13;
   V142 = V14 * V14;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;
   delta8 = delta2 * delta6;
   delta10 = delta2 * delta8;
   delta12 = delta2 * delta10;
   delta14 = delta2 * delta12;
   delta16 = delta2 * delta14;
   delta18 = delta2 * delta16;
   delta20 = delta2 * delta18;
   delta22 = delta2 * delta20;
   delta24 = delta2 * delta22;
   delta26 = delta2 * delta24;
   delta28 = delta2 * delta26;
   delta30 = delta2 * delta28;

   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 + 
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) + 
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 + 
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) + 
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 
      0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 + 
   0.000297619047619047619*delta4*eps*V06 + 
   eps4*(0.00416666666666666667*V012*V02 - 0.000570436507936507937*V032 - 
      0.000595238095238095238*V02*V04 - 0.000446428571428571429*V01*V05 + 4.1335978835978836e-6*V08) + 
   delta2*eps3*(-0.000992063492063492063*V032 - 0.000793650793650793651*V02*V04 - 
      0.000595238095238095238*V01*V05 + 8.2671957671957672e-6*V08) + 
   delta4*eps2*(-0.000496031746031746032*V032 - 0.000396825396825396825*V02*V04 - 
      0.000297619047619047619*V01*V05 + 8.2671957671957672e-6*V08) + 2.75573192239858907e-6*delta8*V08 + 
   5.51146384479717813e-6*delta6*eps*V08 + eps5*
    (0.0001763668430335097*V023 + 0.00143849206349206349*V01*V02*V03 + 0.000446428571428571429*V012*V04 - 
      0.0000388558201058201058*V042 - 0.0000785383597883597884*V03*V05 - 0.0000330687830687830688*V02*V06 - 
      0.0000165343915343915344*V01*V07 + 9.39454064454064454e-8*V10) + 
   delta6*eps2*(-0.0000154320987654320988*V042 - 0.0000385802469135802469*V03*V05 - 
      0.0000110229276895943563*V02*V06 - 5.51146384479717813e-6*V01*V07 + 1.25260541927208594e-7*V10) + 
   delta2*eps4*(0.0000661375661375661376*V023 + 0.00119047619047619048*V01*V02*V03 + 
      0.000297619047619047619*V012*V04 - 0.0000644841269841269841*V042 - 0.00014880952380952381*V03*V05 - 
      0.0000496031746031746032*V02*V06 - 0.0000248015873015873016*V01*V07 + 1.87890812890812891e-7*V10) + 
   delta4*eps3*(-0.0000462962962962962963*V042 - 0.000115740740740740741*V03*V05 - 
      0.0000330687830687830688*V02*V06 - 0.0000165343915343915344*V01*V07 + 1.87890812890812891e-7*V10) + 
   2.50521083854417188e-8*delta10*V10 + 6.26302709636042969e-8*delta8*eps*V10 + 
   delta8*eps2*(-7.89141414141414141e-7*V052 - 9.01875901875901876e-7*V04*V06 - 
      7.51563251563251563e-7*V03*V07 - 1.67014055902944792e-7*V02*V08 - 6.26302709636042969e-8*V01*V09 + 
      1.20442828776162109e-9*V12) + eps6*(-0.000421626984126984127*V012*V022 - 
      0.00014880952380952381*V013*V03 + 0.000144675925925925926*V02*V032 + 
      0.0000793650793650793651*V022*V04 + 0.000188492063492063492*V01*V03*V04 + 0.000111607142857142857*V01*V02*V05 - 
      3.33506192881192881e-6*V052 + 0.0000248015873015873016*V012*V06 - 5.11063011063011063e-6*V04*V06 - 
      3.56992544492544493e-6*V03*V07 - 1.25260541927208594e-6*V02*V08 - 4.69727032227032227e-7*V01*V09 + 
      1.80664243164243164e-9*V12) + delta6*eps3*
    (-3.15656565656565657e-6*V052 - 3.6075036075036075e-6*V04*V06 - 3.00625300625300625e-6*V03*V07 - 
      6.68056223611779167e-7*V02*V08 - 2.50521083854417188e-7*V01*V09 + 2.40885657552324219e-9*V12) + 
   delta2*eps5*(0.00020667989417989418*V02*V032 + 0.0000727513227513227513*V022*V04 + 
      0.000243055555555555556*V01*V03*V04 + 0.000124007936507936508*V01*V02*V05 - 6.57617845117845118e-6*V052 + 
      0.0000248015873015873016*V012*V06 - 9.16907166907166907e-6*V04*V06 - 6.95196007696007696e-6*V03*V07 - 
      2.0041686708353375e-6*V02*V08 - 7.51563251563251563e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   delta4*eps4*(0.000082671957671957672*V02*V032 + 0.0000198412698412698413*V022*V04 + 
      0.0000925925925925925926*V01*V03*V04 + 0.0000496031746031746032*V01*V02*V05 - 6.1377665544332211e-6*V052 + 
      8.2671957671957672e-6*V012*V06 - 7.56573673240339907e-6*V04*V06 - 6.0751362834696168e-6*V03*V07 - 
      1.50312650312650313e-6*V02*V08 - 5.63672438672438672e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   1.60590438368216146e-10*delta12*V12 + 4.81771315104648438e-10*delta10*eps*V12 + 
   delta10*eps2*(-1.3627245770102913e-8*V062 - 3.17969067969067969e-8*V05*V07 - 
      1.41319585764030208e-8*V04*V08 - 8.83247411025188803e-9*V03*V09 - 1.60590438368216146e-9*V02*V10 - 
      4.81771315104648438e-10*V01*V11 + 8.0295219184108073e-12*V14) + 
   delta8*eps3*(-6.81362288505145648e-8*V062 - 1.58984533984533985e-7*V05*V07 - 
      7.06597928820151042e-8*V04*V08 - 4.41623705512594401e-8*V03*V09 - 8.0295219184108073e-9*V02*V10 - 
      2.40885657552324219e-9*V01*V11 + 2.00738047960270182e-11*V14) + 
   eps7*(-0.0000132275132275132275*V024 - 0.000203373015873015873*V01*V022*V03 - 
      0.0000777116402116402116*V012*V032 - 0.000124007936507936508*V012*V02*V04 + 
      0.0000224842672759339426*V032*V04 + 0.000013452982202982203*V02*V042 - 
      0.0000165343915343915344*V013*V05 + 0.0000264299743466410133*V02*V03*V05 + 0.0000173485850569183903*V01*V04*V05 + 
      5.71188071188071188e-6*V022*V06 + 0.0000124383718133718134*V01*V03*V06 - 1.95667978406073644e-7*V062 + 
      5.44883357383357383e-6*V01*V02*V07 - 3.61569371986038653e-7*V05*V07 + 9.39454064454064454e-7*V012*V08 - 
      2.24023661523661524e-7*V04*V08 - 1.20442828776162109e-7*V03*V09 - 3.61328486328486328e-8*V02*V10 - 
      1.08398545898545899e-8*V01*V11 + 3.01107071940405274e-11*V14) + 
   delta6*eps4*(6.76406926406926407e-6*V032*V04 + 1.90396023729357063e-6*V02*V042 + 
      7.01459034792368126e-6*V02*V03*V05 + 4.05844155844155844e-6*V01*V04*V05 + 6.51354818021484688e-7*V022*V06 + 
      2.70562770562770563e-6*V01*V03*V06 - 1.88303759732331161e-7*V062 + 1.00208433541766875e-6*V01*V02*V07 - 
      4.20586358086358086e-7*V05*V07 + 1.25260541927208594e-7*V012*V08 - 1.99453324453324453e-7*V04*V08 - 
      1.22048733159844271e-7*V03*V09 - 2.40885657552324219e-8*V02*V10 - 7.22656972656972657e-9*V01*V11 + 
      4.01476095920540365e-11*V14) + delta2*eps6*
    (-1.65343915343915344e-6*V024 - 0.000133928571428571429*V01*V022*V03 - 
      0.0000562169312169312169*V012*V032 - 0.0000744047619047619048*V012*V02*V04 + 
      0.0000395197009780343114*V032*V04 + 0.0000179623617123617124*V02*V042 - 
      8.2671957671957672e-6*V013*V05 + 0.0000417743907327240661*V02*V03*V05 + 0.0000256408329324995992*V01*V04*V05 + 
      6.68891293891293891e-6*V022*V06 + 0.0000185636123136123136*V01*V03*V06 - 3.70998324867372486e-7*V062 + 
      6.95196007696007696e-6*V01*V02*V07 - 7.19525459108792442e-7*V05*V07 + 1.12734487734487734e-6*V012*V08 - 
      4.17213958880625547e-7*V04*V08 - 2.37272372689039356e-7*V03*V09 - 6.02214143880810547e-8*V02*V10 - 
      1.80664243164243164e-8*V01*V11 + 6.02214143880810547e-11*V14) + 
   delta4*eps5*(0.0000263047138047138047*V032*V04 + 9.11896745230078563e-6*V02*V042 + 
      0.0000267431257014590348*V02*V03*V05 + 0.0000157828282828282828*V01*V04*V05 + 3.20666987333654e-6*V022*V06 + 
      0.0000109352453102453102*V01*V03*V06 - 3.36345202416630988e-7*V062 + 3.82044652877986211e-6*V01*V02*V07 - 
      7.00254606504606505e-7*V05*V07 + 5.63672438672438672e-7*V012*V08 - 3.67591513424846758e-7*V04*V08 - 
      2.18001520084853418e-7*V03*V09 - 4.81771315104648438e-8*V02*V10 - 1.44531394531394531e-8*V01*V11 + 
      6.02214143880810547e-11*V14) + 7.64716373181981648e-13*delta14*V14 + 
   2.67650730613693577e-12*delta12*eps*V14 + 
   delta12*eps2*(-3.28063324095070127e-10*V072 - 4.37417765460093502e-10*V06*V08 - 
      3.82740544777581815e-10*V05*V09 - 1.3917837991912066e-10*V04*V10 - 6.95891899595603299e-11*V03*V11 - 
      1.07060292245477431e-11*V02*V12 - 2.67650730613693577e-12*V01*V13 + 3.93604015608372907e-14*V16) + 
   delta10*eps3*(-1.96837994457042076e-9*V072 - 2.62450659276056101e-9*V06*V08 - 
      2.29644326866549089e-9*V05*V09 - 8.35070279514723959e-10*V04*V10 - 4.1753513975736198e-10*V03*V11 - 
      6.42361753472864584e-11*V02*V12 - 1.60590438368216146e-11*V01*V13 + 1.18081204682511872e-13*V16) + 
   delta8*eps4*(5.93542260208926876e-8*V043 + 5.93542260208926876e-7*V03*V04*V05 + 
      1.51757964257964258e-7*V02*V052 + 2.04408686551543694e-7*V032*V06 + 1.2498524403286308e-7*V02*V04*V06 + 
      1.22645211930926217e-7*V01*V05*V06 + 1.44531394531394531e-7*V02*V03*V07 + 8.47917514584181251e-8*V01*V04*V07 - 
      6.52972193150764579e-9*V072 + 1.09201498090386979e-8*V022*V08 + 4.23958757292090625e-8*V01*V03*V08 - 
      9.08483051340194197e-9*V06*V08 + 1.20442828776162109e-8*V01*V02*V09 - 7.72841484647040203e-9*V05*V09 + 
      1.20442828776162109e-9*V012*V10 - 2.9709231098119987e-9*V04*V10 - 1.46538775010997233e-9*V03*V11 - 
      2.40885657552324219e-10*V02*V12 - 6.02214143880810547e-11*V01*V13 + 2.9520301170627968e-13*V16) + 
   eps8*(0.0000427138447971781305*V012*V023 + 0.0000454695767195767196*V013*V02*V03 - 
      0.0000265865500240500241*V022*V032 - 0.0000157201980118646785*V01*V033 + 
      4.1335978835978836e-6*V014*V04 - 0.0000100208433541766875*V023*V04 - 
      0.000068329625621292288*V01*V02*V03*V04 - 0.0000103840989257655924*V012*V042 + 
      8.50711788211788212e-7*V043 - 0.0000202922077922077922*V01*V022*V05 - 
      0.0000166283369408369408*V012*V03*V05 + 4.77122221913888581e-6*V03*V04*V05 + 
      1.40881976819476819e-6*V02*V052 - 8.83086820586820587e-6*V012*V02*V06 + 
      1.726031766954386e-6*V032*V06 + 2.18586528110337634e-6*V02*V04*V06 + 1.33467860402384212e-6*V01*V05*V06 - 
      9.39454064454064454e-7*V013*V07 + 1.49830878997545664e-6*V02*V03*V07 + 9.8088639755306422e-7*V01*V04*V07 - 
      1.13969026729443396e-8*V072 + 2.66580127691238802e-7*V022*V08 + 5.46810442643775977e-7*V01*V03*V08 - 
      1.96493872089110184e-8*V06*V08 + 1.92708526041859375e-7*V01*V02*V09 - 1.41821430883930884e-8*V05*V09 + 
      2.70996364746364746e-8*V012*V10 - 7.34701255534588868e-9*V04*V10 - 3.22184566976233643e-9*V03*V11 - 
      8.43099801433134766e-10*V02*V12 - 2.10774950358283692e-10*V01*V13 + 4.4280451755941952e-13*V16) + 
   delta6*eps5*(3.56125356125356125e-7*V043 + 3.07900047483380817e-6*V03*V04*V05 + 
      7.79024216524216524e-7*V02*V052 + 1.07882362346648061e-6*V032*V06 + 7.57069209450161831e-7*V02*V04*V06 + 
      6.47294174079888366e-7*V01*V05*V06 + 7.41927825261158594e-7*V02*V03*V07 + 4.39857210690544024e-7*V01*V04*V07 - 
      1.45735822819156152e-8*V072 + 6.83044664526146008e-8*V022*V08 + 2.31410821688599466e-7*V01*V03*V08 - 
      2.17026506709046392e-8*V06*V08 + 6.18273187717632162e-8*V01*V02*V09 - 1.76649482205037761e-8*V05*V09 + 
      7.22656972656972657e-9*V012*V10 - 7.38716016493794272e-9*V04*V10 - 3.57313725369280925e-9*V03*V11 - 
      6.42361753472864584e-10*V02*V12 - 1.60590438368216146e-10*V01*V13 + 5.9040602341255936e-13*V16) + 
   delta2*eps7*(-0.0000311898749398749399*V022*V032 - 
      0.0000202922077922077922*V01*V033 - 6.91438191438191438e-6*V023*V04 - 
      0.0000756072631072631073*V01*V02*V03*V04 - 0.0000108976671476671477*V012*V042 + 
      1.41486599819933153e-6*V043 - 0.0000187139249639249639*V01*V022*V05 - 
      0.0000174362674362674363*V012*V03*V05 + 8.83134997718331052e-6*V03*V04*V05 + 
      2.36067944401277735e-6*V02*V052 - 7.89141414141414141e-6*V012*V02*V06 + 
      3.2333737690880548e-6*V032*V06 + 3.3093559879274165e-6*V02*V04*V06 + 2.16549323692180835e-6*V01*V05*V06 - 
      7.51563251563251563e-7*V013*V07 + 2.48834884251550918e-6*V02*V03*V07 + 1.55419426252759586e-6*V01*V04*V07 - 
      2.27636946386946387e-8*V072 + 3.52656602656602657e-7*V022*V08 + 8.77305564805564806e-7*V01*V03*V08 - 
      3.81287583668536049e-8*V06*V08 + 2.67383079883079883e-7*V01*V02*V09 - 2.83040647623980957e-8*V05*V09 + 
      3.61328486328486328e-8*V012*V10 - 1.39713681380348047e-8*V04*V10 - 6.3834699251365918e-9*V03*V11 - 
      1.44531394531394531e-9*V02*V12 - 3.61328486328486328e-10*V01*V13 + 8.8560903511883904e-13*V16) + 
   delta4*eps6*(-0.0000102087341670675004*V022*V032 - 7.13985088985088985e-6*V01*V033 - 
      9.01875901875901876e-7*V023*V04 - 0.0000239999198332531666*V01*V02*V03*V04 - 
      3.34445646945646946e-6*V012*V042 + 9.90714532381199048e-7*V043 - 
      6.12524050024050024e-6*V01*V022*V05 - 5.59914622414622415e-6*V012*V03*V05 + 
      7.18272853689520356e-6*V03*V04*V05 + 1.84751269820714265e-6*V02*V052 - 
      2.31732002565335899e-6*V012*V02*V06 + 2.5855634114562686e-6*V032*V06 + 
      2.17219215235088251e-6*V02*V04*V06 + 1.60770529074100503e-6*V01*V05*V06 - 1.87890812890812891e-7*V013*V07 + 
      1.8291250930139819e-6*V02*V03*V07 + 1.10662871079537746e-6*V01*V04*V07 - 2.25830303955303955e-8*V072 + 
      2.09088750755417422e-7*V022*V08 + 6.12813112813112813e-7*V01*V03*V08 - 3.60296119224690653e-8*V06*V08 + 
      1.69824388574388574e-7*V01*V02*V09 - 2.79427362760696094e-8*V05*V09 + 2.16797091797091797e-8*V012*V10 - 
      1.27669398502731836e-8*V04*V10 - 6.02214143880810547e-9*V03*V11 - 1.20442828776162109e-9*V02*V12 - 
      3.01107071940405274e-10*V01*V13 + 8.8560903511883904e-13*V16) + 2.81145725434552076e-15*delta16*V16 + 
   1.12458290173820831e-14*delta14*eps*V16 + 
   delta14*eps2*(-3.57367455441252861e-12*V082 - 8.04076774742818938e-12*V07*V09 - 
      4.38587331677901239e-12*V06*V10 - 3.07011132174530867e-12*V05*V11 - 9.44649637460094976e-13*V04*V12 - 
      3.93604015608372907e-13*V03*V13 - 5.24805354144497209e-14*V02*V14 - 1.12458290173820831e-14*V01*V15 + 
      1.47971434439237935e-16*V18) + delta12*eps3*
    (-2.50157218808877003e-11*V082 - 5.62853742319973257e-11*V07*V09 - 3.07011132174530867e-11*V06*V10 - 
      2.14907792522171607e-11*V05*V11 - 6.61254746222066484e-12*V04*V12 - 2.75522810925861035e-12*V03*V13 - 
      3.67363747901148046e-13*V02*V14 - 7.87208031216745814e-14*V01*V15 + 5.17900020537332772e-16*V18) + 
   delta10*eps4*(1.31523569023569024e-8*V04*V052 + 5.84549195660306771e-9*V042*V06 + 
      1.83715461493239271e-8*V03*V05*V06 + 2.06932250583044234e-9*V02*V062 + 1.25260541927208594e-8*V03*V04*V07 + 
      6.35938135938135938e-9*V02*V05*V07 + 2.62450659276056101e-9*V01*V06*V07 + 3.28063324095070127e-9*V032*V08 + 
      2.11061718998226935e-9*V02*V04*V08 + 1.96837994457042076e-9*V01*V05*V08 - 1.03457878350242703e-10*V082 + 
      1.76649482205037761e-9*V02*V03*V09 + 1.04383784939340495e-9*V01*V04*V09 - 2.25945573702732122e-10*V07*V09 + 
      1.12413306857751302e-10*V022*V10 + 4.1753513975736198e-10*V01*V03*V10 - 1.28213696627173129e-10*V06*V10 + 
      9.63542630209296876e-11*V01*V02*V11 - 8.8009857890032182e-11*V05*V11 + 8.0295219184108073e-12*V012*V12 - 
      2.84182099269245239e-11*V04*V12 - 1.17293996651295126e-11*V03*V13 - 1.65313686555516621e-12*V02*V14 - 
      3.54243614047535616e-13*V01*V15 + 1.55370006161199832e-15*V18) + 
   delta8*eps5*(8.54903198653198653e-8*V04*V052 + 4.25885842552509219e-8*V042*V06 + 
      1.20563271604938272e-7*V03*V05*V06 + 1.51413841890032366e-8*V02*V062 + 8.1419352252685586e-8*V03*V04*V07 + 
      4.10710046126712793e-8*V02*V05*V07 + 1.72233245149911817e-8*V01*V06*V07 + 2.18708882730046751e-8*V032*V08 + 
      1.55696253579851463e-8*V02*V04*V08 + 1.31225329638028051e-8*V01*V05*V08 - 3.06889302360175895e-10*V082 + 
      1.14086123924086887e-8*V02*V03*V09 + 6.78494602105713217e-9*V01*V04*V09 - 6.39241035920541056e-10*V07*V09 + 
      8.56482337963819445e-10*V022*V10 + 2.87055408583186361e-9*V01*V03*V10 - 3.8595685187655309e-10*V06*V10 + 
      6.22287948676837566e-10*V01*V02*V11 - 2.57121823196169601e-10*V05*V11 + 6.02214143880810547e-11*V012*V12 - 
      8.91513095352964634e-11*V04*V12 - 3.63099704398724007e-11*V03*V13 - 5.5104562185172207e-12*V02*V14 - 
      1.18081204682511872e-12*V01*V15 + 3.88425015402999579e-15*V18) + 
   eps9*(1.06888995777884667e-6*V025 + 0.0000263923961840628507*V01*V023*V03 + 
      0.0000299748476831810165*V012*V02*V032 - 1.21518211175949271e-6*V034 + 
      0.0000238245550745550746*V012*V022*V04 + 0.0000102212602212602213*V013*V03*V04 - 
      0.0000101287830702513242*V02*V032*V04 - 3.09484386865339246e-6*V022*V042 - 
      6.45033978367311701e-6*V01*V03*V042 + 6.32565736732403399e-6*V013*V02*V05 - 
      5.97243869813314258e-6*V022*V03*V05 - 5.42102848650467698e-6*V01*V032*V05 - 
      7.74114737408388202e-6*V01*V02*V04*V05 - 9.78856075582266058e-7*V012*V052 + 
      2.90447881593714927e-7*V04*V052 + 4.69727032227032227e-7*V014*V06 - 
      8.74346112441350537e-7*V023*V06 - 5.52347371543800115e-6*V01*V02*V03*V06 - 
      1.67601358077548554e-6*V012*V04*V06 + 2.3201418290704005e-7*V042*V06 + 
      4.20311060192012573e-7*V03*V05*V06 + 1.000249016122032e-7*V02*V062 - 
      1.21213662880329547e-6*V01*V022*V07 - 1.0095517908017908e-6*V012*V03*V07 + 
      3.08183088131004798e-7*V03*V04*V07 + 1.83444465128492906e-7*V02*V05*V07 + 8.64564434132886514e-8*V01*V06*V07 - 
      4.09505617838951172e-7*V012*V02*V08 + 8.67546827988296242e-8*V032*V08 + 
      1.14248626153388058e-7*V02*V04*V08 + 6.72587168122882409e-8*V01*V05*V08 - 5.58025064485634825e-10*V082 - 
      3.61328486328486328e-8*V013*V09 + 6.05727059720115276e-8*V02*V03*V09 + 3.94450264241930909e-8*V01*V04*V09 - 
      1.01977880393934316e-9*V07*V09 + 9.15365498698832032e-9*V022*V10 + 1.79760921948421948e-8*V01*V03*V10 - 
      7.27717595714794594e-10*V06*V10 + 5.32959517334517335e-9*V01*V02*V11 - 4.32620013655552871e-10*V05*V11 + 
      6.32324851074851075e-10*V012*V12 - 1.92177160620788072e-10*V04*V12 - 7.12915273270665428e-11*V03*V13 - 
      1.65313686555516621e-11*V02*V14 - 3.54243614047535616e-12*V01*V15 + 5.82637523104499369e-15*V18) + 
   delta6*eps6*(-3.02827683780064732e-7*V034 - 1.85757254209635162e-6*V02*V032*V04 - 
      1.58222876476844731e-7*V022*V042 - 1.08321462488129155e-6*V01*V03*V042 - 
      9.25161515439293217e-7*V022*V03*V05 - 1.03112826327112041e-6*V01*V032*V05 - 
      1.11454352525781097e-6*V01*V02*V04*V05 - 1.39369559012416155e-7*V012*V052 + 
      2.68161943509165731e-7*V04*V052 - 3.51463645114438765e-8*V023*V06 - 
      7.62712816284244856e-7*V01*V02*V03*V06 - 2.12598798908322718e-7*V012*V04*V06 + 
      1.55031715051556321e-7*V042*V06 + 3.8440189109831967e-7*V03*V05*V06 + 5.61607704464847322e-8*V02*V062 - 
      1.32165930777041888e-7*V01*V022*V07 - 1.24296999296999297e-7*V012*V03*V07 + 
      2.6128064322508767e-7*V03*V04*V07 + 1.32968882968882969e-7*V02*V05*V07 + 5.73479926158497587e-8*V01*V06*V07 - 
      3.77387530165307943e-8*V012*V02*V08 + 7.26576144069530313e-8*V032*V08 + 
      5.89825738635262445e-8*V02*V04*V08 + 4.44778160551970076e-8*V01*V05*V08 - 6.7521831725198257e-10*V082 - 
      2.40885657552324219e-9*V013*V09 + 3.86086178910252984e-8*V02*V03*V09 + 2.32454659537992871e-8*V01*V04*V09 - 
      1.33786004905285951e-9*V07*V09 + 3.45269442491664714e-9*V022*V10 + 1.03580832747499414e-8*V01*V03*V10 - 
      8.61655419311815204e-10*V06*V10 + 2.28841374674708008e-9*V01*V02*V11 - 5.54981662007805799e-10*V05*V11 + 
      2.40885657552324219e-10*V012*V12 - 2.07822920241220895e-10*V04*V12 - 8.32472493011708698e-11*V03*V13 - 
      1.37761405462930517e-11*V02*V14 - 2.9520301170627968e-12*V01*V15 + 7.76850030805999158e-15*V18) + 
   delta2*eps8*(4.1753513975736198e-8*V025 + 0.0000140291806958473625*V01*V023*V03 + 
      0.0000188517115600448934*V012*V02*V032 - 2.104308279903518e-6*V034 + 
      0.0000125886844636844637*V012*V022*V04 + 5.82461519961519962e-6*V013*V03*V04 - 
      0.0000153405163325798246*V02*V032*V04 - 3.46221514376276281e-6*V022*V042 - 
      9.37767864851198185e-6*V01*V03*V042 + 2.94362273528940196e-6*V013*V02*V05 - 
      7.97973888251666029e-6*V022*V03*V05 - 8.09444633849395754e-6*V01*V032*V05 - 
      9.9663114296050804e-6*V01*V02*V04*V05 - 1.24727152256914162e-6*V012*V052 + 
      5.53495019640852974e-7*V04*V052 + 1.87890812890812891e-7*V014*V06 - 
      8.40346822489679633e-7*V023*V06 - 7.21314895422038279e-6*V01*V02*V03*V06 - 
      2.10547829595448643e-6*V012*V04*V06 + 4.143130073189597e-7*V042*V06 + 
      8.11973933253695158e-7*V03*V05*V06 + 1.64565051717829496e-7*V02*V062 - 
      1.3248711165377832e-6*V01*V022*V07 - 1.25380984755984756e-6*V012*V03*V07 + 
      5.84147719564386231e-7*V03*V04*V07 + 3.1668434446212224e-7*V02*V05*V07 + 1.46458479791813125e-7*V01*V06*V07 - 
      4.40820753320753321e-7*V012*V02*V08 + 1.6699971747094763e-7*V032*V08 + 
      1.84426647720298514e-7*V02*V04*V08 + 1.14231420034991464e-7*V01*V05*V08 - 1.09940630202554417e-9*V082 - 
      3.61328486328486328e-8*V013*V09 + 1.03781570795459684e-7*V02*V03*V09 + 6.52800131966798633e-8*V01*V04*V09 - 
      2.03867199884356747e-9*V07*V09 + 1.30479731174175619e-8*V022*V10 + 3.01107071940405274e-8*V01*V03*V10 - 
      1.42836085807024182e-9*V06*V10 + 7.82878387045053712e-9*V01*V02*V11 - 8.64354418275986903e-10*V05*V11 + 
      9.03321215821215821e-10*V012*V12 - 3.70184576679674719e-10*V04*V12 - 1.41697445619014246e-10*V03*V13 - 
      2.89298951472154087e-11*V02*V14 - 6.19926324583187328e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   delta4*eps7*(-1.3248711165377832e-6*V034 - 8.6670659587326254e-6*V02*V032*V04 - 
      1.31581381581381581e-6*V022*V042 - 5.14897910731244065e-6*V01*V03*V042 - 
      4.27957459207459207e-6*V022*V03*V05 - 4.63174942341609008e-6*V01*V032*V05 - 
      5.20023957523957524e-6*V01*V02*V04*V05 - 6.59063159063159063e-7*V012*V052 + 
      5.00520248784137673e-7*V04*V052 - 3.03928875357446786e-7*V023*V06 - 
      3.68334817739579644e-6*V01*V02*V03*V06 - 1.04922909982433792e-6*V012*V04*V06 + 
      3.34278174059920092e-7*V042*V06 + 7.29246916002868384e-7*V03*V05*V06 + 1.25604664295140486e-7*V02*V062 - 
      6.11367798867798868e-7*V01*V022*V07 - 6.07995399662066329e-7*V012*V03*V07 + 
      5.08188442216219994e-7*V03*V04*V07 + 2.63408466533466533e-7*V02*V05*V07 + 1.17724262069500165e-7*V01*V06*V07 - 
      1.95117382617382617e-7*V012*V02*V08 + 1.4478948630734345e-7*V032*V08 + 
      1.36065984280269995e-7*V02*V04*V08 + 9.21731762505572029e-8*V01*V05*V08 - 1.06818506921603716e-9*V082 - 
      1.44531394531394531e-8*V013*V09 + 8.19011235677902345e-8*V02*V03*V09 + 5.02246595996595997e-8*V01*V04*V09 - 
      2.03276793860944188e-9*V07*V09 + 8.67188367188367188e-9*V022*V10 + 2.30045802962469629e-8*V01*V03*V10 - 
      1.37834503351543501e-9*V06*V10 + 5.41992729492729493e-9*V01*V02*V11 - 8.5845035804186131e-10*V05*V11 + 
      6.02214143880810547e-10*V012*V12 - 3.45977929719759785e-10*V04*V12 - 1.35793385384888653e-10*V03*V13 - 
      2.47970529833274931e-11*V02*V14 - 5.31365421071303424e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   8.22063524662432972e-18*delta18*V18 + 3.69928586098094837e-17*delta16*eps*V18 + 
   delta16*eps2*(-4.99609107113593639e-14*V092 - 7.26704155801590747e-14*V08*V10 - 
      6.54033740221431672e-14*V07*V11 - 3.01861726256045387e-14*V06*V12 - 1.76086006982693143e-14*V05*V13 - 
      4.69562685287181713e-15*V04*V14 - 1.67700959031136326e-15*V03*V15 - 1.97295245918983913e-16*V02*V16 - 
      3.69928586098094837e-17*V01*V17 + 4.40391173926303378e-19*V20) + 
   delta14*eps3*(-3.99687285690874911e-13*V092 - 5.81363324641272598e-13*V08*V10 - 
      5.23226992177145338e-13*V07*V11 - 2.4148938100483631e-13*V06*V12 - 1.40868805586154514e-13*V05*V13 - 
      3.75650148229745371e-14*V04*V14 - 1.34160767224909061e-14*V03*V15 - 1.57836196735187131e-15*V02*V16 - 
      2.9594286887847587e-16*V01*V17 + 1.76156469570521351e-18*V20) + 
   delta12*eps4*(4.14465028435616671e-10*V052*V06 + 1.9311337588648513e-10*V04*V062 + 
      5.61121884651296416e-10*V04*V05*V07 + 3.94728598510111115e-10*V03*V06*V07 + 6.75424490783967908e-11*V02*V072 + 
      9.9293173004138872e-11*V042*V08 + 3.00188662570652404e-10*V03*V05*V08 + 7.05638284744001105e-11*V02*V06*V08 + 
      4.28840946529503434e-11*V01*V07*V08 + 1.55867190180915671e-10*V03*V04*V09 + 7.8799523924796256e-11*V02*V05*V09 + 
      3.28940498758425929e-11*V01*V06*V09 - 1.87500359022631024e-12*V092 + 3.28940498758425929e-11*V032*V10 + 
      2.19068749258602978e-11*V02*V04*V10 + 1.97364299255055558e-11*V01*V05*V10 - 2.808497825656736e-12*V08*V10 + 
      1.43271861681447738e-11*V02*V03*V11 + 8.50184673714085479e-12*V01*V04*V11 - 2.47282462663132475e-12*V07*V11 + 
      7.87208031216745814e-13*V022*V12 + 2.83394891238028493e-12*V01*V03*V12 - 1.183475532645025e-12*V06*V12 + 
      5.5104562185172207e-13*V01*V02*V13 - 6.80520626986055263e-13*V05*V13 + 3.93604015608372907e-14*V012*V14 - 
      1.89344247508448862e-13*V04*V14 - 6.71543693296741495e-14*V03*V15 - 8.28640032859732435e-15*V02*V16 - 
      1.55370006161199832e-15*V01*V17 + 6.16547643496824729e-18*V20) + 
   delta10*eps5*(3.26045822369351781e-9*V052*V06 + 1.65543101467471215e-9*V04*V062 + 
      4.38766140359277614e-9*V04*V05*V07 + 3.10519830827954077e-9*V03*V06*V07 + 5.25866210681803586e-10*V02*V072 + 
      8.54383116547241456e-10*V042*V08 + 2.38274750915455345e-9*V03*V05*V08 + 6.08564288665958964e-10*V02*V06*V08 + 
      3.40392501307793351e-10*V01*V07*V08 + 1.21879483433132671e-9*V03*V04*V09 + 6.1351057912877085e-10*V02*V05*V09 + 
      2.58766525689961731e-10*V01*V06*V09 - 6.38324106265132578e-12*V092 + 2.64979846222065332e-10*V032*V10 + 
      1.91044143347286827e-10*V02*V04*V10 + 1.58987907733239199e-10*V01*V05*V10 - 1.00156931590772184e-11*V08*V10 + 
      1.11547378023412882e-10*V02*V03*V11 + 6.6479718236254184e-11*V01*V04*V11 - 8.52071309503185762e-12*V07*V11 + 
      7.08487228095071232e-12*V022*V12 + 2.34981597318198625e-11*V01*V03*V12 - 4.3121835424282719e-12*V06*V12 + 
      4.29028377013126468e-12*V01*V02*V13 - 2.42687949623794137e-12*V05*V13 + 3.54243614047535616e-13*V012*V14 - 
      7.18016588472958155e-13*V04*V14 - 2.5221731000168106e-13*V03*V15 - 3.31456013143892974e-14*V02*V16 - 
      6.21480024644799327e-15*V01*V17 + 1.84964293049047419e-17*V20) + 
   delta8*eps6*(-8.45508658008658009e-8*V032*V042 - 1.14340392118169896e-8*V02*V043 - 
      5.74110817166372722e-8*V033*V05 - 1.70707635985413763e-7*V02*V03*V04*V05 - 
      5.07305194805194805e-8*V01*V042*V05 - 2.09931850556850557e-8*V022*V052 - 
      4.97910654160654161e-8*V01*V03*V052 - 5.99346457481378116e-8*V02*V032*V06 - 
      1.17185137026406868e-8*V022*V04*V06 - 6.97283683394794506e-8*V01*V03*V04*V06 - 
      3.5960787448882687e-8*V01*V02*V05*V06 + 1.29533113516637482e-8*V052*V06 - 
      3.43835599291948498e-9*V012*V062 + 7.392378229602008e-9*V04*V062 - 
      1.99935095768429102e-8*V022*V03*V07 - 2.28153129938844225e-8*V01*V032*V07 - 
      2.43868051407733947e-8*V01*V02*V04*V07 - 6.24582097796383511e-9*V012*V05*V07 + 
      1.75019961580419097e-8*V04*V05*V07 + 1.2518744403859561e-8*V03*V06*V07 + 2.14039052230578841e-9*V02*V072 - 
      6.57656080936504217e-10*V023*V08 - 1.26407616486981566e-8*V01*V02*V03*V08 - 
      3.52151889850302549e-9*V012*V04*V08 + 3.86929241225589394e-9*V042*V08 + 
      9.72664871847229976e-9*V03*V05*V08 + 2.79046504017974087e-9*V02*V06*V08 + 1.42857640312640831e-9*V01*V07*V08 - 
      1.66612579807024251e-9*V01*V022*V09 - 1.58583057888613444e-9*V012*V03*V09 + 
      5.00664307853850338e-9*V03*V04*V09 + 2.53392425148280268e-9*V02*V05*V09 + 1.08879305089038983e-9*V01*V06*V09 - 
      1.6748072821287926e-11*V092 - 3.81402291124513347e-10*V012*V02*V10 + 
      1.12917963434906323e-9*V032*V10 + 9.01690570613695419e-10*V02*V04*V10 + 6.8620642935438298e-10*V01*V05*V10 - 
      2.760150625644289e-11*V08*V10 - 2.00738047960270182e-11*V013*V11 + 4.80787305065627506e-10*V02*V03*V11 + 
      2.88905347456545714e-10*V01*V04*V11 - 2.26228347113945505e-11*V07*V11 + 3.54243614047535616e-11*V022*V12 + 
      1.07453896261085804e-10*V01*V03*V12 - 1.21478628817236775e-11*V06*V12 + 1.97786017843207386e-11*V01*V02*V13 - 
      6.6713291145516521e-12*V05*V13 + 1.77121807023767808e-12*V012*V14 - 2.11096048371016838e-12*V04*V14 - 
      7.32828529060325873e-13*V03*V15 - 1.03580004107466554e-13*V02*V16 - 1.9421250770149979e-14*V01*V17 + 
      4.62410732622618547e-17*V20) + eps10*(-4.32775172358505692e-6*V012*V024 - 
      9.24422799422799423e-6*V013*V022*V03 - 1.23068482443482443e-6*V014*V032 + 
      4.22450354245989167e-6*V023*V032 + 7.39166243258505163e-6*V01*V02*V033 - 
      1.69101731601731602e-6*V014*V02*V04 + 1.21747740795359843e-6*V024*V04 + 
      0.0000161214859875574161*V01*V022*V03*V04 + 6.33712696584720394e-6*V012*V032*V04 + 
      4.84675707889993604e-6*V012*V02*V042 - 1.07324812418438411e-6*V032*V042 - 
      4.62417873132158846e-7*V02*V043 - 9.39454064454064454e-8*V015*V05 + 
      3.19858299769014055e-6*V01*V023*V05 + 7.76295326146516623e-6*V012*V02*V03*V05 - 
      6.14896486982300474e-7*V033*V05 + 1.39724005051386004e-6*V013*V04*V05 - 
      2.56161679617780808e-6*V02*V03*V04*V05 - 8.20972733175114127e-7*V01*V042*V05 - 
      3.79289523169731503e-7*V022*V052 - 6.95468437903953777e-7*V01*V03*V052 + 
      2.05559775872275872e-6*V012*V022*V06 + 9.52221004304337638e-7*V013*V03*V06 - 
      9.2266376058538757e-7*V02*V032*V06 - 5.93101783577974054e-7*V022*V04*V06 - 
      1.16940150577303355e-6*V01*V03*V04*V06 - 7.07132752333645191e-7*V01*V02*V05*V06 + 
      2.89604486589270086e-8*V052*V06 - 7.63370950312914599e-8*V012*V062 + 
      2.35668492554580323e-8*V04*V062 + 4.33594183594183594e-7*V013*V02*V07 - 
      4.0140583760375427e-7*V022*V03*V07 - 3.62902846161774733e-7*V01*V032*V07 - 
      5.19422603685996543e-7*V01*V02*V04*V07 - 1.32534428479368956e-7*V012*V05*V07 + 
      4.25063111758883818e-8*V04*V05*V07 + 3.06977183828184645e-8*V03*V06*V07 + 6.76143520976766775e-9*V02*V072 + 
      2.70996364746364746e-8*V014*V08 - 4.80241882358284475e-8*V023*V08 - 
      2.87815345479035955e-7*V01*V02*V03*V08 - 8.72350202707345564e-8*V012*V04*V08 + 
      1.34766641195601669e-8*V042*V08 + 2.39151691290706619e-8*V03*V05*V08 + 1.16898143469883277e-8*V02*V06*V08 + 
      4.92813313471090471e-9*V01*V07*V08 - 5.07365416219582886e-8*V01*V022*V09 - 
      4.2305543607626941e-8*V012*V03*V09 + 1.39815526419386714e-8*V03*V04*V09 + 8.39144081076270619e-9*V02*V05*V09 + 
      3.92546204816425405e-9*V01*V06*V09 - 2.56298084717075669e-11*V092 - 1.40014788452288452e-8*V012*V02*V10 + 
      3.21391736030508206e-9*V032*V10 + 4.35416007894999492e-9*V02*V04*V10 + 2.49794462727031588e-9*V01*V05*V10 - 
      4.62118489039601052e-11*V08*V10 - 1.05387475179141846e-9*V013*V11 + 1.88841366588507111e-9*V02*V03*V11 + 
      1.22273087448741044e-9*V01*V04*V11 - 3.49496505466431814e-11*V07*V11 + 2.47970529833274931e-10*V022*V12 + 
      4.71144006683222369e-10*V01*V03*V12 - 2.1239079842236017e-11*V06*V12 + 1.20885633293721529e-10*V01*V02*V13 - 
      1.07535465514320433e-11*V05*V13 + 1.23985264916637466e-11*V012*V14 - 4.17634576561305147e-12*V04*V14 - 
      1.34395055329437854e-12*V03*V15 - 2.79666011090159697e-13*V02*V16 - 5.24373770794049432e-14*V01*V17 + 
      6.9361609893392782e-17*V20) + delta6*eps7*
    (-5.30269627491849714e-7*V032*V042 - 1.06760523427190094e-7*V02*V043 - 
      3.44466490299823633e-7*V033*V05 - 1.06134220717554051e-6*V02*V03*V04*V05 - 
      3.18161776495109828e-7*V01*V042*V05 - 1.30511849261849262e-7*V022*V052 - 
      3.03130511463844797e-7*V01*V03*V052 - 3.78534604725080916e-7*V02*V032*V06 - 
      1.11853534472582092e-7*V022*V04*V06 - 4.46345064400619956e-7*V01*V03*V04*V06 - 
      2.27120762835048549e-7*V01*V02*V05*V06 + 3.26639377224889207e-8*V052*V06 - 
      2.2585898081929828e-8*V012*V062 + 2.10193091164924343e-8*V04*V062 - 
      1.24296999296999297e-7*V022*V03*V07 - 1.41067229360880155e-7*V01*V032*V07 - 
      1.51620315310791501e-7*V01*V02*V04*V07 - 4.0124668100858577e-8*V012*V05*V07 + 4.4787492448848658e-8*V04*V05*V07 + 
      3.24298782831501475e-8*V03*V06*V07 + 5.68358575623981786e-9*V02*V072 - 6.5918551368286818e-9*V023*V08 - 
      8.25205438300676396e-8*V01*V02*V03*V08 - 2.34003210193686384e-8*V012*V04*V08 + 
      1.12529063924436888e-8*V042*V08 + 2.54356286410311724e-8*V03*V05*V08 + 8.30444495178907462e-9*V02*V06*V08 + 
      3.92657491666076582e-9*V01*V07*V08 - 1.03580832747499414e-8*V01*V022*V09 - 
      1.05989689323022656e-8*V012*V03*V09 + 1.3470310226165346e-8*V03*V04*V09 + 6.88846387716213424e-9*V02*V05*V09 + 
      3.03283139855268707e-9*V01*V06*V09 - 3.40039836055713167e-11*V092 - 2.64974223307556641e-9*V012*V02*V10 + 
      3.11981788600213748e-9*V032*V10 + 2.79278917817666651e-9*V02*V04*V10 + 1.94147992156084282e-9*V01*V05*V10 - 
      5.8329550274963918e-11*V08*V10 - 1.60590438368216146e-10*V013*V11 + 1.39296461123803172e-9*V02*V03*V11 + 
      8.47035841589218496e-10*V01*V04*V11 - 4.62613453487800303e-11*V07*V11 + 1.18081204682511872e-10*V022*V12 + 
      3.24723312876907648e-10*V01*V03*V12 - 2.6147736236888857e-11*V06*V12 + 6.25830384817312922e-11*V01*V02*V13 - 
      1.39998733551651795e-11*V05*V13 + 5.9040602341255936e-12*V012*V14 - 4.73567778779337087e-12*V04*V14 - 
      1.62102706428185158e-12*V03*V15 - 2.48592009857919731e-13*V02*V16 - 4.66110018483599495e-14*V01*V17 + 
      9.24821465245237093e-17*V20) + delta2*eps9*
    (4.15642466733736575e-6*V023*V032 + 8.35529109338633148e-6*V01*V02*V033 + 
      6.79829796893288957e-7*V024*V04 + 0.0000154207702570797809*V01*V022*V03*V04 + 
      6.74263732299446585e-6*V012*V032*V04 + 4.56072256667494763e-6*V012*V02*V042 - 
      1.91435273280511376e-6*V032*V042 - 6.72419695237155555e-7*V02*V043 + 
      2.49385480040241945e-6*V01*V023*V05 + 7.25582012784393737e-6*V012*V02*V03*V05 - 
      1.13434203215949248e-6*V033*V05 + 1.24703063691158929e-6*V013*V04*V05 - 
      4.15228372817658532e-6*V02*V03*V04*V05 - 1.29452411198442944e-6*V01*V042*V05 - 
      5.49420037267259489e-7*V022*V052 - 1.13306877939814448e-6*V01*V03*V052 + 
      1.63031413031413031e-6*V012*V022*V06 + 8.24792491459158126e-7*V013*V03*V06 - 
      1.51755096571564826e-6*V02*V032*V06 - 7.77042071684928828e-7*V022*V04*V06 - 
      1.86239140232195788e-6*V01*V03*V04*V06 - 1.01627938309485929e-6*V01*V02*V05*V06 + 
      5.68838491377298567e-8*V052*V06 - 1.07641476689095737e-7*V012*V062 + 
      4.41557917412842716e-8*V04*V062 + 3.20377924544591211e-7*V013*V02*V07 - 
      5.77443068762513207e-7*V022*V03*V07 - 5.83046527987004177e-7*V01*V032*V07 - 
      7.28552935894205735e-7*V01*V02*V04*V07 - 1.86531529537481918e-7*V012*V05*V07 + 
      8.20730498018079717e-8*V04*V05*V07 + 6.00686679154524626e-8*V03*V06*V07 + 1.19181468478999992e-8*V02*V072 + 
      1.80664243164243164e-8*V014*V08 - 5.42489795135297781e-8*V023*V08 - 
      4.0979812185169328e-7*V01*V02*V03*V08 - 1.20546065486541677e-7*V012*V04*V08 + 
      2.49040458005988663e-8*V042*V08 + 4.6958392905278604e-8*V03*V05*V08 + 2.00429912245193913e-8*V02*V06*V08 + 
      8.62016691568998603e-9*V01*V07*V08 - 6.16667283333950001e-8*V01*V022*V09 - 
      5.79330006413339747e-8*V012*V03*V09 + 2.68752821857397021e-8*V03*V04*V09 + 1.4780224390110011e-8*V02*V05*V09 + 
      6.83399189285918978e-9*V01*V06*V09 - 5.12537905681840888e-11*V092 - 1.68619960286626953e-8*V012*V02*V10 + 
      6.27264228017029137e-9*V032*V10 + 7.31125081907061366e-9*V02*V04*V10 + 4.36078106078397862e-9*V01*V05*V10 - 
      9.16586854918693502e-11*V08*V10 - 1.20442828776162109e-9*V013*V11 + 3.30686413713374498e-9*V02*V03*V11 + 
      2.08501887168145338e-9*V01*V04*V11 - 6.98876483428242728e-11*V07*V11 + 3.71955794749912397e-10*V022*V12 + 
      8.121034852039754e-10*V01*V03*V12 - 4.19521212350405431e-11*V06*V12 + 1.85092288339837359e-10*V01*V02*V13 - 
      2.14954403524019967e-11*V05*V13 + 1.85977897374956198e-11*V012*V14 - 8.11342172173785521e-12*V04*V14 - 
      2.6762483561266671e-12*V03*V15 - 4.97184019715839461e-13*V02*V16 - 9.3222003696719899e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + delta4*eps8*
    (1.12355953129762654e-6*V023*V032 + 2.5791971476495286e-6*V01*V02*V033 + 
      3.77616945077262538e-8*V024*V04 + 4.13625909657655689e-6*V01*V022*V03*V04 + 
      1.98785727059536583e-6*V012*V032*V04 + 1.22404326273373892e-6*V012*V02*V042 - 
      1.42409880133094419e-6*V032*V042 - 3.91505723846993688e-7*V02*V043 + 
      6.74135718778575921e-7*V01*V023*V05 + 2.06180916746392937e-6*V012*V02*V03*V05 - 
      8.81354738001563398e-7*V033*V05 + 3.3207808505427553e-7*V013*V04*V05 - 
      2.91372423688891943e-6*V02*V03*V04*V05 - 8.88464306123036282e-7*V01*V042*V05 - 
      3.66935769134843209e-7*V022*V052 - 8.12937475883904455e-7*V01*V03*V052 + 
      4.23557281196170085e-7*V012*V022*V06 + 2.13183806933806934e-7*V013*V03*V06 - 
      1.05803289707059548e-6*V02*V032*V06 - 4.22574620656631239e-7*V022*V04*V06 - 
      1.26838342984176318e-6*V01*V03*V04*V06 - 6.5878786116881355e-7*V01*V02*V05*V06 + 
      5.45632582627067921e-8*V052*V06 - 6.76716636538065109e-8*V012*V062 + 
      3.90218908615850726e-8*V04*V062 + 7.34701255534588868e-8*V013*V02*V07 - 
      3.63268954125435607e-7*V022*V03*V07 - 3.97088535729408745e-7*V01*V032*V07 - 
      4.49314840435872182e-7*V01*V02*V04*V07 - 1.17990956904647381e-7*V012*V05*V07 + 
      7.65859343014163276e-8*V04*V05*V07 + 5.59869380444485487e-8*V03*V06*V07 + 1.02824269600355035e-8*V02*V072 + 
      3.61328486328486328e-9*V014*V08 - 2.64209506934374659e-8*V023*V08 - 
      2.52155665102093674e-7*V01*V02*V03*V08 - 7.26442318704223466e-8*V012*V04*V08 + 
      2.14728983840795232e-8*V042*V08 + 4.39814532769423059e-8*V03*V05*V08 + 1.64109258267755e-8*V02*V06*V08 + 
      7.31276900598796024e-9*V01*V07*V08 - 3.37239920573253907e-8*V01*V022*V09 - 
      3.40250991292657959e-8*V012*V03*V09 + 2.42509274116708757e-8*V03*V04*V09 + 1.27037664057680398e-8*V02*V05*V09 + 
      5.74203595255766124e-9*V01*V06*V09 - 5.12110638164897588e-11*V092 - 9.03321215821215821e-9*V012*V02*V10 + 
      5.67822993017028965e-9*V032*V10 + 5.76472441260022959e-9*V02*V04*V10 + 3.68295277404754529e-9*V01*V05*V10 - 
      9.01908088622321099e-11*V08*V10 - 6.02214143880810547e-10*V013*V11 + 2.72767582816602424e-9*V02*V03*V11 + 
      1.68501879081944441e-9*V01*V04*V11 - 6.98021948394356129e-11*V07*V11 + 2.65682710535651712e-10*V022*V12 + 
      6.5535068598794089e-10*V01*V03*V12 - 4.09621923386420413e-11*V06*V12 + 1.35793385384888653e-10*V01*V02*V13 - 
      2.14099868490133368e-11*V05*V13 + 1.32841355267825856e-11*V012*V14 - 7.69703010522583966e-12*V04*V14 - 
      2.59079485273800719e-12*V03*V15 - 4.35036017251359529e-13*V02*V16 - 8.15692532346299116e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + 1.95729410633912612e-20*delta20*V20 + 
   9.78647053169563062e-20*delta18*eps*V20 + 
   delta18*eps2*(-3.73576270568999572e-16*V102 - 8.21867795251799059e-16*V09*V11 - 
      5.0576479707803019e-16*V08*V12 - 3.79323597808522643e-16*V07*V13 - 1.51729439123409057e-16*V06*V14 - 
      7.58647195617045285e-17*V05*V15 - 1.78505222498128302e-17*V04*V16 - 5.57828820306650945e-18*V03*V17 - 
      5.87188231901737837e-19*V02*V18 - 9.78647053169563062e-20*V01*V19 + 1.06374679692343811e-21*V22) + 
   delta16*eps3*(-3.36218643512099615e-15*V102 - 7.39681015726619153e-15*V09*V11 - 
      4.55188317370227171e-15*V08*V12 - 3.41391238027670378e-15*V07*V13 - 1.36556495211068151e-15*V06*V14 - 
      6.82782476055340757e-16*V05*V15 - 1.60654700248315472e-16*V04*V16 - 5.02045938275985851e-17*V03*V17 - 
      5.28469408711564053e-18*V02*V18 - 8.80782347852606755e-19*V01*V19 + 4.7868605861554715e-21*V22) + 
   delta14*eps4*(2.13459363566774952e-12*V063 + 1.7930586539609096e-11*V05*V06*V07 + 
      6.04327175964602865e-12*V04*V072 + 6.86735427232503256e-12*V052*V08 + 
      6.60875939349902034e-12*V04*V06*V08 + 6.54033740221431672e-12*V03*V07*V08 + 6.07011706610740506e-13*V02*V082 + 
      7.05048371958703343e-12*V04*V05*V09 + 4.98071848322474889e-12*V03*V06*V09 + 1.69279320998488198e-12*V02*V07*V09 + 
      5.4502811685119306e-13*V01*V08*V09 + 1.03773353448467159e-12*V042*V10 + 3.05215745436668114e-12*V03*V05*V10 + 
      7.38870695966594755e-13*V02*V06*V10 + 4.36022493480954448e-13*V01*V07*V10 - 1.85215182566314525e-14*V102 + 
      1.28190613083400608e-12*V03*V04*V11 + 6.463392256305913e-13*V02*V05*V11 + 2.71675553630440848e-13*V01*V06*V11 - 
      3.9838959969837207e-14*V09*V11 + 2.2639629469203404e-13*V032*V12 + 1.54600554702115794e-13*V02*V04*V12 + 
      1.35837776815220424e-13*V01*V05*V12 - 2.52150370543244262e-14*V08*V12 + 8.28640032859732435e-14*V02*V03*V13 + 
      4.93040819551540799e-14*V01*V04*V13 - 1.8596838492559939e-14*V07*V13 + 4.00509349215537344e-15*V022*V14 + 
      1.40868805586154514e-14*V01*V03*V14 - 7.6902868355706801e-15*V06*V14 + 2.36754295102780696e-15*V01*V02*V15 - 
      3.80321817802755597e-15*V05*V15 + 1.47971434439237935e-16*V012*V16 - 9.29401533454070648e-16*V04*V16 - 
      2.88896610095655016e-16*V03*V17 - 3.17081645226938432e-17*V02*V18 - 5.28469408711564053e-18*V01*V19 + 
      1.9147442344621886e-20*V22) + delta12*eps5*
    (2.10613238719217953e-11*V063 + 1.64612745870577951e-10*V05*V06*V07 + 5.52527703739065477e-11*V04*V072 + 
      6.34085711144678006e-11*V052*V08 + 6.53389768538752109e-11*V04*V06*V08 + 6.03891153471121911e-11*V03*V07*V08 + 
      6.02167012238729901e-12*V02*V082 + 6.44615654362243056e-11*V04*V05*V09 + 4.57257627418272085e-11*V03*V06*V09 + 
      1.54291047785080388e-11*V02*V07*V09 + 5.03242627892601592e-12*V01*V08*V09 + 1.03162921957593822e-11*V042*V10 + 
      2.84232162937897181e-11*V03*V05*V10 + 7.35516676785972028e-12*V02*V06*V10 + 4.0604594705413883e-12*V01*V07*V10 - 
      7.67994164653953858e-14*V102 + 1.17202846247680556e-11*V03*V04*V11 + 5.89111273361216028e-12*V02*V05*V11 + 
      2.49413251319057501e-12*V01*V06*V11 - 1.5942072417897397e-13*V09*V11 + 2.13818722764698816e-12*V032*V12 + 
      1.55808001607139976e-12*V02*V04*V12 + 1.2829123365881929e-12*V01*V05*V12 - 1.05441977990826965e-13*V08*V12 + 
      7.55270863283610293e-13*V02*V03*V13 + 4.50780177875694445e-13*V01*V04*V13 - 7.57798708621947274e-14*V07*V13 + 
      4.16161438725110068e-14*V022*V14 + 1.36760132089891674e-13*V01*V03*V14 - 3.29532384496182881e-14*V06*V14 + 
      2.15791675223888655e-14*V01*V02*V15 - 1.60364042073524112e-14*V05*V15 + 1.55370006161199832e-15*V012*V16 - 
      4.13580159257670028e-15*V04*V16 - 1.27625362203842719e-15*V03*V17 - 1.47971434439237935e-16*V02*V18 - 
      2.46619057398729892e-17*V01*V19 + 6.7016048206176601e-20*V22) + 
   delta10*eps6*(-2.95801289810004407e-10*V044 - 7.84358338143741194e-9*V03*V042*V05 - 
      4.09348176232707823e-9*V032*V052 - 3.92005983305002913e-9*V02*V04*V052 - 
      8.01299054975525564e-10*V01*V053 - 5.49887301462931715e-9*V032*V04*V06 - 
      1.23515189263710895e-9*V02*V042*V06 - 5.57736890117064409e-9*V02*V03*V05*V06 - 
      3.29932380877759029e-9*V01*V04*V05*V06 - 2.13153443195460002e-10*V022*V062 - 
      1.13590745155871206e-9*V01*V03*V062 + 1.11077632135397347e-10*V063 - 
      1.27190326186591359e-9*V033*V07 - 3.73339031719050393e-9*V02*V03*V04*V07 - 
      1.12051191163391599e-9*V01*V042*V07 - 9.11823062558356676e-10*V022*V05*V07 - 
      2.2213661141454481e-9*V01*V03*V05*V07 - 7.96766985881520584e-10*V01*V02*V06*V07 + 7.90818238274194341e-10*V05*V06*V07 - 
      7.07587561773680666e-11*V012*V072 + 2.66182291692605467e-10*V04*V072 - 
      1.0063142665720734e-9*V02*V032*V08 - 2.14750350915928258e-10*V022*V04*V08 - 
      1.16958121224642648e-9*V01*V03*V04*V08 - 6.03788559943244039e-10*V01*V02*V05*V08 + 
      3.07308867141893107e-10*V052*V08 - 1.15543395934255982e-10*V012*V06*V08 + 
      3.48020435329644263e-10*V04*V06*V08 + 2.95653173692384828e-10*V03*V07*V08 + 3.2678175994266238e-11*V02*V082 - 
      2.53284184043987966e-10*V022*V03*V09 - 2.92166637871586518e-10*V01*V032*V09 - 
      3.11115859765875328e-10*V01*V02*V04*V09 - 8.04807753628948774e-11*V012*V05*V09 + 
      3.13793240103475455e-10*V04*V05*V09 + 2.24240350892254344e-10*V03*V06*V09 + 7.61580611867156797e-11*V02*V07*V09 + 
      2.53822800065346792e-11*V01*V08*V09 - 7.30978886129835398e-12*V023*V10 - 
      1.29608179425328507e-10*V01*V02*V03*V10 - 3.60822424022704135e-11*V012*V04*V10 + 
      5.60804732543481649e-11*V042*V10 + 1.42000663750085985e-10*V03*V05*V10 + 4.03355333137918687e-11*V02*V06*V10 + 
      2.06774049390104097e-11*V01*V07*V10 - 2.53132042505487258e-13*V102 - 
      1.3815500947853889e-11*V01*V022*V11 - 1.32250949244413297e-11*V012*V03*V11 + 
      5.88245344526877608e-11*V03*V04*V11 + 2.96754985434489887e-11*V02*V05*V11 + 1.27296865619387611e-11*V01*V06*V11 - 
      5.05754031960445325e-13*V09*V11 - 2.63714690457609848e-12*V012*V02*V12 + 
      1.11352203701387527e-11*V032*V12 + 8.81730210584071817e-12*V02*V04*V12 + 6.74017282442450755e-12*V01*V05*V12 - 
      3.50568990092294541e-13*V08*V12 - 1.18081204682511872e-13*V013*V13 + 3.95761932360611793e-12*V02*V03*V13 + 
      2.37602171422117529e-12*V01*V04*V13 - 2.44874227567633878e-13*V07*V13 + 2.48384849849704798e-13*V022*V14 + 
      7.57584150042010379e-13*V01*V03*V14 - 1.12391703028323173e-13*V06*V14 + 1.1963490474412387e-13*V01*V02*V15 - 
      5.36951342721384656e-14*V05*V15 + 9.3222003696719899e-15*V012*V16 - 1.46935634398163269e-14*V04*V16 - 
      4.49463232109185227e-15*V03*V17 - 5.54892879147142256e-16*V02*V18 - 9.24821465245237093e-17*V01*V19 + 
      2.01048144618529803e-19*V22) + delta8*eps7*
    (-3.12288574815807931e-9*V044 - 6.13302756208529629e-8*V03*V042*V05 - 
      3.11053445414828857e-8*V032*V052 - 3.05407589414942356e-8*V02*V04*V052 - 
      6.13408242084712673e-9*V01*V053 - 4.34778369389713928e-8*V032*V04*V06 - 
      1.31957658023639972e-8*V02*V042*V06 - 4.3769553743682284e-8*V02*V03*V05*V06 - 
      2.60867021633828357e-8*V01*V04*V05*V06 - 2.31124277965236571e-9*V022*V062 - 
      9.11367606483152702e-9*V01*V03*V062 + 3.89361294085025683e-10*V063 - 
      9.73663876324940751e-9*V033*V07 - 2.90864370871373672e-8*V02*V03*V04*V07 - 
      8.76146794583613756e-9*V01*V042*V07 - 7.13092395077689195e-9*V022*V05*V07 - 
      1.71856509877829517e-8*V01*V03*V05*V07 - 6.252793391954612e-9*V01*V02*V06*V07 + 2.5282819527162001e-9*V05*V06*V07 - 
      5.70894510067401446e-10*V012*V072 + 8.58885837973415987e-10*V04*V072 - 
      8.03345795856689103e-9*V02*V032*V08 - 2.36162409365023744e-9*V022*V04*V08 - 
      9.43862429428878231e-9*V01*V03*V04*V08 - 4.82007477514013462e-9*V01*V02*V05*V08 + 
      9.90550771013638422e-10*V052*V08 - 9.52465488627175524e-10*V012*V06*V08 + 
      1.24013655702525207e-9*V04*V06*V08 + 9.70630955157051171e-10*V03*V07*V08 + 1.20233202577373189e-10*V02*V082 - 
      1.98081220854913665e-9*V022*V03*V09 - 2.30511380283789247e-9*V01*V032*V09 - 
      2.42386975726144727e-9*V01*V02*V04*V09 - 6.55688060858462352e-10*V012*V05*V09 + 
      1.03082561137740446e-9*V04*V05*V09 + 7.43326732405203706e-10*V03*V06*V09 + 2.56405271524897592e-10*V02*V07*V09 + 
      8.76982300491031469e-11*V01*V08*V09 - 8.45686342107132646e-11*V023*V10 - 1.06762277776516805e-9*V01*V02*V03*V10 - 
      3.02034852834339296e-10*V012*V04*V10 + 2.06123073726194409e-10*V042*V10 + 
      4.7748951503009169e-10*V03*V05*V10 + 1.50591515305042041e-10*V02*V06*V10 + 7.19068418752763738e-11*V01*V07*V10 - 
      6.67076525370678137e-13*V102 - 1.08044302284498363e-10*V01*V022*V11 - 
      1.12177144448386278e-10*V012*V03*V11 + 2.03127638655029436e-10*V03*V04*V11 + 
      1.03144968090215195e-10*V02*V05*V11 + 4.50206788567242398e-11*V01*V06*V11 - 1.29003346187058122e-12*V09*V11 - 
      2.30258349130898151e-11*V012*V02*V12 + 3.95028240664850572e-11*V032*V12 + 
      3.43243417611322668e-11*V02*V04*V12 + 2.42921004633035937e-11*V01*V05*V12 - 9.30432048801058198e-13*V08*V12 - 
      1.18081204682511872e-12*V013*V13 + 1.45685275777151709e-11*V02*V03*V13 + 8.81931944973023978e-12*V01*V04*V13 - 
      6.32855328667315743e-13*V07*V13 + 1.03165684091036688e-12*V022*V14 + 2.90075801502960086e-12*V01*V03*V14 - 
      3.05117097813708622e-13*V06*V14 + 4.73878518791659487e-13*V01*V02*V15 - 1.4295890209760875e-13*V05*V15 + 
      3.88425015402999579e-14*V012*V16 - 4.15429802188160502e-14*V04*V16 - 1.25775719273352245e-14*V03*V17 - 
      1.66467863744142677e-15*V02*V18 - 2.77446439573571128e-16*V01*V19 + 5.02620361546324507e-19*V22) + 
   eps11*(-9.01835117002665504e-8*V026 - 3.25916459348999032e-6*V01*V024*V03 - 
      7.35068548808628174e-6*V012*V022*V032 - 1.0854789500622834e-6*V013*V033 + 
      6.78100295225791258e-7*V02*V034 - 3.88445328921519398e-6*V012*V023*V04 - 
      4.99063464093225998e-6*V013*V02*V03*V04 + 2.84278006510562727e-6*V022*V032*V04 + 
      1.64707575731881287e-6*V01*V033*V04 - 2.84933320647606362e-7*V014*V042 + 
      5.87400058299529199e-7*V023*V042 + 3.58815504059799695e-6*V01*V02*V03*V042 + 
      3.5912954439740154e-7*V012*V043 - 2.81868399275952575e-8*V044 - 
      1.54110614180058625e-6*V013*V022*V05 - 4.60814262897596231e-7*V014*V03*V05 + 
      1.12000694579646299e-6*V023*V03*V05 + 3.00648528885136028e-6*V01*V02*V032*V05 + 
      2.15679602202006303e-6*V01*V022*V04*V05 + 1.75801937489685506e-6*V012*V03*V04*V05 - 
      3.02837308803974984e-7*V03*V042*V05 + 5.39000298734921751e-7*V012*V02*V052 - 
      1.30260107162109282e-7*V032*V052 - 1.81474604951678073e-7*V02*V04*V052 - 
      3.30907815972154207e-8*V01*V053 - 2.28841374674708008e-7*V014*V02*V06 + 
      1.2426335177657929e-7*V024*V06 + 1.53341242595954898e-6*V01*V022*V03*V06 + 
      6.11779025097477478e-7*V012*V032*V06 + 9.21724593289573448e-7*V012*V02*V04*V06 - 
      2.1732776138249265e-7*V032*V04*V06 - 1.45683102372722665e-7*V02*V042*V06 + 
      1.38048989425477521e-7*V013*V05*V06 - 2.61595716210939036e-7*V02*V03*V05*V06 - 
      1.66642922459441776e-7*V01*V04*V05*V06 - 3.13513920345541883e-8*V022*V062 - 
      5.92808427693683879e-8*V01*V03*V062 + 8.84509142307875836e-10*V063 - 
      1.08398545898545899e-8*V015*V07 + 2.24590985483015906e-7*V01*V023*V07 + 
      5.54011203192750812e-7*V012*V02*V03*V07 - 4.56228874516762589e-8*V033*V07 + 
      1.01933346911025482e-7*V013*V04*V07 - 1.91754429908024679e-7*V02*V03*V04*V07 - 
      6.13420781184067054e-8*V01*V042*V07 - 5.72043116871378037e-8*V022*V05*V07 - 
      1.03916952302356811e-7*V01*V03*V05*V07 - 5.3133259730785894e-8*V01*V02*V06*V07 + 4.73703555517935601e-9*V05*V06*V07 - 
      5.00584884186415077e-9*V012*V072 + 1.741265174578467e-9*V04*V072 + 
      1.12062015273820829e-7*V012*V022*V08 + 5.3898165877332544e-8*V013*V03*V08 - 
      5.36809105180029939e-8*V02*V032*V08 - 3.57374452845974788e-8*V022*V04*V08 - 
      6.77966188714758976e-8*V01*V03*V04*V08 - 4.12668507250089883e-8*V01*V02*V05*V08 + 
      1.84415328275492498e-9*V052*V08 - 8.89450891456902195e-9*V012*V06*V08 + 
      3.03796541544199087e-9*V04*V06*V08 + 1.95419862124377447e-9*V03*V07*V08 + 3.79246470634262349e-10*V02*V082 + 
      1.95719596761263428e-8*V013*V02*V09 - 1.87589213813852975e-8*V022*V03*V09 - 
      1.67786011778556713e-8*V01*V032*V09 - 2.41704845909809145e-8*V01*V02*V04*V09 - 
      6.17402338833098637e-9*V012*V05*V09 + 2.15772698503969466e-9*V04*V05*V09 + 1.55508035764887683e-9*V03*V06*V09 + 
      6.91653165373944804e-10*V02*V07*V09 + 2.50103168132130448e-10*V01*V08*V09 + 1.05387475179141846e-9*V014*V10 - 
      1.89829593813409562e-9*V023*V10 - 1.09471819705392301e-8*V01*V02*V03*V10 - 
      3.31517199332033599e-9*V012*V04*V10 + 5.66213951638936691e-10*V042*V10 + 
      9.90709445715168765e-10*V03*V05*V10 + 4.93857621869645393e-10*V02*V06*V10 + 2.04600194881280817e-10*V01*V07*V10 - 
      1.0592820988240287e-12*V102 - 1.62155014330259428e-9*V01*V022*V11 - 
      1.34701134241575418e-9*V012*V03*V11 + 4.83293552740012793e-10*V03*V04*V11 + 2.92311187466604348e-10*V02*V05*V11 + 
      1.35732624614622041e-10*V01*V06*V11 - 1.95010166215273807e-12*V09*V11 - 3.7815505799574427e-10*V012*V02*V12 + 
      9.37949305944393234e-11*V032*V12 + 1.29817854947928907e-10*V02*V04*V12 + 7.30666296474582508e-11*V01*V05*V12 - 
      1.49261560383255041e-12*V08*V12 - 2.47970529833274931e-11*V013*V13 + 4.77180131422584983e-11*V02*V03*V13 + 
      3.07298566685929087e-11*V01*V04*V13 - 9.64334462347839848e-13*V07*V13 + 5.53945861966731133e-12*V022*V14 + 
      1.02559741067008009e-11*V01*V03*V14 - 5.09835577360394305e-13*V06*V14 + 2.32278159210993748e-12*V01*V02*V15 - 
      2.25009062494166185e-13*V05*V15 + 2.09749508317619773e-13*V012*V16 - 7.75740245047704874e-14*V04*V16 - 
      2.20569919460989047e-14*V03*V17 - 4.16169659360356692e-15*V02*V18 - 6.9361609893392782e-16*V01*V19 + 
      7.53930542319486761e-19*V22) + delta6*eps8*
    (1.16714836456899949e-7*V02*V034 + 3.3167660895835499e-7*V022*V032*V04 + 
      2.55740273101384212e-7*V01*V033*V04 + 1.0639753805538638e-8*V023*V042 + 
      4.0211845767401323e-7*V01*V02*V03*V042 + 3.92643621810288477e-8*V012*V043 - 
      1.44647796358943781e-8*V044 + 1.06435773874045479e-7*V023*V03*V05 + 
      3.97805457329266853e-7*V01*V02*V032*V05 + 1.99005965375012994e-7*V01*V022*V04*V05 + 
      2.09450079241745908e-7*V012*V03*V04*V05 - 2.23205463736282545e-7*V03*V042*V05 + 
      5.46638381459810031e-8*V012*V02*V052 - 1.08785983451243074e-7*V032*V052 - 
      1.12518714013131224e-7*V02*V04*V052 - 2.20587498467400428e-8*V01*V053 + 
      1.74482785814355479e-9*V024*V06 + 1.40126628221866317e-7*V01*V022*V03*V06 + 
      6.90710946167295374e-8*V012*V032*V06 + 8.25320145756653693e-8*V012*V02*V04*V06 - 
      1.60306931018687944e-7*V032*V04*V06 - 6.23141806988030663e-8*V02*V042*V06 + 
      1.17976618472650219e-8*V013*V05*V06 - 1.63158892000544402e-7*V02*V03*V05*V06 - 
      9.83588207974490265e-8*V01*V04*V05*V06 - 1.11381689475890119e-8*V022*V062 - 
      3.48030855806882884e-8*V01*V03*V062 + 9.53886585144753617e-10*V063 + 
      1.52051105534350684e-8*V01*V023*V07 + 4.88653762463286273e-8*V012*V02*V03*V07 - 
      3.50760218509401516e-8*V033*V07 + 8.00084505441648299e-9*V013*V04*V07 - 
      1.0966831245289851e-7*V02*V03*V04*V07 - 3.33776917471737993e-8*V01*V042*V07 - 
      2.72838431539411932e-8*V022*V05*V07 - 6.36466502471469273e-8*V01*V03*V05*V07 - 
      2.43659066418494264e-8*V01*V02*V06*V07 + 5.73454430680343706e-9*V05*V06*V07 - 
      2.24285876770250149e-9*V012*V072 + 1.97943651812315506e-9*V04*V072 + 
      7.29348240922314996e-9*V012*V022*V08 + 3.81402291124513347e-9*V013*V03*V08 - 
      3.10448607244177324e-8*V02*V032*V08 - 1.1607382420290917e-8*V022*V04*V08 - 
      3.68885683428167088e-8*V01*V03*V04*V08 - 1.90217012623058375e-8*V01*V02*V05*V08 + 
      2.25567676854889474e-9*V052*V08 - 3.85231495904931946e-9*V012*V06*V08 + 
      3.10327793500338834e-9*V04*V06*V08 + 2.26552478541084656e-9*V03*V07*V08 + 3.14616699492002765e-10*V02*V082 + 
      1.00369023980135091e-9*V013*V02*V09 - 7.92456084758190786e-9*V022*V03*V09 - 
      9.03546132401563463e-9*V01*V032*V09 - 9.76593414783968783e-9*V01*V02*V04*V09 - 
      2.6475492964171769e-9*V012*V05*V09 + 2.41967965015243137e-9*V04*V05*V09 + 1.75967541052281089e-9*V03*V06*V09 + 
      6.25456165059616089e-10*V02*V07*V09 + 2.19248139960954814e-10*V01*V08*V09 + 4.01476095920540365e-11*V014*V10 - 
      4.41323816738797546e-10*V023*V10 - 4.45295468686769652e-9*V01*V02*V03*V10 - 
      1.27550192715147586e-9*V012*V04*V10 + 5.34938290003461784e-10*V042*V10 + 
      1.1361175216718043e-9*V03*V05*V10 + 4.00148693505997441e-10*V02*V06*V10 + 1.80018298529104411e-10*V01*V07*V10 - 
      1.37352914624220985e-12*V102 - 4.69963194636397251e-10*V01*V022*V11 - 
      4.90627405455836828e-10*V012*V03*V11 + 5.02893349542243018e-10*V03*V04*V11 + 
      2.59112630875115109e-10*V02*V05*V11 + 1.15332635287803027e-10*V01*V06*V11 - 2.59545595292284319e-12*V09*V11 - 
      1.05092272167435566e-10*V012*V02*V12 + 9.92078181483731716e-11*V032*V12 + 
      9.54439427562594958e-11*V02*V04*V12 + 6.26440027127202582e-11*V01*V05*V12 - 1.92513302396022541e-12*V08*V12 - 
      5.9040602341255936e-12*V013*V13 + 3.87855325380408513e-11*V02*V03*V13 + 2.3732250541102737e-11*V01*V04*V13 - 
      1.28109968651631223e-12*V07*V13 + 3.08841045580429443e-12*V022*V14 + 7.94458631504268473e-12*V01*V03*V14 - 
      6.42639939769610351e-13*V06*V14 + 1.37243505442393185e-12*V01*V02*V15 - 2.95332486711414013e-13*V05*V15 + 
      1.16527504620899874e-13*V012*V16 - 9.08914536043019015e-14*V04*V16 - 2.71897510782099705e-14*V03*V17 - 
      3.88425015402999579e-15*V02*V18 - 6.47375025671665965e-16*V01*V19 + 1.00524072309264901e-18*V22) + 
   delta2*eps10*(-1.05683802773749864e-9*V026 - 1.43624287969526065e-6*V01*V024*V03 - 
      4.03239837763647287e-6*V012*V022*V032 - 6.39695952195952196e-7*V013*V033 + 
      1.03731386283469617e-6*V02*V034 - 1.80719302743112267e-6*V012*V023*V04 - 
      2.58256954685526114e-6*V013*V02*V03*V04 + 3.76126895224117446e-6*V022*V032*V04 + 
      2.41349362443112443e-6*V01*V033*V04 - 1.39266322302036588e-7*V014*V042 + 
      5.67501373552960855e-7*V023*V042 + 4.64213503648027458e-6*V01*V02*V03*V042 + 
      4.56605646337789195e-7*V012*V043 - 4.8511255774108832e-8*V044 - 
      6.58099616432949766e-7*V013*V022*V05 - 2.11015836015836016e-7*V014*V03*V05 + 
      1.29053917496377814e-6*V023*V03*V05 + 3.9946842867229772e-6*V01*V02*V032*V05 + 
      2.44500548319992764e-6*V01*V022*V04*V05 + 2.24826843130414559e-6*V012*V03*V04*V05 - 
      5.60125414233724224e-7*V03*V042*V05 + 6.19076139909473243e-7*V012*V02*V052 - 
      2.49438911785360782e-7*V032*V052 - 3.07119530720429413e-7*V02*V04*V052 - 
      5.691691187504096e-8*V01*V053 - 8.67188367188367188e-8*V014*V02*V06 + 
      1.01721424886107426e-7*V024*V06 + 1.76647646885742124e-6*V01*V022*V03*V06 + 
      7.76630845455250217e-7*V012*V032*V06 + 1.04599434956577814e-6*V012*V02*V04*V06 - 
      4.0652457348302353e-7*V032*V04*V06 - 2.31405524903132279e-7*V02*V042*V06 + 
      1.52463415112224636e-7*V013*V05*V06 - 4.49494829929295382e-7*V02*V03*V05*V06 - 
      2.8006164438601997e-7*V01*V04*V05*V06 - 4.55565553349458578e-8*V022*V062 - 
      1.00457618621134027e-7*V01*V03*V062 + 1.71256554412201539e-9*V063 - 
      3.61328486328486328e-9*V015*V07 + 2.13711461231302501e-7*V01*V023*V07 + 
      6.20745133393942918e-7*V012*V02*V03*V07 - 8.67051308647217844e-8*V033*V07 + 
      1.10772990237275952e-7*V013*V04*V07 - 3.23151314667712894e-7*V02*V03*V04*V07 - 
      1.01333081107021933e-7*V01*V042*V07 - 8.70315157488360103e-8*V022*V05*V07 - 
      1.77061130153304523e-7*V01*V03*V05*V07 - 8.07420722001137501e-8*V01*V02*V06*V07 + 9.36414228087805413e-9*V05*V06*V07 - 
      7.52927932914510879e-9*V012*V072 + 3.39053821003755583e-9*V04*V072 + 
      1.08217881655381655e-7*V012*V022*V08 + 5.69694580111246778e-8*V013*V03*V08 - 
      9.20055009399080361e-8*V02*V032*V08 - 5.09313924784279593e-8*V022*V04*V08 - 
      1.13208170487071631e-7*V01*V03*V04*V08 - 6.28664755448281359e-8*V01*V02*V05*V08 + 
      3.65860240983193125e-9*V052*V08 - 1.33508092355693896e-8*V012*V06*V08 + 
      5.81472070492569043e-9*V04*V06*V08 + 3.86604911270109038e-9*V03*V07*V08 + 6.69355072471856466e-10*V02*V082 + 
      1.80664243164243164e-8*V013*V02*V09 - 2.83619245526925265e-8*V022*V03*V09 - 
      2.81638855036964281e-8*V01*V032*V09 - 3.58774136840050706e-8*V01*V02*V04*V09 - 
      9.23462495591347132e-9*V012*V05*V09 + 4.20004124525269606e-9*V04*V05*V09 + 3.06443310291299597e-9*V03*V06*V09 + 
      1.23744774342815094e-9*V02*V07*V09 + 4.45845885430025007e-10*V01*V08*V09 + 9.03321215821215821e-10*V014*V10 - 
      2.36809044533523214e-9*V023*V10 - 1.64647371186236732e-8*V01*V02*V03*V10 - 
      4.8689519595069315e-9*V012*V04*V10 + 1.06738757717012689e-9*V042*V10 + 
      1.95993066468536445e-9*V03*V05*V10 + 8.68331150576541423e-10*V02*V06*V10 + 3.64912169506311622e-10*V01*V07*V10 - 
      2.10980781986575818e-12*V102 - 2.1210336391096195e-9*V01*V022*V11 - 
      1.96605205796382267e-9*V012*V03*V11 + 9.3749562552640253e-10*V03*V04*V11 + 5.22594784223503694e-10*V02*V05*V11 + 
      2.40847369943663066e-10*V01*V06*V11 - 3.90006460108568935e-12*V09*V11 - 4.91513014490955667e-10*V012*V02*V12 + 
      1.84496333387633329e-10*V032*V12 + 2.23917921136611244e-10*V02*V04*V12 + 1.29959796546414746e-10*V01*V05*V12 - 
      2.97043406422117702e-12*V08*V12 - 3.09963162291593664e-11*V013*V13 + 8.4929129617865858e-11*V02*V03*V13 + 
      5.3556817973796388e-11*V01*V04*V13 - 1.92853020147589291e-12*V07*V13 + 8.62458904200820265e-12*V022*V14 + 
      1.80431188155001364e-11*V01*V03*V14 - 1.01084835794234905e-12*V06*V14 + 3.67061639555834602e-12*V01*V02*V15 - 
      4.49879401768545584e-13*V05*V15 + 3.26277012938519646e-13*V012*V16 - 1.51596734582999264e-13*V04*V16 - 
      4.39752606724110238e-14*V03*V17 - 7.49105386848642045e-15*V02*V18 - 1.24850897808107008e-15*V01*V19 + 
      1.50786108463897352e-18*V22) + delta4*eps9*
    (5.77265272205748396e-7*V02*V034 + 1.82975598402185704e-6*V022*V032*V04 + 
      1.29435893324782214e-6*V01*V033*V04 + 1.71045640622360199e-7*V023*V042 + 
      2.22836898184120406e-6*V01*V02*V03*V042 + 2.17760634427301094e-7*V012*V043 - 
      3.60906857706966639e-8*V044 + 5.88336453498490536e-7*V023*V03*V05 + 
      2.02834900255535176e-6*V01*V02*V032*V05 + 1.09785359041311422e-6*V01*V022*V04*V05 + 
      1.10349719724719725e-6*V012*V03*V04*V05 - 4.68083420578654783e-7*V03*V042*V05 + 
      2.91282378335949765e-7*V012*V02*V052 - 2.17885800504264557e-7*V032*V052 - 
      2.43074095879106772e-7*V02*V04*V052 - 4.63433304017454344e-8*V01*V053 + 
      2.92978136893480809e-8*V024*V06 + 7.90223105451280054e-7*V01*V022*V03*V06 + 
      3.71694599125154681e-7*V012*V032*V06 + 4.64519313725662932e-7*V012*V02*V04*V06 - 
      3.39387086707542668e-7*V032*V04*V06 - 1.61809756133596781e-7*V02*V042*V06 + 
      6.75684269434269434e-8*V013*V05*V06 - 3.55806643708089008e-7*V02*V03*V05*V06 - 
      2.17671871098866897e-7*V01*V04*V05*V06 - 3.00604608299908642e-8*V022*V062 - 
      7.77819282174149121e-8*V01*V03*V062 + 1.60833310225194172e-9*V063 + 
      8.40480647854986479e-8*V01*V023*V07 + 2.70296649264903233e-7*V012*V02*V03*V07 - 
      7.32294648124869102e-8*V033*V07 + 4.66974053283577093e-8*V013*V04*V07 - 
      2.46677484412856339e-7*V02*V03*V04*V07 - 7.61219370190736515e-8*V01*V042*V07 - 
      6.29359832025273202e-8*V022*V05*V07 - 1.38998120525801042e-7*V01*V03*V05*V07 - 
      5.7467395205441813e-8*V01*V02*V06*V07 + 9.13001277706507386e-9*V05*V06*V07 - 
      5.30907153538845104e-9*V012*V072 + 3.22444623072974743e-9*V04*V072 + 
      4.26367613867613868e-8*V012*V022*V08 + 2.3125023125023125e-8*V013*V03*V08 - 
      7.06136849830438377e-8*V02*V032*V08 - 3.23479074354424494e-8*V022*V04*V08 - 
      8.51545756400059232e-8*V01*V03*V04*V08 - 4.4997879418105842e-8*V01*V02*V05*V08 + 
      3.58588104686483122e-9*V052*V08 - 9.33831149945373413e-9*V012*V06*V08 + 
      5.35219682347953734e-9*V04*V06*V08 + 3.70330815615235731e-9*V03*V07*V08 + 5.74573573165675699e-10*V02*V082 + 
      6.62435558268891602e-9*V013*V02*V09 - 1.95347640966513516e-8*V022*V03*V09 - 
      2.10785071604399335e-8*V01*V032*V09 - 2.43510434044981197e-8*V01*V02*V04*V09 - 
      6.44571558874780163e-9*V012*V05*V09 + 3.98584660105880436e-9*V04*V05*V09 + 2.91333022299243766e-9*V03*V06*V09 + 
      1.09040704931153581e-9*V02*V07*V09 + 3.89198166147944597e-10*V01*V08*V09 + 3.01107071940405274e-10*V014*V10 - 
      1.34500115047889713e-9*V023*V10 - 1.12181361634267797e-8*V01*V02*V03*V10 - 
      3.25870387436680621e-9*V012*V04*V10 + 9.5573417761393829e-10*V042*V10 + 
      1.87501133817503019e-9*V03*V05*V10 + 7.39981468201118634e-10*V02*V06*V10 + 3.1894243886195272e-10*V01*V07*V10 - 
      2.09271123396052009e-12*V102 - 1.28944675513302964e-9*V01*V022*V11 - 
      1.29121797320326732e-9*V012*V03*V11 + 8.658560693855349e-10*V03*V04*V11 + 4.59043272703367589e-10*V02*V05*V11 + 
      2.08292359616979377e-10*V01*V06*V11 - 3.89895481532739506e-12*V09*V11 - 2.9520301170627968e-10*V012*V02*V12 + 
      1.71398086975365036e-10*V032*V12 + 1.84287767650791223e-10*V02*V04*V12 + 1.129495553361591e-10*V01*V05*V12 - 
      2.94167211665205015e-12*V08*V12 - 1.77121807023767808e-11*V013*V13 + 7.22146841136743384e-11*V02*V03*V13 + 
      4.47838505759042395e-11*V01*V04*V13 - 1.92742041571759863e-12*V07*V13 + 6.47582185679880898e-12*V022*V14 + 
      1.51042951489610416e-11*V01*V03*V14 - 9.94035103704190637e-13*V06*V14 + 2.80831286136368696e-12*V01*V02*V15 - 
      4.48769616010251299e-13*V05*V15 + 2.44707759703889735e-13*V012*V16 - 1.45326445048636557e-13*V04*V16 - 
      4.28654749141167393e-14*V03*V17 - 6.65871454976570707e-15*V02*V18 - 1.10978575829428451e-15*V01*V19 + 
      1.50786108463897352e-18*V22) + 3.86817017063068404e-23*delta22*V22 + 
   2.12749359384687622e-22*delta20*eps*V22 + 
   delta20*eps2*(-3.41091377476043088e-18*V112 - 5.24755965347758597e-18*V10*V12 - 
      4.81026301568778714e-18*V09*V13 - 2.56547360836681981e-18*V08*V14 - 1.64923303395009845e-18*V07*V15 - 
      5.82082247276505334e-19*V06*V16 - 2.54660983183471084e-19*V05*V17 - 5.36128385649412808e-20*V04*V18 - 
      1.48924551569281335e-20*V03*V19 - 1.41832906256458415e-21*V02*V20 - 2.12749359384687622e-22*V01*V21 + 
      2.12749359384687622e-24*V24) + delta18*eps3*
    (-3.41091377476043088e-17*V112 - 5.24755965347758597e-17*V10*V12 - 4.81026301568778714e-17*V09*V13 - 
      2.56547360836681981e-17*V08*V14 - 1.64923303395009845e-17*V07*V15 - 5.82082247276505334e-18*V06*V16 - 
      2.54660983183471084e-18*V05*V17 - 5.36128385649412808e-19*V04*V18 - 1.48924551569281335e-19*V03*V19 - 
      1.41832906256458415e-20*V02*V20 - 2.12749359384687622e-21*V01*V21 + 1.06374679692343811e-23*V24) + 
   delta16*eps4*(1.95275788151827456e-13*V06*V072 + 1.10155572803594975e-13*V062*V08 + 
      3.00424289464349933e-13*V05*V07*V08 + 5.69431659769029285e-14*V04*V082 + 2.27821752843798699e-13*V05*V06*V09 + 
      1.53157480903394083e-13*V04*V07*V09 + 8.34511915178749814e-14*V03*V08*V09 + 1.07059094381484351e-14*V02*V092 + 
      7.06059151375409192e-14*V052*V10 + 6.95537485590207015e-14*V04*V06*V10 + 6.7243728702419923e-14*V03*V07*V10 + 
      1.28135148350630137e-14*V02*V08*V10 + 5.60364405853499358e-15*V01*V09*V10 + 5.84783108903868319e-14*V04*V05*V11 + 
      4.14221368806906726e-14*V03*V06*V11 + 1.40150087190306787e-14*V02*V07*V11 + 4.55188317370227171e-15*V01*V08*V11 - 
      2.06888162885766611e-16*V112 + 7.37226568917269889e-15*V042*V12 + 2.1242121477277268e-14*V03*V05*V12 + 
      5.25463004964227156e-15*V02*V06*V12 + 3.03458878246818114e-15*V01*V07*V12 - 3.25473640412121701e-16*V10*V12 + 
      7.4972193449213887e-15*V03*V04*V13 + 3.77327157820056734e-15*V02*V05*V13 + 1.5931591107957951e-15*V01*V06*V13 - 
      2.93082453741548745e-16*V09*V13 + 1.13797079342556793e-15*V032*V14 + 7.91999487189063994e-16*V02*V04*V14 + 
      6.82782476055340757e-16*V01*V05*V14 - 1.60525348637809582e-16*V08*V14 + 3.59359197923863556e-16*V02*V03*V15 + 
      2.14206266997753963e-16*V01*V04*V15 - 1.01840139846418579e-16*V07*V15 + 1.55017693222058789e-17*V022*V16 + 
      5.35515667494384907e-17*V01*V03*V16 - 3.70592364099375063e-17*V06*V16 + 7.9270411306734608e-18*V01*V02*V17 - 
      1.60739587242709963e-17*V05*V17 + 4.40391173926303378e-19*V012*V18 - 3.50142895675318888e-18*V04*V18 - 
      9.68541458598790399e-19*V03*V19 - 9.57372117231094299e-20*V02*V20 - 1.43605817584664145e-20*V01*V21 + 
      4.7868605861554715e-23*V24) + delta14*eps5*
    (2.05039577559418829e-12*V06*V072 + 1.23173958680383473e-12*V062*V08 + 
      3.16697271810335554e-12*V05*V07*V08 + 6.37501651281648877e-13*V04*V082 + 2.39212840485988634e-12*V05*V06*V09 + 
      1.60336737820740681e-12*V04*V07*V09 + 8.79714643917598762e-13*V03*V08*V09 + 1.11817276353994767e-13*V02*V092 + 
      7.48422700457933743e-13*V052*V10 + 7.8015382937856978e-13*V04*V06*V10 + 7.12783524245651184e-13*V03*V07*V10 + 
      1.44021970804301276e-13*V02*V08*V10 + 5.9398627020470932e-14*V01*V09*V10 + 6.12194817133737146e-13*V04*V05*V11 + 
      4.34932437247252062e-13*V03*V06*V11 + 1.46378979954320422e-13*V02*V07*V11 + 4.79844351227781143e-14*V01*V08*V11 - 
      9.47746755987005437e-16*V112 + 8.32191347286274146e-14*V042*V12 + 2.27025173288400802e-13*V03*V05*V12 + 
      5.93661394970222595e-14*V02*V06*V12 + 3.24321676126286859e-14*V01*V07*V12 - 1.54428184088054673e-15*V10*V12 + 
      7.8486515017145788e-14*V03*V04*V13 + 3.94097253723170367e-14*V02*V05*V13 + 1.67281706633558485e-14*V01*V06*V13 - 
      1.35237108783908073e-15*V09*V13 + 1.23280169287769859e-14*V032*V14 + 9.06336779704970386e-15*V02*V04*V14 + 
      7.39681015726619153e-15*V01*V05*V14 - 7.71841059888646073e-16*V08*V14 + 3.75330717831590825e-15*V02*V03*V15 + 
      2.2424718576327368e-15*V01*V04*V15 - 4.79926812879478648e-16*V07*V15 + 1.82732977767820815e-16*V022*V16 + 
      5.95761180087503209e-16*V01*V03*V16 - 1.82773825644822675e-16*V06*V16 + 8.2793540698145035e-17*V01*V02*V17 - 
      7.82900622586899674e-17*V05*V17 + 5.28469408711564053e-18*V012*V18 - 1.78913701268146903e-17*V04*V18 - 
      4.9208926825678247e-18*V03*V19 - 5.10598462523250293e-19*V02*V20 - 7.65897693784875439e-20*V01*V21 + 
      1.9147442344621886e-22*V24) + delta12*eps6*
    (-1.81710194045720362e-10*V042*V052 - 1.29792995746943115e-10*V03*V053 - 
      4.18662090202051216e-11*V043*V06 - 5.14805050014601672e-10*V03*V04*V05*V06 - 
      1.29420107732156236e-10*V02*V052*V06 - 9.01865811069624174e-11*V032*V062 - 
      4.40269978275238859e-11*V02*V04*V062 - 5.41119486641774504e-11*V01*V05*V062 - 
      1.7305732766259082e-10*V03*V042*V07 - 1.82550878953343448e-10*V032*V05*V07 - 
      1.71981279391348682e-10*V02*V04*V05*V07 - 5.3904957766173305e-11*V01*V052*V07 - 
      1.23257245459196415e-10*V02*V03*V06*V07 - 7.35435785735145245e-11*V01*V04*V06*V07 - 
      9.95785605773606822e-12*V022*V072 - 2.49971695512631185e-11*V01*V03*V072 + 
      1.15250268045761243e-11*V06*V072 - 9.3124342549990002e-11*V032*V04*V08 - 
      2.23761745508195875e-11*V02*V042*V08 - 9.46468041976648278e-11*V02*V03*V05*V08 - 
      5.58746055299940012e-11*V01*V04*V05*V08 - 7.76241046146929228e-12*V022*V06*V08 - 
      3.85115190357462705e-11*V01*V03*V06*V08 + 7.53554676494466446e-12*V062*V08 - 
      1.35209720282378325e-11*V01*V02*V07*V08 + 1.79154934532962937e-11*V05*V07*V08 - 
      9.82119292914208671e-13*V012*V082 + 3.92859226055028743e-12*V04*V082 - 
      1.63718061254146838e-11*V033*V09 - 4.77725776087079673e-11*V02*V03*V04*V09 - 
      1.44214439718825684e-11*V01*V042*V09 - 1.16174987340254129e-11*V022*V05*V09 - 
      2.86854167432348997e-11*V01*V03*V05*V09 - 1.02714371215997013e-11*V01*V02*V06*V09 + 1.35496295737393273e-11*V05*V06*V09 - 
      1.84187443018241419e-12*V012*V07*V09 + 9.10052682992914154e-12*V04*V07*V09 + 
      5.05222430881163618e-12*V03*V08*V09 + 6.46063149296892166e-13*V02*V092 - 
      1.04307530326792808e-11*V02*V032*V10 - 2.36513594902759535e-12*V022*V04*V10 - 
      1.21170650938357241e-11*V01*V03*V04*V10 - 6.25845181960756846e-12*V01*V02*V05*V10 + 
      4.29758799138050964e-12*V052*V10 - 1.19770545225693172e-12*V012*V06*V10 + 
      4.84506694116438835e-12*V04*V06*V10 + 4.12322028399698023e-12*V03*V07*V10 + 9.06863113883747762e-13*V02*V08*V10 + 
      3.51171525289348256e-13*V01*V09*V10 - 2.11227249709552962e-12*V022*V03*V11 - 
      2.44960790856780832e-12*V01*V032*V11 - 2.60577696047498003e-12*V01*V02*V04*V11 - 
      6.77191269711172409e-13*V012*V05*V11 + 3.52815936324254369e-12*V04*V05*V11 + 
      2.52016808708015893e-12*V03*V06*V11 + 8.52167490935571267e-13*V02*V07*V11 + 2.83833873160198232e-13*V01*V08*V11 - 
      3.51413879689133865e-15*V112 - 5.41772745293529826e-14*V023*V12 - 
      9.0682813881742576e-13*V01*V02*V03*V12 - 2.52291295718900679e-13*V012*V04*V12 + 
      5.289041628784641e-13*V042*V12 + 1.34433281283334658e-12*V03*V05*V12 + 3.79763754107156185e-13*V02*V06*V12 + 
      1.94742738674907059e-13*V01*V07*V12 - 5.94631364944065399e-15*V10*V12 - 8.12412498882896009e-14*V01*V022*V13 - 
      7.79957430929223155e-14*V012*V03*V13 + 4.66023701813509939e-13*V03*V04*V13 + 
      2.34608709303411746e-13*V02*V05*V13 + 1.0055768755904512e-13*V01*V06*V13 - 5.05191543929168149e-15*V09*V13 - 
      1.32927671937915412e-14*V012*V02*V14 + 7.5919621661387341e-14*V032*V14 + 
      5.98495128495237701e-14*V02*V04*V14 + 4.58452496751368932e-14*V01*V05*V14 - 3.0134525591120312e-15*V08*V14 - 
      5.17900020537332772e-16*V013*V15 + 2.31657501249873611e-14*V02*V03*V15 + 1.3901916265566404e-14*V01*V04*V15 - 
      1.83240640289184556e-15*V07*V15 + 1.26762195502947164e-15*V022*V16 + 3.87685158230803389e-15*V01*V03*V16 - 
      7.33048341698442132e-16*V06*V16 + 5.36396449842237514e-16*V01*V02*V17 - 3.09533723454688484e-16*V05*V17 + 
      3.69928586098094837e-17*V012*V18 - 7.45754584438333215e-17*V04*V18 - 2.03728786546776867e-17*V03*V19 - 
      2.23386827353922003e-18*V02*V20 - 3.35080241030883005e-19*V01*V21 + 6.7016048206176601e-22*V24) + 
   delta10*eps7*(-1.70557610707464509e-9*V042*V052 - 1.19217270167562565e-9*V03*V053 - 
      5.01323905320006685e-10*V043*V06 - 4.86215725920891613e-9*V03*V04*V05*V06 - 
      1.21733642787349358e-9*V02*V052*V06 - 8.59173938356269183e-10*V032*V062 - 
      5.31289659696870534e-10*V02*V04*V062 - 5.1550436301376151e-10*V01*V05*V062 - 
      1.6243581972139477e-9*V03*V042*V07 - 1.68494184567353601e-9*V032*V05*V07 - 
      1.61287383824424957e-9*V02*V04*V05*V07 - 5.00033949543139184e-10*V01*V052*V07 - 
      1.15936802654618436e-9*V02*V03*V06*V07 - 6.94593894172702304e-10*V01*V04*V06*V07 - 
      9.39246312560111764e-11*V022*V072 - 2.33856304153575109e-10*V01*V03*V072 + 
      4.44102205900675288e-11*V06*V072 - 8.89988989578240483e-10*V032*V04*V08 - 
      2.7239765423050433e-10*V02*V042*V08 - 8.9868083163720132e-10*V02*V03*V05*V08 - 
      5.3399339374694429e-10*V01*V04*V05*V08 - 9.55675284983031473e-11*V022*V06*V08 - 
      3.723987620360497e-10*V01*V03*V06*V08 + 3.1674494679726012e-11*V062*V08 - 
      1.28382975948171617e-10*V01*V02*V07*V08 + 6.94986314416835163e-11*V05*V07*V08 - 
      9.71432467093597043e-12*V012*V082 + 1.67162671835187365e-11*V04*V082 - 
      1.52649797958091841e-10*V033*V09 - 4.48020510623402657e-10*V02*V03*V04*V09 - 
      1.35363183101162308e-10*V01*V042*V09 - 1.09578736465346372e-10*V022*V05*V09 - 
      2.69805352535325616e-10*V01*V03*V05*V09 - 9.66140022121820299e-11*V01*V02*V06*V09 + 5.29256680159109844e-11*V05*V06*V09 - 
      1.79602794741199031e-11*V012*V07*V09 + 3.57673098659722354e-11*V04*V07*V09 + 2.0127259476718193e-11*V03*V08*V09 + 
      2.61853949669536431e-12*V02*V092 - 1.00756215900251097e-10*V02*V032*V10 - 
      2.97018917149718008e-11*V022*V04*V10 - 1.18149015058534227e-10*V01*V03*V04*V10 - 
      6.04537295401506583e-11*V01*V02*V05*V10 + 1.69961237638805225e-11*V052*V10 - 
      1.19030688053496982e-11*V012*V06*V10 + 2.08588297254544514e-11*V04*V06*V10 + 
      1.65213712420960515e-11*V03*V07*V10 + 3.99657392471796277e-12*V02*V08*V10 + 1.46042761310808322e-12*V01*V09*V10 - 
      1.99234066300629768e-11*V022*V03*V11 - 2.35260967386419907e-11*V01*V032*V11 - 
      2.44374823976401449e-11*V01*V02*V04*V11 - 6.69245203681785332e-12*V012*V05*V11 + 
      1.42250735474288297e-11*V04*V05*V11 + 1.02303454542559249e-11*V03*V06*V11 + 3.49571416005116678e-12*V02*V07*V11 + 
      1.18753241613923411e-12*V01*V08*V11 - 1.07722042660262976e-14*V112 - 7.15353102653051873e-13*V023*V12 - 
      9.02525129503932721e-12*V01*V02*V03*V12 - 2.54954781538806962e-12*V012*V04*V12 + 
      2.35514294482179882e-12*V042*V12 + 5.54943436053908996e-12*V03*V05*V12 + 1.71018478591264041e-12*V02*V06*V12 + 
      8.23411708842879362e-13*V01*V07*V12 - 1.88276916619772124e-14*V10*V12 - 7.6628487038703757e-13*V01*V022*V13 - 
      8.02123551808220998e-13*V012*V03*V13 + 1.96948746143338698e-12*V03*V04*V13 + 
      9.95921739493290921e-13*V02*V05*V13 + 4.32416922861785017e-13*V01*V06*V13 - 1.55700618665683636e-14*V09*V13 - 
      1.39833005545079848e-13*V012*V02*V14 + 3.29532384496182881e-13*V032*V14 + 
      2.80820188278785753e-13*V02*V04*V14 + 2.01241150837363591e-13*V01*V05*V14 - 9.65495738769839211e-15*V08*V14 - 
      6.21480024644799327e-15*V013*V15 + 1.03543011248856745e-13*V02*V03*V15 + 6.25179310505780275e-14*V01*V04*V15 - 
      5.74558068332762718e-15*V07*V15 + 6.30358310711153603e-15*V022*V16 + 1.7985927856089371e-14*V01*V03*V16 - 
      2.40764535427438304e-15*V06*V16 + 2.55250724407685438e-15*V01*V02*V17 - 1.00124656661956089e-15*V05*V17 + 
      1.84964293049047419e-16*V012*V18 - 2.54660983183471084e-16*V04*V18 - 6.9026529652361899e-17*V03*V19 - 
      8.04192578474119211e-18*V02*V20 - 1.20628886771117882e-18*V01*V21 + 2.01048144618529803e-21*V24) + 
   delta8*eps8*(1.12851894189429203e-8*V034*V04 + 
      3.22772161542391857e-8*V02*V032*V042 + 1.32727772394750297e-9*V022*V043 + 
      1.28988759163051102e-8*V01*V03*V043 + 2.32560932622207132e-8*V02*V033*V05 + 
      3.15213839859809359e-8*V022*V03*V04*V05 + 3.88793049954736852e-8*V01*V032*V04*V05 + 
      1.93663296925435114e-8*V01*V02*V042*V05 + 2.50509275733948937e-9*V023*V052 + 
      2.01676793537496152e-8*V01*V02*V03*V052 + 5.42296366876198809e-9*V012*V04*V052 - 
      7.79716800769014296e-9*V042*V052 - 5.26980793180764275e-9*V03*V053 + 
      1.12944672278822606e-8*V022*V032*V06 + 8.727044463213931e-9*V01*V033*V06 + 
      8.90219825015965694e-10*V023*V04*V06 + 2.72517925412416542e-8*V01*V02*V03*V04*V06 + 
      3.97332007927635067e-9*V012*V042*V06 - 2.82619430165753763e-9*V043*V06 + 
      6.77668033672935634e-9*V01*V022*V05*V06 + 7.21389005435262827e-9*V012*V03*V05*V06 - 
      2.24289006366088539e-8*V03*V04*V05*V06 - 5.65439409962507944e-9*V02*V052*V06 + 
      1.39900924433487459e-9*V012*V02*V062 - 4.00160730277563195e-9*V032*V062 - 
      3.03640156876773161e-9*V02*V04*V062 - 2.43622427282075352e-9*V01*V05*V062 + 
      2.38580262603760892e-9*V023*V03*V07 + 9.24041655785742309e-9*V01*V02*V032*V07 + 
      4.5030548551401337e-9*V01*V022*V04*V07 + 4.91510203033701322e-9*V012*V03*V04*V07 - 
      7.54012879201343963e-9*V03*V042*V07 + 2.57138691939695675e-9*V012*V02*V05*V07 - 
      7.59338696663967903e-9*V032*V05*V07 - 7.5484574628484751e-9*V02*V04*V05*V07 - 
      2.29457182461032637e-9*V01*V052*V07 + 2.82523339489181381e-10*V013*V06*V07 - 
      5.4663977239129376e-9*V02*V03*V06*V07 - 3.30056967893175719e-9*V01*V04*V06*V07 - 
      4.51109044388735651e-10*V022*V072 - 1.09454741335667439e-9*V01*V03*V072 + 
      1.26631398443508704e-10*V06*V072 + 3.65989257687912458e-11*V024*V08 + 
      2.43314756620078749e-9*V01*V022*V03*V08 + 1.21284391647629535e-9*V012*V032*V08 + 
      1.42878257665839365e-9*V012*V02*V04*V08 - 4.21187584438707663e-9*V032*V04*V08 - 
      1.57900113818356684e-9*V02*V042*V08 + 2.09303621061842869e-10*V013*V05*V08 - 
      4.27845468704313461e-9*V02*V03*V05*V08 - 2.56344641051699639e-9*V01*V04*V05*V08 - 
      5.6232564871173011e-10*V022*V06*V08 - 1.80530156382735475e-9*V01*V03*V06*V08 + 
      9.74318743872451483e-11*V062*V08 - 6.28867334096473348e-10*V01*V02*V07*V08 + 
      1.99076135566589245e-10*V05*V07*V08 - 4.90493244688611919e-11*V012*V082 + 
      5.22622857692870916e-11*V04*V082 + 1.98816885503134077e-10*V01*V023*V09 + 
      6.53734098066692215e-10*V012*V02*V03*V09 - 7.14665652030552913e-10*V033*V09 + 
      1.07959958566867997e-10*V013*V04*V09 - 2.16039515045621509e-9*V02*V03*V04*V09 - 
      6.56907690744922031e-10*V01*V042*V09 - 5.34141365181383528e-10*V022*V05*V09 - 
      1.28674492004969786e-9*V01*V03*V05*V09 - 4.75848265203103142e-10*V01*V02*V06*V09 + 1.53293911446729409e-10*V05*V06*V09 - 
      8.93781990681032949e-11*V012*V07*V09 + 1.04748497532374607e-10*V04*V07*V09 + 
      5.96375848728657949e-11*V03*V08*V09 + 8.00285623282956963e-12*V02*V092 + 
      7.68511840475348101e-11*V012*V022*V10 + 4.10332186271728755e-11*V013*V03*V10 - 
      4.99307533109571225e-10*V02*V032*V10 - 1.79761814709409732e-10*V022*V04*V10 - 
      5.90560875518700023e-10*V01*V03*V04*V10 - 3.03615680992265154e-10*V01*V02*V05*V10 + 
      4.95593811626264585e-11*V052*V10 - 6.1010472062228291e-11*V012*V06*V10 + 
      6.60909927939994441e-11*V04*V06*V10 + 4.90642617367695468e-11*V03*V07*V10 + 1.30867700317987669e-11*V02*V08*V10 + 
      4.56632279958408988e-12*V01*V09*V10 + 8.75768934728629718e-12*V013*V02*V11 - 
      1.01397055520901697e-10*V022*V03*V11 - 1.18628329061350954e-10*V01*V032*V11 - 
      1.24778071200457163e-10*V01*V02*V04*V11 - 3.4528579333517025e-11*V012*V05*V11 + 
      4.27939492219946726e-11*V04*V05*V11 + 3.09900829324836135e-11*V03*V06*V11 + 1.08063045332860666e-11*V02*V07*V11 + 
      3.74521866042146181e-12*V01*V08*V11 - 2.71163685054242072e-14*V112 + 2.9520301170627968e-13*V014*V12 - 
      4.5881009438459709e-12*V023*V12 - 4.77907041094267739e-11*V01*V02*V03*V12 - 
      1.3647553369765354e-11*V012*V04*V12 + 7.75800666716767563e-12*V042*V12 + 
      1.69422051777957712e-11*V03*V05*V12 + 5.72886205574953589e-12*V02*V06*V12 + 2.60664012717587559e-12*V01*V07*V12 - 
      4.85079215546758719e-14*V10*V12 - 4.17427416553090214e-12*V01*V022*V13 - 
      4.44746642636434518e-12*V012*V03*V13 + 6.23590467228488958e-12*V03*V04*V13 + 
      3.18383353458829799e-12*V02*V05*V13 + 1.40300965206493938e-12*V01*V06*V13 - 3.92968703471378353e-14*V09*V13 - 
      8.00155531730179133e-13*V012*V02*V14 + 1.06004577715517818e-12*V032*V14 + 
      9.83467477094655061e-13*V02*V04*V14 + 6.59268229714719714e-13*V01*V05*V14 - 2.50933103808588833e-14*V08*V14 - 
      3.88425015402999579e-14*V013*V15 + 3.49335894805300891e-13*V02*V03*V15 + 2.12560965571965293e-13*V01*V04*V15 - 
      1.46526903520153798e-14*V07*V15 + 2.35521199815787046e-14*V022*V16 + 6.23329667575289801e-14*V01*V03*V16 - 
      6.38931003597687713e-15*V06*V16 + 9.24821465245237093e-15*V01*V02*V17 - 2.61613898184861906e-15*V05*V17 + 
      6.9361609893392782e-16*V012*V18 - 7.01658024718669012e-16*V04*V18 - 1.8848263557987169e-16*V03*V19 - 
      2.34556168721618103e-17*V02*V20 - 3.51834253082427155e-18*V01*V21 + 5.02620361546324507e-21*V24) + 
   eps12*(4.38492191964414187e-7*V012*V025 + 1.56443190297356964e-6*V013*V023*V03 + 
      6.26423152464819131e-7*V014*V02*V032 - 6.15952990446624706e-7*V024*V032 - 
      2.13342389991695547e-6*V01*V022*V033 - 4.02632490461111493e-7*V012*V034 + 
      4.3106488418988419e-7*V014*V022*V04 - 1.43889032777921667e-7*V025*V04 + 
      9.17774355274355274e-8*V015*V03*V04 - 3.11017509368203813e-6*V01*V023*V03*V04 - 
      3.63782652349120603e-6*V012*V02*V032*V04 + 1.63667367473803243e-7*V034*V04 - 
      1.39086131227128251e-6*V012*V022*V042 - 6.47181474004390671e-7*V013*V03*V042 + 
      6.94893262950216634e-7*V02*V032*V042 + 1.51283642180000723e-7*V022*V043 + 
      2.90338231387046747e-7*V01*V03*V043 + 4.81771315104648438e-8*V015*V02*V05 - 
      4.63494115837865838e-7*V01*V024*V05 - 2.22791129909185465e-6*V012*V022*V03*V05 - 
      5.21445756440796123e-7*V013*V032*V05 + 3.96565639823316158e-7*V02*V033*V05 - 
      7.97474910818164786e-7*V013*V02*V04*V05 + 8.3079202034726953e-7*V022*V03*V04*V05 + 
      7.30771143336125926e-7*V01*V032*V04*V05 + 5.27975212689593233e-7*V01*V02*V042*V05 - 
      3.96192383729586111e-8*V014*V052 + 8.21761150132950242e-8*V023*V052 + 
      4.45765187284624921e-7*V01*V02*V03*V052 + 1.3232200882651688e-7*V012*V04*V052 - 
      2.37469976794500349e-8*V042*V052 - 1.36096627499663723e-8*V03*V053 + 
      1.80664243164243164e-9*V016*V06 - 3.92472994469522247e-7*V012*V023*V06 - 
      5.43036567342122898e-7*V013*V02*V03*V06 + 2.9825624725585578e-7*V022*V032*V06 + 
      1.71632696794454206e-7*V01*V033*V06 - 6.66349950204116871e-8*V014*V04*V06 + 
      1.29177689090543121e-7*V023*V04*V06 + 7.4981900942536933e-7*V01*V02*V03*V04*V06 + 
      1.1252040651039834e-7*V012*V042*V06 - 1.29392157703847877e-8*V043*V06 + 
      2.26994879836485229e-7*V01*V022*V05*V06 + 1.8517650554189128e-7*V012*V03*V05*V06 - 
      6.81809509230165907e-8*V03*V04*V05*V06 - 2.05992629199890677e-8*V02*V052*V06 + 
      4.8446145797846895e-8*V012*V02*V062 - 1.22055305562127859e-8*V032*V062 - 
      1.68156090978436291e-8*V02*V04*V062 - 9.37819813764003117e-9*V01*V05*V062 - 
      1.2330334595959596e-7*V013*V022*V07 - 3.92944728882228882e-8*V014*V03*V07 + 
      8.66334246474497019e-8*V023*V03*V07 + 2.31846393732372082e-7*V01*V02*V032*V07 + 
      1.6665107427975075e-7*V01*V022*V04*V07 + 1.36708868964792167e-7*V012*V03*V04*V07 - 
      2.50571343461910233e-8*V03*V042*V07 + 8.40820834182762287e-8*V012*V02*V05*V07 - 
      2.14821947819303148e-8*V032*V05*V07 - 3.02261663079119173e-8*V02*V04*V05*V07 - 
      8.22752243934466367e-9*V01*V052*V07 + 1.09705030084640262e-8*V013*V06*V07 - 
      2.17543301382968463e-8*V02*V03*V06*V07 - 1.38315040954813512e-8*V01*V04*V06*V07 - 
      2.39937340072932961e-9*V022*V072 - 4.31306178988452739e-9*V01*V03*V072 + 
      2.14767307517493529e-10*V06*V072 - 1.5356460668960669e-8*V014*V02*V08 + 
      7.81750055533643043e-9*V024*V08 + 9.19141145218555349e-8*V01*V022*V03*V08 + 
      3.68678479028521823e-8*V012*V032*V08 + 5.52415504398901925e-8*V012*V02*V04*V08 - 
      1.39583195853626023e-8*V032*V04*V08 - 9.5986425764438334e-9*V02*V042*V08 + 
      8.45095936083720086e-9*V013*V05*V08 - 1.6922158316131765e-8*V02*V03*V05*V08 - 
      1.07323878817334722e-8*V01*V04*V05*V08 - 4.15583968693321596e-9*V022*V06*V08 - 
      7.63161126818879759e-9*V01*V03*V06*V08 + 1.88392481149618117e-10*V062*V08 - 
      3.44611396259379405e-9*V01*V02*V07*V08 + 3.34163144371482397e-10*V05*V07*V08 - 
      2.87881903030246724e-10*V012*V082 + 1.07955611905981345e-10*V04*V082 - 
      6.32324851074851075e-10*V015*V09 + 1.08012321958230183e-8*V01*V023*V09 + 
      2.67003744013037314e-8*V012*V02*V03*V09 - 2.32715627508698703e-9*V033*V09 + 
      4.97490875478007831e-9*V013*V04*V09 - 9.88389262871376166e-9*V02*V03*V04*V09 - 
      3.15013205391853196e-9*V01*V042*V09 - 2.97133665297839776e-9*V022*V05*V09 - 
      5.32644539790241181e-9*V01*V03*V05*V09 - 2.74320110204596492e-9*V01*V02*V06*V09 + 2.65885815201741545e-10*V05*V06*V09 - 
      5.17205072695488891e-10*V012*V07*V09 + 1.95841700939319757e-10*V04*V07*V09 + 1.096083942566415e-10*V03*V08*V09 + 
      1.95715989957548972e-11*V02*V092 + 4.40590494971622423e-9*V012*V022*V10 + 
      2.16310006827776436e-9*V013*V03*V10 - 2.25902809958179182e-9*V02*V032*V10 - 
      1.54286144998219302e-9*V022*V04*V10 - 2.84471333483214826e-9*V01*V03*V04*V10 - 
      1.74167770044125429e-9*V01*V02*V05*V10 + 8.46077491142124186e-11*V052*V10 - 
      3.74968030744362659e-10*V012*V06*V10 + 1.40534807154727983e-10*V04*V06*V10 + 
      8.96631141416310435e-11*V03*V07*V10 + 3.53068698438173758e-11*V02*V08*V10 + 1.14933982587741202e-11*V01*V09*V10 + 
      6.56088693517206589e-10*V013*V02*V11 - 6.63592935339787407e-10*V022*V03*V11 - 
      5.86501686136304238e-10*V01*V032*V11 - 8.50965315512898983e-10*V01*V02*V04*V11 - 
      2.17109607466627468e-10*V012*V05*V11 + 8.25656605053924563e-11*V04*V05*V11 + 
      5.93973291009376551e-11*V03*V06*V11 + 2.66550932927223941e-11*V02*V07*V11 + 9.56771272405064299e-12*V01*V08*V11 - 
      4.07749009133190344e-14*V112 + 3.09963162291593664e-11*V014*V12 - 
      5.82036759080676063e-11*V023*V12 - 3.25941413725211455e-10*V01*V02*V03*V12 - 
      9.86366484114377131e-11*V012*V04*V12 + 1.84687031573766897e-11*V042*V12 + 
      3.1993273768693732e-11*V03*V05*V12 + 1.61905904420380971e-11*V02*V06*V12 + 6.62190665544894663e-12*V01*V07*V12 - 
      7.51070723847808455e-14*V10*V12 - 4.17471438054835888e-11*V01*V022*V13 - 
      3.44956371929249896e-11*V012*V03*V13 + 1.34089170629807992e-11*V03*V04*V13 + 
      8.16679779260448407e-12*V02*V05*V13 + 3.76684869312443917e-12*V01*V06*V13 - 5.91460018310722003e-14*V09*V13 - 
      8.42882283424509087e-12*V012*V02*V14 + 2.25096920533364482e-12*V032*V14 + 
      3.16777246847520571e-12*V02*V04*V14 + 1.75706830181942595e-12*V01*V05*V14 - 3.93062525938867e-14*V08*V14 - 
      4.8941551940777947e-13*V013*V15 + 1.01138475439219129e-12*V02*V03*V15 + 6.48114882843862155e-13*V01*V04*V15 - 
      2.21797318383885171e-14*V07*V15 + 1.05207689886298172e-13*V022*V16 + 1.90772171850787508e-13*V01*V03*V16 - 
      1.03716716845807155e-14*V06*V16 + 3.87037783205131723e-14*V01*V02*V17 - 4.05901125373965282e-15*V05*V17 + 
      3.12127244520267519e-15*V012*V18 - 1.25755614458890392e-15*V04*V18 - 3.20420480485781873e-16*V03*V19 - 
      5.52882397700956958e-17*V02*V20 - 8.29323596551435437e-18*V01*V21 + 7.53930542319486761e-21*V24) + 
   delta6*eps9*(7.65183075086203004e-8*V034*V04 + 
      2.36200532725392669e-7*V02*V032*V042 + 2.10474956623416007e-8*V022*V043 + 
      9.48188609885232979e-8*V01*V03*V043 + 1.57752553415679777e-7*V02*V033*V05 + 
      2.30720518966025502e-7*V022*V03*V04*V05 + 2.68114688535634692e-7*V01*V032*V04*V05 + 
      1.41720319635235602e-7*V01*V02*V042*V05 + 1.84747491222164425e-8*V023*V052 + 
      1.39170980163627222e-7*V01*V02*V03*V052 + 3.83673161377993311e-8*V012*V04*V052 - 
      2.2023741600738457e-8*V042*V052 - 1.42734771738816095e-8*V03*V053 + 
      8.35556661619725734e-8*V022*V032*V06 + 6.10311140773325647e-8*V01*V033*V06 + 
      1.45381579205108617e-8*V023*V04*V06 + 2.02131518633813996e-7*V01*V02*V03*V04*V06 + 
      2.94928838394835905e-8*V012*V042*V06 - 9.41028310842586455e-9*V043*V06 + 
      5.01333996971835441e-8*V01*V022*V05*V06 + 5.18720048632708141e-8*V012*V03*V05*V06 - 
      6.38881832797249232e-8*V03*V04*V05*V06 - 1.63995054407892911e-8*V02*V052*V06 + 
      1.04752648131110627e-8*V012*V02*V062 - 1.14954440383213866e-8*V032*V062 - 
      1.0373940513735223e-8*V02*V04*V062 - 7.1995374382365363e-9*V01*V05*V062 + 
      1.75949991640156595e-8*V023*V03*V07 + 6.49355534538774501e-8*V01*V02*V032*V07 + 
      3.29600741380036431e-8*V01*V022*V04*V07 + 3.5490127012847212e-8*V012*V03*V04*V07 - 
      2.19073568194984549e-8*V03*V042*V07 + 1.86392868465697597e-8*V012*V02*V05*V07 - 
      2.1179389152059458e-8*V032*V05*V07 - 2.23122299449632283e-8*V02*V04*V05*V07 - 
      6.59696094049781919e-9*V01*V052*V07 + 2.17904805955303932e-9*V013*V06*V07 - 
      1.62855136239927535e-8*V02*V03*V06*V07 - 9.93213689609712688e-9*V01*V04*V06*V07 - 
      1.39055312077097546e-9*V022*V072 - 3.23282820827403963e-9*V01*V03*V072 + 
      2.70691673066425051e-10*V06*V072 + 6.3274781919956039e-10*V024*V08 + 
      1.84578803786903694e-8*V01*V022*V03*V08 + 9.01661706319217472e-9*V012*V032*V08 + 
      1.08198370142036497e-8*V012*V02*V04*V08 - 1.23996749144077e-8*V032*V04*V08 - 
      5.5206283010412297e-9*V02*V042*V08 + 1.63325049124276223e-9*V013*V05*V08 - 
      1.28086576834036954e-8*V02*V03*V05*V08 - 7.75394468687961361e-9*V01*V04*V05*V08 - 
      2.01580544695901625e-9*V022*V06*V08 - 5.50766241918738492e-9*V01*V03*V06*V08 + 
      2.20755502650434519e-10*V062*V08 - 1.97947906813119159e-9*V01*V02*V07*V08 + 4.2591718923221259e-10*V05*V07*V08 - 
      1.583082256110483e-10*V012*V082 + 1.20675045280608754e-10*V04*V082 + 
      1.46624993033463829e-9*V01*V023*V09 + 4.95485603591345888e-9*V012*V02*V03*V09 - 
      2.10097487807609381e-9*V033*V09 + 8.58787732912382772e-10*V013*V04*V09 - 
      6.70950969054189387e-9*V02*V03*V04*V09 - 2.05870427299032854e-9*V01*V042*V09 - 
      1.68483925214565814e-9*V022*V05*V09 - 3.89132664126299495e-9*V01*V03*V05*V09 - 
      1.52386038876203899e-9*V01*V02*V06*V09 + 3.32066820728828843e-10*V05*V06*V09 - 
      2.85511375988624393e-10*V012*V07*V09 + 2.30855487854577695e-10*V04*V07*V09 + 
      1.32285455360861002e-10*V03*V08*V09 + 1.86224886360941026e-11*V02*V092 + 
      6.04575767974460785e-10*V012*V022*V10 + 3.40073869485634192e-10*V013*V03*V10 - 
      1.57213310981915158e-9*V02*V032*V10 - 6.71181261929988321e-10*V022*V04*V10 - 
      1.87883873030537691e-9*V01*V03*V04*V10 - 9.79242152784242622e-10*V01*V02*V05*V10 + 
      1.07336839085989354e-10*V052*V10 - 2.00661102814361779e-10*V012*V06*V10 + 
      1.54495629503149789e-10*V04*V06*V10 + 1.08715403184487502e-10*V03*V07*V10 + 3.19419553321709642e-11*V02*V08*V10 + 
      1.07962929205513937e-11*V01*V09*V10 + 7.75399910748494626e-11*V013*V02*V11 - 
      3.40440197433494265e-10*V022*V03*V11 - 3.83107217992122246e-10*V01*V032*V11 - 
      4.21791587392818139e-10*V01*V02*V04*V11 - 1.14751107550456822e-10*V012*V05*V11 + 
      9.62065320400714134e-11*V04*V05*V11 + 7.0053450335113439e-11*V03*V06*V11 + 2.5310464537020169e-11*V02*V07*V11 + 
      8.92101281804860605e-12*V01*V08*V11 - 5.43372820460500498e-14*V112 + 2.9520301170627968e-12*V014*V12 - 
      1.849485094293739e-11*V023*V12 - 1.63911361271335963e-10*V01*V02*V03*V12 - 
      4.73197850193238992e-11*V012*V04*V12 + 1.88537309952640217e-11*V042*V12 + 
      3.82877627980636899e-11*V03*V05*V12 + 1.42638050703933002e-11*V02*V06*V12 + 6.20117454352671344e-12*V01*V07*V12 - 
      9.861716111939824e-14*V10*V12 - 1.52801222059334661e-11*V01*V022*V13 - 
      1.59005664305371908e-11*V012*V03*V13 + 1.46902340825414441e-11*V03*V04*V13 + 
      7.63906846126070317e-12*V02*V05*V13 + 3.41839908555666496e-12*V01*V06*V13 - 7.88028307646789415e-14*V09*V13 - 
      3.00382011911653008e-12*V012*V02*V14 + 2.51465121876614934e-12*V032*V14 + 
      2.55827813001998466e-12*V02*V04*V14 + 1.60913386023879783e-12*V01*V05*V14 - 5.13051632836443249e-14*V08*V14 - 
      1.55370006161199832e-13*V013*V15 + 8.81293201614361267e-13*V02*V03*V15 + 5.4133499646664708e-13*V01*V04*V15 - 
      2.95144707744340306e-14*V07*V15 + 6.57733026082412621e-14*V022*V16 + 1.60419531361438826e-13*V01*V03*V16 - 
      1.32723943151368635e-14*V06*V16 + 2.52476260011949726e-14*V01*V02*V17 - 5.35350999490221159e-15*V05*V17 + 
      1.9421250770149979e-15*V012*V18 - 1.50866527721744764e-15*V04*V18 - 4.01091048513966957e-16*V03*V19 - 
      5.36128385649412808e-17*V02*V20 - 8.04192578474119211e-18*V01*V21 + 1.00524072309264901e-20*V24) + 
   delta2*eps11*(-5.19942132872027052e-7*V024*V032 - 
      2.12909656114021193e-6*V01*V022*V033 - 4.30973118225102352e-7*V012*V034 - 
      6.80612866459427306e-8*V025*V04 - 2.60643787429501715e-6*V01*V023*V03*V04 - 
      3.48396023619237905e-6*V012*V02*V032*V04 + 2.92634394072278254e-7*V034*V04 - 
      1.17616437060881505e-6*V012*V022*V042 - 5.9607155961322628e-7*V013*V03*V042 + 
      1.1082481523457393e-6*V02*V032*V042 + 1.95584655809718057e-7*V022*V043 + 
      4.54467079326658575e-7*V01*V03*V043 - 3.11965279723216231e-7*V01*V024*V05 - 
      1.86285023214586707e-6*V012*V022*V03*V05 - 4.72547688569513966e-7*V013*V032*V05 + 
      6.54479977676270082e-7*V02*V033*V05 - 6.53448229093070363e-7*V013*V02*V04*V05 + 
      1.19518228764965654e-6*V022*V03*V04*V05 + 1.16986246668154153e-6*V01*V032*V04*V05 + 
      7.49205341404634316e-7*V01*V02*V042*V05 - 3.07473335747145271e-8*V014*V052 + 
      1.0472435081384564e-7*V023*V052 + 6.53677756463315131e-7*V01*V02*V03*V052 + 
      1.8926780842484624e-7*V012*V04*V052 - 4.49111369355517819e-8*V042*V052 - 
      2.66308862018481758e-8*V03*V053 - 2.7752321899147296e-7*V012*V023*V06 - 
      4.30835469277929595e-7*V013*V02*V03*V06 + 4.35860386828621345e-7*V022*V032*V06 + 
      2.74950060854005765e-7*V01*V033*V06 - 5.11709961114723019e-8*V014*V04*V06 + 
      1.49373083789906074e-7*V023*V04*V06 + 1.07553785650458347e-6*V01*V02*V03*V04*V06 + 
      1.58959003141207273e-7*V012*V042*V06 - 2.34589188319894784e-8*V043*V06 + 
      2.91743367359030291e-7*V01*V022*V05*V06 + 2.64325940625106125e-7*V012*V03*V05*V06 - 
      1.30477649586021645e-7*V03*V04*V05*V06 - 3.63982154243717568e-8*V02*V052*V06 + 
      6.21909667103265376e-8*V012*V02*V062 - 2.35866641208131788e-8*V032*V062 - 
      2.83830922891645865e-8*V02*V04*V062 - 1.64809807039780169e-8*V01*V05*V062 - 
      8.3627470780248558e-8*V013*V022*V07 - 2.86653932487265821e-8*V014*V03*V07 + 
      1.09769440570337318e-7*V023*V03*V07 + 3.35492824806258513e-7*V01*V02*V032*V07 + 
      2.09044847038933562e-7*V01*V022*V04*V07 + 1.92355750008498608e-7*V012*V03*V04*V07 - 
      4.72618338936615608e-8*V03*V042*V07 + 1.07650164092011664e-7*V012*V02*V05*V07 - 
      4.18304532027872241e-8*V032*V05*V07 - 5.2495110872022949e-8*V02*V04*V05*V07 - 
      1.45549356985976133e-8*V01*V052*V07 + 1.36847681855268223e-8*V013*V06*V07 - 
      3.83220680268478737e-8*V02*V03*V06*V07 - 2.39667134245575088e-8*V01*V04*V06*V07 - 
      3.78370234356419949e-9*V022*V072 - 7.57514185448521646e-9*V01*V03*V072 + 
      4.26147160475657499e-10*V06*V072 - 9.63542630209296876e-9*V014*V02*V08 + 
      7.72535223236800164e-9*V024*V08 + 1.17120217666946775e-7*V01*V022*V03*V08 + 
      5.1466665825082803e-8*V012*V032*V08 + 6.95025549042676727e-8*V012*V02*V04*V08 - 
      2.66734083953653464e-8*V032*V04*V08 - 1.59763800882102491e-8*V02*V042*V08 + 
      1.04776967236360716e-8*V013*V05*V08 - 2.9909484601287233e-8*V02*V03*V05*V08 - 
      1.86295937434687129e-8*V01*V04*V05*V08 - 6.38461798617259437e-9*V022*V06*V08 - 
      1.33424917612395601e-8*V01*V03*V06*V08 + 3.69473760663051925e-10*V062*V08 - 
      5.46385122184290841e-9*V01*V02*V07*V08 + 6.65193360464561812e-10*V05*V07*V08 - 
      4.51929472006984006e-10*V012*V082 + 2.09622080250661849e-10*V04*V082 - 
      3.61328486328486328e-10*V015*V09 + 1.16554442820539537e-8*V01*V023*V09 + 
      3.32813562272012319e-8*V012*V02*V03*V09 - 4.49623559158400142e-9*V033*V09 + 
      6.05996959616532446e-9*V013*V04*V09 - 1.71008894358145883e-8*V02*V03*V04*V09 - 
      5.36744415768178965e-9*V01*V042*V09 - 4.68188403056017865e-9*V022*V05*V09 - 
      9.32814612085776875e-9*V01*V03*V05*V09 - 4.32938137442453789e-9*V01*V02*V06*V09 + 5.27480366322598665e-10*V05*V06*V09 - 
      8.11379645939557258e-10*V012*V07*V09 + 3.83426984261945439e-10*V04*V07*V09 + 2.1768055216367305e-10*V03*V08*V09 + 
      3.5427496549520743e-11*V02*V092 + 4.80738104563676459e-9*V012*V022*V10 + 
      2.57712229219582161e-9*V013*V03*V10 - 3.97089667710882205e-9*V02*V032*V10 - 
      2.32086891334837589e-9*V022*V04*V10 - 4.89421578838019756e-9*V01*V03*V04*V10 - 
      2.7556254125600797e-9*V01*V02*V05*V10 + 1.68525837843121799e-10*V052*V10 - 
      5.86367513038126459e-10*V012*V06*V10 + 2.72167713347360047e-10*V04*V06*V10 + 
      1.78212007585668558e-10*V03*V07*V10 + 6.34254219220624266e-11*V02*V08*V10 + 2.07887313037605561e-11*V01*V09*V10 + 
      6.93727077509757248e-10*V013*V02*V11 - 1.04023300630045484e-9*V022*V03*V11 - 
      1.01343227212338563e-9*V01*V032*V11 - 1.31535377883894447e-9*V01*V02*V04*V11 - 
      3.38479662243844452e-10*V012*V05*V11 + 1.61601702895817855e-10*V04*V05*V11 + 
      1.17549811516796611e-10*V03*V06*V11 + 4.82422574380474134e-11*V02*V07*V11 + 1.72881408123471871e-11*V01*V08*V11 - 
      8.15490478960957494e-14*V112 + 3.09963162291593664e-11*V014*V12 - 
      7.7737976854129163e-11*V023*V12 - 5.09456252588209318e-10*V01*V02*V03*V12 - 
      1.51223846568212385e-10*V012*V04*V12 + 3.5268177555702946e-11*V042*V12 + 
      6.35409685554323088e-11*V03*V05*V12 + 2.89625228485092606e-11*V02*V06*V12 + 1.19713052157937093e-11*V01*V07*V12 - 
      1.49876201115561999e-13*V10*V12 - 5.76407185857435255e-11*V01*V022*V13 - 
      5.26657709884619069e-11*V012*V03*V13 + 2.61749907254696341e-11*V03*V04*V13 + 
      1.47714796482632382e-11*V02*V05*V13 + 6.77909855989667958e-12*V01*V06*V13 - 1.18290495801059762e-13*V09*V13 - 
      1.15828339593174474e-11*V012*V02*V14 + 4.4488998996354753e-12*V032*V14 + 
      5.57193834952672406e-12*V02*V04*V14 + 3.16827187206643814e-12*V01*V05*V14 - 7.8365081937796196e-14*V08*V14 - 
      6.52554025877039293e-13*V013*V15 + 1.82291559014488683e-12*V02*V03*V15 + 1.14846179197084033e-12*V01*V04*V15 - 
      4.43579558156923953e-14*V07*V15 + 1.68539463826292008e-13*V022*V16 + 3.40815206372174774e-13*V01*V03*V16 - 
      2.06130641714486236e-14*V06*V16 + 6.27028953436270749e-14*V01*V02*V17 - 8.11651464639466667e-15*V05*V17 + 
      4.9940359123242803e-15*V012*V18 - 2.46806702333707186e-15*V04*V18 - 6.39333099886924773e-16*V03*V19 - 
      1.00524072309264901e-16*V02*V20 - 1.50786108463897352e-17*V01*V21 + 1.50786108463897352e-20*V24) + 
   delta4*eps10*(-1.17745291769762669e-7*V024*V032 - 
      5.79433243123719314e-7*V01*V022*V033 - 1.24555091072948216e-7*V012*V034 - 
      1.48202033122668043e-9*V025*V04 - 5.98870803897258924e-7*V01*V023*V03*V04 - 
      9.19068255377779187e-7*V012*V02*V032*V04 + 2.14311482438524922e-7*V034*V04 - 
      2.78216052025575835e-7*V012*V022*V042 - 1.52528798362131695e-7*V013*V03*V042 + 
      7.28419279216334149e-7*V02*V032*V042 + 9.77137892841674354e-8*V022*V043 + 
      2.94835574485628952e-7*V01*V03*V043 - 7.06471750618576015e-8*V01*V024*V05 - 
      4.70752516883469264e-7*V012*V022*V03*V05 - 1.22944598391026962e-7*V013*V032*V05 + 
      4.53829576895904121e-7*V02*V033*V05 - 1.57814517933565553e-7*V013*V02*V04*V05 + 
      7.3417265658745584e-7*V022*V03*V04*V05 + 7.89349551944867849e-7*V01*V032*V04*V05 + 
      4.54844988100998839e-7*V01*V02*V042*V05 - 7.17495137137994281e-9*V014*V052 + 
      6.06452340719542971e-8*V023*V052 + 4.1961331835354361e-7*V01*V02*V03*V052 + 
      1.18468274871461146e-7*V012*V04*V052 - 4.026399605523601e-8*V042*V052 - 
      2.49344252732416599e-8*V03*V053 - 6.40105840171977738e-8*V012*V023*V06 - 
      1.01929045381426334e-7*V013*V02*V03*V06 + 2.68121481016361191e-7*V022*V032*V06 + 
      1.83131423420507804e-7*V01*V033*V06 - 1.15108932073217788e-8*V014*V04*V06 + 
      6.94660406346006512e-8*V023*V04*V06 + 6.53241508264072845e-7*V01*V02*V03*V04*V06 + 
      9.57025503606288698e-8*V012*V042*V06 - 1.94107261144450045e-8*V043*V06 + 
      1.67111827140421912e-7*V01*V022*V05*V06 + 1.63286817054226796e-7*V012*V03*V05*V06 - 
      1.17292675685637981e-7*V03*V04*V05*V06 - 3.1097029829286499e-8*V02*V052*V06 + 
      3.52784186586804856e-8*V012*V02*V062 - 2.12175240295383638e-8*V032*V062 - 
      2.22496709765014992e-8*V02*V04*V062 - 1.3892605532982901e-8*V01*V05*V062 - 
      1.7584653001319668e-8*V013*V022*V07 - 6.08236285319618653e-9*V014*V03*V07 + 
      6.00239001444391008e-8*V023*V03*V07 + 2.05120027408751926e-7*V01*V02*V032*V07 + 
      1.13262007082035093e-7*V01*V022*V04*V07 + 1.1481891901160303e-7*V012*V03*V04*V07 - 
      4.13685034628376481e-8*V03*V042*V07 + 6.13554156716213205e-8*V012*V02*V05*V07 - 
      3.81989797524358541e-8*V032*V05*V07 - 4.35034561212444647e-8*V02*V04*V05*V07 - 
      1.24465574767207969e-8*V01*V052*V07 + 7.51825841670807435e-9*V013*V06*V07 - 
      3.18774024187369472e-8*V02*V03*V06*V07 - 1.9667871997796414e-8*V01*V04*V06*V07 - 
      2.88384332637313435e-9*V022*V072 - 6.2963852833022967e-9*V01*V03*V072 + 
      4.1939913591699306e-10*V06*V072 - 1.80664243164243164e-9*V014*V02*V08 + 
      3.19339934526286845e-9*V024*V08 + 6.40864146422619812e-8*V01*V022*V03*V08 + 
      3.00955337592388246e-8*V012*V032*V08 + 3.77117630268890773e-8*V012*V02*V04*V08 - 
      2.34923487086251406e-8*V032*V04*V08 - 1.21932300356941412e-8*V02*V042*V08 + 
      5.71217827651651181e-9*V013*V05*V08 - 2.5025281349342178e-8*V02*V03*V05*V08 - 
      1.53470257143579543e-8*V01*V04*V05*V08 - 4.61685998131022047e-9*V022*V06*V08 - 
      1.09728674070220722e-8*V01*V03*V06*V08 + 3.55652899273829005e-10*V062*V08 - 
      4.15881740242510684e-9*V01*V02*V07*V08 + 6.57949166107055085e-10*V05*V07*V08 - 
      3.39306748576642572e-10*V012*V082 + 1.98294607994327916e-10*V04*V082 - 
      6.02214143880810547e-11*V015*V09 + 5.56862526910962952e-9*V01*V023*V09 + 
      1.77171569817169724e-8*V012*V02*V03*V09 - 3.97927241519096207e-9*V033*V09 + 
      3.15622625744591197e-9*V013*V04*V09 - 1.37407137803524885e-8*V02*V03*V04*V09 - 
      4.2604639747773317e-9*V01*V042*V09 - 3.55753189027397834e-9*V022*V05*V09 - 
      7.70861279121372267e-9*V01*V03*V05*V09 - 3.26262256487220193e-9*V01*V02*V06*V09 + 5.18422609402698898e-10*V05*V06*V09 - 
      6.09370338393160972e-10*V012*V07*V09 + 3.68525742913893642e-10*V04*V07*V09 + 
      2.10984752273151009e-10*V03*V08*V09 + 3.17026393750257638e-11*V02*V092 + 
      2.31409640876552641e-9*V012*V022*V10 + 1.29948365753104315e-9*V013*V03*V10 - 
      3.22012106269394711e-9*V02*V032*V10 - 1.61126775629484608e-9*V022*V04*V10 - 
      3.90065748563062876e-9*V01*V03*V04*V10 - 2.08963724511459505e-9*V01*V02*V05*V10 + 
      1.66708646337348923e-10*V052*V10 - 4.36754705462371277e-10*V012*V06*V10 + 
      2.56156280440564972e-10*V04*V06*V10 + 1.72991833207666797e-10*V03*V07*V10 + 5.59156137952565482e-11*V02*V08*V10 + 
      1.85371567607405689e-11*V01*V09*V10 + 3.18819252642782055e-10*V013*V02*V11 - 
      7.60905183923706026e-10*V022*V03*V11 - 8.04406011184446243e-10*V01*V032*V11 - 
      9.51332212403664011e-10*V01*V02*V04*V11 - 2.51421963541570156e-10*V012*V05*V11 + 
      1.55046124435856297e-10*V04*V05*V11 + 1.13147716831517197e-10*V03*V06*V11 + 4.31537972541215944e-11*V02*V07*V11 + 
      1.53827773885756874e-11*V01*V08*V11 - 8.15425138313956472e-14*V112 + 1.32841355267825856e-11*V014*V12 - 
      4.86248930710779778e-11*V023*V12 - 3.70489767763205647e-10*V01*V02*V03*V12 - 
      1.0830510193769752e-10*V012*V04*V12 + 3.23502918471370033e-11*V042*V12 + 
      6.15313315114544086e-11*V03*V05*V12 + 2.53281964472471377e-11*V02*V06*V12 + 1.06661509229663684e-11*V01*V07*V12 - 
      1.4921036621479354e-13*V10*V12 - 3.77044162451691691e-11*V01*V022*V13 - 
      3.72150007257613897e-11*V012*V03*V13 + 2.45643216615985292e-11*V03*V04*V13 + 
      1.31821739602392982e-11*V02*V05*V13 + 5.98357638370737909e-12*V01*V06*V13 - 1.18277427671659557e-13*V09*V13 - 
      7.51602404804804186e-12*V012*V02*V14 + 4.20331355953960259e-12*V032*V14 + 
      4.72524580166540459e-12*V02*V04*V14 + 2.80845158458347374e-12*V01*V05*V14 - 7.78802878450727144e-14*V08*V14 - 
      4.07846266173149558e-13*V013*V15 + 1.58477406284423828e-12*V02*V03*V15 + 9.84657414046603933e-13*V01*V04*V15 - 
      4.43448876862921908e-14*V07*V15 + 1.31287655206213858e-13*V022*V16 + 2.92872461613861683e-13*V01*V03*V16 - 
      2.03625581832539355e-14*V06*V16 + 4.95241894638824463e-14*V01*V02*V17 - 8.10344651699446223e-15*V05*V17 + 
      3.88425015402999579e-15*V012*V18 - 2.3840288988865264e-15*V04*V18 - 6.26264970486720336e-16*V03*V19 - 
      9.04716650783384113e-17*V02*V20 - 1.35707497617507617e-17*V01*V21 + 1.50786108463897352e-20*V24) + 
   6.4469502843844734e-26*delta24*V24 + 3.86817017063068404e-25*delta22*eps*V24 + 
   delta22*eps2*(-1.85682880046129965e-20*V122 - 4.02312906766614924e-20*V11*V13 - 
      2.68208604511076616e-20*V10*V14 - 2.10735332115845913e-20*V09*V15 - 9.91695680545157236e-21*V08*V16 - 
      5.57828820306650945e-21*V07*V17 - 1.76156469570521351e-21*V06*V18 - 6.85052937218694143e-22*V05*V19 - 
      1.30486273755941742e-22*V04*V20 - 3.26215684389854354e-23*V03*V21 - 2.83665812512916829e-24*V02*V22 - 
      3.86817017063068404e-25*V01*V23 + 3.581639046880263e-27*V26) + 
   delta20*eps3*(-2.04251168050742961e-19*V122 - 4.42544197443276416e-19*V11*V13 - 
      2.95029464962184278e-19*V10*V14 - 2.31808865327430504e-19*V09*V15 - 1.09086524859967296e-19*V08*V16 - 
      6.1361170233731604e-20*V07*V17 - 1.93772116527573486e-20*V06*V18 - 7.53558230940563557e-21*V05*V19 - 
      1.43534901131535916e-21*V04*V20 - 3.58837252828839789e-22*V03*V21 - 3.12032393764208512e-23*V02*V22 - 
      4.25498718769375244e-24*V01*V23 + 1.96990147578414465e-26*V26) + 
   delta18*eps4*(3.30176453396809709e-15*V072*V08 + 1.9052198711412549e-15*V06*V082 + 
      4.99426568163241577e-15*V06*V07*V09 + 3.85205862296277994e-15*V05*V08*V09 + 9.77496079135291902e-16*V04*V092 + 
      1.16561970017120193e-15*V062*V10 + 3.11705043416568606e-15*V05*V07*V10 + 1.2063126956394299e-15*V04*V08*V10 + 
      8.65847342823801684e-16*V03*V09*V10 + 6.80933335986972465e-17*V02*V102 + 1.90690144207783147e-15*V05*V06*V11 + 
      1.27963123086801849e-15*V04*V07*V11 + 7.00374295084141807e-16*V03*V08*V11 + 1.78666912011260665e-16*V02*V09*V11 + 
      4.72280368812982737e-17*V01*V10*V11 + 4.95894387253631874e-16*V052*V12 + 4.97254203795415384e-16*V04*V06*V12 + 
      4.72280368812982737e-16*V03*V07*V12 + 9.17573287979509317e-17*V02*V08*V12 + 3.93566974010818947e-17*V01*V09*V12 - 
      1.4057404994796687e-18*V122 + 3.4451610061831267e-16*V04*V05*V13 + 2.4447454385613224e-16*V03*V06*V13 + 
      8.24616516975049223e-17*V02*V07*V13 + 2.6937472887851608e-17*V01*V08*V13 - 2.991109002482224e-18*V11*V13 + 
      3.79960143891801628e-17*V042*V14 + 1.07749891551406432e-16*V03*V05*V14 + 2.70991624009839705e-17*V02*V06*V14 + 
      1.53928416502009188e-17*V01*V07*V14 - 2.03780233210046255e-18*V10*V14 + 3.28110572017440638e-17*V03*V04*V15 + 
      1.64923303395009845e-17*V02*V05*V15 + 6.98498696731806401e-18*V01*V06*V15 - 1.57822438943280254e-18*V09*V15 + 
      4.36561685457379e-18*V032*V16 + 3.08401471364043177e-18*V02*V04*V16 + 2.619370112744274e-18*V01*V05*V16 - 
      7.61557606853427812e-19*V08*V16 + 1.21267134849271945e-18*V02*V03*V17 + 7.2377332062670729e-19*V01*V04*V17 - 
      4.23828636298205446e-19*V07*V17 + 4.72303577834006521e-20*V022*V18 + 1.60838515694823842e-19*V01*V03*V18 - 
      1.3767011045783136e-19*V06*V18 + 2.12749359384687622e-20*V01*V02*V19 - 5.31660649102334368e-20*V05*V19 + 
      1.06374679692343811e-21*V012*V20 - 1.04459935457881622e-20*V04*V20 - 2.60263382980601191e-21*V03*V21 - 
      2.34024295323156384e-22*V02*V22 - 3.19124039077031433e-23*V01*V23 + 9.84950737892072324e-26*V26) + 
   delta16*eps5*(3.91494937599074369e-14*V072*V08 + 2.38059997491145151e-14*V06*V082 + 
      5.90467869651332489e-14*V06*V07*V09 + 4.56744093865586764e-14*V05*V08*V09 + 1.15308333779477952e-14*V04*V092 + 
      1.45811602942764586e-14*V062*V10 + 3.71015586399999022e-14*V05*V07*V10 + 1.51019979579681752e-14*V04*V08*V10 + 
      1.03059885111110839e-14*V03*V09*V10 + 8.54602572137778286e-16*V02*V102 + 2.2545136841232695e-14*V05*V06*V11 + 
      1.50949091493134774e-14*V04*V07*V11 + 8.30443807028339571e-15*V03*V08*V11 + 2.10380288893259433e-15*V02*V09*V11 + 
      5.62144827878786397e-16*V01*V10*V11 + 5.93420283413512809e-15*V052*V12 + 6.24345874560816188e-15*V04*V06*V12 + 
      5.65162174679536008e-15*V03*V07*V12 + 1.15366349562739614e-15*V02*V08*V12 + 4.7096847889961334e-16*V01*V09*V12 - 
      7.4883685401212359e-18*V122 + 4.06401400173824391e-15*V04*V05*V13 + 2.8904021591323968e-15*V03*V06*V13 + 
      9.7098594873812046e-16*V02*V07*V13 + 3.19401464241669066e-16*V01*V08*V13 - 1.54868604273257256e-17*V11*V13 + 
      4.80337674442322357e-16*V042*V14 + 1.29973306683884008e-15*V03*V05*V14 + 3.42781767840608697e-16*V02*V06*V14 + 
      1.85676152405548583e-16*V01*V07*V14 - 1.09149240792333788e-17*V10*V14 + 3.8704895254649942e-16*V03*V04*V15 + 
      1.94197189747624092e-16*V02*V05*V15 + 8.25829188323541943e-17*V01*V06*V15 - 8.26678058267486846e-18*V09*V15 + 
      5.33575393336796556e-17*V032*V16 + 3.95203209992995727e-17*V02*V04*V16 + 3.20145236002077934e-17*V01*V05*V16 - 
      4.14491066914811507e-18*V08*V16 + 1.42792051285017715e-17*V02*V03*V17 + 8.53784454146689896e-18*V01*V04*V17 - 
      2.2701207643783708e-18*V07*V17 + 6.22930124278365357e-19*V022*V18 + 2.01718305100591569e-18*V01*V03*V18 - 
      7.68578335713122504e-19*V06*V18 + 2.50512370675469675e-19*V01*V02*V19 - 2.93865371384084395e-19*V05*V19 + 
      1.43605817584664145e-20*V012*V20 - 6.02825309816512377e-20*V04*V20 - 1.49509612307589226e-20*V03*V21 - 
      1.40414577193893831e-21*V02*V22 - 1.9147442344621886e-22*V01*V23 + 4.43227832051432546e-25*V26) + 
   delta14*eps6*(-1.54203318660389367e-12*V054 - 1.20222768349253792e-11*V04*V052*V06 - 
      2.20810148842809719e-12*V042*V062 - 8.49950385609556685e-12*V03*V05*V062 - 
      5.19154254600674884e-13*V02*V063 - 8.03458254146862924e-12*V042*V05*V07 - 
      8.72037364191043845e-12*V03*V052*V07 - 1.14497874618336945e-11*V03*V04*V06*V07 - 
      5.72782625570846122e-12*V02*V05*V06*V07 - 1.21421483658508098e-12*V01*V062*V07 - 
      2.04958885084975925e-12*V032*V072 - 1.89411468817236972e-12*V02*V04*V072 - 
      1.21671837233061723e-12*V01*V05*V072 - 7.53220636853102185e-13*V043*V08 - 
      8.7898649136415848e-12*V03*V04*V05*V08 - 2.21582514890753923e-12*V02*V052*V08 - 
      3.07934896700958681e-12*V032*V06*V08 - 1.58993354704801313e-12*V02*V04*V06*V08 - 
      1.84760938020575209e-12*V01*V05*V06*V08 - 2.11030966562622784e-12*V02*V03*V07*V08 - 
      1.25569498766308354e-12*V01*V04*V07*V08 + 2.52902464207594821e-13*V072*V08 - 
      7.05860041184046148e-14*V022*V082 - 3.2938676181467125e-13*V01*V03*V082 + 
      1.65322644154544154e-13*V06*V082 - 2.2318284837412859e-12*V03*V042*V09 - 
      2.36584127953175572e-12*V032*V05*V09 - 2.20980046953443135e-12*V02*V04*V05*V09 - 
      7.00410678164405918e-13*V01*V052*V09 - 1.5910628488079059e-12*V02*V03*V06*V09 - 
      9.54148955152807872e-13*V01*V04*V06*V09 - 2.55178500255161524e-13*V022*V07*V09 - 
      6.50858439786300493e-13*V01*V03*V07*V09 + 3.8183588904119501e-13*V06*V07*V09 - 1.75859138802185653e-13*V01*V02*V08*V09 + 
      2.96791441398816354e-13*V05*V08*V09 - 1.20920740210491967e-14*V012*V092 + 
      7.51242092489750279e-14*V04*V092 - 9.72977199189485451e-13*V032*V04*V10 - 
      2.45301962166125281e-13*V02*V042*V10 - 9.89880319917499004e-13*V02*V03*V05*V10 - 
      5.8378631951369127e-13*V01*V04*V05*V10 - 8.53406564866380643e-14*V022*V06*V10 - 
      4.02592159254841163e-13*V01*V03*V06*V10 + 1.01860733210772983e-13*V062*V10 - 
      1.41411474273928429e-13*V01*V02*V07*V10 + 2.42414016797913357e-13*V05*V07*V10 - 
      2.05587945175887093e-14*V012*V08*V10 + 1.06087349072260034e-13*V04*V08*V10 + 
      6.81155107853280148e-14*V03*V09*V10 + 6.10328012679467652e-15*V02*V102 - 
      1.38073789602302242e-13*V033*V11 - 4.0178190355171479e-13*V02*V03*V04*V11 - 
      1.21736099113161049e-13*V01*V042*V11 - 9.74317910065162182e-14*V022*V05*V11 - 
      2.4234761532458389e-13*V01*V03*V05*V11 - 8.67852462986130488e-14*V01*V02*V06*V11 + 1.47517807276666873e-13*V05*V06*V11 - 
      1.56321251096880647e-14*V012*V07*V11 + 9.89245613535953171e-14*V04*V07*V11 + 
      5.49103892488515527e-14*V03*V08*V11 + 1.39755139279545053e-14*V02*V09*V11 + 3.80029519523811889e-15*V01*V10*V11 - 
      7.36486711745073699e-14*V02*V032*V12 - 1.74606292638300763e-14*V022*V04*V12 - 
      8.55307773599781761e-14*V01*V03*V04*V12 - 4.4189202704704422e-14*V01*V02*V05*V12 + 
      3.94736305220268869e-14*V052*V12 - 8.45492335115312311e-15*V012*V06*V12 + 
      4.4391093491512922e-14*V04*V06*V12 + 3.7804669162617643e-14*V03*V07*V12 + 8.28983170499228742e-15*V02*V08*V12 + 
      3.20307292991376506e-15*V01*V09*V12 - 3.2885668253304498e-17*V122 - 1.2491255257245669e-14*V022*V03*V13 - 
      1.45258624807851906e-14*V01*V032*V13 - 1.5453150136604415e-14*V01*V02*V04*V13 - 
      4.02482301674727183e-15*V012*V05*V13 + 2.71021119581024799e-14*V04*V05*V13 + 
      1.93550835918877473e-14*V03*V06*V13 + 6.52510369708493555e-15*V02*V07*V13 + 2.17272708614309219e-15*V01*V08*V13 - 
      6.59474565261144479e-17*V11*V13 - 2.87957108924612235e-16*V023*V14 - 4.61600412862594148e-15*V01*V02*V03*V14 - 
      1.28347603729081856e-15*V012*V04*V14 + 3.49836247258676175e-15*V042*V14 + 
      8.9090194133122693e-15*V03*V05*V14 + 2.5090229770134993e-15*V02*V06*V14 + 1.28626433039491428e-15*V01*V07*V14 - 
      4.82088307689125368e-17*V10*V14 - 3.56893007349876257e-16*V01*V022*V15 - 
      3.43152802723375592e-16*V012*V03*V15 + 2.65553069586017059e-15*V03*V04*V15 + 
      1.33496733924397574e-15*V02*V05*V15 + 5.71968568230076054e-16*V01*V06*V15 - 3.56303053376302519e-17*V09*V15 - 
      5.10853761754511918e-17*V012*V02*V16 + 3.79444864943371915e-16*V032*V16 + 
      2.98429483390964099e-16*V02*V04*V16 + 2.28782576606636451e-16*V01*V05*V16 - 1.86185474371915526e-17*V08*V16 - 
      1.76156469570521351e-18*V013*V17 + 1.01462296984151374e-16*V02*V03*V17 + 6.08748251981782081e-17*V01*V04*V17 - 
      1.00166653385498626e-17*V07*V17 + 4.92472217103674908e-18*V022*V18 + 1.50805255906241974e-17*V01*V03*V18 - 
      3.54738281838028141e-18*V06*V18 + 1.85730190742832294e-18*V01*V02*V19 - 1.34095921220168608e-18*V05*V19 + 
      1.14884654067731316e-19*V012*V20 - 2.88488131325636416e-19*V04*V20 - 7.11646607141780096e-20*V03*V21 - 
      7.02072885969469153e-21*V02*V22 - 9.57372117231094299e-22*V01*V23 + 1.77291132820573018e-24*V26) + 
   delta12*eps7*(-1.66065112403496242e-11*V054 - 1.32286910338566607e-10*V04*V052*V06 - 
      2.9624444362982876e-11*V042*V062 - 9.40202849236138478e-11*V03*V05*V062 - 
      6.99935888436239844e-12*V02*V063 - 8.81082588939342752e-11*V042*V05*V07 - 
      9.41948082625692053e-11*V03*V052*V07 - 1.25987533655777721e-10*V03*V04*V06*V07 - 
      6.28954061798325235e-11*V02*V05*V06*V07 - 1.34314692748019783e-11*V01*V062*V07 - 
      2.22227074615757362e-11*V032*V072 - 2.07868960496107846e-11*V02*V04*V072 - 
      1.32336899509046145e-11*V01*V05*V072 - 1.0160231656237466e-11*V043*V08 - 
      9.74169938630722944e-11*V03*V04*V05*V08 - 2.44607475427185688e-11*V02*V052*V08 - 
      3.43735457862127048e-11*V032*V06*V08 - 2.15689127816977362e-11*V02*V04*V06*V08 - 
      2.06241274717276229e-11*V01*V05*V06*V08 - 2.32959500406843512e-11*V02*V03*V07*V08 - 
      1.39167134090103278e-11*V01*V04*V07*V08 + 1.14358065959054919e-12*V072*V08 - 
      9.72492181709934615e-13*V022*V082 - 3.72143225233535432e-12*V01*V03*V082 + 
      8.06832513790939047e-13*V06*V082 - 2.44745163594261876e-11*V03*V042*V09 - 
      2.57321749045367505e-11*V032*V05*V09 - 2.42513787245459154e-11*V02*V04*V05*V09 - 
      7.64803272769843236e-12*V01*V052*V09 - 1.74709461610645899e-11*V02*V03*V06*V09 - 
      1.04989611379814768e-11*V01*V04*V06*V09 - 2.81955869038106904e-12*V022*V07*V09 - 
      7.15964568449305329e-12*V01*V03*V07*V09 + 1.73526454756329624e-12*V06*V07*V09 - 1.94132917005702927e-12*V01*V02*V08*V09 + 
      1.35608337396241624e-12*V05*V08*V09 - 1.37908629566892789e-13*V012*V092 + 
      3.46474443578993563e-13*V04*V092 - 1.09131825067883835e-11*V032*V04*V10 - 
      3.37043773226947542e-12*V02*V042*V10 - 1.10387250589529224e-11*V02*V03*V05*V10 - 
      6.54790950407303009e-12*V01*V04*V05*V10 - 1.18352037247364295e-12*V022*V06*V10 - 
      4.56141900382685922e-12*V01*V03*V06*V10 + 5.0179374673263931e-13*V062*V10 - 
      1.57696072270756034e-12*V01*V02*V07*V10 + 1.11318188386107411e-12*V05*V07*V10 - 
      2.37735166353798372e-13*V012*V08*V10 + 5.27507721727871024e-13*V04*V08*V10 + 
      3.19132526809428339e-13*V03*V09*V10 + 3.11787899621623516e-14*V02*V102 - 
      1.51881168562532466e-12*V033*V11 - 4.40934158628107553e-12*V02*V03*V04*V11 - 
      1.33497361960506478e-12*V01*V042*V11 - 1.07655877269095363e-12*V022*V05*V11 - 
      2.68644112176895661e-12*V01*V03*V05*V11 - 9.52960699694432174e-13*V01*V02*V06*V11 + 6.84129584149527379e-13*V05*V06*V11 - 
      1.79020773765738028e-13*V012*V07*V11 + 4.60774808337594117e-13*V04*V07*V11 + 
      2.58509306778680506e-13*V03*V08*V11 + 6.66112563825561374e-14*V02*V09*V11 + 1.84889018457526946e-14*V01*V10*V11 - 
      8.35290526774251518e-13*V02*V032*V12 - 2.47605533628324811e-13*V022*V04*V12 - 
      9.78324647684366881e-13*V01*V03*V04*V12 - 5.01174316064550911e-13*V01*V02*V05*V12 + 
      1.85755303096988537e-13*V052*V12 - 9.84544380311962849e-14*V012*V06*V12 + 
      2.24702992214237174e-13*V04*V06*V12 + 1.79638835024222621e-13*V03*V07*V12 + 4.27110664190148531e-14*V02*V08*V12 + 
      1.56521585564102695e-14*V01*V09*V12 - 1.21283886108971637e-16*V122 - 
      1.38020355473199184e-13*V022*V03*V13 - 1.64470249379212965e-13*V01*V032*V13 - 
      1.69590061010810597e-13*V01*V02*V04*V13 - 4.6788567569687035e-14*V012*V05*V13 + 
      1.2987681548843124e-13*V04*V05*V13 + 9.32407235128521577e-14*V03*V06*V13 + 3.16695058366000516e-14*V02*V07*V13 + 
      1.07086075255241517e-14*V01*V08*V13 - 2.36726161901129699e-16*V11*V13 - 4.28788334463925038e-15*V023*V14 - 
      5.38763992793265321e-14*V01*V02*V03*V14 - 1.52040648886316978e-14*V012*V04*V14 + 
      1.83220005303319117e-14*V042*V14 + 4.36973912871109959e-14*V03*V05*V14 + 1.32520690923386879e-14*V02*V06*V14 + 
      6.42266317854633338e-15*V01*V07*V14 - 1.7866191433540021e-16*V10*V14 - 3.94343872780569097e-15*V01*V022*V15 - 
      4.14813254544663678e-15*V012*V03*V15 + 1.32933569350157555e-14*V03*V04*V15 + 
      6.70424078518043637e-15*V02*V05*V15 + 2.90109792042610258e-15*V01*V06*V15 - 1.29107459341060207e-16*V09*V15 - 
      6.28878596366761223e-16*V012*V02*V16 + 1.9498542612414436e-15*V032*V16 + 
      1.63958782899303425e-15*V02*V04*V16 + 1.18553176371345238e-15*V01*V05*V16 - 7.00374295084141807e-17*V08*V16 - 
      2.46619057398729892e-17*V013*V17 + 5.33805162644932019e-16*V02*V03*V17 + 3.2177532159368341e-16*V01*V04*V17 - 
      3.70192182554372465e-17*V07*V17 + 2.85220301165487614e-17*V022*V18 + 8.2215287939337454e-17*V01*V03*V18 - 
      1.36918254221765874e-17*V06*V18 + 1.03204714237511965e-17*V01*V02*V19 - 5.11287770447656681e-18*V05*V19 + 
      6.7016048206176601e-19*V012*V20 - 1.1553566710744846e-18*V04*V20 - 2.832544970847731e-19*V03*V21 - 
      2.94870612107177044e-20*V02*V22 - 4.02096289237059606e-21*V01*V23 + 6.20518964872005564e-24*V26) + 
   delta10*eps8*(1.03644223710013184e-9*V032*V043 + 7.69281785172546935e-11*V02*V044 + 
      2.23576403065925483e-9*V033*V04*V05 + 3.0758151273048265e-9*V02*V03*V042*V05 + 
      6.21865342260079102e-10*V01*V043*V05 + 1.72425317004195095e-9*V02*V032*V052 + 
      7.44933924140365489e-10*V022*V04*V052 + 1.95196621320524829e-9*V01*V03*V04*V052 + 
      3.37044154365490795e-10*V01*V02*V053 - 8.86044777363391133e-11*V054 + 
      3.8244802639047179e-10*V034*V06 + 2.19627954448125206e-9*V02*V032*V04*V06 + 
      1.57554740974366134e-10*V022*V042*V06 + 1.3106433671735816e-9*V01*V03*V042*V06 + 
      1.07889346598353593e-9*V022*V03*V05*V06 + 1.32380166356476179e-9*V01*V032*V05*V06 + 
      1.31776772668875124e-9*V01*V02*V04*V05*V06 + 1.85737232406228952e-10*V012*V052*V06 - 
      7.31437823120934984e-10*V04*V052*V06 + 1.78028801454292508e-11*V023*V062 + 
      4.63481031146693903e-10*V01*V02*V03*V062 + 1.3454676832729077e-10*V012*V04*V062 - 
      1.95663925615815219e-10*V042*V062 - 5.235117843415e-10*V03*V05*V062 - 
      4.66936333251060897e-11*V02*V063 + 5.34990721215064754e-10*V02*V033*V07 + 
      7.09460880133681418e-10*V022*V03*V04*V07 + 9.00830856579603447e-10*V01*V032*V04*V07 + 
      4.39402161043546643e-10*V01*V02*V042*V07 + 1.12101974959691146e-10*V023*V05*V07 + 
      9.34561339650519572e-10*V01*V02*V03*V05*V07 + 2.53549200883068641e-10*V012*V04*V05*V07 - 
      4.89345958036449584e-10*V042*V05*V07 - 5.0936164839679545e-10*V03*V052*V07 + 
      1.5412763799764799e-10*V01*V022*V06*V07 + 1.6931956922865567e-10*V012*V03*V06*V07 - 
      7.04068186757063522e-10*V03*V04*V06*V07 - 3.53228899935868542e-10*V02*V05*V06*V07 - 
      7.6362931160826196e-11*V01*V062*V07 + 3.02631670953244222e-11*V012*V02*V072 - 
      1.21809194119213621e-10*V032*V072 - 1.17419159346054373e-10*V02*V04*V072 - 
      7.34560746088200637e-11*V01*V05*V072 + 1.9730626157021439e-10*V022*V032*V08 + 
      1.52448556807254477e-10*V01*V033*V08 + 1.77815628638582902e-11*V023*V04*V08 + 
      4.7487650391059968e-10*V01*V02*V03*V04*V08 + 6.90528428335295722e-11*V012*V042*V08 - 
      6.78083241517972135e-11*V043*V08 + 1.18383756942128634e-10*V01*V022*V05*V08 + 
      1.26591387143792804e-10*V012*V03*V05*V08 - 5.48630925336919625e-10*V03*V04*V05*V08 - 
      1.38327168512975287e-10*V02*V052*V08 + 4.8745308936170531e-11*V012*V02*V06*V08 - 
      1.95031783256437153e-10*V032*V06*V08 - 1.4543219266699888e-10*V02*V04*V06*V08 - 
      1.18210669118258031e-10*V01*V05*V06*V08 + 5.01746472277715964e-12*V013*V07*V08 - 
      1.33112230181405307e-10*V02*V03*V07*V08 - 8.00030249249020578e-11*V01*V04*V07*V08 + 
      3.92990368802391292e-12*V072*V08 - 6.70541348750019e-12*V022*V082 - 
      2.17404810478333747e-11*V01*V03*V082 + 2.97203456063187927e-12*V06*V082 + 
      3.1139437488803096e-11*V023*V03*V09 + 1.22754882439275202e-10*V01*V02*V032*V09 + 
      5.91217400111401182e-11*V01*V022*V04*V09 + 6.56508562462427927e-11*V012*V03*V04*V09 - 
      1.38854417015004065e-10*V03*V042*V09 + 3.43776854632476121e-11*V012*V02*V05*V09 - 
      1.42941449688980166e-10*V032*V05*V09 - 1.38448103897304411e-10*V02*V04*V05*V09 - 
      4.30276258233606887e-11*V01*V052*V09 + 3.81396372267135777e-12*V013*V06*V09 - 
      1.00202658874331531e-10*V02*V03*V06*V09 - 6.05375329378461776e-11*V01*V04*V06*V09 - 
      1.64118652809714842e-11*V022*V07*V09 - 4.08646481491317894e-11*V01*V03*V07*V09 + 
      6.01397796505936062e-12*V06*V07*V09 - 1.14357032716647961e-11*V01*V02*V08*V09 + 4.72038477027008684e-12*V05*V08*V09 - 
      8.2482864742720661e-13*V012*V092 + 1.22588102727520073e-12*V04*V092 + 
      4.41628966719152241e-13*V024*V10 + 2.58472555773542445e-11*V01*V022*V03*V10 + 
      1.29549237470610211e-11*V012*V032*V10 + 1.51456161720281988e-11*V012*V02*V04*V10 - 
      6.3325802769482879e-11*V032*V04*V10 - 2.32112737609917358e-11*V02*V042*V10 + 
      2.24854925583291979e-12*V013*V05*V10 - 6.42691019807710967e-11*V02*V03*V05*V10 - 
      3.83706426821222986e-11*V01*V04*V05*V10 - 8.24636658227674083e-12*V022*V06*V10 - 
      2.69448662011830399e-11*V01*V03*V06*V10 + 1.86934827302314237e-12*V062*V10 - 
      9.3636809477959793e-12*V01*V02*V07*V10 + 3.88547034161994706e-12*V05*V07*V10 - 
      1.44871320788164355e-12*V012*V08*V10 + 1.99004986634628615e-12*V04*V08*V10 + 
      1.14387030318298649e-12*V03*V09*V10 + 1.21953854967834181e-13*V02*V102 + 
      1.69851477211653251e-12*V01*V023*V11 + 5.6508811098000575e-12*V012*V02*V03*V11 - 
      8.77872595288240884e-12*V033*V11 + 9.38064908627548888e-13*V013*V04*V11 - 
      2.59682468869140614e-11*V02*V03*V04*V11 - 7.89296648013855657e-12*V01*V042*V11 - 
      6.39681333144350255e-12*V022*V05*V11 - 1.57396968193959993e-11*V01*V03*V05*V11 - 
      5.69289266622793113e-12*V01*V02*V06*V11 + 2.42670699692985867e-12*V05*V06*V11 - 
      1.08447647752873986e-12*V012*V07*V11 + 1.64742693740948427e-12*V04*V07*V11 + 
      9.33604454491042186e-13*V03*V08*V11 + 2.46029316174515537e-13*V02*V09*V11 + 6.96299380888316339e-14*V01*V10*V11 + 
      5.48801388429393628e-13*V012*V022*V12 + 2.96756711767891678e-13*V013*V03*V12 - 
      5.06091900069081585e-12*V02*V032*V12 - 1.78082799284098192e-12*V022*V04*V12 - 
      5.96983353673383486e-12*V01*V03*V04*V12 - 3.06467337152966668e-12*V01*V02*V05*V12 + 
      6.64541833429161692e-13*V052*V12 - 6.12971667164543145e-13*V012*V06*V12 + 
      8.64904687778891982e-13*V04*V06*V12 + 6.515886536102613e-13*V03*V07*V12 + 1.6855302949908041e-13*V02*V08*V12 + 
      5.90505816400706376e-14*V01*V09*V12 - 3.74596196056266142e-16*V122 + 
      5.33437021153452755e-14*V013*V02*V13 - 8.53556778292250779e-13*V022*V03*V13 - 
      1.01555261646222982e-12*V01*V032*V13 - 1.04979567258204347e-12*V01*V02*V04*V13 - 
      2.945001473926933e-13*V012*V05*V13 + 4.78694801337721704e-13*V04*V05*V13 + 3.45583666266237063e-13*V03*V06*V13 + 
      1.1908242444271215e-13*V02*V07*V13 + 4.09234391918326829e-14*V01*V08*V13 - 7.16541842251606127e-16*V11*V13 + 
      1.55370006161199832e-15*V014*V14 - 3.25948187528654673e-14*V023*V14 - 
      3.46142178011987339e-13*V01*V02*V03*V14 - 9.8667352484083855e-14*V012*V04*V14 + 
      7.33058474524930906e-14*V042*V14 + 1.6352256203831978e-13*V03*V05*V14 + 5.36870923463537244e-14*V02*V06*V14 + 
      2.46884977078012e-14*V01*V07*V14 - 5.53761160863980495e-16*V10*V14 - 2.58210153096470196e-14*V01*V022*V15 - 
      2.7874118962491446e-14*V012*V03*V15 + 5.13986819450477708e-14*V03*V04*V15 + 2.60977111694806816e-14*V02*V05*V15 + 
      1.14235555772248634e-14*V01*V06*V15 - 3.92931397871210248e-16*V09*V15 - 4.3281644573477096e-15*V012*V02*V16 + 
      7.66455841729221167e-15*V032*V16 + 6.93053164128995936e-15*V02*V04*V16 + 4.72235285289644036e-15*V01*V05*V16 - 
      2.19634375428030821e-16*V08*V16 - 1.84964293049047419e-16*V013*V17 + 2.18324881846082131e-15*V02*V03*V17 + 
      1.32375459700696516e-15*V01*V04*V17 - 1.14226173525499769e-16*V07*V17 + 1.27732587880972601e-16*V022*V18 + 
      3.44998616165397142e-16*V01*V03*V18 - 4.39182970314357737e-17*V06*V18 + 4.49007522981383226e-17*V01*V02*V19 - 
      1.61950982095046374e-17*V05*V19 + 3.01572216927794704e-18*V012*V20 - 3.8427002041421663e-18*V04*V20 - 
      9.35544032958225349e-19*V03*V21 - 1.03204714237511965e-19*V02*V22 - 1.40733701232970862e-20*V01*V23 + 
      1.86155689461601669e-23*V26) + delta8*eps9*
    (9.45532553415107021e-9*V032*V043 + 1.26121885620031857e-9*V02*V044 + 
      1.9236691918831295e-8*V033*V04*V05 + 2.80143356086422153e-8*V02*V03*V042*V05 + 
      5.67319532049064213e-9*V01*V043*V05 + 1.48129746610753902e-8*V02*V032*V052 + 
      6.81024771582047124e-9*V022*V04*V052 + 1.69721695215116268e-8*V01*V03*V04*V052 + 
      2.92333949172506964e-9*V01*V02*V053 - 3.01794207563108192e-10*V054 + 
      3.32166487416964801e-9*V034*V06 + 2.01536861179702234e-8*V02*V032*V04*V06 + 
      2.63380560248332698e-9*V022*V042*V06 + 1.20713226448484733e-8*V01*V03*V042*V06 + 
      9.90150503351099135e-9*V022*V03*V05*V06 + 1.16365122459848362e-8*V01*V032*V05*V06 + 
      1.20922116707821341e-8*V01*V02*V04*V05*V06 + 1.66451337448793449e-9*V012*V052*V06 - 
      2.60533004952591578e-9*V04*V052*V06 + 3.04152605911516103e-10*V023*V062 + 
      4.29268672053267617e-9*V01*V02*V03*V062 + 1.24788195969702198e-9*V012*V04*V062 - 
      8.06569167406602239e-10*V042*V062 - 1.87772943073893864e-9*V03*V05*V062 - 
      1.96002792948003781e-10*V02*V063 + 4.64022141543661848e-9*V02*V033*V07 + 
      6.48595020554330594e-9*V022*V03*V04*V07 + 7.91967443622623238e-9*V01*V032*V04*V07 + 
      4.00204794409174504e-9*V01*V02*V042*V07 + 1.03563623669674131e-9*V023*V05*V07 + 
      8.20429847684633615e-9*V01*V02*V03*V05*V07 + 2.27371485633562394e-9*V012*V04*V05*V07 - 
      1.76603097599484093e-9*V042*V05*V07 - 1.7725841772712883e-9*V03*V052*V07 + 
      1.41450071907299876e-9*V01*V022*V06*V07 + 1.53932493269909523e-9*V012*V03*V06*V07 - 
      2.55804468490423388e-9*V03*V04*V06*V07 - 1.29848555321289188e-9*V02*V05*V06*V07 - 
      2.84730444412418445e-10*V01*V062*V07 + 2.75556597736724661e-10*V012*V02*V072 - 
      4.32782883923761649e-10*V032*V072 - 4.37045606733090645e-10*V02*V04*V072 - 
      2.66544802682082887e-10*V01*V05*V072 + 1.83748806362752038e-9*V022*V032*V08 + 
      1.36783610224156033e-9*V01*V033*V08 + 3.09244777418661657e-10*V023*V04*V08 + 
      4.4295562598826887e-9*V01*V02*V03*V04*V08 + 6.4469062655569227e-10*V012*V042*V08 - 
      2.84375948424868838e-10*V043*V08 + 1.10249283817651223e-9*V01*V022*V05*V08 + 
      1.16187002620730595e-9*V012*V03*V05*V08 - 2.00379019114445587e-9*V03*V04*V05*V08 - 
      5.11059549984255632e-10*V02*V052*V08 + 4.57908455110747334e-10*V012*V02*V06*V08 - 
      7.17308210461874218e-10*V032*V06*V08 - 6.20926322796909474e-10*V02*V04*V06*V08 - 
      4.43164997112489852e-10*V01*V05*V06*V08 + 4.87383378374813935e-11*V013*V07*V08 - 
      5.00958232930441006e-10*V02*V03*V07*V08 - 3.03361359199640337e-10*V01*V04*V07*V08 + 
      1.05185172877049743e-11*V072*V08 - 2.96368428745279302e-11*V022*V082 - 
      8.34852942360073705e-11*V01*V03*V082 + 8.42135875274038724e-12*V06*V082 + 
      2.87676732415761474e-10*V023*V03*V09 + 1.10333888951482431e-9*V01*V02*V032*V09 + 
      5.40495850461942162e-10*V01*V022*V04*V09 + 6.04535618391916272e-10*V012*V03*V04*V09 - 
      5.20240032580919634e-10*V03*V042*V09 + 3.16809430634511105e-10*V012*V02*V05*V09 - 
      5.17637658963436757e-10*V032*V05*V09 - 5.24562163091996322e-10*V02*V04*V05*V09 - 
      1.59044648426037593e-10*V01*V052*V09 + 3.71995253799096194e-11*V013*V06*V09 - 
      3.81897553570740288e-10*V02*V03*V06*V09 - 2.3236488317619325e-10*V01*V04*V06*V09 - 
      6.40105065788137506e-11*V022*V07*V09 - 1.53992753440856139e-10*V01*V03*V07*V09 + 
      1.62711915862272012e-11*V06*V07*V09 - 4.53052324091337561e-11*V01*V02*V08*V09 + 1.27970839761365963e-11*V05*V08*V09 - 
      3.29435978864654287e-12*V012*V092 + 3.40283698966436004e-12*V04*V092 + 
      8.1607890220289046e-12*V024*V10 + 2.46944717864024914e-10*V01*V022*V03*V10 + 
      1.23282523912579785e-10*V012*V032*V10 + 1.44532282360001167e-10*V012*V02*V04*V10 - 
      2.40824437360646892e-10*V032*V04*V10 - 1.02282749004364433e-10*V02*V042*V10 + 
      2.23117494323917926e-11*V013*V05*V10 - 2.46940637439620681e-10*V02*V03*V05*V10 - 
      1.48568020885695002e-10*V01*V04*V05*V10 - 3.69865033114333662e-11*V022*V06*V10 - 
      1.05079828554496227e-10*V01*V03*V06*V10 + 5.3573388311976452e-12*V062*V10 - 
      3.7225474562396066e-11*V01*V02*V07*V10 + 1.05331784243999658e-11*V05*V07*V10 - 
      5.88727892826532548e-12*V012*V08*V10 + 5.79164320309262717e-12*V04*V08*V10 + 
      3.19802563074875501e-12*V03*V09*V10 + 3.7107362635932425e-13*V02*V102 + 
      1.56914581317688077e-11*V01*V023*V11 + 5.45080893329476388e-11*V012*V02*V03*V11 - 
      3.35412399372212098e-11*V033*V11 + 9.46750831829132155e-12*V013*V04*V11 - 
      1.03379823418576005e-10*V02*V03*V04*V11 - 3.16140969679431848e-11*V01*V042*V11 - 
      2.57464068793074689e-11*V022*V05*V11 - 6.13166742838945541e-11*V01*V03*V05*V11 - 
      2.314427988088199e-11*V01*V02*V06*V11 + 6.70145101878702692e-12*V05*V06*V11 - 
      4.39712531127282944e-12*V012*V07*V11 + 4.60832450404364041e-12*V04*V07*V11 + 
      2.63025586772588469e-12*V03*V08*V11 + 7.18500274567017961e-13*V02*V09*V11 + 2.0643658012849413e-13*V01*V10*V11 + 
      5.43484281551877011e-12*V012*V022*V12 + 3.12397292388119128e-12*V013*V03*V12 - 
      2.04535364896567126e-11*V02*V032*V12 - 8.33434307335563745e-12*V022*V04*V12 - 
      2.43186859976911768e-11*V01*V03*V04*V12 - 1.25867461562704572e-11*V01*V02*V05*V12 + 
      1.83811761205944291e-12*V052*V12 - 2.55921528243809983e-12*V012*V06*V12 + 
      2.56527370540687419e-12*V04*V06*V12 + 1.83501369778612031e-12*V03*V07*V12 + 5.16770641723490209e-13*V02*V08*V12 + 
      1.7500680491185295e-13*V01*V09*V12 - 9.51467811463379367e-16*V122 + 
      5.92995523515246024e-13*V013*V02*V13 - 3.63570130250712084e-12*V022*V03*V13 - 
      4.20778969543138954e-12*V01*V032*V13 - 4.48928068754629983e-12*V01*V02*V04*V13 - 
      1.24654835657475017e-12*V012*V05*V13 + 1.37299761393899378e-12*V04*V05*V13 + 
      9.96161857994013652e-13*V03*V06*V13 + 3.52057919143315269e-13*V02*V07*V13 + 1.22784748364545112e-13*V01*V08*V13 - 
      1.79621550299223666e-15*V11*V13 + 1.9421250770149979e-14*V014*V14 - 1.63228933456972691e-13*V023*V14 - 
      1.50547987041411165e-12*V01*V02*V03*V14 - 4.33112388603649435e-13*V012*V04*V14 + 
      2.26134324491859549e-13*V042*V14 + 4.72403651941420687e-13*V03*V05*V14 + 1.68587357962076689e-13*V02*V06*V14 + 
      7.409507624095008e-14*V01*V07*V14 - 1.40971547280422602e-15*V10*V14 - 1.1822917611695111e-13*V01*V022*V15 - 
      1.26164144288755244e-13*V012*V03*V15 + 1.54348581062465391e-13*V03*V04*V15 + 
      7.93638556122369489e-14*V02*V05*V15 + 3.51664367400224497e-14*V01*V06*V15 - 9.87189392041246962e-16*V09*V15 - 
      2.0346072235395216e-14*V012*V02*V16 + 2.32222334842838003e-14*V032*V16 + 
      2.27093261593378277e-14*V02*V04*V16 + 1.45999822301012219e-14*V01*V05*V16 - 5.63749049917588494e-16*V08*V16 - 
      9.24821465245237093e-16*V013*V17 + 6.96548051042948046e-15*V02*V03*V17 + 4.25303946730858563e-15*V01*V04*V17 - 
      2.89206080632549967e-16*V07*V17 + 4.45522688474662043e-16*V022*V18 + 1.12194917104370556e-15*V01*V03*V18 - 
      1.14825296996462988e-16*V06*V18 + 1.53299210271628975e-16*V01*V02*V19 - 4.18163386794490446e-17*V05*V19 + 
      1.05550275924728147e-17*V012*V20 - 1.03975398791882996e-17*V04*V20 - 2.51142640652646812e-18*V03*V21 - 
      2.94870612107177044e-19*V02*V22 - 4.02096289237059606e-20*V01*V23 + 4.65389223654004173e-23*V26) + 
   eps13*(7.83069566138349207e-9*V027 + 3.89470526809316492e-7*V01*V025*V03 + 
      1.4560094596883618e-6*V012*V023*V032 + 6.43388385203861394e-7*V013*V02*V033 - 
      2.25963672458806971e-7*V022*V034 - 7.40421868182868416e-8*V01*V035 + 
      5.75913158068416005e-7*V012*V024*V04 + 1.47733453165000784e-6*V013*V022*V03*V04 + 
      2.2660888081274986e-7*V014*V032*V04 - 6.34316323392156272e-7*V023*V032*V04 - 
      1.09169531821405071e-6*V01*V02*V033*V04 + 1.68546834283441426e-7*V014*V02*V042 - 
      9.93094869534334209e-8*V024*V042 - 1.19255469126537345e-6*V01*V022*V03*V042 - 
      4.7194417974956753e-7*V012*V032*V042 - 2.36977895033304697e-7*V012*V02*V043 + 
      6.15396422160911125e-8*V032*V043 + 2.08755249185163841e-8*V02*V044 + 
      3.0365453335856775e-7*V013*V023*V05 + 2.72437377162079543e-7*V014*V02*V03*V05 - 
      1.87735168274331277e-7*V024*V03*V05 - 9.9695598435458963e-7*V01*V022*V032*V05 - 
      2.57829614588594222e-7*V012*V033*V05 + 2.32669736017950304e-8*V015*V04*V05 - 
      4.78481933545874632e-7*V01*V023*V04*V05 - 1.15909676568249893e-6*V012*V02*V03*V04*V05 + 
      1.04774569359265628e-7*V033*V04*V05 - 1.06365326721047134e-7*V013*V042*V05 + 
      2.22867743488102149e-7*V02*V03*V042*V05 + 4.68070079918040045e-8*V01*V043*V05 - 
      1.77712107617533329e-7*V012*V022*V052 - 8.62823368941701691e-8*V013*V03*V052 + 
      9.55102875060511121e-8*V02*V032*V052 + 6.68835757659441601e-8*V022*V04*V052 + 
      1.18262788679119731e-7*V01*V03*V04*V052 + 2.4114996135405519e-8*V01*V02*V053 - 
      5.87971432306545918e-10*V054 + 6.7598537650620984e-8*V014*V022*V06 - 
      1.67841748918624113e-8*V025*V06 + 1.55672356193189527e-8*V015*V03*V06 - 
      3.39250098452824682e-7*V01*V023*V03*V06 - 4.02710445142131358e-7*V012*V02*V032*V06 + 
      1.85997849341130047e-8*V034*V06 - 3.03600293319488289e-7*V012*V022*V04*V06 - 
      1.4652365639961199e-7*V013*V03*V04*V06 + 1.59493451267026331e-7*V02*V032*V04*V06 + 
      5.38775891387696344e-8*V022*V042*V06 + 9.95998783780060399e-8*V01*V03*V042*V06 - 
      9.0371657699760816e-8*V013*V02*V05*V06 + 9.61234477073195602e-8*V022*V03*V05*V06 + 
      8.35480469489877804e-8*V01*V032*V05*V06 + 1.21508776031097569e-7*V01*V02*V04*V05*V06 + 
      1.52399636306011813e-8*V012*V052*V06 - 5.89896157218003488e-9*V04*V052*V06 - 
      3.96868820344981643e-9*V014*V062 + 7.7188754804050435e-9*V023*V062 + 
      4.31138384904303964e-8*V01*V02*V03*V062 + 1.29330943052344899e-8*V012*V04*V062 - 
      2.43809977936439083e-9*V042*V062 - 4.2243022736965277e-9*V03*V05*V062 - 
      7.07716085533879318e-10*V02*V063 + 6.41358063233063233e-9*V015*V02*V07 - 
      3.72903536990352272e-8*V01*V024*V07 - 1.82159404246676656e-7*V012*V022*V03*V07 - 
      4.37857125942516349e-8*V013*V032*V07 + 3.33510664947870221e-8*V02*V033*V07 - 
      6.66512522719849401e-8*V013*V02*V04*V07 + 7.0436522298911306e-8*V022*V03*V04*V07 + 
      6.1629967050080088e-8*V01*V032*V04*V07 + 4.47039502924786497e-8*V01*V02*V042*V07 - 
      6.89687013435262735e-9*V014*V05*V07 + 1.40319220319051179e-8*V023*V05*V07 + 
      7.55002763583002605e-8*V01*V02*V03*V05*V07 + 2.25165618306410122e-8*V012*V04*V05*V07 - 
      4.3390872573251391e-9*V042*V05*V07 - 3.71581570466195363e-9*V03*V052*V07 + 
      1.93279029537411271e-8*V01*V022*V06*V07 + 1.57967461763094828e-8*V012*V03*V06*V07 - 
      6.22175490190489495e-9*V03*V04*V06*V07 - 3.78129113979179746e-9*V02*V05*V06*V07 - 
      8.58084901628134437e-10*V01*V062*V07 + 3.60138821890595882e-9*V012*V02*V072 - 
      9.78266741482981504e-10*V032*V072 - 1.38948128968561484e-9*V02*V04*V072 - 
      7.52394819580870262e-10*V01*V05*V072 + 2.10774950358283692e-10*V016*V08 - 
      2.45112683534232709e-8*V012*V023*V08 - 3.51761800156262108e-8*V013*V02*V03*V08 + 
      1.96330626303350956e-8*V022*V032*V08 + 1.1216843817911246e-8*V01*V033*V08 - 
      4.47633195393757952e-9*V014*V04*V08 + 8.78358434831316382e-9*V023*V04*V08 + 
      4.92151309619481556e-8*V01*V02*V03*V04*V08 + 7.3841526455329652e-9*V012*V042*V08 - 
      9.28787617588229207e-10*V043*V08 + 1.49915135042101125e-8*V01*V022*V05*V08 + 
      1.22042032643364276e-8*V012*V03*V05*V08 - 4.83269600788884407e-9*V03*V04*V05*V08 - 
      1.47011713658956168e-9*V02*V052*V08 + 6.3955703261807191e-9*V012*V02*V06*V08 - 
      1.72787802715219131e-9*V032*V06*V08 - 2.42668113764751516e-9*V02*V04*V06*V08 - 
      1.33087411285108721e-9*V01*V05*V06*V08 + 7.34425621745087177e-10*V013*V07*V08 - 
      1.55259713298449543e-9*V02*V03*V07*V08 - 9.82807179230375702e-10*V01*V04*V07*V08 + 
      1.66409833207679984e-11*V072*V08 - 1.50941041769118968e-10*V022*V082 - 
      2.70912027194210816e-10*V01*V03*V082 + 1.46477147933849181e-11*V06*V082 - 
      6.3675289625044527e-9*V013*V022*V09 - 2.10996352617063401e-9*V014*V03*V09 + 
      4.57593414678611544e-9*V023*V03*V09 + 1.21308679000675984e-8*V01*V02*V032*V09 + 
      8.77025813340971257e-9*V01*V022*V04*V09 + 7.1834582491458546e-9*V012*V03*V04*V09 - 
      1.4153130144278294e-9*V03*V042*V09 + 4.43374919694538825e-9*V012*V02*V05*V09 - 
      1.2085493846929004e-9*V032*V05*V09 - 1.71860988325774967e-9*V02*V04*V05*V09 - 
      4.64537966320880956e-10*V01*V052*V09 + 5.85119928881510634e-10*V013*V06*V09 - 
      1.23485121005822109e-9*V02*V03*V06*V09 - 7.82527221124742941e-10*V01*V04*V06*V09 - 
      2.74866492876620447e-10*V022*V07*V09 - 4.87679733209617839e-10*V01*V03*V07*V09 + 
      2.64872102510882816e-11*V06*V07*V09 - 1.96132737209951713e-10*V01*V02*V08*V09 + 2.05915231695656882e-11*V05*V08*V09 - 
      1.47194794595128582e-11*V012*V092 + 6.04604398570575428e-12*V04*V092 - 
      6.81918957041506061e-10*V014*V02*V10 + 3.48265568096190404e-10*V024*V10 + 
      3.9527475182641169e-9*V01*V022*V03*V10 + 1.58723639999545373e-9*V012*V032*V10 + 
      2.37547505225306883e-9*V012*V02*V04*V10 - 6.43522757525397723e-10*V032*V04*V10 - 
      4.50952228298101522e-10*V02*V042*V10 + 3.68274912836089829e-10*V013*V05*V10 - 
      7.85069953286181082e-10*V02*V03*V05*V10 - 4.96120765508822204e-10*V01*V04*V05*V10 - 
      1.96309128408017937e-10*V022*V06*V10 - 3.52688219460775253e-10*V01*V03*V06*V10 + 
      9.5316233966908681e-12*V062*V10 - 1.60333731470374093e-10*V01*V02*V07*V10 + 1.68369529618378081e-11*V05*V07*V10 - 
      2.67557676759354174e-11*V012*V08*V10 + 1.0935460066826233e-11*V04*V08*V10 + 5.52161429611184481e-12*V03*V09*V10 + 
      8.9919967036980298e-13*V02*V102 - 2.47970529833274931e-11*V015*V11 + 
      3.89954577624368677e-10*V01*V023*V11 + 9.61437921518691765e-10*V012*V02*V03*V11 - 
      8.91464542226039259e-11*V033*V11 + 1.80678947825540564e-10*V013*V04*V11 - 
      3.82417051477253683e-10*V02*V03*V04*V11 - 1.21402737967798751e-10*V01*V042*V11 - 
      1.1579794533571919e-10*V022*V05*V11 - 2.04845647122264229e-10*V01*V03*V05*V11 - 
      1.06250624924977204e-10*V01*V02*V06*V11 + 1.11490964617701429e-11*V05*V06*V11 - 
      2.0020992866254189e-11*V012*V07*V11 + 8.22649391242126872e-12*V04*V07*V11 + 4.59415296211132609e-12*V03*V08*V11 + 
      1.65438981434644094e-12*V02*V09*V11 + 4.82472259286606351e-13*V01*V10*V11 + 
      1.34548483210522039e-10*V012*V022*V12 + 6.68595979013183176e-11*V013*V03*V12 - 
      7.38062556142881292e-11*V02*V032*V12 - 5.13963980381249043e-11*V022*V04*V12 - 
      9.27015141760798796e-11*V01*V03*V04*V12 - 5.70547794500081007e-11*V01*V02*V05*V12 + 
      2.99860569026803575e-12*V052*V12 - 1.2273583111709115e-11*V012*V06*V12 + 
      5.01003651777715458e-12*V04*V06*V12 + 3.17860203949389117e-12*V03*V07*V12 + 1.2659976078683143e-12*V02*V08*V12 + 
      4.08194929348678229e-13*V01*V09*V12 - 1.4504663090396124e-15*V122 + 
      1.74558201922108011e-11*V013*V02*V13 - 1.87565584625415959e-11*V022*V03*V13 - 
      1.63891079936603135e-11*V01*V032*V13 - 2.39430034807101478e-11*V01*V02*V04*V13 - 
      6.09778721055783964e-12*V012*V05*V13 + 2.51300746588976029e-12*V04*V05*V13 + 
      1.80512891105252166e-12*V03*V06*V13 + 8.16578853091849905e-13*V02*V07*V13 + 2.91207984024564874e-13*V01*V08*V13 - 
      2.69675342393643147e-15*V11*V13 + 7.34123279111669205e-13*V014*V14 - 1.4520930099637216e-12*V023*V14 - 
      7.94578858294750353e-12*V01*V02*V03*V14 - 2.40313008101044368e-12*V012*V04*V14 + 
      4.89671735163281324e-13*V042*V14 + 8.42069244727671752e-13*V03*V05*V14 + 4.31272395984100651e-13*V02*V06*V14 + 
      1.74658263583684653e-13*V01*V07*V14 - 2.15457447914380396e-15*V10*V14 - 8.9781667846007617e-13*V01*V022*V15 - 
      7.37730082826125629e-13*V012*V03*V15 + 3.09546490011871761e-13*V03*V04*V15 + 
      1.89703701486212331e-13*V02*V05*V15 + 8.69839823895684655e-14*V01*V06*V15 - 1.48321425750994692e-15*V09*V15 - 
      1.5980914919437697e-13*V012*V02*V16 + 4.57771546685545971e-14*V032*V16 + 
      6.52843535205289976e-14*V02*V04*V16 + 3.57966221493292314e-14*V01*V05*V16 - 8.70649042677774238e-16*V08*V16 - 
      8.32339318720713384e-15*V013*V17 + 1.84343556902537708e-14*V02*V03*V17 + 1.17610148879670657e-14*V01*V04*V17 - 
      4.36239290396901429e-16*V07*V17 + 1.7370559695040975e-15*V022*V18 + 3.09639273730613213e-15*V01*V03*V18 - 
      1.8281307790162915e-16*V06*V18 + 5.69217559451212504e-16*V01*V02*V19 - 6.42876573435826361e-17*V05*V19 + 
      4.14661798275717718e-17*V012*V20 - 1.80792544048212925e-17*V04*V20 - 4.17426210264222503e-18*V03*V21 - 
      6.63458877241148349e-19*V02*V22 - 9.04716650783384113e-20*V01*V23 + 6.9808383548100626e-23*V26) + 
   delta6*eps10*(-2.74769340381696435e-8*V022*V034 - 1.07639452439872608e-8*V01*V035 - 
      4.89821079515290533e-8*V023*V032*V04 - 1.22930855987967722e-7*V01*V02*V033*V04 - 
      6.21784885258793341e-10*V024*V042 - 9.20991292139751524e-8*V01*V022*V03*V042 - 
      4.92875941492888272e-8*V012*V032*V042 - 1.87580428009933145e-8*V012*V02*V043 + 
      3.8824614260066828e-8*V032*V043 + 7.35917308458240036e-9*V02*V044 - 
      1.14557399132108646e-8*V024*V03*V05 - 9.39409530971155621e-8*V01*V022*V032*V05 - 
      2.85950056049067876e-8*V012*V033*V05 - 2.9389264770917432e-8*V01*V023*V04*V05 - 
      1.01809884577158153e-7*V012*V02*V03*V04*V05 + 7.44574559481591069e-8*V033*V04*V05 - 
      8.71032191546508384e-9*V013*V042*V05 + 1.17074384057691148e-7*V02*V03*V042*V05 + 
      2.38540431258448046e-8*V01*V043*V05 - 1.30756378568003218e-8*V012*V022*V052 - 
      7.29685615792836459e-9*V013*V03*V052 + 5.81283378552467414e-8*V02*V032*V052 + 
      2.89942622476878869e-8*V022*V04*V052 + 6.76905840804596579e-8*V01*V03*V04*V052 + 
      1.18056790875543742e-8*V01*V02*V053 - 7.06794045525907851e-10*V054 - 
      8.08275217575974916e-11*V025*V06 - 2.12515129940433395e-8*V01*V023*V03*V06 - 
      3.38762155989046745e-8*V012*V02*V032*V06 + 1.30392731897766477e-8*V034*V06 - 
      1.95949349048088544e-8*V012*V022*V04*V06 - 1.13983674421738536e-8*V013*V03*V04*V06 + 
      8.48076389399461026e-8*V02*V032*V04*V06 + 1.56786788592745625e-8*V022*V042*V06 + 
      5.10787322326783384e-8*V01*V03*V042*V06 - 5.92992564086557239e-9*V013*V02*V05*V06 + 
      4.24257291634024247e-8*V022*V03*V05*V06 + 4.70787089119660635e-8*V01*V032*V05*V06 + 
      5.20706209726761905e-8*V01*V02*V04*V05*V06 + 6.94713693255276068e-9*V012*V052*V06 - 
      6.40105790975212439e-9*V04*V052*V06 - 2.24298059751685646e-10*V014*V062 + 
      1.84866682635380758e-9*V023*V062 + 1.85948157653287073e-8*V01*V02*V03*V062 + 
      5.42265501444226541e-9*V012*V04*V062 - 2.22130745594143576e-9*V042*V062 - 
      4.63736991429361019e-9*V03*V05*V062 - 5.54580846146333209e-10*V02*V063 - 
      1.63653427331583779e-9*V01*V024*V07 - 1.17421299435771891e-8*V012*V022*V03*V07 - 
      3.20093405070451445e-9*V013*V032*V07 + 1.87592204069923935e-8*V02*V033*V07 - 
      4.00733871205393148e-9*V013*V02*V04*V07 + 2.82652039123999253e-8*V022*V03*V04*V07 + 
      3.2547018463495343e-8*V01*V032*V04*V07 + 1.75210095995387451e-8*V01*V02*V042*V07 - 
      3.83623342355446308e-10*V014*V05*V07 + 4.60317291956745984e-9*V023*V05*V07 + 
      3.41071335553664913e-8*V01*V02*V03*V05*V07 + 9.62912321222397202e-9*V012*V04*V05*V07 - 
      4.42951313977359782e-9*V042*V05*V07 - 4.25973443487603526e-9*V03*V052*V07 + 
      6.34079407561570895e-9*V01*V022*V06*V07 + 6.61773317046439941e-9*V012*V03*V06*V07 - 
      6.44617457894883118e-9*V03*V04*V06*V07 - 3.34149468111654351e-9*V02*V05*V06*V07 - 
      7.42741450773490953e-10*V01*V062*V07 + 1.21142067789604728e-9*V012*V02*V072 - 
      1.06680612584732195e-9*V032*V072 - 1.14702018027081605e-9*V02*V04*V072 - 
      6.77478100005880002e-10*V01*V05*V072 - 1.14891137851247821e-9*V012*V023*V08 - 
      1.92910950964172253e-9*V013*V02*V03*V08 + 8.11039841871320418e-9*V022*V032*V08 + 
      5.76365642877216439e-9*V01*V033*V08 - 2.22498727108904513e-10*V014*V04*V08 + 
      1.91415314893434211e-9*V023*V04*V08 + 1.96330381410626959e-8*V01*V02*V03*V04*V08 + 
      2.86591172869538992e-9*V012*V042*V08 - 8.01282368730101966e-10*V043*V08 + 
      4.97306318106403491e-9*V01*V022*V05*V08 + 5.05041475517903175e-9*V012*V03*V05*V08 - 
      5.05492119438749656e-9*V03*V04*V05*V08 - 1.31604917227658524e-9*V02*V052*V08 + 
      2.08191788365372175e-9*V012*V02*V06*V08 - 1.82019520578530927e-9*V032*V06*V08 - 
      1.79627438518836763e-9*V02*V04*V06*V08 - 1.15840113098896455e-9*V01*V05*V06*V08 + 
      2.25606373851185909e-10*V013*V07*V08 - 1.32165695838759844e-9*V02*V03*V07*V08 - 
      8.07434980281941008e-10*V01*V04*V07*V08 + 2.17051692867928172e-11*V072*V08 - 
      8.98487444929676867e-11*V022*V082 - 2.24134068354309549e-10*V01*V03*V082 + 
      1.81331803232160107e-11*V06*V082 - 2.52693778020575406e-10*V013*V022*V09 - 
      9.09225276055341415e-11*V014*V03*V09 + 1.3370593591798383e-9*V023*V03*V09 + 
      4.85068722880645286e-9*V01*V02*V032*V09 + 2.51833886420762107e-9*V01*V022*V04*V09 + 
      2.70947346742516175e-9*V012*V03*V04*V09 - 1.36161805484418992e-9*V03*V042*V09 + 
      1.43096367560202802e-9*V012*V02*V05*V09 - 1.29851267719888812e-9*V032*V05*V09 - 
      1.40116539159537664e-9*V02*V04*V05*V09 - 4.11291740294556219e-10*V01*V052*V09 + 
      1.74891630887711094e-10*V013*V06*V09 - 1.02452104590438096e-9*V02*V03*V06*V09 - 
      6.28379847623859237e-10*V01*V04*V06*V09 - 1.78484697920670409e-10*V022*V07*V09 - 
      4.08092701013585716e-10*V01*V03*V07*V09 + 3.3953132833433193e-11*V06*V07*V09 - 1.27888002532006643e-10*V01*V02*V08*V09 + 
      2.6678956657570525e-11*V05*V08*V09 - 9.36810066023675533e-12*V012*V092 + 
      7.3042193898542391e-12*V04*V092 - 2.1254616842852137e-11*V014*V02*V10 + 
      5.34565056721994546e-11*V024*V10 + 1.16830609307205209e-9*V01*V022*V03*V10 + 
      5.7084323796536825e-10*V012*V032*V10 + 6.85449851410095157e-10*V012*V02*V04*V10 - 
      6.33606321810949201e-10*V032*V04*V10 - 3.07470334617415872e-10*V02*V042*V10 + 
      1.06936736097720667e-10*V013*V05*V10 - 6.62203685910129601e-10*V02*V03*V05*V10 - 
      4.02223295614672744e-10*V01*V04*V05*V10 - 1.13976288763887216e-10*V022*V06*V10 - 
      2.86328062844170295e-10*V01*V03*V06*V10 + 1.16480856420793068e-11*V062*V10 - 
      1.04988399583446367e-10*V01*V02*V07*V10 + 2.19163995634344966e-11*V05*V07*V10 - 
      1.69271171359636885e-11*V012*V08*V10 + 1.28132665874286097e-11*V04*V08*V10 + 
      6.86706159496541213e-12*V03*V09*V10 + 8.64949181561006468e-13*V02*V102 - 
      5.9040602341255936e-13*V015*V11 + 7.9301443030414151e-11*V01*V023*V11 + 
      2.6594713548899463e-10*V012*V02*V03*V11 - 8.87299917031129082e-11*V033*V11 + 
      4.73697993641643616e-11*V013*V04*V11 - 2.90710931892431905e-10*V02*V03*V04*V11 - 
      8.95415287043420387e-11*V01*V042*V11 - 7.38304027027456823e-11*V022*V05*V11 - 
      1.6709053987121586e-10*V01*V03*V05*V11 - 6.70736015883760654e-11*V01*V02*V06*V11 + 1.41806766887971536e-11*V05*V06*V11 - 
      1.26383881868897513e-11*V012*V07*V11 + 9.92787536971747346e-12*V04*V07*V11 + 
      5.68022819682475523e-12*V03*V08*V11 + 1.63246143178152037e-12*V02*V09*V11 + 4.7344232554941086e-13*V01*V10*V11 + 
      2.78562884046415178e-11*V012*V022*V12 + 1.62444520441739797e-11*V013*V03*V12 - 
      5.77149632529734132e-11*V02*V032*V12 - 2.6944414439909714e-11*V022*V04*V12 - 
      6.92962743396114235e-11*V01*V03*V04*V12 - 3.64699830497891316e-11*V01*V02*V05*V12 + 
      3.87536377323733394e-12*V052*V12 - 7.53905826800908323e-12*V012*V06*V12 + 
      5.76198889094579598e-12*V04*V06*V12 + 3.95150326642972839e-12*V03*V07*V12 + 1.21099716344026668e-12*V02*V08*V12 + 
      4.00943552284233181e-13*V01*V09*V12 - 1.91905668480552483e-15*V122 + 
      3.26277012938519646e-12*V013*V02*V13 - 1.10242787871679341e-11*V022*V03*V13 - 
      1.21615132465506972e-11*V01*V032*V13 - 1.36914823893645027e-11*V01*V02*V04*V13 - 
      3.70892250064880374e-12*V012*V05*V13 + 3.00593384548658181e-12*V04*V05*V13 + 
      2.18822945116350435e-12*V03*V06*V13 + 8.0426113589143413e-13*V02*V07*V13 + 2.83733661829447263e-13*V01*V08*V13 - 
      3.5950044222355905e-15*V11*V13 + 1.16527504620899874e-13*V014*V14 - 5.70142157529630388e-13*V023*V14 - 
      4.61744861167641976e-12*V01*V02*V03*V14 - 1.3414535353382164e-12*V012*V04*V14 + 
      5.26901714422590449e-13*V042*V14 + 1.03479343769192604e-12*V03*V05*V14 + 4.02694965934368117e-13*V02*V06*V14 + 
      1.70833668881899522e-13*V01*V07*V14 - 2.84703099736483097e-15*V10*V14 - 3.89072390428671245e-13*V01*V022*V15 - 
      4.00077765865089566e-13*V012*V03*V15 + 3.51758725996098794e-13*V03*V04*V15 + 
      1.84741598720858294e-13*V02*V05*V15 + 8.28519403972961318e-14*V01*V06*V15 - 1.97695220033361111e-15*V09*V15 - 
      6.79743776955249263e-14*V012*V02*V16 + 5.30733593768815591e-14*V032*V16 + 
      5.64663818975602804e-14*V02*V04*V16 + 3.43795678100096272e-14*V01*V05*V16 - 1.14444869229479259e-15*V08*V16 - 
      3.23687512835832983e-15*V013*V17 + 1.69279186966391785e-14*V02*V03*V17 + 1.04222688009763788e-14*V01*V04*V17 - 
      5.80985577516217115e-16*V07*V17 + 1.18497776438161466e-15*V022*V18 + 2.76682456624020715e-15*V01*V03*V18 - 
      2.36325392394261166e-16*V06*V18 + 4.01091048513966957e-16*V01*V02*V19 - 8.50500667784587243e-17*V05*V19 + 
      2.81467402465941724e-17*V012*V20 - 2.20750862791145724e-17*V04*V20 - 5.28421540105702499e-18*V03*V21 - 
      6.63458877241148349e-19*V02*V22 - 9.04716650783384113e-20*V01*V23 + 9.30778447308008347e-23*V26) + 
   delta2*eps12*(2.67650730613693577e-11*V027 + 1.45976708476708477e-7*V01*V025*V03 + 
      7.0347310654023617e-7*V012*V023*V032 + 3.42178076553076553e-7*V013*V02*V033 - 
      3.084430776406004e-7*V022*V034 - 1.08118735615307161e-7*V01*V035 + 
      2.37633701175367842e-7*V012*V024*V04 + 6.93810915165081832e-7*V013*V022*V03*V04 + 
      1.13156037635204302e-7*V014*V032*V04 - 7.43688622196506832e-7*V023*V032*V04 - 
      1.44359805672247316e-6*V01*V02*V033*V04 + 7.64811962728629395e-8*V014*V02*V042 - 
      8.46192910475220622e-8*V024*V042 - 1.38524165905300651e-6*V01*V022*V03*V042 - 
      6.05303266276509741e-7*V012*V032*V042 - 2.74664734491634001e-7*V012*V02*V043 + 
      1.11694089518080728e-7*V032*V043 + 3.25142589196534057e-8*V02*V044 + 
      1.18629495076254336e-7*V013*V023*V05 + 1.16106886940220274e-7*V014*V02*V03*V05 - 
      1.89987803884635766e-7*V024*V03*V05 - 1.18823842681875478e-6*V01*V022*V032*V05 - 
      3.31736914716460702e-7*V012*V033*V05 + 9.63542630209296876e-9*V015*V04*V05 - 
      4.83504726572034514e-7*V01*V023*V04*V05 - 1.34919420843425862e-6*V012*V02*V03*V04*V05 + 
      1.95378476733736308e-7*V033*V04*V05 - 1.21287286511449093e-7*V013*V042*V05 + 
      3.72522518500135835e-7*V02*V03*V042*V05 + 7.73089389403570869e-8*V01*V043*V05 - 
      1.8487438634533931e-7*V012*V022*V052 - 9.78097825560769072e-8*V013*V03*V052 + 
      1.65316922135894928e-7*V02*V032*V052 + 1.01740062258203634e-7*V022*V04*V052 + 
      2.00321126014137137e-7*V01*V03*V04*V052 + 3.76852254599081583e-8*V01*V02*V053 - 
      1.16437164809287144e-9*V054 + 2.40283443408443408e-8*V014*V022*V06 - 
      1.2002167247946115e-8*V025*V06 + 5.90169861003194337e-9*V015*V03*V06 - 
      3.48537536633261034e-7*V01*V023*V03*V06 - 4.65194063466705857e-7*V012*V02*V032*V06 + 
      3.48391497335826987e-8*V034*V06 - 3.12553644628662136e-7*V012*V022*V04*V06 - 
      1.64529391194015377e-7*V013*V03*V04*V06 + 2.69770771364478109e-7*V02*V032*V04*V06 + 
      7.7090098636797543e-8*V022*V042*V06 + 1.65806390843634817e-7*V01*V03*V042*V06 - 
      9.2022791402022261e-8*V013*V02*V05*V06 + 1.48557661675356213e-7*V022*V03*V05*V06 + 
      1.41952602899461084e-7*V01*V032*V05*V06 + 1.85640328809827055e-7*V01*V02*V04*V05*V06 + 
      2.34643216241922976e-8*V012*V052*V06 - 1.14432768100795188e-8*V04*V052*V06 - 
      3.87938929240866683e-9*V014*V062 + 1.00510417097837275e-8*V023*V062 + 
      6.64465440764529479e-8*V01*V02*V03*V062 + 1.96674517835845123e-8*V012*V04*V062 - 
      4.58348028122747872e-9*V042*V062 - 8.278219783333639e-9*V03*V05*V062 - 
      1.24683518334632837e-9*V02*V063 + 2.04752808919475586e-9*V015*V02*V07 - 
      3.13823433674672781e-8*V01*V024*V07 - 1.84926089044246724e-7*V012*V022*V03*V07 - 
      4.810012569626832e-8*V013*V032*V07 + 5.73194526254322907e-8*V02*V033*V07 - 
      6.68356487246543269e-8*V013*V02*V04*V07 + 1.0676507036741326e-7*V022*V03*V04*V07 + 
      1.03432916432419505e-7*V01*V032*V04*V07 + 6.71412123632643145e-8*V01*V02*V042*V07 - 
      6.69646946126287863e-9*V014*V05*V07 + 1.90859584989206258e-8*V023*V05*V07 + 
      1.16939449769792707e-7*V01*V02*V03*V05*V07 + 3.4238071677382654e-8*V012*V04*V05*V07 - 
      8.30823257228058229e-9*V042*V05*V07 - 7.33675818986803955e-9*V03*V052*V07 + 
      2.65804099641751113e-8*V01*V022*V06*V07 + 2.40101095250355247e-8*V012*V03*V06*V07 - 
      1.20455061030964279e-8*V03*V04*V06*V07 - 6.79398788954425902e-9*V02*V05*V06*V07 - 
      1.53869034002724677e-9*V01*V062*V07 + 4.96562880025493872e-9*V012*V02*V072 - 
      1.92466642630860559e-9*V032*V072 - 2.45920200644826241e-9*V02*V04*V072 - 
      1.35724029323924052e-9*V01*V05*V072 + 6.02214143880810547e-11*V016*V08 - 
      2.13611851300781039e-8*V012*V023*V08 - 3.42695272229585955e-8*V013*V02*V03*V08 + 
      3.02792194681157412e-8*V022*V032*V08 + 1.88389345300225058e-8*V01*V033*V08 - 
      4.26361709807379742e-9*V014*V04*V08 + 1.12167139606465727e-8*V023*V04*V08 + 
      7.47344361790665714e-8*V01*V02*V03*V04*V08 + 1.10687472366313311e-8*V012*V042*V08 - 
      1.72772347997289948e-9*V043*V08 + 2.06640487907188666e-8*V01*V022*V05*V08 + 
      1.85082141198720689e-8*V012*V03*V05*V08 - 9.37950419429437389e-9*V03*V04*V05*V08 - 
      2.65050454855617483e-9*V02*V052*V08 + 8.80299398332571031e-9*V012*V02*V06*V08 - 
      3.38269656824215663e-9*V032*V06*V08 - 4.22589433929602085e-9*V02*V04*V06*V08 - 
      2.38981532068142626e-9*V01*V05*V06*V08 + 9.90515159221750045e-10*V013*V07*V08 - 
      2.79267731905870259e-9*V02*V03*V07*V08 - 1.74370892281823102e-9*V01*V04*V07*V08 + 
      3.31867925608791034e-11*V072*V08 - 2.41409229250683865e-10*V022*V082 - 
      4.84349766673563639e-10*V01*V03*V082 + 2.89712894379706975e-11*V06*V082 - 
      5.41549924975170073e-9*V013*V022*V09 - 1.93062769655906911e-9*V014*V03*V09 + 
      6.18950644102830038e-9*V023*V03*V09 + 1.85179574839370135e-8*V01*V02*V032*V09 + 
      1.17828203493836249e-8*V01*V022*V04*V09 + 1.07257156401284082e-8*V012*V03*V04*V09 - 
      2.70359820304872567e-9*V03*V042*V09 + 6.07914170003273737e-9*V012*V02*V05*V09 - 
      2.37460104972733882e-9*V032*V05*V09 - 3.04046225768207461e-9*V02*V04*V05*V09 - 
      8.36430987272470724e-10*V01*V052*V09 + 7.86772810235201405e-10*V013*V06*V09 - 
      2.21263297880806407e-9*V02*V03*V06*V09 - 1.38398602015655266e-9*V01*V04*V06*V09 - 
      4.4520846148331938e-10*V022*V07*V09 - 8.72931442629041828e-10*V01*V03*V07*V09 + 
      5.26721248135003586e-11*V06*V07*V09 - 3.19721355448360149e-10*V01*V02*V08*V09 + 4.10606581135547258e-11*V05*V08*V09 - 
      2.38199168900336927e-11*V012*V092 + 1.18839211140883258e-11*V04*V092 - 
      5.49077601773680205e-10*V014*V02*V10 + 3.86984390179204898e-10*V024*V10 + 
      5.38127123739438841e-9*V01*V022*V03*V10 + 2.35425271167935375e-9*V012*V032*V10 + 
      3.1997553842434887e-9*V012*V02*V04*V10 - 1.24450308167573351e-9*V032*V04*V10 - 
      7.73375929443341844e-10*V02*V042*V10 + 4.92008163903447967e-10*V013*V05*V10 - 
      1.41186771676983161e-9*V02*V03*V05*V10 - 8.79027095323632989e-10*V01*V04*V05*V10 - 
      3.12777136181320367e-10*V022*V06*V10 - 6.28829694329919415e-10*V01*V03*V06*V10 + 
      1.88137017465615999e-11*V062*V10 - 2.61467955813591311e-10*V01*V02*V07*V10 + 
      3.36011857984340028e-11*V05*V07*V10 - 4.32819850759256635e-11*V012*V08*V10 + 
      2.13961039994227219e-11*V04*V08*V10 + 1.09996421190625787e-11*V03*V09*V10 + 1.63674936427126164e-12*V02*V102 - 
      1.85977897374956198e-11*V015*V11 + 4.59321643964406406e-10*V01*V023*V11 + 
      1.28685984453044567e-9*V012*V02*V03*V11 - 1.73965530086105601e-10*V033*V11 + 
      2.37428674915237523e-10*V013*V04*V11 - 6.74434524894710797e-10*V02*V03*V04*V11 - 
      2.11500334074548793e-10*V01*V042*V11 - 1.87388333343387057e-10*V022*V05*V11 - 
      3.65495445156227141e-10*V01*V03*V05*V11 - 1.72407649831470694e-10*V01*V02*V06*V11 + 2.21675458077228265e-11*V05*V06*V11 - 
      3.23547309901701805e-11*V012*V07*V11 + 1.61689362500497414e-11*V04*V07*V11 + 
      9.14425764956572053e-12*V03*V08*V11 + 3.02273164582402388e-12*V02*V09*V11 + 8.81698213101695296e-13*V01*V10*V11 + 
      1.59805819837102087e-10*V012*V022*V12 + 8.63507651742408364e-11*V013*V03*V12 - 
      1.32009755806277339e-10*V02*V032*V12 - 8.03257382924611658e-11*V022*V04*V12 - 
      1.62859423095692768e-10*V01*V03*V04*V12 - 9.27706260841776561e-11*V01*V02*V05*V12 + 
      5.98372199130302705e-12*V052*V12 - 1.97702321500602692e-11*V012*V06*V12 + 
      9.77437966473708316e-12*V04*V06*V12 + 6.3322572941193529e-12*V03*V07*V12 + 2.30242322547588044e-12*V02*V08*V12 + 
      7.46025996387384221e-13*V01*V09*V12 - 2.89767620050883711e-15*V122 + 
      2.02563645532664281e-11*V013*V02*V13 - 3.02249688860715764e-11*V022*V03*V13 - 
      2.89074219856099494e-11*V01*V032*V13 - 3.81567556720352671e-11*V01*V02*V04*V13 - 
      9.79910305465500131e-12*V012*V05*V13 + 4.93805918318293845e-12*V04*V05*V13 + 
      3.58232318765102169e-12*V03*V06*V13 + 1.49168263991744812e-12*V02*V07*V13 + 5.31637941831333841e-13*V01*V08*V13 - 
      5.39349176926201655e-15*V11*V13 + 8.15692532346299116e-13*V014*V14 - 2.0394039642059269e-12*V023*V14 - 
      1.27822904068819101e-11*V01*V02*V03*V14 - 3.80462302587238088e-12*V012*V04*V14 + 
      9.43493087903362422e-13*V042*V14 + 1.6761637137509049e-12*V03*V05*V14 + 7.81357932304635833e-13*V02*V06*V14 + 
      3.18991229225688745e-13*V01*V07*V14 - 4.30350651164704879e-15*V10*V14 - 1.2922900262457796e-12*V01*V022*V15 - 
      1.16469240868589424e-12*V012*V03*V15 + 6.0699923045643279e-13*V03*V04*V15 + 3.46354183280487579e-13*V02*V05*V15 + 
      1.58266004160357444e-13*V01*V06*V15 - 2.96641343640904745e-15*V09*V15 - 2.29170759087769752e-13*V012*V02*V16 + 
      9.0756148202973631e-14*V032*V16 + 1.1655806393888189e-13*V02*V04*V16 + 6.52324830992174169e-14*V01*V05*V16 - 
      1.73765241233313247e-15*V08*V16 - 1.16527504620899874e-14*V013*V17 + 3.35629772626173653e-14*V02*V03*V17 + 
      2.11142771959826184e-14*V01*V04*V17 - 8.72463502182956469e-16*V07*V17 + 2.84623858336452642e-15*V022*V18 + 
      5.59838663504758089e-15*V01*V03*V18 - 3.6390719416676987e-16*V06*V18 + 9.40905316814719477e-16*V01*V02*V19 - 
      1.28560236076318882e-16*V05*V19 + 6.78537488087538085e-17*V012*V20 - 3.55955740047107016e-17*V04*V20 - 
      8.33344559443806033e-18*V03*V21 - 1.21634127494210531e-18*V02*V22 - 1.65864719310287087e-19*V01*V23 + 
      1.39616767096201252e-22*V26) + delta4*eps11*
    (-1.52806918959560572e-7*V022*V034 - 5.68856203558000944e-8*V01*V035 - 
      3.15876669022093859e-7*V023*V032*V04 - 6.958119979804348e-7*V01*V02*V033*V04 - 
      2.12135350797297057e-8*V024*V042 - 5.88091694777424625e-7*V01*V022*V03*V042 - 
      2.84453623063372519e-7*V012*V032*V042 - 1.17619271009793886e-7*V012*V02*V043 + 
      8.86966561558005104e-8*V032*V043 + 2.14460056215349951e-8*V02*V044 - 
      7.48091926548262786e-8*V024*V03*V05 - 5.39058962601990924e-7*V01*V022*V032*V05 - 
      1.58909001373938738e-7*V012*V033*V05 - 1.89526001413256315e-7*V01*V023*V04*V05 - 
      5.98055205770687797e-7*V012*V02*V03*V04*V05 + 1.61506258237866329e-7*V033*V04*V05 - 
      5.25955727480781947e-8*V013*V042*V05 + 2.7817888422773766e-7*V02*V03*V042*V05 + 
      5.71626170411310686e-8*V01*V043*V05 - 7.79750415933013972e-8*V012*V022*V052 - 
      4.30718512656148822e-8*V013*V03*V052 + 1.29951972063580657e-7*V02*V032*V052 + 
      7.14529200788832413e-8*V022*V04*V052 + 1.54251296369004045e-7*V01*V03*V04*V052 + 
      2.7666147109001462e-8*V01*V02*V053 - 1.13709972354473621e-9*V054 - 
      2.88534984820906597e-9*V025*V06 - 1.37982768361308666e-7*V01*V023*V03*V06 - 
      2.02380681221523114e-7*V012*V02*V032*V06 + 2.86427995168255253e-8*V034*V06 - 
      1.2455520353123839e-7*V012*V022*V04*V06 - 6.98371886039661483e-8*V013*V03*V04*V06 + 
      2.02138696129166647e-7*V02*V032*V04*V06 + 4.76440170839494897e-8*V022*V042*V06 + 
      1.22766511580894927e-7*V01*V03*V042*V06 - 3.73179340947003568e-8*V013*V02*V05*V06 + 
      1.04883064752468015e-7*V022*V03*V05*V06 + 1.08613935887695355e-7*V01*V032*V05*V06 + 
      1.29739082094093604e-7*V01*V02*V04*V05*V06 + 1.67949996998712611e-8*V012*V052*V06 - 
      1.07734910420858212e-8*V04*V052*V06 - 1.49676361306846834e-9*V014*V062 + 
      5.84866874828278493e-9*V023*V062 + 4.6490749479958687e-8*V01*V02*V03*V062 + 
      1.36335308620654137e-8*V012*V04*V062 - 4.07075243007609874e-9*V042*V062 - 
      7.81909983324219675e-9*V03*V05*V062 - 1.05468946841692334e-9*V02*V063 - 
      1.06870275221180398e-8*V01*V024*V07 - 7.26839521385117401e-8*V012*V022*V03*V07 - 
      1.97934519015381916e-8*V013*V032*V07 + 4.36427528289873252e-8*V02*V033*V07 - 
      2.5795429568918131e-8*V013*V02*V04*V07 + 7.24637097784827881e-8*V022*V03*V04*V07 + 
      7.71187361798493556e-8*V01*V032*V04*V07 + 4.5233620195199384e-8*V01*V02*V042*V07 - 
      2.55167860404399464e-9*V014*V05*V07 + 1.21804939863605216e-8*V023*V05*V07 + 
      8.29641982955464781e-8*V01*V02*V03*V05*V07 + 2.38538285080762939e-8*V012*V04*V05*V07 - 
      7.64283130640170456e-9*V042*V05*V07 - 7.0292409799740354e-9*V03*V052*V07 + 
      1.69392668103744883e-8*V01*V022*V06*V07 + 1.6595678076758996e-8*V012*V03*V06*V07 - 
      1.11310141599262844e-8*V03*V04*V06*V07 - 5.96678959169407956e-9*V02*V05*V06*V07 - 
      1.34126360695585486e-9*V01*V062*V07 + 3.18336816442698659e-9*V012*V02*V072 - 
      1.80743274343053554e-9*V032*V072 - 2.10266307800613464e-9*V02*V04*V072 - 
      1.19842672976589113e-9*V01*V05*V072 - 7.53560510796738621e-9*V012*V023*V08 - 
      1.27980626820787885e-8*V013*V02*V03*V08 + 2.07894937321814828e-8*V022*V032*V08 + 
      1.3921933471288758e-8*V01*V033*V08 - 1.54652640647038406e-9*V014*V04*V08 + 
      6.26249873969185865e-9*V023*V04*V08 + 5.07187641611914184e-8*V01*V02*V03*V04*V08 + 
      7.44622710619452884e-9*V012*V042*V08 - 1.50432993014089171e-9*V043*V08 + 
      1.32561219817359938e-8*V01*V022*V05*V08 + 1.27619496246252961e-8*V012*V03*V05*V08 - 
      8.70482219950651634e-9*V03*V04*V05*V08 - 2.34132189036775429e-9*V02*V052*V08 + 
      5.60267195480498943e-9*V012*V02*V06*V08 - 3.14457965704656587e-9*V032*V06*V08 - 
      3.49886763160363477e-9*V02*V04*V06*V08 - 2.08946769759537164e-9*V01*V05*V06*V08 + 
      6.17035147718537668e-10*V013*V07*V08 - 2.4147989327076599e-9*V02*V03*V07*V08 - 
      1.49030395092540559e-9*V01*V04*V07*V08 + 3.29892849746113782e-11*V072*V08 - 
      1.85769012528000428e-10*V022*V082 - 4.15060292854459985e-10*V01*V03*V082 + 
      2.8347059314050546e-11*V06*V082 - 1.82258339427457075e-9*V013*V022*V09 - 
      6.67749212479604636e-10*V014*V03*V09 + 3.77339507269355975e-9*V023*V03*V09 + 
      1.25618347953540254e-8*V01*V02*V032*V09 + 7.14196990737920524e-9*V01*V022*V04*V09 + 
      7.14037566314455689e-9*V012*V03*V04*V09 - 2.43543286477891104e-9*V03*V042*V09 + 
      3.85955520133643137e-9*V012*V02*V05*V09 - 2.22293375126654135e-9*V032*V05*V09 - 
      2.59506546555557269e-9*V02*V04*V05*V09 - 7.3581687943856921e-10*V01*V052*V09 + 
      4.8665825669129732e-10*V013*V06*V09 - 1.89847107157496911e-9*V02*V03*V06*V09 - 
      1.17490485564995988e-9*V01*V04*V06*V09 - 3.51426447562011315e-10*V022*V07*V09 - 
      7.50335709632982461e-10*V01*V03*V07*V09 + 5.20763182348270563e-11*V06*V07*V09 - 2.5303234703178275e-10*V01*V02*V08*V09 + 
      4.07778441576321774e-11*V05*V08*V09 - 1.8695582881471011e-11*V012*V092 + 
      1.15072965190096386e-11*V04*V092 - 1.71217746789642214e-10*V014*V02*V10 + 
      1.92113878170659558e-10*V024*V10 + 3.29879529180663194e-9*V01*V022*V03*V10 + 
      1.54202785290627957e-9*V012*V032*V10 + 1.94591185098659104e-9*V012*V02*V04*V10 - 
      1.13024061335515152e-9*V032*V04*V10 - 6.21893994910565973e-10*V02*V042*V10 + 
      3.01718378928932375e-10*V013*V05*V10 - 1.21968969858732122e-9*V02*V03*V05*V10 - 
      7.49404778180590171e-10*V01*V04*V05*V10 - 2.38893190799719848e-10*V022*V06*V10 - 
      5.35874668934533298e-10*V01*V03*V06*V10 + 1.83359842204111559e-11*V062*V10 - 
      2.0718693649376069e-10*V01*V02*V07*V10 + 3.34199798567538781e-11*V05*V07*V10 - 
      3.3924902962824983e-11*V012*V08*V10 + 2.05328632884404755e-11*V04*V08*V10 + 1.07581102072366036e-11*V03*V09*V10 + 
      1.47070404889579494e-12*V02*V102 - 5.31365421071303424e-12*V015*V11 + 
      2.48358769884384882e-10*V01*V023*V11 + 7.71874861251565881e-10*V012*V02*V03*V11 - 
      1.58559391707317819e-10*V033*V11 + 1.40032212088693673e-10*V013*V04*V11 - 
      5.61357991571373525e-10*V02*V03*V04*V11 - 1.7433030741664228e-10*V01*V042*V11 - 
      1.47512793895455299e-10*V022*V05*V11 - 3.12222269925821467e-10*V01*V03*V05*V11 - 
      1.35159910425839623e-10*V01*V02*V06*V11 + 2.18922952159847789e-11*V05*V06*V11 - 
      2.5333763872467914e-11*V012*V07*V11 + 1.56536001965007288e-11*V04*V07*V11 + 8.92813645643280211e-12*V03*V08*V11 + 
      2.73641576630246169e-12*V02*V09*V11 + 7.97100635634540666e-13*V01*V10*V11 + 
      8.70369827014528024e-11*V012*V022*V12 + 4.96329484681952862e-11*V013*V03*V12 - 
      1.1096220648949361e-10*V02*V032*V12 - 5.91343175830674534e-11*V022*V04*V12 - 
      1.34862071672957394e-10*V01*V03*V04*V12 - 7.31229327782623809e-11*V01*V02*V05*V12 + 
      5.9457389675347873e-12*V052*V12 - 1.53633191449469276e-11*V012*V06*V12 + 
      9.3275632375441689e-12*V04*V06*V12 + 6.19310925351062037e-12*V03*V07*V12 + 2.06544449972002528e-12*V02*V08*V12 + 
      6.74624177338058683e-13*V01*V09*V12 - 2.89121865360783184e-15*V122 + 
      1.06816879235824884e-11*V013*V02*V13 - 2.30842065612378769e-11*V022*V03*V13 - 
      2.38773642772143671e-11*V01*V032*V13 - 2.88804264470394409e-11*V01*V02*V04*V13 - 
      7.59812044951786155e-12*V012*V05*V13 + 4.77430004109124123e-12*V04*V05*V13 + 
      3.47710866212780649e-12*V03*V06*V13 + 1.34988740448089142e-12*V02*V07*V13 + 4.7964793038172923e-13*V01*V08*V13 - 
      5.39335103556078358e-15*V11*V13 + 4.07846266173149558e-13*V014*V14 - 1.36409933028385478e-12*V023*V14 - 
      9.72954723225390703e-12*V01*V02*V03*V14 - 2.85819773119901505e-12*V012*V04*V14 + 
      8.79942667404491114e-13*V042*V14 + 1.63558710494722192e-12*V03*V05*V14 + 6.95851218173700222e-13*V02*V06*V14 + 
      2.88122330608983782e-13*V01*V07*V14 - 4.29233219484547072e-15*V10*V14 - 8.92212260380690033e-13*V01*V022*V15 - 
      8.66576209364092061e-13*V012*V03*V15 + 5.76254546085077975e-13*V03*V04*V15 + 
      3.12876249383043852e-13*V02*V05*V15 + 1.418321277710942e-13*V01*V06*V15 - 2.96627270270781448e-15*V09*V15 - 
      1.5731213123821483e-13*V012*V02*V16 + 8.6747750819641693e-14*V032*V16 + 
      1.01055643603636294e-13*V02*V04*V16 + 5.86680601292778003e-14*V01*V05*V16 - 1.73047164276784065e-15*V08*V16 - 
      7.76850030805999158e-15*V013*V17 + 2.96757113864180916e-14*V02*V03*V17 + 1.84515955686548097e-14*V01*V04*V17 - 
      8.72322768481723498e-16*V07*V17 + 2.28069015255260208e-15*V022*V18 + 4.90597682498136425e-15*V01*V03*V18 - 
      3.60579847373333201e-16*V06*V18 + 7.61972468104227953e-16*V01*V02*V19 - 1.28419502375085912e-16*V05*V19 + 
      5.42829990470030468e-17*V012*V20 - 3.45802808743871261e-17*V04*V20 - 8.19271189320508947e-18*V03*V21 - 
      1.10576479540191392e-18*V02*V22 - 1.50786108463897352e-19*V01*V23 + 1.39616767096201252e-22*V26) + 
   9.18368986379554615e-29*delta26*V26 + 5.969398411467105e-28*delta24*eps*V26 + 
   delta24*eps2*(-1.19394855996739947e-22*V132 - 1.91031769594783915e-22*V12*V14 - 
      1.77386643195156492e-22*V11*V15 - 1.04345084232444995e-22*V10*V16 - 7.17372454098059343e-23*V09*V17 - 
      3.02051559620235513e-23*V08*V18 - 1.51025779810117756e-23*V07*V19 - 4.31502228028907875e-24*V06*V20 - 
      1.51025779810117756e-24*V05*V21 - 2.6265353010455262e-25*V04*V22 - 5.969398411467105e-26*V03*V23 - 
      4.775518729173684e-27*V02*V24 - 5.969398411467105e-28*V01*V25 + 5.1460331133337112e-30*V28) + 
   delta22*eps3*(-1.43273827196087936e-21*V132 - 2.29238123513740697e-21*V12*V14 - 
      2.1286397183418779e-21*V11*V15 - 1.25214101078933994e-21*V10*V16 - 8.60846944917671212e-22*V09*V17 - 
      3.62461871544282615e-22*V08*V18 - 1.81230935772141308e-22*V07*V19 - 5.17802673634689451e-23*V06*V20 - 
      1.81230935772141308e-23*V05*V21 - 3.15184236125463144e-24*V04*V22 - 7.163278093760526e-25*V03*V23 - 
      5.7306224750084208e-26*V02*V24 - 7.163278093760526e-27*V01*V25 + 3.08761986800022672e-29*V28) + 
   delta20*eps4*(1.10298597358411377e-17*V083 + 8.50874893907744908e-17*V07*V08*V09 + 
      3.21177283144453053e-17*V06*V092 + 3.45184474005755605e-17*V072*V10 + 
      4.05285146835004812e-17*V06*V08*V10 + 4.02715219673381539e-17*V05*V09*V10 + 6.42551185378679264e-18*V04*V102 + 
      4.20450261570920361e-17*V06*V07*V11 + 3.2487950494659351e-17*V05*V08*V11 + 1.64373559050359812e-17*V04*V09*V11 + 
      7.32209490315239162e-18*V03*V10*V11 + 7.50401030447294793e-19*V02*V112 + 
      8.37583361314851212e-18*V062*V12 + 2.20591261494802398e-17*V05*V07*V12 + 8.6735229906141829e-18*V04*V08*V12 + 
      6.12753504152228884e-18*V03*V09*V12 + 9.81159102388680945e-19*V02*V10*V12 + 3.34229184083033937e-19*V01*V11*V12 + 
      1.1319814734601702e-17*V05*V06*V13 + 7.58647195617045285e-18*V04*V07*V13 + 4.16512185828966039e-18*V03*V08*V13 + 
      1.05825786345131317e-18*V02*V09*V13 + 2.81619034736630447e-19*V01*V10*V13 - 1.06595727433889424e-20*V132 + 
      2.53457131262967402e-18*V052*V14 + 2.57722253056508207e-18*V04*V06*V14 + 2.41387744059968954e-18*V03*V07*V14 + 
      4.76053124119404531e-19*V02*V08*V14 + 2.01156453383307462e-19*V01*V09*V14 - 1.73647878561658578e-20*V12*V14 + 
      1.51729439123409057e-18*V04*V05*V15 + 1.07807759377159067e-18*V03*V06*V15 + 3.62831267469021658e-19*V02*V07*V15 + 
      1.19003481665418868e-19*V01*V08*V15 - 1.58849738981262639e-20*V11*V15 + 1.48754352081773585e-19*V042*V16 + 
      4.16512185828966039e-19*V03*V05*V16 + 1.06136400409832961e-19*V02*V06*V16 + 5.95017408327094341e-20*V01*V07*V16 - 
      9.54131450221477037e-21*V10*V16 + 1.11565764061330189e-19*V03*V04*V17 + 5.60254163003636384e-20*V02*V05*V17 + 
      2.37811233920203824e-20*V01*V06*V17 - 6.48217749523006422e-21*V09*V17 + 1.32117352177891013e-20*V032*V18 + 
      9.44607155668013042e-21*V02*V04*V18 + 7.9270411306734608e-21*V01*V05*V18 - 2.79458102960641896e-21*V08*V18 + 
      3.27634013452418938e-21*V02*V03*V19 + 1.95729410633912612e-21*V01*V04*V19 - 1.38505742663858994e-21*V07*V19 + 
      1.163029831302959e-22*V022*V20 + 3.91458821267825225e-22*V01*V03*V20 - 4.06216197466413874e-22*V06*V20 + 
      4.68048590646312769e-23*V01*V02*V21 - 1.4136012990227022e-22*V05*V21 + 2.12749359384687622e-24*V012*V22 - 
      2.52935349490684173e-23*V04*V22 - 5.73241329453186093e-24*V03*V23 - 4.72776354188194716e-25*V02*V24 - 
      5.90970442735243395e-26*V01*V25 + 1.6981909274001247e-28*V28) + 
   delta18*eps5*(1.52317110637806187e-16*V083 + 1.12120493832635136e-15*V07*V08*V09 + 
      4.22288650060299385e-16*V06*V092 + 4.56136626364748478e-16*V072*V10 + 
      5.60091452293578975e-16*V06*V08*V10 + 5.32159397425539891e-16*V05*V09*V10 + 8.89111523954218982e-17*V04*V102 + 
      5.52814232806210104e-16*V06*V07*V11 + 4.28096430997334157e-16*V05*V08*V11 + 2.15740296253597253e-16*V04*V09*V11 + 
      9.67562540773708892e-17*V03*V10*V11 + 9.8348013838925757e-18*V02*V112 + 
      1.15962448868508278e-16*V062*V12 + 2.92589798232689292e-16*V05*V07*V12 + 1.20147745912201742e-16*V04*V08*V12 + 
      8.12749439535248034e-17*V03*V09*V12 + 1.36140534804836448e-17*V02*V10*V12 + 4.43317876110135291e-18*V01*V11*V12 + 
      1.4883460114013349e-16*V05*V06*V13 + 9.95724444247371937e-17*V04*V07*V13 + 5.48841578201710458e-17*V03*V08*V13 + 
      1.38695916952331196e-17*V02*V09*V13 + 3.72139438759118805e-18*V01*V10*V13 - 6.13928349535236805e-20*V132 + 
      3.37942841683956536e-17*V052*V14 + 3.58270230657427606e-17*V04*V06*V14 + 3.21850325413291939e-17*V03*V07*V14 + 
      6.62404371072965862e-18*V02*V08*V14 + 2.68208604511076616e-18*V01*V09*V14 - 1.02870607926791138e-19*V12*V14 + 
      1.99144888849474387e-17*V04*V05*V15 + 1.41747239181079514e-17*V03*V06*V15 + 4.75528858122278385e-18*V02*V07*V15 + 
      1.56811879486202988e-18*V01*V08*V15 - 9.1930627835889852e-20*V11*V15 + 2.08256092914483019e-18*V042*V16 + 
      5.59688249707673115e-18*V03*V05*V16 + 1.48652232389268935e-18*V02*V06*V16 + 7.99554642439533021e-19*V01*V07*V16 - 
      5.70350230414544345e-20*V10*V16 + 1.46430065330495873e-18*V03*V04*V17 + 7.34272501512341624e-19*V02*V05*V17 + 
      3.12677733487675398e-19*V01*V06*V17 - 3.80494349653610676e-20*V09*V17 + 1.79826396019907213e-19*V032*V18 + 
      1.34032096412353202e-19*V02*V04*V18 + 1.07895837611944328e-19*V01*V05*V18 - 1.69994617754268547e-20*V08*V18 + 
      4.29399123691427851e-20*V02*V03*V19 + 2.56894851457010304e-20*V01*V04*V19 - 8.31623456524413426e-21*V07*V19 + 
      1.69726711153561903e-21*V022*V20 + 5.46411271353006043e-21*V01*V03*V20 - 2.53334958075771814e-21*V06*V20 + 
      6.13427319559182644e-22*V01*V02*V21 - 8.7443926510058181e-22*V05*V21 + 3.19124039077031433e-23*V012*V22 - 
      1.62713861899770348e-22*V04*V22 - 3.67386625233742977e-23*V03*V23 - 3.15184236125463144e-24*V02*V24 - 
      3.9398029515682893e-25*V01*V25 + 8.49095463700062349e-28*V28) + 
   delta16*eps6*(-1.9971583877377173e-13*V052*V062 - 5.15012279872686278e-14*V04*V063 - 
      1.38552891798664746e-13*V053*V07 - 5.35296957748947698e-13*V04*V05*V06*V07 - 
      1.90205560736925457e-13*V03*V062*V07 - 8.90955092929180725e-14*V042*V072 - 
      1.9633954345872527e-13*V03*V05*V072 - 6.35520307987724906e-14*V02*V06*V072 - 
      9.19777263033969904e-15*V01*V073 - 2.06722420226566058e-13*V04*V052*V08 - 
      7.93140422857561947e-14*V042*V06*V08 - 2.92044310053531097e-13*V03*V05*V06*V08 - 
      2.8054165341348957e-14*V02*V062*V08 - 1.96878495453872436e-13*V03*V04*V07*V08 - 
      9.88055510639503979e-14*V02*V05*V07*V08 - 4.17206157219330139e-14*V01*V06*V07*V08 - 
      2.64742324327273891e-14*V032*V082 - 1.43533312602985843e-14*V02*V04*V082 - 
      1.58845394596364335e-14*V01*V05*V082 + 1.1820275926538449e-15*V083 - 
      1.03944760841737751e-13*V042*V05*V09 - 1.13602057536292194e-13*V03*V052*V09 - 
      1.48693599374707694e-13*V03*V04*V06*V09 - 7.41440359319012391e-14*V02*V05*V06*V09 - 
      1.58504633947437881e-14*V01*V062*V09 - 5.34751684544834494e-14*V032*V07*V09 - 
      4.88875816832892394e-14*V02*V04*V07*V09 - 3.18195745542241038e-14*V01*V05*V07*V09 - 
      2.74459864066528883e-14*V02*V03*V08*V09 - 1.6406541287822703e-14*V01*V04*V08*V09 + 8.17560521363213863e-15*V07*V08*V09 - 
      1.643382958440418e-15*V022*V092 - 4.26733622425923663e-15*V01*V03*V092 + 
      3.08192679142743045e-15*V06*V092 - 8.23776276145120962e-15*V043*V10 - 
      9.24961930882277239e-14*V03*V04*V05*V10 - 2.33503285680618882e-14*V02*V052*V10 - 
      3.24037911030739563e-14*V032*V06*V10 - 1.74238643178067204e-14*V02*V04*V06*V10 - 
      1.94422746618443738e-14*V01*V05*V06*V10 - 2.22384081600589411e-14*V02*V03*V07*V10 - 
      1.32137418697468177e-14*V01*V04*V07*V10 + 3.34029474072375626e-15*V072*V10 - 
      1.55351438944380804e-15*V022*V08*V10 - 6.93994367294913794e-15*V01*V03*V08*V10 + 
      4.36673324974551584e-15*V06*V08*V10 - 1.85320068000491176e-15*V01*V02*V09*V10 + 3.91504901715321151e-15*V05*V09*V10 - 
      1.08465183908934031e-16*V012*V102 + 6.99478132891690773e-16*V04*V102 - 
      1.88990474257705002e-14*V03*V042*V11 - 2.0079848750027906e-14*V032*V05*V11 - 
      1.8666167551801346e-14*V02*V04*V05*V11 - 5.9528162369059927e-15*V01*V052*V11 - 
      1.34807338058002253e-14*V02*V03*V06*V11 - 8.11055996589314694e-15*V01*V04*V06*V11 - 
      2.15133769104927447e-15*V022*V07*V11 - 5.5380535084000978e-15*V01*V03*V07*V11 + 
      4.05344001817784992e-15*V06*V07*V11 - 1.49705380399924845e-15*V01*V02*V08*V11 + 3.15077698022744369e-15*V05*V08*V11 - 
      2.06810074200447004e-16*V012*V09*V11 + 1.59121692189397229e-15*V04*V09*V11 + 
      7.21666268378127112e-16*V03*V10*V11 + 7.36581415510666222e-17*V02*V112 - 
      6.9185418610290725e-15*V032*V04*V12 - 1.80834826436122564e-15*V02*V042*V12 - 
      7.0425748922771522e-15*V02*V03*V05*V12 - 4.1511251166174435e-15*V01*V04*V05*V12 - 
      6.30237871364720846e-16*V022*V06*V12 - 2.86359817679713366e-15*V01*V03*V06*V12 + 
      9.12710887385849357e-16*V062*V12 - 1.0060821274681646e-15*V01*V02*V07*V12 + 2.17298619641462655e-15*V05*V07*V12 - 
      1.46306960814815552e-16*V012*V08*V12 + 9.49799932113489445e-16*V04*V08*V12 + 
      6.09073484754213193e-16*V03*V09*V12 + 1.09033397228799142e-16*V02*V10*V12 + 3.38185036744886271e-17*V01*V11*V12 - 
      8.23403845626556504e-16*V033*V13 - 2.39309840407709564e-15*V02*V03*V04*V13 - 
      7.26886439452711547e-16*V01*V042*V13 - 5.79206301436343127e-16*V022*V05*V13 - 
      1.44677819056731709e-15*V01*V03*V05*V13 - 5.18489761761547126e-16*V01*V02*V06*V13 + 1.10659043311581401e-15*V05*V06*V13 - 
      9.35939746766680868e-17*V012*V07*V13 + 7.41243447021940299e-16*V04*V07*V13 + 
      4.11428398053562672e-16*V03*V08*V13 + 1.04354074922474458e-16*V02*V09*V13 + 2.83871112421247911e-17*V01*V10*V13 - 
      2.94467426655281363e-19*V132 - 3.77787547433765198e-16*V02*V032*V14 - 
      9.26777057356701142e-17*V022*V04*V14 - 4.38655479552699342e-16*V01*V03*V04*V14 - 
      2.26672528460259119e-16*V01*V02*V05*V14 + 2.55854974493514799e-16*V052*V14 - 
      4.33570429464430293e-17*V012*V06*V14 + 2.8735149788757784e-16*V04*V06*V14 + 2.44740351616357412e-16*V03*V07*V14 + 
      5.35741052876326988e-17*V02*V08*V14 + 2.06622661355679947e-17*V01*V09*V14 - 5.08721755295465973e-19*V12*V14 - 
      5.51625048986993454e-17*V022*V03*V15 - 6.42358395777375031e-17*V01*V032*V15 - 
      6.83742401164884467e-17*V01*V02*V04*V15 - 1.78262688228429759e-17*V012*V05*V15 + 
      1.50982944171200065e-16*V04*V05*V15 + 1.07814907755634392e-16*V03*V06*V15 + 3.6269383138285915e-17*V02*V07*V15 + 
      1.20757812882905002e-17*V01*V08*V15 - 4.43179318750542553e-19*V11*V15 - 1.15395252530254566e-18*V023*V16 - 
      1.78862641421894578e-17*V01*V02*V03*V16 - 4.9706760326638416e-18*V012*V04*V16 + 
      1.71110905763354099e-17*V042*V16 + 4.3613320824757824e-17*V03*V05*V16 + 1.22621922769833635e-17*V02*V06*V16 + 
      6.28244603275794854e-18*V01*V07*V16 - 2.8474503199052279e-19*V10*V16 - 1.21681996100072085e-18*V01*V022*V17 - 
      1.17086609937362833e-18*V012*V03*V17 + 1.14032592883395642e-17*V03*V04*V17 + 
      5.72673938731115986e-18*V02*V05*V17 + 2.45317031319295603e-18*V01*V06*V17 - 1.86187158637677321e-19*V09*V17 - 
      1.54775158952360245e-19*V012*V02*V18 + 1.45049853861487712e-18*V032*V18 + 
      1.1394855688643869e-18*V02*V04*V18 + 8.73649925579235103e-19*V01*V05*V18 - 8.64577938312806382e-20*V08*V18 - 
      4.7868605861554715e-21*V013*V19 + 3.45239022941501839e-19*V02*V03*V19 + 2.071115013609934e-19*V01*V04*V19 - 
      4.16838046931090252e-20*V07*V19 + 1.50626546444358836e-20*V022*V20 + 4.61453360505387452e-20*V01*V03*V20 - 
      1.32340232459151162e-20*V06*V20 + 5.1219408271863545e-21*V01*V02*V21 - 4.52579939307717773e-21*V05*V21 + 
      2.8721163516932829e-22*V012*V22 - 8.79364018790042171e-22*V04*V22 - 1.97679613094938916e-22*V03*V23 - 
      1.77291132820573018e-23*V02*V24 - 2.21613916025716273e-24*V01*V25 + 3.82092958665028057e-27*V28) + 
   delta14*eps7*(-2.51986024216111903e-12*V052*V062 - 
      7.66374204694040638e-13*V04*V063 - 1.71500114887796047e-12*V053*V07 - 
      6.73187355701465464e-12*V04*V05*V06*V07 - 2.39986689729630384e-12*V03*V062*V07 - 
      1.11856831327609723e-12*V042*V072 - 2.43566320925706709e-12*V03*V05*V072 - 
      7.98583082493023281e-13*V02*V06*V072 - 1.14618397393463942e-13*V01*V073 - 
      2.61143204268681004e-12*V04*V052*V08 - 1.18471866425539801e-12*V042*V06*V08 - 
      3.70632780010077628e-12*V03*V05*V06*V08 - 4.20522991215922173e-13*V02*V062*V08 - 
      2.48707813589220004e-12*V03*V04*V07*V08 - 1.24518743296266383e-12*V02*V05*V07*V08 - 
      5.29475400014396611e-13*V01*V06*V07*V08 - 3.38500229532863735e-13*V032*V082 - 
      2.1618555087787909e-13*V02*V04*V082 - 2.03100137719718241e-13*V01*V05*V082 + 
      6.55112010707955772e-15*V083 - 1.3049963654887801e-12*V042*V05*V09 - 
      1.41243945340161121e-12*V03*V052*V09 - 1.86996487694851518e-12*V03*V04*V06*V09 - 
      9.31680262908527161e-13*V02*V05*V06*V09 - 1.9998890810802532e-13*V01*V062*V09 - 
      6.67000771126056506e-13*V032*V07*V09 - 6.14853248028864449e-13*V02*V04*V07*V09 - 
      3.97810724009440211e-13*V01*V05*V07*V09 - 3.45885398045184397e-13*V02*V03*V08*V09 - 
      2.07256511324350003e-13*V01*V04*V08*V09 + 4.25003916946786307e-14*V07*V08*V09 - 
      2.082221806665971e-14*V022*V092 - 5.38830472713085848e-14*V01*V03*V092 + 
      1.60812251786407803e-14*V06*V092 - 1.24056419875980856e-13*V043*V10 - 
      1.17736463407971587e-12*V03*V04*V05*V10 - 2.96119791245740176e-13*V02*V052*V10 - 
      4.15039194364330216e-13*V032*V06*V10 - 2.63587490168626055e-13*V02*V04*V06*V10 - 
      2.49023516618598129e-13*V01*V05*V06*V10 - 2.82018848805466834e-13*V02*V03*V07*V10 - 
      1.68194947725673695e-13*V01*V04*V07*V10 + 1.74383716386006097e-14*V072*V10 - 
      2.38053768189902368e-14*V022*V08*V10 - 8.98202690897743747e-14*V01*V03*V08*V10 + 
      2.43846652416793024e-14*V06*V08*V10 - 2.35015707337889029e-14*V01*V02*V09*V10 + 2.06057236803017738e-14*V05*V09*V10 - 
      1.43370826246798331e-15*V012*V102 + 3.96428932547644154e-15*V04*V102 - 
      2.37272066452505473e-13*V03*V042*V11 - 2.51631536127520512e-13*V032*V05*V11 - 
      2.34762149247384608e-13*V02*V04*V05*V11 - 7.48492153453347417e-14*V01*V052*V11 - 
      1.69396411437914029e-13*V02*V03*V06*V11 - 1.01998084197191737e-13*V01*V04*V06*V11 - 
      2.72581763781727113e-14*V022*V07*V11 - 7.01033093976778396e-14*V01*V03*V07*V11 + 
      2.13218354709983197e-14*V06*V07*V11 - 1.8866476257010058e-14*V01*V02*V08*V11 + 1.66463961920891562e-14*V05*V08*V11 - 
      2.70549182705722968e-15*V012*V09*V11 + 8.46519127348510629e-15*V04*V09*V11 + 
      3.88883527020090202e-15*V03*V10*V11 + 4.02081764258068888e-16*V02*V112 - 
      8.9119744245507192e-14*V032*V04*V12 - 2.77615388249572503e-14*V02*V042*V12 - 
      9.02401843369926548e-14*V02*V03*V05*V12 - 5.34718465473043152e-14*V01*V04*V05*V12 - 
      9.75373498117561726e-15*V022*V06*V12 - 3.72237934749807608e-14*V01*V03*V06*V12 + 
      5.17221526231414158e-15*V062*V12 - 1.2891454905284665e-14*V01*V02*V07*V12 + 1.15738056510318501e-14*V05*V07*V12 - 
      1.9385984662704339e-15*V012*V08*V12 + 5.42172521751850093e-15*V04*V08*V12 + 3.29486197473159965e-15*V03*V09*V12 + 
      6.35760112757530432e-16*V02*V10*V12 + 1.88437848864205698e-16*V01*V11*V12 - 1.04411003105223144e-14*V033*V13 - 
      3.00977114419723856e-14*V02*V03*V04*V13 - 9.12584870971174895e-15*V01*V042*V13 - 
      7.33873979412342228e-15*V022*V05*V13 - 1.84758419748958044e-14*V01*V03*V05*V13 - 
      6.5152465937659242e-15*V01*V02*V06*V13 + 5.95861129736542136e-15*V05*V06*V13 - 
      1.23197707636072354e-15*V012*V07*V13 + 4.0041533527362525e-15*V04*V07*V13 + 2.2415825653105088e-15*V03*V08*V13 + 
      5.73795659728471751e-16*V02*V09*V13 + 1.58694949853917996e-16*V01*V10*V13 - 1.2092933945033283e-18*V132 - 
      4.9215054007228526e-15*V02*V032*V14 - 1.46814009844390231e-15*V022*V04*V14 - 
      5.7597988081150496e-15*V01*V03*V04*V14 - 2.95290324043371156e-15*V01*V02*V05*V14 + 
      1.39952415958247218e-15*V052*V14 - 5.79171836040122807e-16*V012*V06*V14 + 
      1.6750370091965098e-15*V04*V06*V14 + 1.34875401993507653e-15*V03*V07*V14 + 3.16627754139116627e-16*V02*V08*V14 + 
      1.16364635315865469e-16*V01*V09*V14 - 2.14611734546070503e-18*V12*V14 - 6.98927599440325931e-16*V022*V03*V15 - 
      8.37876759046778033e-16*V01*V032*V15 - 8.59934612627782446e-16*V01*V02*V04*V15 - 
      2.38362680259728934e-16*V012*V05*V15 + 8.3968746884450111e-16*V04*V05*V15 + 6.02108557224745365e-16*V03*V06*V15 + 
      2.03680279692837158e-16*V02*V07*V15 + 6.86493250381728478e-17*V01*V08*V15 - 1.82727523647880226e-18*V11*V15 - 
      1.9167866283122816e-17*V023*V16 - 2.3955748066203334e-16*V01*V02*V03*V16 - 
      6.75521765918260138e-17*V012*V04*V16 + 1.03124890677870831e-16*V042*V16 + 
      2.48128726852923635e-16*V03*V05*V16 + 7.43882390075747964e-17*V02*V06*V16 + 3.62386621307907661e-17*V01*V07*V16 - 
      1.21120144382787979e-18*V10*V16 - 1.54175205758895426e-17*V01*V022*V17 - 
      1.62676670159907543e-17*V012*V03*V17 + 6.60274019331159576e-17*V03*V04*V17 + 3.323932166218544e-17*V02*V05*V17 + 
      1.43510080372941035e-17*V01*V06*V17 - 7.77120222492417712e-19*V09*V17 - 2.182808427286895e-18*V012*V02*V18 + 
      8.61634905507984869e-18*V032*V18 + 7.17646139076428287e-18*V02*V04*V18 + 5.2234222716128505e-18*V01*V05*V18 - 
      3.7401337379828084e-19*V08*V18 - 7.65897693784875439e-20*V013*V19 + 2.09026245595455589e-18*V02*V03*V19 + 
      1.25862521011981197e-18*V01*V04*V19 - 1.77698902426060336e-19*V07*V19 + 9.95667001920338071e-20*V022*V20 + 
      2.89126379403790478e-19*V01*V03*V20 - 5.87492159558001676e-20*V06*V20 + 3.25506519858572062e-20*V01*V02*V21 - 
      1.98920651024682927e-20*V05*V21 + 1.9147442344621886e-21*V012*V22 - 4.04223782830906482e-21*V04*V22 - 
      9.04184777384922394e-22*V03*V23 - 8.50997437538750488e-23*V02*V24 - 1.06374679692343811e-23*V01*V25 + 
      1.52837183466011223e-26*V28) + delta12*eps8*
    (1.69722051530330397e-12*V045 + 9.90045300593593985e-11*V03*V043*V05 + 
      1.65145212109441825e-10*V032*V04*V052 + 7.29432517380202435e-11*V02*V042*V052 + 
      5.64335642606010761e-11*V02*V03*V053 + 3.24106070216067245e-11*V01*V04*V053 + 
      1.05663509164113951e-10*V032*V042*V06 + 1.17532365180228153e-11*V02*V043*V06 + 
      7.57945446961099518e-11*V033*V05*V06 + 2.10162034740904921e-10*V02*V03*V04*V05*V06 + 
      6.33981054984683709e-11*V01*V042*V05*V06 + 2.56238332842952961e-11*V022*V052*V06 + 
      6.63802309875038209e-11*V01*V03*V052*V06 + 3.74575065295956479e-11*V02*V032*V062 + 
      6.06698639197789842e-12*V022*V04*V062 + 4.45126951642857669e-11*V01*V03*V04*V062 + 
      2.24745039177573887e-11*V01*V02*V05*V062 - 1.63160233770679799e-11*V052*V062 + 
      1.52221561580565904e-12*V012*V063 - 5.78540684073728724e-12*V04*V063 + 
      5.14454079708043246e-11*V033*V04*V07 + 6.94697635600192795e-11*V02*V03*V042*V07 + 
      1.41435042941941998e-11*V01*V043*V07 + 7.92724339032897677e-11*V02*V032*V05*V07 + 
      3.34782410990087043e-11*V022*V04*V05*V07 + 9.03276914070541286e-11*V01*V03*V04*V05*V07 + 
      2.33776470874305423e-11*V01*V02*V052*V07 - 1.08185146013897752e-11*V053*V07 + 
      2.4403650746947901e-11*V022*V03*V06*V07 + 3.07358913088136596e-11*V01*V032*V06*V07 + 
      3.00231478201292744e-11*V01*V02*V04*V06*V07 + 8.68957492519746369e-12*V012*V05*V06*V07 - 
      4.37093686329841425e-11*V04*V05*V06*V07 - 1.566181267711276e-11*V03*V062*V07 + 
      1.25464861823383465e-12*V023*V072 + 1.08474889550181841e-11*V01*V02*V03*V072 + 
      2.96769747346639897e-12*V012*V04*V072 - 7.28858817233331817e-12*V042*V072 - 
      1.55159626435125332e-11*V03*V05*V072 - 5.24660148877228691e-12*V02*V06*V072 - 
      7.44212283487397049e-13*V01*V073 + 6.67609532142999851e-12*V034*V08 + 
      3.84582775897924735e-11*V02*V032*V04*V08 + 3.05603303904589489e-12*V022*V042*V08 + 
      2.28990069525048949e-11*V01*V03*V042*V08 + 1.89494560578382592e-11*V022*V03*V05*V08 + 
      2.31650689866383551e-11*V01*V032*V05*V08 + 2.30749665538754841e-11*V01*V02*V04*V05*V08 + 
      3.25981262240335248e-12*V012*V052*V08 - 1.70529257356118519e-11*V04*V052*V08 + 
      6.94763678262057234e-13*V023*V06*V08 + 1.62296042957806157e-11*V01*V02*V03*V06*V08 + 
      4.69918606764911534e-12*V012*V04*V06*V08 - 9.01512332233048342e-12*V042*V06*V08 - 
      2.43390798066278307e-11*V03*V05*V06*V08 - 3.22453879873185615e-12*V02*V062*V08 + 
      2.70706515111975132e-12*V01*V022*V07*V08 + 2.98045856840657767e-12*V012*V03*V07*V08 - 
      1.63678310962694555e-11*V03*V04*V07*V08 - 8.22054068494952146e-12*V02*V05*V07*V08 - 
      3.5306585954940383e-12*V01*V06*V07*V08 + 4.27227659317861358e-13*V012*V02*V082 - 
      2.25523495409310078e-12*V032*V082 - 1.67159794752105173e-12*V02*V04*V082 - 
      1.36330647299124867e-12*V01*V05*V082 + 2.80098426526990846e-14*V083 + 
      7.09060617403523279e-12*V02*V033*V09 + 9.29951141639130675e-12*V022*V03*V04*V09 + 
      1.19842625250196528e-11*V01*V032*V04*V09 + 5.78914696333493996e-12*V01*V02*V042*V09 + 
      1.46375672127280709e-12*V023*V05*V09 + 1.2430913178878777e-11*V01*V02*V03*V05*V09 + 
      3.3886904571058416e-12*V012*V04*V05*V09 - 8.57100355790489362e-12*V042*V05*V09 - 
      9.08705561862994056e-12*V03*V052*V09 + 2.03363756224565842e-12*V01*V022*V06*V09 + 
      2.26814706342825295e-12*V012*V03*V06*V09 - 1.23340808419557285e-11*V03*V04*V06*V09 - 
      6.1692665648056855e-12*V02*V05*V06*V09 - 1.33583675497378195e-12*V01*V062*V09 + 
      8.11760639874362548e-13*V012*V02*V07*V09 - 4.33464495272616129e-12*V032*V07*V09 - 
      4.09110037577523526e-12*V02*V04*V07*V09 - 2.60926157468941e-12*V01*V05*V07*V09 + 
      6.79697068800438898e-14*V013*V08*V09 - 2.31898587308895023e-12*V02*V03*V08*V09 - 
      1.39572328551556802e-12*V01*V04*V08*V09 + 1.71686331083175458e-13*V07*V08*V09 - 
      1.41825665686594023e-13*V022*V092 - 3.61035387268690237e-13*V01*V03*V092 + 
      6.53857258245341292e-14*V06*V092 + 2.10846776290424879e-12*V022*V032*V10 + 
      1.62762786071965243e-12*V01*V033*V10 + 2.0882306763634111e-13*V023*V04*V10 + 
      5.06712184364963239e-12*V01*V02*V03*V04*V10 + 7.35486409901654912e-13*V012*V042*V10 - 
      9.59305627506322286e-13*V043*V10 + 1.26508065774254928e-12*V01*V022*V05*V10 + 
      1.35509493219951251e-12*V012*V03*V05*V10 - 7.86276590867499058e-12*V03*V04*V05*V10 - 
      1.98258060474281681e-12*V02*V052*V10 + 5.19864378696037504e-13*V012*V02*V06*V10 - 
      2.78858403478309586e-12*V032*V06*V10 - 2.05469609340393125e-12*V02*V04*V06*V10 - 
      1.68557798488720377e-12*V01*V05*V06*V10 + 5.40740308239601506e-14*V013*V07*V10 - 
      1.90247352254040442e-12*V02*V03*V07*V10 - 1.14020824033674051e-12*V01*V04*V07*V10 + 
      7.06450656808127573e-14*V072*V10 - 1.88915965409151507e-13*V022*V08*V10 - 
      6.17169857042578985e-13*V01*V03*V08*V10 + 1.05241906443131414e-13*V06*V08*V10 - 1.62114839717559375e-13*V01*V02*V09*V10 + 
      8.43512198400368814e-14*V05*V09*V10 - 1.01879759579391264e-14*V012*V102 + 
      1.74429213223327529e-14*V04*V102 + 2.66137585685964925e-13*V023*V03*V11 + 
      1.05906854914023571e-12*V01*V02*V032*V11 + 5.07246077257707641e-13*V01*V022*V04*V11 + 
      5.68284293963893289e-13*V012*V03*V04*V11 - 1.59526465971872016e-12*V03*V042*V11 + 
      2.9770002966244182e-13*V012*V02*V05*V11 - 1.66744937872337325e-12*V032*V05*V11 - 
      1.58652933824338137e-12*V02*V04*V05*V11 - 5.007211389248975e-13*V01*V052*V11 + 
      3.32257525080438846e-14*V013*V06*V11 - 1.1479929179126796e-12*V02*V03*V06*V11 - 
      6.93777815562933079e-13*V01*V04*V06*V11 - 1.87092052579593526e-13*V022*V07*V11 - 
      4.74251271528799159e-13*V01*V03*V07*V11 + 8.74934122198606157e-14*V06*V07*V11 - 1.30363122113054841e-13*V01*V02*V08*V11 + 
      6.8574529490516731e-14*V05*V08*V11 - 1.90080765250655044e-14*V012*V09*V11 + 3.53027384466007188e-14*V04*V09*V11 + 
      1.64052489611799716e-14*V03*V10*V11 + 1.73546694453885326e-15*V02*V112 + 
      3.48280913281984102e-15*V024*V12 + 1.85950769278642338e-13*V01*V022*V03*V12 + 
      9.34645124364953167e-14*V012*V032*V12 + 1.08783666218579755e-13*V012*V02*V04*V12 - 
      6.13856704112766429e-13*V032*V04*V12 - 2.21778759541654563e-13*V02*V042*V12 + 
      1.6280968105939485e-14*V013*V05*V12 - 6.22704221012906932e-13*V02*V03*V05*V12 - 
      3.70956271646512361e-13*V01*V04*V05*V12 - 7.86666000003416018e-14*V022*V06*V12 - 
      2.60023262126741606e-13*V01*V03*V06*V12 + 2.27134927216431786e-14*V062*V12 - 
      9.02421222515664391e-14*V01*V02*V07*V12 + 4.79014585663032558e-14*V05*V07*V12 - 
      1.38882189976287973e-14*V012*V08*V12 + 2.40467287854516429e-14*V04*V08*V12 + 
      1.39260898601988465e-14*V03*V09*V12 + 2.9018707451200084e-15*V02*V10*V12 + 8.28596396924692205e-16*V01*V11*V12 + 
      1.02360609879217279e-14*V01*V023*V13 + 3.42738835019884867e-14*V012*V02*V03*V13 - 
      7.19332390498911321e-14*V033*V13 + 5.70923117878059699e-15*V013*V04*V13 - 
      2.09676282115613157e-13*V02*V03*V04*V13 - 6.37217418137510935e-14*V01*V042*V13 - 
      5.1525422695415292e-14*V022*V05*V13 - 1.28648176024020543e-13*V01*V03*V05*V13 - 
      4.58399896599754662e-14*V01*V02*V06*V13 + 2.51117911730858733e-14*V05*V06*V13 - 
      8.82037675447656105e-15*V012*V07*V13 + 1.69741932779255435e-14*V04*V07*V13 + 
      9.58338797132798474e-15*V03*V08*V13 + 2.49469101004387013e-15*V02*V09*V13 + 7.01380077351058344e-16*V01*V10*V13 - 
      4.27353345192435548e-18*V132 + 2.83817431889704983e-15*V012*V022*V14 + 
      1.54753458517703007e-15*V013*V03*V14 - 3.52847386806752976e-14*V02*V032*V14 - 
      1.22374878213716136e-14*V022*V04*V14 - 4.15516029503519116e-14*V01*V03*V04*V14 - 
      2.13136767458152763e-14*V01*V02*V05*V14 + 5.95542265348387808e-15*V052*V14 - 
      4.25021139007428497e-15*V012*V06*V14 + 7.60517821823443363e-15*V04*V06*V14 + 
      5.80084922444112894e-15*V03*V07*V14 + 1.46578502492623655e-15*V02*V08*V14 + 5.160537622557416e-16*V01*V09*V14 - 
      7.73886903353060472e-18*V12*V14 + 2.40453580963761644e-16*V013*V02*V15 - 
      5.09043477455507611e-15*V022*V03*V15 - 6.12709857802884349e-15*V01*V032*V15 - 
      6.25968312779994327e-15*V01*V02*V04*V15 - 1.77277552319798963e-15*V012*V05*V15 + 
      3.67333501324724325e-15*V04*V05*V15 + 2.64593878461763225e-15*V03*V06*V15 + 9.04658570208272093e-16*V02*V07*V15 + 
      3.08960363931146751e-16*V01*V08*V15 - 6.47264097833335275e-18*V11*V15 + 6.16547643496824729e-18*V014*V16 - 
      1.68403882914543334e-16*V023*V16 - 1.81046088097259627e-15*V01*V02*V03*V16 - 
      5.15451700909533787e-16*V012*V04*V16 + 4.86090927718546833e-16*V042*V16 + 
      1.10218688305046193e-15*V03*V05*V16 + 3.54020465499464205e-16*V02*V06*V16 + 1.64312925482935176e-16*V01*V07*V16 - 
      4.39498432485673238e-18*V10*V16 - 1.17948244842870818e-16*V01*V022*V17 - 
      1.28469764411240544e-16*V012*V03*V17 + 3.01963143875664068e-16*V03*V04*V17 + 
      1.52772017359073719e-16*V02*V05*V17 + 6.65625729466481393e-17*V01*V06*V17 - 2.77491205584608323e-18*V09*V17 - 
      1.75582046300182694e-17*V012*V02*V18 + 4.00700121566097593e-17*V032*V18 + 
      3.5554247441650226e-17*V02*V04*V18 + 2.45368091165547928e-17*V01*V05*V18 - 1.3760805856134416e-18*V08*V18 - 
      6.7016048206176601e-19*V013*V19 + 1.00524072309264901e-17*V02*V03*V19 + 6.08058944057375693e-18*V01*V04*V19 - 
      6.44825579181706125e-19*V07*V19 + 5.19746684976791861e-19*V022*V20 + 1.42520795851802238e-18*V01*V03*V20 - 
      2.21277062873357184e-19*V06*V20 + 1.65306252241902282e-19*V01*V02*V21 - 7.41520163022046649e-20*V05*V21 + 
      1.00524072309264901e-20*V012*V22 - 1.57611817077489413e-20*V04*V22 - 3.50593215152683144e-21*V03*V23 - 
      3.47490620328323116e-22*V02*V24 - 4.34363275410403895e-23*V01*V25 + 5.3493014213103928e-26*V28) + 
   delta10*eps9*(2.94346529368315861e-11*V045 + 1.07985655286172715e-9*V03*V043*V05 + 
      1.71897339904773307e-9*V032*V04*V052 + 7.96266008412303666e-10*V02*V042*V052 + 
      5.8607426055896506e-10*V02*V03*V053 + 3.39463604350525028e-10*V01*V04*V053 + 
      1.15932748685713087e-9*V032*V042*V06 + 2.06411599190622904e-10*V02*V043*V06 + 
      7.94747422420482385e-10*V033*V05*V06 + 2.30172081336221789e-9*V02*V03*V04*V05*V06 + 
      6.95596492114278522e-10*V01*V042*V05*V06 + 2.81347387631380162e-10*V022*V052*V06 + 
      7.01468961792346197e-10*V01*V03*V052*V06 + 4.12513514218773564e-10*V02*V032*V062 + 
      1.08095995688749874e-10*V022*V04*V062 + 4.91928317844827125e-10*V01*V03*V04*V062 + 
      2.47508108531264139e-10*V01*V02*V05*V062 - 6.99871235822987974e-11*V052*V062 + 
      1.69186310382554962e-11*V012*V063 - 2.82711509161556807e-11*V04*V063 + 
      5.38831118016706393e-10*V033*V04*V07 + 7.58348579440289206e-10*V02*V03*V042*V07 + 
      1.54265221837389593e-10*V01*V043*V07 + 8.28508293443252896e-10*V02*V032*V05*V07 + 
      3.67630249386954262e-10*V022*V04*V05*V07 + 9.535216764415262e-10*V01*V03*V04*V05*V07 + 
      2.45930292969252426e-10*V01*V02*V052*V07 - 4.50648873161857779e-11*V053*V07 + 
      2.67949892982266821e-10*V022*V03*V06*V07 + 3.27459639717265832e-10*V01*V032*V06*V07 + 
      3.28817259051745412e-10*V01*V02*V04*V06*V07 + 9.4048614407050179e-11*V012*V05*V06*V07 - 
      1.89215565149637133e-10*V04*V05*V06*V07 - 6.81763445170203853e-11*V03*V062*V07 + 
      1.39444848287510596e-11*V023*V072 + 1.15182666174941962e-10*V01*V02*V03*V072 + 
      3.21017537411587722e-11*V012*V04*V072 - 3.18406426463850054e-11*V042*V072 - 
      6.56634174168191508e-11*V03*V05*V072 - 2.32359443397106751e-11*V02*V06*V072 - 
      3.24855532859376506e-12*V01*V073 + 7.09335127901937342e-11*V034*V08 + 
      4.255771685715893e-10*V02*V032*V04*V08 + 5.51372149754177856e-11*V022*V042*V08 + 
      2.54174166457058009e-10*V01*V03*V042*V08 + 2.09757140803781025e-10*V022*V03*V05*V08 + 
      2.48540229250877708e-10*V01*V032*V05*V08 + 2.5534630114295358e-10*V01*V02*V04*V05*V08 + 
      3.55537576199033233e-11*V012*V052*V08 - 7.41718453423337579e-11*V04*V052*V08 + 
      1.27541569802581361e-11*V023*V06*V08 + 1.8086421825184335e-10*V01*V02*V03*V06*V08 + 
      5.24600512141898831e-11*V012*V04*V06*V08 - 4.4634629696567675e-11*V042*V06*V08 - 
      1.06465580947736599e-10*V03*V05*V06*V08 - 1.61793688506655506e-11*V02*V062*V08 + 
      2.9965305829111575e-11*V01*V022*V07*V08 + 3.28863762865051076e-11*V012*V03*V07*V08 - 
      7.22184165366019031e-11*V03*V04*V07*V08 - 3.65672326448746265e-11*V02*V05*V07*V08 - 
      1.58851445341324774e-11*V01*V06*V07*V08 + 4.81429545930922416e-12*V012*V02*V082 - 
      1.00567311914564964e-11*V032*V082 - 8.49608394495698954e-12*V02*V04*V082 - 
      6.1646152851312787e-12*V01*V05*V082 + 9.4887905784810694e-14*V083 + 
      7.50950919461509207e-11*V02*V033*V09 + 1.02119513718598406e-10*V022*V03*V04*V09 + 
      1.28440672102984811e-10*V01*V032*V04*V09 + 6.31957149533574338e-11*V01*V02*V042*V09 + 
      1.62685656335429029e-11*V023*V05*V09 + 1.32923002168697043e-10*V01*V02*V03*V05*V09 + 
      3.69364418100398072e-11*V012*V04*V05*V09 - 3.79694474739357151e-11*V042*V05*V09 - 
      3.9034308676048156e-11*V03*V052*V09 + 2.23291577485222351e-11*V01*V022*V06*V09 + 
      2.50290819078244188e-11*V012*V03*V06*V09 - 5.49219470293534729e-11*V03*V04*V06*V09 - 
      2.76958345878698167e-11*V02*V05*V06*V09 - 6.06184731941184335e-12*V01*V062*V09 + 
      8.94597365597926538e-12*V012*V02*V07*V09 - 1.89037760065707799e-11*V032*V07*V09 - 
      1.85289155193646286e-11*V02*V04*V07*V09 - 1.15536048336506895e-11*V01*V05*V07*V09 + 
      7.95055001224887219e-13*V013*V08*V09 - 1.05951063776393714e-11*V02*V03*V08*V09 - 
      6.41284233545450153e-12*V01*V04*V08*V09 + 5.55883324588347876e-13*V07*V08*V09 - 
      6.65118998787311756e-13*V022*V092 - 1.64515184248772008e-12*V01*V03*V092 + 
      2.13608060848841071e-13*V06*V092 + 2.37158096442747268e-11*V022*V032*V10 + 
      1.78646809595064318e-11*V01*V033*V10 + 3.93339699765279626e-12*V023*V04*V10 + 
      5.70557438613053632e-11*V01*V02*V03*V04*V10 + 8.29135109407503231e-12*V012*V042*V10 - 
      4.86945810336921357e-12*V043*V10 + 1.42294857865648361e-11*V01*V022*V05*V10 + 
      1.51736511538758572e-11*V012*V03*V05*V10 - 3.53050072330784785e-11*V03*V04*V05*V10 - 
      8.97064762190009636e-12*V02*V052*V10 + 5.88941853542087871e-12*V012*V02*V06*V10 - 
      1.25932366524160681e-11*V032*V06*V10 - 1.05676700348517258e-11*V02*V04*V06*V10 - 
      7.71623126310894452e-12*V01*V05*V06*V10 + 6.36406082595999729e-13*V013*V07*V10 - 
      8.72294959529437055e-12*V02*V03*V07*V10 - 5.25867723896048924e-12*V01*V04*V07*V10 + 
      2.28898431203407425e-13*V072*V10 - 9.97338905526024202e-13*V022*V08*V10 - 
      2.8782774654125242e-12*V01*V03*V08*V10 + 3.60135174475426985e-13*V06*V08*V10 - 7.71781383693338668e-13*V01*V02*V09*V10 + 
      2.76443023372544839e-13*V05*V09*V10 - 4.96460571321507087e-14*V012*V102 + 
      6.10495166679236661e-14*V04*V102 + 2.9579210242805278e-12*V023*V03*V11 + 
      1.16146626148653275e-11*V01*V02*V032*V11 + 5.57015529374173124e-12*V01*V022*V04*V11 + 
      6.37387447085132202e-12*V012*V03*V04*V11 - 7.35191647879915301e-12*V03*V042*V11 + 
      3.33627493944288791e-12*V012*V02*V05*V11 - 7.47447845867108231e-12*V032*V05*V11 - 
      7.3704400826648317e-12*V02*V04*V05*V11 - 2.27772842501028492e-12*V01*V052*V11 + 
      3.92839496530436844e-13*V013*V06*V11 - 5.35591512045307342e-12*V02*V03*V06*V11 - 
      3.2534226911779279e-12*V01*V04*V06*V11 - 8.87941756531218918e-13*V022*V07*V11 - 
      2.18868978399247471e-12*V01*V03*V07*V11 + 2.88103562668946431e-13*V06*V07*V11 - 6.25646721041756942e-13*V01*V02*V08*V11 + 
      2.26356906084163136e-13*V05*V08*V11 - 9.17518543701169467e-14*V012*V09*V11 + 
      1.18720485286494369e-13*V04*V09*V11 + 5.55963333795981137e-14*V03*V10*V11 + 6.08766127182957582e-15*V02*V112 + 
      6.97126310184236409e-14*V024*V12 + 2.14508023030128266e-12*V01*V022*V03*V12 + 
      1.08549131494993563e-12*V012*V032*V12 + 1.25421574306927669e-12*V012*V02*V04*V12 - 
      2.87395694078467199e-12*V032*V04*V12 - 1.18073000878447294e-12*V02*V042*V12 + 
      1.96419748265218422e-13*V013*V05*V12 - 2.93488217411979218e-12*V02*V03*V05*V12 - 
      1.75892385028531593e-12*V01*V04*V05*V12 - 4.24427157495073098e-13*V022*V06*V12 - 
      1.24049252083159444e-12*V01*V03*V06*V12 + 7.90915954466652055e-14*V062*V12 - 
      4.35830349941432114e-13*V01*V02*V07*V12 + 1.58221233806604946e-13*V05*V07*V12 - 
      6.83918592447986524e-14*V012*V08*V12 + 8.47838077594851237e-14*V04*V08*V12 + 
      4.71921138034589144e-14*V03*V09*V12 + 1.06064692652075795e-14*V02*V10*V12 + 2.94712436112520976e-15*V01*V11*V12 + 
      1.13766193241558761e-13*V01*V023*V13 + 4.018188964103246e-13*V012*V02*V03*V13 - 
      3.39446113184688056e-13*V033*V13 + 6.98943070573740386e-14*V013*V04*V13 - 
      1.02076494598224435e-12*V02*V03*V04*V13 - 3.115083629311985e-13*V01*V042*V13 - 
      2.52986278945218013e-13*V022*V05*V13 - 6.15808787097615085e-13*V01*V03*V05*V13 - 
      2.26529352821879131e-13*V01*V02*V06*V13 + 8.4727092316375805e-14*V05*V06*V13 - 
      4.35519694409946241e-14*V012*V07*V13 + 5.78301316721366918e-14*V04*V07*V13 + 
      3.28743702409754702e-14*V03*V08*V13 + 8.79555959489167708e-15*V02*V09*V13 + 2.50710033784371886e-15*V01*V10*V13 - 
      1.28605817626567052e-17*V132 + 3.39150527734733347e-14*V012*V022*V14 + 
      1.97689836410821881e-14*V013*V03*V14 - 1.74504919696047553e-13*V02*V032*V14 - 
      6.88531028421720269e-14*V022*V04*V14 - 2.06827059977782492e-13*V01*V03*V04*V14 - 
      1.06625347370051632e-13*V01*V02*V05*V14 + 2.01573940483405383e-14*V052*V14 - 
      2.15718046925592802e-14*V012*V06*V14 + 2.74241246925085559e-14*V04*V06*V14 + 1.9914991776080897e-14*V03*V07*V14 + 
      5.42456758466606654e-15*V02*V08*V14 + 1.84487798792354805e-15*V01*V09*V14 - 2.36008514869398616e-17*V12*V14 + 
      3.21837869905342508e-15*V013*V02*V15 - 2.63042546300521179e-14*V022*V03*V15 - 
      3.10484279082444893e-14*V01*V032*V15 - 3.24148583247491478e-14*V01*V02*V04*V15 - 
      9.13844236549065366e-15*V012*V05*V15 + 1.28653803882824346e-14*V04*V05*V15 + 
      9.30702659603714739e-15*V03*V06*V15 + 3.24213499459520527e-15*V02*V07*V15 + 1.12131899680374015e-15*V01*V08*V15 - 
      1.94978857487673357e-17*V11*V15 + 9.24821465245237093e-17*V014*V16 - 1.00713504338861027e-15*V023*V16 - 
      9.5489022575438441e-15*V01*V02*V03*V16 - 2.74127804866401263e-15*V012*V04*V16 + 
      1.82135143557975467e-15*V042*V16 + 3.8926459245492656e-15*V03*V05*V16 + 1.34458139769482602e-15*V02*V06*V16 + 
      5.97447399597582336e-16*V01*V07*V16 - 1.34599721373616975e-17*V10*V16 - 6.48500895281529732e-16*V01*V022*V17 - 
      7.04231440969786193e-16*V012*V03*V17 + 1.10490698998487486e-15*V03*V04*V17 + 
      5.64120095437823358e-16*V02*V05*V17 + 2.48213369185554833e-16*V01*V06*V17 - 8.39360579453806537e-18*V09*V17 - 
      9.91837513451413694e-17*V012*V02*V18 + 1.48092063326009053e-16*V032*V18 + 
      1.40635411028935136e-16*V02*V04*V18 + 9.20552542974503644e-17*V01*V05*V18 - 4.25846563971969208e-18*V08*V18 - 
      4.02096289237059606e-18*V013*V19 + 3.88268644623851834e-17*V02*V03*V19 + 2.36131045854463253e-17*V01*V04*V19 - 
      1.97123450811280778e-18*V07*V19 + 2.17400060380836893e-18*V022*V20 + 5.6072327534107962e-18*V01*V03*V20 - 
      6.98636983815406448e-19*V06*V20 + 6.77532247364445436e-19*V01*V02*V21 - 2.31689371103909438e-19*V05*V21 + 
      4.22201103698912586e-20*V012*V22 - 5.14534325671867014e-20*V04*V22 - 1.1374112626103862e-20*V03*V23 - 
      1.19139641255425068e-21*V02*V24 - 1.48924551569281335e-22*V01*V25 + 1.60479042639311784e-25*V28) + 
   delta8*eps10*(-3.48353822487445235e-10*V036 - 5.63618331860497148e-9*V02*V034*V04 - 
      7.52142487857241595e-9*V022*V032*V042 - 6.31557116084406533e-9*V01*V033*V042 - 
      1.18235613578975095e-10*V023*V043 - 6.20497920477853972e-9*V01*V02*V03*V043 - 
      4.68244180888229736e-10*V012*V044 + 2.04522364126337295e-10*V045 - 
      5.69957259001663313e-9*V022*V033*V05 - 2.91870821835366133e-9*V01*V034*V05 - 
      4.75996246502304676e-9*V023*V03*V04*V05 - 1.94477609941236912e-8*V01*V02*V032*V04*V05 - 
      4.51285492714344957e-9*V01*V022*V042*V05 - 5.29793573792971798e-9*V012*V03*V042*V05 + 
      5.59571374853810928e-9*V03*V043*V05 - 2.76558300226923378e-10*V024*V052 - 
      4.94975404004256773e-9*V01*V022*V03*V052 - 2.375237797497436e-9*V012*V032*V052 - 
      2.73842679842908882e-9*V012*V02*V04*V052 + 8.44899434558817426e-9*V032*V04*V052 + 
      4.17434942425085623e-9*V02*V042*V052 - 1.38131989351095415e-10*V013*V053 + 
      2.90352382085443044e-9*V02*V03*V053 + 1.70184735404769042e-9*V01*V04*V053 - 
      1.73954584163477662e-9*V023*V032*V06 - 4.40434437955229898e-9*V01*V02*V033*V06 - 
      5.87254203673968461e-11*V024*V04*V06 - 6.49781876600089265e-9*V01*V022*V03*V04*V06 - 
      3.5490267205211955e-9*V012*V032*V04*V06 - 1.97199129312179211e-9*V012*V02*V042*V06 + 
      6.04178321890165732e-9*V032*V042*V06 + 1.45494291493694489e-9*V02*V043*V06 - 
      1.04372750498086597e-9*V01*V023*V05*V06 - 3.67813736079536552e-9*V012*V02*V03*V05*V06 + 
      3.94832555048672289e-9*V033*V05*V06 - 6.34555710698009723e-10*V013*V04*V05*V06 + 
      1.21278448455036406e-8*V02*V03*V04*V05*V06 + 3.68117797660595973e-9*V01*V042*V05*V06 + 
      1.50086149642047213e-9*V022*V052*V06 + 3.55613591527038345e-9*V01*V03*V052*V06 - 
      3.44719728612722945e-10*V012*V022*V062 - 2.08773784678927438e-10*V013*V03*V062 + 
      2.18499743603896193e-9*V02*V032*V062 + 7.73560057249388023e-10*V022*V04*V062 + 
      2.61697161424435874e-9*V01*V03*V04*V062 + 1.33089573649811817e-9*V01*V02*V05*V062 - 
      2.15515965268820468e-10*V052*V062 + 9.16959769356950817e-11*V012*V063 - 
      9.67413716629006364e-11*V04*V063 - 2.63388857358974646e-10*V024*V03*V07 - 
      2.27137749955722174e-9*V01*V022*V032*V07 - 7.11282704434497315e-10*V012*V033*V07 - 
      6.79994637860435252e-10*V01*V023*V04*V07 - 2.48766852904853134e-9*V012*V02*V03*V04*V07 + 
      2.70257970473577217e-9*V033*V04*V07 - 2.15513291631896969e-10*V013*V042*V07 + 
      4.03779812962716808e-9*V02*V03*V042*V07 + 8.24512636044631884e-10*V01*V043*V07 - 
      6.39821675829280626e-10*V012*V022*V05*V07 - 3.68508356270347032e-10*V013*V03*V05*V07 + 
      4.1867374435375795e-9*V02*V032*V05*V07 + 1.98341983515254212e-9*V022*V04*V05*V07 + 
      4.87810293002306012e-9*V01*V03*V04*V05*V07 + 1.26645435615914452e-9*V01*V02*V052*V07 - 
      1.34822783062642816e-10*V053*V07 - 1.47932961866283733e-10*V013*V02*V06*V07 + 
      1.45131577655238092e-9*V022*V03*V06*V07 + 1.69420034313961507e-9*V01*V032*V06*V07 + 
      1.78593788867828818e-9*V01*V02*V04*V06*V07 + 4.97484348880810243e-10*V012*V05*V06*V07 - 
      5.91527317494421009e-10*V04*V05*V06*V07 - 2.14111837640765805e-10*V03*V062*V07 - 
      4.98460273337877888e-12*V014*V072 + 7.75456826903812862e-11*V023*V072 + 
      6.04883423727214372e-10*V01*V02*V03*V072 + 1.71199337557789747e-10*V012*V04*V072 - 
      1.01035142618061238e-10*V042*V072 - 2.00437065382737022e-10*V03*V05*V072 - 
      7.51436497578171893e-11*V02*V06*V072 - 1.034089196038987e-11*V01*V073 - 
      1.90317570721649182e-12*V025*V08 - 3.82821435828408598e-10*V01*V023*V03*V08 - 
      6.21948995444348751e-10*V012*V02*V032*V08 + 3.62822522193854791e-10*V034*V08 - 
      3.51341006389575525e-10*V012*V022*V04*V08 - 2.10733814299509583e-10*V013*V03*V04*V08 + 
      2.29129168331781158e-9*V02*V032*V04*V08 + 4.00038718360123285e-10*V022*V042*V08 + 
      1.37391448269021764e-9*V01*V03*V042*V08 - 1.09914167977695533e-10*V013*V02*V05*V08 + 
      1.14273217810063096e-9*V022*V03*V05*V08 + 1.29747898633794244e-9*V01*V032*V05*V08 + 
      1.39521690195051682e-9*V01*V02*V04*V05*V08 + 1.89817244764465933e-10*V012*V052*V08 - 
      2.32345054050319718e-10*V04*V052*V08 - 8.4691450501297832e-12*V014*V06*V08 + 
      9.40480899945783424e-11*V023*V06*V08 + 9.92961990520016034e-10*V01*V02*V03*V06*V08 + 
      2.88801564071787016e-10*V012*V04*V06*V08 - 1.55454334755832098e-10*V042*V06*V08 - 
      3.35167087204343158e-10*V03*V05*V06*V08 - 5.74591434619374414e-11*V02*V062*V08 + 
      1.68078190530655331e-10*V01*V022*V07*V08 + 1.7922784297330001e-10*V012*V03*V07*V08 - 
      2.30627741795751109e-10*V03*V04*V07*V08 - 1.1847375577040188e-10*V02*V05*V07*V08 - 
      5.20635310606352351e-11*V01*V06*V07*V08 + 2.73302791010986286e-11*V012*V02*V082 - 
      3.23689884485910393e-11*V032*V082 - 3.0687952430678249e-11*V02*V04*V082 - 
      2.02660877457561619e-11*V01*V05*V082 + 2.5478272581313858e-13*V083 - 
      2.19490714465812205e-11*V01*V024*V09 - 1.63453537653180961e-10*V012*V022*V03*V09 - 
      4.5621590851981985e-11*V013*V032*V09 + 3.9451350045098616e-10*V02*V033*V09 - 
      5.63016510897856419e-11*V013*V02*V04*V09 + 5.67847963196590586e-10*V022*V03*V04*V09 + 
      6.83497674924997587e-10*V01*V032*V04*V09 + 3.52039989815995021e-10*V01*V02*V042*V09 - 
      5.54652425566178494e-12*V014*V05*V09 + 9.18275435053114489e-11*V023*V05*V09 + 
      7.11472707603287305e-10*V01*V02*V03*V05*V09 + 2.00808560272265483e-10*V012*V04*V05*V09 - 
      1.22379251573796394e-10*V042*V05*V09 - 1.2104186629599732e-10*V03*V052*V09 + 
      1.26423950179252656e-10*V01*V022*V06*V09 + 1.3777207229766087e-10*V012*V03*V06*V09 - 
      1.77770794499627443e-10*V03*V04*V06*V09 - 9.09454281396483529e-11*V02*V05*V06*V09 - 
      2.01178788126795057e-11*V01*V062*V09 + 4.98127842058461555e-11*V012*V02*V07*V09 - 
      5.97734920434934253e-11*V032*V07*V09 - 6.17065865165672288e-11*V02*V04*V07*V09 - 
      3.73422990754700221e-11*V01*V05*V07*V09 + 4.6326605235350596e-12*V013*V08*V09 - 
      3.54902394595375172e-11*V02*V03*V08*V09 - 2.16182468692036307e-11*V01*V04*V08*V09 + 1.44416410754209022e-12*V07*V08*V09 - 
      2.31982052822957649e-12*V022*V092 - 5.50043602650990372e-12*V01*V03*V092 + 
      5.60756891947137004e-13*V06*V092 - 1.25177421440102926e-11*V012*V023*V10 - 
      2.16603545160845274e-11*V013*V02*V03*V10 + 1.33909625510296353e-10*V022*V032*V10 + 
      9.76607742790705792e-11*V01*V033*V10 - 2.52831391454603897e-12*V014*V04*V10 + 
      2.97886436303311412e-11*V023*V04*V10 + 3.23010487473487697e-10*V01*V02*V03*V04*V10 + 
      4.70550540341506635e-11*V012*V042*V10 - 1.75022677593823745e-11*V043*V10 + 
      8.14695838240757881e-11*V01*V022*V05*V10 + 8.48788142856757976e-11*V012*V03*V05*V10 - 
      1.14552171393243433e-10*V03*V04*V05*V10 - 2.95108352868355473e-11*V02*V052*V10 + 
      3.39326742656223317e-11*V012*V02*V06*V10 - 4.10807357303802357e-11*V032*V06*V10 - 
      3.87061693537785587e-11*V02*V04*V06*V10 - 2.57011365522157467e-11*V01*V05*V06*V10 + 
      3.73548841761136647e-12*V013*V07*V10 - 2.92217665576245852e-11*V02*V03*V07*V10 - 
      1.77384521140662386e-11*V01*V04*V07*V10 + 5.93962491830135727e-13*V072*V10 - 
      3.78246057178661458e-12*V022*V08*V10 - 9.79616287622452431e-12*V01*V03*V08*V10 + 
      9.76297712086681666e-13*V06*V08*V10 - 2.72121658140061301e-12*V01*V02*V09*V10 + 7.25084909932484695e-13*V05*V09*V10 - 
      1.78323033133655411e-13*V012*V102 + 1.69575297984627578e-13*V04*V102 - 
      2.29222549089823485e-12*V013*V022*V11 - 8.44435983486121085e-13*V014*V03*V11 + 
      1.74364153827111444e-11*V023*V03*V11 + 6.5728760123736834e-11*V01*V02*V032*V11 + 
      3.281694442754688e-11*V01*V022*V04*V11 + 3.66814218986499327e-11*V012*V03*V04*V11 - 
      2.47814438354677427e-11*V03*V042*V11 + 1.92631247960223483e-11*V012*V02*V05*V11 - 
      2.4270321576788209e-11*V032*V05*V11 - 2.51925693621858727e-11*V02*V04*V05*V11 - 
      7.5569455661131593e-12*V01*V052*V11 + 2.35164218730202385e-12*V013*V06*V11 - 
      1.83757610573746442e-11*V02*V03*V06*V11 - 1.12271506506756399e-11*V01*V04*V06*V11 - 
      3.13110455057833352e-12*V022*V07*V11 - 7.39832471867915497e-12*V01*V03*V07*V11 + 
      7.60245426486413122e-13*V06*V07*V11 - 2.22886744666734419e-12*V01*V02*V08*V11 + 5.97517127561872589e-13*V05*V08*V11 - 
      3.27626045988909981e-13*V012*V09*V11 + 3.21185006823789825e-13*V04*V09*V11 + 
      1.50808308443720851e-13*V03*V10*V11 + 1.72946818913936683e-14*V02*V112 - 
      1.63138506469259823e-13*V014*V02*V12 + 5.58419531667944093e-13*V024*V12 + 
      1.28764372320438753e-11*V01*V022*V03*V12 + 6.45396832557506403e-12*V012*V032*V12 + 
      7.54254792767127526e-12*V012*V02*V04*V12 - 9.75145473881211404e-12*V032*V04*V12 - 
      4.50376637938931664e-12*V02*V042*V12 + 1.20158353693452675e-12*V013*V05*V12 - 
      1.00839260572710666e-11*V02*V03*V05*V12 - 6.08782612914198772e-12*V01*V04*V05*V12 - 
      1.6484320757807942e-12*V022*V06*V12 - 4.31836552247896612e-12*V01*V03*V06*V12 + 
      2.17717556668614242e-13*V062*V12 - 1.55274369081896802e-12*V01*V02*V07*V12 + 
      4.16717345659387109e-13*V05*V07*V12 - 2.47998588843422056e-13*V012*V08*V12 + 
      2.36849734453498605e-13*V04*V08*V12 + 1.27868089741642656e-13*V03*V09*V12 + 3.09373294846011127e-14*V02*V10*V12 + 
      8.44356355298828722e-15*V01*V11*V12 - 3.88425015402999579e-15*V015*V13 + 
      7.1809920585718673e-13*V01*V023*V13 + 2.48945291657643411e-12*V012*V02*V03*V13 - 
      1.16160373954814387e-12*V033*V13 + 4.43525878302310805e-13*V013*V04*V13 - 
      3.66707114608416697e-12*V02*V03*V04*V13 - 1.12477065389886273e-12*V01*V042*V13 - 
      9.21441289700999496e-13*V022*V05*V13 - 2.15189828220726337e-12*V01*V03*V05*V13 - 
      8.31430815663206351e-13*V01*V02*V06*V13 + 2.27749640225126443e-13*V05*V06*V13 - 
      1.58376245559656605e-13*V012*V07*V13 + 1.57655305342467814e-13*V04*V07*V13 + 
      8.99693016116435438e-14*V03*V08*V13 + 2.50465583102290494e-14*V02*V09*V13 + 7.20849329211898222e-15*V01*V10*V13 - 
      3.21803883195180805e-17*V132 + 2.18045156860869549e-13*V012*V022*V14 + 
      1.30270351594444097e-13*V013*V03*V14 - 6.30326478088255669e-13*V02*V032*V14 - 
      2.80122041894993088e-13*V022*V04*V14 - 7.52745557853500325e-13*V01*V03*V04*V14 - 
      3.92273981607649023e-13*V01*V02*V05*V14 + 5.40803287586297931e-14*V052*V14 - 
      8.04948184417643853e-14*V012*V06*V14 + 7.80891139128618399e-14*V04*V06*V14 + 
      5.43740781719425874e-14*V03*V07*V14 + 1.597202818528769e-14*V02*V08*V14 + 5.29724316851910525e-15*V01*V09*V14 - 
      5.95245198917411751e-17*V12*V14 + 2.21957151658856902e-14*V013*V02*V15 - 
      1.00947915306144865e-13*V022*V03*V15 - 1.14771751173946253e-13*V01*V032*V15 - 
      1.24857632920951728e-13*V01*V02*V04*V15 - 3.4513834462590702e-14*V012*V05*V15 + 
      3.58028429140039697e-14*V04*V05*V15 + 2.59899778457856372e-14*V03*V06*V15 + 9.32107114925971582e-15*V02*V07*V15 + 
      3.25854476754579703e-15*V01*V08*V15 - 4.88025821976709744e-17*V11*V15 + 6.9361609893392782e-16*V014*V16 - 
      4.38463664730278108e-15*V023*V16 - 3.70702621454876177e-14*V01*V02*V03*V16 - 
      1.07299394782909356e-14*V012*V04*V16 + 5.38104465524185602e-15*V042*V16 + 
      1.08618951941430341e-14*V03*V05*V16 + 4.04737615083692379e-15*V02*V06*V16 + 1.73388722735808211e-15*V01*V07*V16 - 
      3.40357899883500811e-17*V10*V16 - 2.66841149944943681e-15*V01*V022*V17 - 
      2.82321857080570476e-15*V012*V03*V17 + 3.20146552388739126e-15*V03*V04*V17 + 
      1.65932740599216357e-15*V02*V05*V17 + 7.37439568257151854e-16*V01*V06*V17 - 2.10418823120977985e-17*V09*V17 - 
      4.14661798275717718e-16*V012*V02*V18 + 4.31147746134437162e-16*V032*V18 + 
      4.40295436714580268e-16*V02*V04*V18 + 2.73892913617438614e-16*V01*V05*V18 - 1.08451911250036055e-17*V08*V18 - 
      1.75917126541213578e-17*V013*V19 + 1.19137779698530452e-16*V02*V03*V19 + 7.29134604483201418e-17*V01*V04*V19 - 
      4.96989816781859134e-18*V07*V19 + 7.22432999662583758e-18*V022*V20 + 1.74509789528883869e-17*V01*V03*V20 - 
      1.80799724339092158e-18*V06*V20 + 2.21655579441929108e-18*V01*V02*V21 - 5.93510876925951522e-19*V05*V21 + 
      1.40733701232970862e-19*V012*V22 - 1.37382898822662032e-19*V04*V22 - 3.01572216927794704e-20*V03*V23 - 
      3.35080241030883005e-21*V02*V24 - 4.18850301288603756e-22*V01*V25 + 4.0119760659827946e-25*V28) + 
   eps14*(-4.44285396439000936e-8*V012*V026 - 2.38124362318310731e-7*V013*V024*V03 - 
      1.91046128236108395e-7*V014*V022*V032 + 8.47814123243652694e-8*V025*V032 - 
      1.35979953688287022e-8*V015*V033 + 4.85554468215240858e-7*V01*V023*V033 + 
      2.73534843558599589e-7*V012*V02*V034 - 5.66691941869923714e-9*V036 - 
      8.77483361362329616e-8*V014*V023*V04 + 1.66609565924847593e-8*V026*V04 - 
      5.61693735056830295e-8*V015*V02*V03*V04 + 5.31943375712827938e-7*V01*V024*V03*V04 + 
      1.23637235775819508e-6*V012*V022*V032*V04 + 
      1.92166939849085624e-7*V013*V033*V04 - 1.23357570532137392e-7*V02*V034*V04 - 
      1.71415954526073574e-9*V016*V042 + 3.15099921017591905e-7*V012*V023*V042 + 
      4.38158827637666048e-7*V013*V02*V03*V042 - 2.6288958283670669e-7*V022*V032*V042 - 
      1.49320092000854684e-7*V01*V033*V042 + 1.81036536333863598e-8*V014*V043 - 
      3.84541066603365207e-8*V023*V043 - 2.18275281392033712e-7*V01*V02*V03*V043 - 
      1.62557222292894705e-8*V012*V044 + 1.23616495716322489e-9*V045 - 
      1.47743203298758854e-8*V015*V022*V05 + 6.3486237399161944e-8*V01*V025*V05 - 
      2.61963152588152588e-9*V016*V03*V05 + 5.04749092373161098e-7*V012*V023*V03*V05 + 
      3.52991140766754484e-7*V013*V02*V032*V05 - 1.49577749258686372e-7*V022*V033*V05 - 
      6.20592452742179181e-8*V01*V034*V05 + 2.69761723133219301e-7*V013*V022*V04*V05 + 
      8.77107272725415816e-8*V014*V03*V04*V05 - 2.09818162328113677e-7*V023*V03*V04*V05 - 
      5.48198735129195742e-7*V01*V02*V032*V04*V05 - 1.98662769889577042e-7*V01*V022*V042*V05 - 
      1.6042882424496805e-7*V012*V03*V042*V05 + 2.15636899144237912e-8*V03*V043*V05 + 
      2.67278282813924154e-8*V014*V02*V052 - 1.55886771333317162e-8*V024*V052 - 
      1.67299596589608388e-7*V01*V022*V03*V052 - 
      6.60736192207424135e-8*V012*V032*V052 - 
      9.87358270157971727e-8*V012*V02*V04*V052 + 2.75385910139636236e-8*V032*V04*V052 + 
      1.95974610187973338e-8*V02*V042*V052 - 5.0322316333669934e-9*V013*V053 + 
      1.11939649437148335e-8*V02*V03*V053 + 6.96824490892339008e-9*V01*V04*V053 - 
      1.11409616617949951e-9*V016*V02*V06 + 6.65795095057685511e-8*V012*V024*V06 + 
      1.83568097555524123e-7*V013*V022*V03*V06 + 2.97925711255105513e-8*V014*V032*V06 - 
      7.51309637948993831e-8*V023*V032*V06 - 1.2851692907095802e-7*V01*V02*V033*V06 + 
      4.49398509403761505e-8*V014*V02*V04*V06 - 2.45969778812155529e-8*V024*V04*V06 - 
      2.81476680443194741e-7*V01*V022*V03*V04*V06 - 1.11990144232753333e-7*V012*V032*V04*V06 - 
      8.39195240244391173e-8*V012*V02*V042*V06 + 2.30850772817083477e-8*V032*V042*V06 + 
      1.07019465801876516e-8*V02*V043*V06 + 3.34093899905641269e-9*V015*V05*V06 - 
      5.68612789544256521e-8*V01*V023*V05*V06 - 1.37946216092929594e-7*V012*V02*V03*V05*V06 + 
      1.30513790433038994e-8*V033*V05*V06 - 2.5648829174374078e-8*V013*V04*V05*V06 + 
      5.61239769146853626e-8*V02*V03*V04*V05*V06 + 1.76001840353159858e-8*V01*V042*V05*V06 + 
      8.48834586634070483e-9*V022*V052*V06 + 1.47938814807311634e-8*V01*V03*V052*V06 - 
      1.80369720913617452e-8*V012*V022*V062 - 8.88476205467893865e-9*V013*V03*V062 + 
      1.00226471812315941e-8*V02*V032*V062 + 6.94477230572795859e-9*V022*V04*V062 + 
      1.24772222583550127e-8*V01*V03*V04*V062 + 7.65341039943219654e-9*V01*V02*V05*V062 - 
      4.00421842173653072e-10*V052*V062 + 5.42508390784734171e-10*V012*V063 - 
      2.22402533455576898e-10*V04*V063 - 3.01107071940405274e-11*V017*V07 + 
      2.77283134599238124e-8*V013*V023*V07 + 2.64719083561724785e-8*V014*V02*V03*V07 - 
      1.63832980432584913e-8*V024*V03*V07 - 8.67821980500707419e-8*V01*V022*V032*V07 - 
      2.26562275544794585e-8*V012*V033*V07 + 2.42602052206102159e-9*V015*V04*V07 - 
      4.17244583788554264e-8*V01*V023*V04*V07 - 1.01754981256123818e-7*V012*V02*V03*V04*V07 + 
      9.61933163483392822e-9*V033*V04*V07 - 9.46603145239704213e-9*V013*V042*V07 + 
      2.06181050369082218e-8*V02*V03*V042*V07 + 4.32428629621820677e-9*V01*V043*V07 - 
      3.12950296226941361e-8*V012*V022*V05*V07 - 1.54385614355878046e-8*V013*V03*V05*V07 + 
      1.76198113679567036e-8*V02*V032*V05*V07 + 1.24514430520378678e-8*V022*V04*V05*V07 + 
      2.18382321119836989e-8*V01*V03*V04*V05*V07 + 6.7076755062824439e-9*V01*V02*V052*V07 - 
      2.34661747410824179e-10*V053*V07 - 8.10809190164792969e-9*V013*V02*V06*V07 + 
      8.93730376339007827e-9*V022*V03*V06*V07 + 7.72142743457785924e-9*V01*V032*V06*V07 + 
      1.12813037607382006e-8*V01*V02*V04*V06*V07 + 2.83745875649115152e-9*V012*V05*V06*V07 - 
      1.18025293159619893e-9*V04*V05*V06*V07 - 4.22181735978734033e-10*V03*V062*V07 - 
      3.18691793748441956e-10*V014*V072 + 6.57786841443475241e-10*V023*V072 + 
      3.50638547974525262e-9*V01*V02*V03*V072 + 1.04890139026294974e-9*V012*V04*V072 - 
      2.17336706555266237e-10*V042*V072 - 3.70918013728160585e-10*V03*V05*V072 - 
      1.90194226432363861e-10*V02*V06*V072 - 2.51314251998090779e-11*V01*V073 + 
      5.16310067474283161e-9*V014*V022*V08 - 1.18730700632077167e-9*V025*V08 + 
      1.25136556662291956e-9*V015*V03*V08 - 2.29279375669576944e-8*V01*V023*V03*V08 - 
      2.73729662872491818e-8*V012*V02*V032*V08 + 1.32330997386533185e-9*V034*V08 - 
      2.05293337471624539e-8*V012*V022*V04*V08 - 1.00946782145188957e-8*V013*V03*V04*V08 + 
      1.14433490804597708e-8*V02*V032*V04*V08 + 3.9580363656136679e-9*V022*V042*V08 + 
      7.12851884157794588e-9*V01*V03*V042*V08 - 6.24094168156796559e-9*V013*V02*V05*V08 + 
      6.94356978258042249e-9*V022*V03*V05*V08 + 5.97551640081225015e-9*V01*V032*V05*V08 + 
      8.74380863198565107e-9*V01*V02*V04*V05*V08 + 1.09674986486655438e-9*V012*V052*V08 - 
      4.581985947432085e-10*V04*V052*V08 - 5.64122782334582771e-10*V014*V06*V08 + 
      1.14077085538480067e-9*V023*V06*V08 + 6.2033225723360664e-9*V01*V02*V03*V06*V08 + 
      1.86052874460750999e-9*V012*V04*V06*V08 - 3.81590377099588795e-10*V042*V06*V08 - 
      6.55281918259906118e-10*V03*V05*V06*V08 - 1.66926781546952041e-10*V02*V062*V08 + 
      1.4005434568201366e-9*V01*V022*V07*V08 + 1.13979684147809739e-9*V012*V03*V07*V08 - 
      4.83322804309876299e-10*V03*V04*V07*V08 - 2.95582748451497857e-10*V02*V05*V07*V08 - 
      1.33409947208532761e-10*V01*V06*V07*V08 + 2.31526965969625083e-10*V012*V02*V082 - 
      6.69929031241200044e-11*V032*V082 - 9.55031661992683771e-11*V02*V04*V082 - 
      5.17126889322778945e-11*V01*V05*V082 + 4.13107977656135402e-13*V083 + 
      4.2464953233948332e-10*V015*V02*V09 - 2.02019027419996013e-9*V01*V024*V09 - 
      9.89520180800151304e-9*V012*V022*V03*V09 - 2.41562895063108654e-9*V013*V032*V09 + 
      1.90018113274307923e-9*V02*V033*V09 - 3.66727316596148449e-9*V013*V02*V04*V09 + 
      4.05192218156296103e-9*V022*V03*V04*V09 + 3.51340513992207514e-9*V01*V032*V04*V09 + 
      2.56351206321914891e-9*V01*V02*V042*V09 - 3.89765451634726026e-10*V014*V05*V09 + 
      8.1311449232293595e-10*V023*V05*V09 + 4.32302295795212964e-9*V01*V02*V03*V05*V09 + 
      1.29182440988578419e-9*V012*V04*V05*V09 - 2.68529095864056996e-10*V042*V05*V09 - 
      2.29028113383650342e-10*V03*V052*V09 + 1.1142292397210049e-9*V01*V022*V06*V09 + 
      9.07931717762568069e-10*V012*V03*V06*V09 - 3.84555435601096485e-10*V03*V04*V06*V09 - 
      2.35077579863707066e-10*V02*V05*V06*V09 - 5.31194531671469679e-11*V01*V062*V09 + 
      4.15842572147764832e-10*V012*V02*V07*V09 - 1.20677033057322425e-10*V032*V07*V09 - 
      1.7307782150521251e-10*V02*V04*V07*V09 - 9.30875921523964184e-11*V01*V05*V07*V09 + 
      4.27915270305025167e-11*V013*V08*V09 - 9.64922137274363018e-11*V02*V03*V08*V09 - 
      6.0897977955022888e-11*V01*V04*V08*V09 + 2.23672006049290896e-12*V07*V08*V09 - 
      8.61435126001093185e-12*V022*V092 - 1.5101570440934915e-11*V01*V03*V092 + 
      8.90312494831359498e-13*V06*V092 + 1.23985264916637466e-11*V016*V10 - 
      1.08597003336772874e-9*V012*V023*V10 - 1.59037792603074527e-9*V013*V02*V03*V10 + 
      9.21839305565832322e-10*V022*V032*V10 + 5.2290045243083601e-10*V01*V033*V10 - 
      2.07045792763975322e-10*V014*V04*V10 + 4.223102586584077e-10*V023*V04*V10 + 
      2.30531604195516552e-9*V01*V02*V03*V04*V10 + 3.45866196153316002e-10*V012*V042*V10 - 
      4.730140076757285e-11*V043*V10 + 7.06111048292429286e-10*V01*V022*V05*V10 + 
      5.72957043956577621e-10*V012*V03*V05*V10 - 2.43995573875325085e-10*V03*V04*V05*V10 - 
      7.46676721210225473e-11*V02*V052*V10 + 3.01169854286320233e-10*V012*V02*V06*V10 - 
      8.71561659032362657e-11*V032*V06*V10 - 1.24184781432973377e-10*V02*V04*V06*V10 - 
      6.72932958419904147e-11*V01*V05*V06*V10 + 3.49217470015431594e-11*V013*V07*V10 - 
      7.88821815003766501e-11*V02*V03*V07*V10 - 4.97562731181520737e-11*V01*V04*V07*V10 + 
      9.14063254057000579e-13*V072*V10 - 1.55453703275504475e-11*V022*V08*V10 - 
      2.74200591514209273e-11*V01*V03*V08*V10 + 1.61275026622152242e-12*V06*V08*V10 - 9.98822615803830342e-12*V01*V02*V09*V10 + 
      1.13079968870586721e-12*V05*V09*V10 - 6.80460290457835636e-13*V012*V102 + 
      3.01293286387371767e-13*V04*V102 - 2.40416310658712261e-10*V013*V022*V11 - 
      8.17459866166382764e-11*V014*V03*V11 + 1.80452585440968922e-10*V023*V03*V11 + 
      4.7330571674483787e-10*V01*V02*V032*V11 + 3.44422568062248563e-10*V01*V022*V04*V11 + 
      2.81012315314083125e-10*V012*V03*V04*V11 - 5.95582892105503442e-11*V03*V042*V11 + 
      1.74071537746559336e-10*V012*V02*V05*V11 - 5.06728075205236914e-11*V032*V05*V11 - 
      7.27687542032896293e-11*V02*V04*V05*V11 - 1.95355626099852823e-11*V01*V052*V11 + 
      2.31618530300907583e-11*V013*V06*V11 - 5.2207755670901011e-11*V02*V03*V06*V11 - 
      3.297199918412495e-11*V01*V04*V06*V11 - 1.1719434646825447e-11*V022*V07*V11 - 
      2.05337843265451811e-11*V01*V03*V07*V11 + 1.2105816634917136e-12*V06*V07*V11 - 8.31119230639439751e-12*V01*V02*V08*V11 + 
      9.40616387175285778e-13*V05*V08*V11 - 1.24684884587326264e-12*V012*V09*V11 + 
      5.53411506155556774e-13*V04*V09*V11 + 2.5217127119503702e-13*V03*V10*V11 + 3.80558411977371771e-14*V02*V112 - 
      2.25674933949142755e-11*V014*V02*V12 + 1.18826980712085631e-11*V024*V12 + 
      1.31282476206008484e-10*V01*V022*V03*V12 + 5.26689431260876981e-11*V012*V032*V12 + 
      7.88924869784827072e-11*V012*V02*V04*V12 - 2.28704609621203231e-11*V032*V04*V12 - 
      1.62613938571251225e-11*V02*V042*V12 + 1.2343499614481655e-11*V013*V05*V12 - 
      2.8057126377794321e-11*V02*V03*V05*V12 - 1.76754020392417743e-11*V01*V04*V05*V12 - 
      7.11446422836924071e-12*V022*V06*V12 - 1.25639885755102269e-11*V01*V03*V06*V12 + 
      3.69165227756859453e-13*V062*V12 - 5.7461886803326097e-12*V01*V02*V07*V12 + 6.50304802067189682e-13*V05*V07*V12 - 
      9.58157148441811182e-13*V012*V08*V12 + 4.23974042778759694e-13*V04*V08*V12 + 
      2.13299545045710937e-13*V03*V09*V12 + 7.01010201669626122e-14*V02*V10*V12 + 1.86645558392741721e-14*V01*V11*V12 - 
      7.34123279111669205e-13*V015*V13 + 1.11917223375579105e-11*V01*V023*V13 + 
      2.74773798021158917e-11*V012*V02*V03*V13 - 2.71184870502481249e-12*V033*V13 + 
      5.19683538733058212e-12*V013*V04*V13 - 1.17379576815014896e-11*V02*V03*V04*V13 - 
      3.7125710821677119e-12*V01*V042*V13 - 3.57769544470418032e-12*V022*V05*V13 - 
      6.25241942029032562e-12*V01*V03*V05*V13 - 3.26429884921483961e-12*V01*V02*V06*V13 + 3.69055431492914755e-13*V05*V06*V13 - 
      6.14606188580291793e-13*V012*V07*V13 + 2.72738495171039016e-13*V04*V07*V13 + 
      1.52048984007312621e-13*V03*V08*V13 + 5.51653449031946066e-14*V02*V09*V13 + 1.59933365724365125e-14*V01*V10*V13 - 
      4.82840505109887935e-17*V132 + 3.34634624519940854e-12*V012*V022*V14 + 
      1.67527709143313718e-12*V013*V03*V14 - 1.96009308477979693e-12*V02*V032*V14 - 
      1.38589788154165138e-12*V022*V04*V14 - 2.45614126959940437e-12*V01*V03*V04*V14 - 
      1.5188247425853835e-12*V01*V02*V05*V14 + 8.59482153995903017e-14*V052*V14 - 
      3.26537068713583715e-13*V012*V06*V14 + 1.44221830492316582e-13*V04*V06*V14 + 
      9.11392462040902418e-14*V03*V07*V14 + 3.66389488900220047e-14*V02*V08*V14 + 1.17260332723494438e-14*V01*V09*V14 - 
      9.00758329931411365e-17*V12*V14 + 3.84540765248969583e-13*V013*V02*V15 - 
      4.39666189529948373e-13*V022*V03*V15 - 3.80178623655181342e-13*V01*V032*V15 - 
      5.58897255567581823e-13*V01*V02*V04*V15 - 1.42081226422276558e-13*V012*V05*V15 + 
      6.31543037165354444e-14*V04*V05*V15 + 4.53093106098236628e-14*V03*V06*V15 + 2.06422463096400032e-14*V02*V07*V15 + 
      7.32019980438718352e-15*V01*V08*V15 - 7.32308093599298073e-17*V11*V15 + 1.45659380776124842e-14*V014*V16 - 
      3.04692484132274287e-14*V023*V16 - 1.63637306916058396e-13*V01*V02*V03*V16 - 
      4.94650813093645986e-14*V012*V04*V16 + 1.08989807582861954e-14*V042*V16 + 
      1.86396459507237516e-14*V03*V05*V16 + 9.64001727668496181e-15*V02*V06*V16 + 3.8737051788447539e-15*V01*V07*V16 - 
      5.16507406747715027e-17*V10*V16 - 1.6556767067661321e-14*V01*V022*V17 - 
      1.35313945874416845e-14*V012*V03*V17 + 6.10374627756433287e-15*V03*V04*V17 + 
      3.76127654327226431e-15*V02*V05*V17 + 1.71578004959984158e-15*V01*V06*V17 - 3.15897595315700434e-17*V09*V17 - 
      2.63498724540660623e-15*V012*V02*V18 + 8.06592590700502911e-16*V032*V18 + 
      1.16286246847357638e-15*V02*V04*V18 + 6.31725940714921152e-16*V01*V05*V18 - 1.66021090089434833e-17*V08*V18 - 
      1.24398539482715316e-16*V013*V19 + 2.94460138811914213e-16*V02*V03*V19 + 1.87125560603696614e-16*V01*V04*V19 - 
      7.48178331515123269e-18*V07*V19 + 2.53588726412172258e-17*V022*V20 + 4.45623212546971308e-17*V01*V03*V20 - 
      2.83988482374650272e-18*V06*V20 + 7.49155648884796678e-18*V01*V02*V21 - 9.06880710673375232e-19*V05*V21 + 
      4.97594157930861262e-19*V012*V22 - 2.33439234584848493e-19*V04*V22 - 4.9284718784959042e-20*V03*V23 - 
      7.2600718890024651e-21*V02*V24 - 9.07508986125308138e-22*V01*V25 + 6.0179640989741919e-25*V28) + 
   delta6*eps11*(-2.49661808097621507e-9*V036 - 4.26038561333340795e-8*V02*V034*V04 - 
      6.35525387519264992e-8*V022*V032*V042 - 4.83292346032964941e-8*V01*V033*V042 - 
      3.48009271425128996e-9*V023*V043 - 5.21007542194428255e-8*V01*V02*V03*V043 - 
      3.88562403920447723e-9*V012*V044 + 7.74456172615070677e-10*V045 - 
      4.33178344404360152e-8*V022*V033*V05 - 2.14585667164907926e-8*V01*V034*V05 - 
      4.05750607908712866e-8*V023*V03*V04*V05 - 1.49701349905328914e-7*V01*V02*V032*V04*V05 - 
      3.81315232511558995e-8*V01*V022*V042*V05 - 4.14542305333481087e-8*V012*V03*V042*V05 + 
      1.74757770810771918e-8*V03*V043*V05 - 2.39083324048852658e-9*V024*V052 - 
      3.83066196167295525e-8*V01*V022*V03*V052 - 
      1.80376103167323091e-8*V012*V032*V052 - 
      2.15672748820465144e-8*V012*V02*V04*V052 + 2.50208225944889591e-8*V032*V04*V052 + 
      1.33552205247362602e-8*V02*V042*V052 - 1.0931822218562792e-9*V013*V053 + 
      8.75985166357305396e-9*V02*V03*V053 + 5.20810599820024563e-9*V01*V04*V053 - 
      1.48779795339320709e-8*V023*V032*V06 - 3.43121584273838304e-8*V01*V02*V033*V06 - 
      1.78831917683038053e-9*V024*V04*V06 - 5.51184596961167823e-8*V01*V022*V03*V04*V06 - 
      2.80922928946639527e-8*V012*V032*V04*V06 - 1.64962882079455804e-8*V012*V02*V042*V06 + 
      1.8942406412571866e-8*V032*V042*V06 + 5.66450426445252467e-9*V02*V043*V06 - 
      8.92678772035924254e-9*V01*V023*V05*V06 - 2.93794851767513907e-8*V012*V02*V03*V05*V06 + 
      1.18176763577933914e-8*V033*V05*V06 - 5.18481639171417276e-9*V013*V04*V05*V06 + 
      3.89480165738484644e-8*V02*V03*V04*V05*V06 + 1.18938744327780421e-8*V01*V042*V05*V06 + 
      4.93394369258030515e-9*V022*V052*V06 + 1.09980585927146159e-8*V01*V03*V052*V06 - 
      2.90935693102773385e-9*V012*V022*V062 - 1.72637399528795707e-9*V013*V03*V062 + 
      7.0439280037250256e-9*V02*V032*V062 + 3.09503195995822463e-9*V022*V04*V062 + 
      8.48663599829213159e-9*V01*V03*V04*V062 + 4.41494802311360294e-9*V01*V02*V05*V062 - 
      4.84192342238050314e-10*V052*V062 + 3.06606269118169895e-10*V012*V063 - 
      2.3609905663751539e-10*V04*V063 - 2.2769840385605015e-9*V024*V03*V07 - 
      1.79177086843174721e-8*V01*V022*V032*V07 - 5.54028518810008891e-9*V012*V033*V07 - 
      5.79643725583875523e-9*V01*V023*V04*V07 - 2.00156143389004272e-8*V012*V02*V03*V04*V07 + 
      8.24612384933782233e-9*V033*V04*V07 - 1.77952711019574461e-9*V013*V042*V07 + 
      1.32850691831887295e-8*V02*V03*V042*V07 + 2.72810098339074092e-9*V01*V043*V07 - 
      5.17986347072184624e-9*V012*V022*V05*V07 - 3.00001458976562176e-9*V013*V03*V05*V07 + 
      1.30002531630843894e-8*V02*V032*V05*V07 + 6.67320638621514296e-9*V022*V04*V05*V07 + 
      1.5359262313915318e-8*V01*V03*V04*V05*V07 + 4.05369906224963899e-9*V01*V02*V052*V07 - 
      2.95320892275880125e-10*V053*V07 - 1.25602716004587036e-9*V013*V02*V06*V07 + 
      4.89987598832738015e-9*V022*V03*V06*V07 + 5.39008937563491906e-9*V01*V032*V06*V07 + 
      6.05928022089994357e-9*V01*V02*V04*V06*V07 + 1.63292218138416486e-9*V012*V05*V06*V07 - 
      1.35522339946117897e-9*V04*V05*V06*V07 - 4.9177054136235004e-10*V03*V062*V07 - 
      4.42819314702863444e-11*V014*V072 + 2.73300107347243502e-10*V023*V072 + 
      1.98787540226761154e-9*V01*V02*V03*V072 + 5.70839279729497001e-10*V012*V04*V072 - 
      2.36194080412229453e-10*V042*V072 - 4.48932968279637233e-10*V03*V05*V072 - 
      1.80111790128789343e-10*V02*V06*V072 - 2.44145584190784027e-11*V01*V073 - 
      6.1591651792682389e-11*V025*V08 - 3.3205120028876497e-9*V01*V023*V03*V08 - 
      5.12971004917428142e-9*V012*V02*V032*V08 + 1.12654005149410709e-9*V034*V08 - 
      2.99579217556008662e-9*V012*V022*V04*V08 - 1.77931999951134116e-9*V013*V03*V04*V08 + 
      7.57072442063727112e-9*V02*V032*V04*V08 + 1.63909310102557311e-9*V022*V042*V08 + 
      4.56593896082372445e-9*V01*V03*V042*V08 - 9.42611166537989541e-10*V013*V02*V05*V08 + 
      3.86025914024896609e-9*V022*V03*V05*V08 + 4.15757927376058933e-9*V01*V032*V05*V08 + 
      4.73780983192891003e-9*V01*V02*V04*V05*V08 + 6.27676099485222348e-10*V012*V052*V08 - 
      5.31670146918461443e-10*V04*V052*V08 - 7.66171425620634154e-11*V014*V06*V08 + 
      3.95636370021983198e-10*V023*V06*V08 + 3.38492848473740677e-9*V01*V02*V03*V06*V08 + 
      9.88657452675484232e-10*V012*V04*V06*V08 - 3.87119861701422049e-10*V042*V06*V08 - 
      7.695276814491008e-10*V03*V05*V06*V08 - 1.46948279806190887e-10*V02*V062*V08 + 
      5.9700727167391108e-10*V01*V022*V07*V08 + 6.08501502443267155e-10*V012*V03*V07*V08 - 
      5.39598172457962928e-10*V03*V04*V07*V08 - 2.83515124264387506e-10*V02*V05*V07*V08 - 
      1.25932010249151538e-10*V01*V06*V07*V08 + 9.79822849116433203e-11*V012*V02*V082 - 
      7.60321202835209672e-11*V032*V082 - 8.00438662894526186e-11*V02*V04*V082 - 
      4.90581509132273981e-11*V01*V05*V082 + 5.30370390189967646e-13*V083 - 
      1.89748669880041792e-10*V01*V024*V09 - 1.38492783871933339e-9*V012*V022*V03*V09 - 
      3.92619956245540495e-10*V013*V032*V09 + 1.28926976485616982e-9*V02*V033*V09 - 
      4.94435450321130617e-10*V013*V02*V04*V09 + 2.00577754615659779e-9*V022*V03*V04*V09 + 
      2.26381328315603608e-9*V01*V032*V04*V09 + 1.24854198374475265e-9*V01*V02*V042*V09 - 
      5.06266999599834683e-11*V014*V05*V09 + 3.30997431172136471e-10*V023*V05*V09 + 
      2.39176482559352055e-9*V01*V02*V03*V05*V09 + 6.84796104831609499e-10*V012*V04*V05*V09 - 
      2.8964693312899592e-10*V042*V05*V09 - 2.7452581036405451e-10*V03*V052*V09 + 
      4.58543497875720728e-10*V01*V022*V06*V09 + 4.74776799562345758e-10*V012*V03*V06*V09 - 
      4.21594857816365011e-10*V03*V04*V06*V09 - 2.20749527071950243e-10*V02*V05*V06*V09 - 
      4.92822244041278936e-11*V01*V062*V09 + 1.76500396127192128e-10*V012*V02*V07*V09 - 
      1.38689184975927788e-10*V032*V07*V09 - 1.52857352811459595e-10*V02*V04*V07*V09 - 
      8.93272283859778263e-11*V01*V05*V07*V09 + 1.70090809796901564e-11*V013*V08*V09 - 
      8.79396612859014719e-11*V02*V03*V08*V09 - 5.39460898133261518e-11*V01*V04*V08*V09 + 2.94106739734106171e-12*V07*V08*V09 - 
      6.08730636079525797e-12*V022*V092 - 1.3637441496554828e-11*V01*V03*V092 + 
      1.15356416762231491e-12*V06*V092 - 1.10290212716417116e-10*V012*V023*V10 - 
      1.96961668981946391e-10*V013*V02*V03*V10 + 4.73736502833791189e-10*V022*V032*V10 + 
      3.30526268265465486e-10*V01*V033*V10 - 2.40308568958011191e-11*V014*V04*V10 + 
      1.306858449197228e-10*V023*V04*V10 + 1.14855445011369218e-9*V01*V02*V03*V04*V10 + 
      1.68032962650687216e-10*V012*V042*V10 - 4.50591365188107947e-11*V043*V10 + 
      2.95281792295839512e-10*V01*V022*V05*V10 + 2.96087417912995843e-10*V012*V03*V05*V10 - 
      2.70958150839110306e-10*V03*V04*V05*V10 - 7.13538949593980984e-11*V02*V052*V10 + 
      1.23973004586497602e-10*V012*V02*V06*V10 - 9.75850911950480834e-11*V032*V06*V10 - 
      1.02290832413024991e-10*V02*V04*V06*V10 - 6.29210003101351228e-11*V01*V05*V06*V10 + 
      1.37901305728218524e-11*V013*V07*V10 - 7.22394463607154801e-11*V02*V03*V07*V10 - 
      4.42014311579501796e-11*V01*V04*V07*V10 + 1.20693083515099705e-12*V072*V10 - 
      1.04548365252086475e-11*V022*V08*V10 - 2.45525098402197856e-11*V01*V03*V08*V10 + 
      2.04868873712807041e-12*V06*V08*V10 - 7.16738347520472014e-12*V01*V02*V09*V10 + 1.48553413763209583e-12*V05*V09*V10 - 
      4.76362356925007745e-13*V012*V102 + 3.64596047658544612e-13*V04*V102 - 
      2.2225852014699815e-11*V013*V022*V11 - 8.46041473549786817e-12*V014*V03*V11 + 
      6.68071543587624776e-11*V023*V03*V11 + 2.35400430463378888e-10*V01*V02*V032*V11 + 
      1.25999768576681367e-10*V01*V022*V04*V11 + 1.33242160559910272e-10*V012*V03*V04*V11 - 
      6.1093208918199871e-11*V03*V042*V11 + 7.08712637913533671e-11*V012*V02*V05*V11 - 
      5.73967385086297412e-11*V032*V05*V11 - 6.35821678907591332e-11*V02*V04*V05*V11 - 
      1.84336694398277715e-11*V01*V052*V11 + 8.89175146688824675e-12*V013*V06*V11 - 
      4.64625183219576854e-11*V02*V03*V06*V11 - 2.85686697464344414e-11*V01*V04*V06*V11 - 
      8.26546389412233474e-12*V022*V07*V11 - 1.84599259550681866e-11*V01*V03*V07*V11 + 
      1.56758121391240015e-12*V06*V07*V11 - 5.91926806409766088e-12*V01*V02*V08*V11 + 1.22978944900088456e-12*V05*V08*V11 - 
      8.73047668890433673e-13*V012*V09*V11 + 6.79875661187316609e-13*V04*V09*V11 + 
      3.18472665746274171e-13*V03*V10*V11 + 3.86507060780704276e-14*V02*V112 - 
      1.76086006982693143e-12*V014*V02*V12 + 2.65284831789715095e-12*V024*V12 + 
      4.94243888968296153e-11*V01*V022*V03*V12 + 2.4059427713600762e-11*V012*V032*V12 + 
      2.90634455322732559e-11*V012*V02*V04*V12 - 2.40332415562754902e-11*V032*V04*V12 - 
      1.24004736709692699e-11*V02*V042*V12 + 4.62159797731715339e-12*V013*V05*V12 - 
      2.53817340430362582e-11*V02*V03*V05*V12 - 1.54582452810502205e-11*V01*V04*V05*V12 - 
      4.65443001013582812e-12*V022*V06*V12 - 1.10195143774801306e-11*V01*V03*V06*V12 + 
      4.62275445114552831e-13*V062*V12 - 4.11091841812275455e-12*V01*V02*V07*V12 + 
      8.54827264660022273e-13*V05*V07*V12 - 6.6677690271151634e-13*V012*V08*V12 + 5.11140088822477658e-13*V04*V08*V12 + 
      2.69716890703278048e-13*V03*V09*V12 + 7.01887047142654836e-14*V02*V10*V12 + 1.89467326589422553e-14*V01*V11*V12 - 
      4.66110018483599495e-14*V015*V13 + 2.99423691357777777e-12*V01*V023*V13 + 
      9.82167794662163755e-12*V012*V02*V03*V13 - 2.87880905295321031e-12*V033*V13 + 
      1.77930100984392145e-12*V013*V04*V13 - 9.67816167205109803e-12*V02*V03*V04*V13 - 
      2.98580071451049345e-12*V01*V042*V13 - 2.48794034649747452e-12*V022*V05*V13 - 
      5.49948735789160165e-12*V01*V03*V05*V13 - 2.26100990709481797e-12*V01*V02*V06*V13 + 4.7500858695694337e-13*V05*V06*V13 - 
      4.26483138776411711e-13*V012*V07*V13 + 3.34748910337749257e-13*V04*V07*V13 + 
      1.91031803190879603e-13*V03*V08*V13 + 5.60095614202921938e-14*V02*V09*V13 + 1.62074470333207622e-14*V01*V10*V13 - 
      6.43752435954743197e-17*V132 + 9.10425077769586236e-13*V012*V022*V14 + 
      5.39910771410169415e-13*V013*V03*V14 - 1.66140669058117387e-12*V02*V032*V14 - 
      8.28263992410037937e-13*V022*V04*V14 - 2.00219641298408411e-12*V01*V03*V04*V14 - 
      1.06363153783049786e-12*V01*V02*V05*V14 + 1.12234590097211278e-13*V052*V14 - 
      2.21355079481772612e-13*V012*V06*V14 + 1.70954099969788965e-13*V04*V06*V14 + 
      1.15073071065298605e-13*V03*V07*V14 + 3.64577550958467795e-14*V02*V08*V14 + 1.18950180456313298e-14*V01*V09*V14 - 
      1.19600364870750189e-16*V12*V14 + 9.71062538507498948e-14*V013*V02*V15 - 
      2.85947268917745482e-13*V022*V03*V15 - 3.0871699887519981e-13*V01*V032*V15 - 
      3.55411636751721068e-13*V01*V02*V04*V15 - 9.56295552285267934e-14*V012*V05*V15 + 
      7.69887767065883574e-14*V04*V05*V15 + 5.59914492163303378e-14*V03*V06*V15 + 2.09270410588993816e-14*V02*V07*V15 + 
      7.37375232850873924e-15*V01*V08*V15 - 9.76340983082182663e-17*V11*V15 + 3.23687512835832983e-15*V014*V16 - 
      1.39609618717725926e-14*V023*V16 - 1.05698917519649446e-13*V01*V02*V03*V16 - 
      3.08646430976438706e-14*V012*V04*V16 + 1.21795591493021946e-14*V042*V16 + 
      2.33127207864400535e-14*V03*V05*V16 + 9.39590908722569e-15*V02*V06*V16 + 3.91432583953079108e-15*V01*V07*V16 - 
      6.8486373534522317e-17*V10*V16 - 8.15973999748765058e-15*V01*V022*V17 - 
      8.26669761042470843e-15*V012*V03*V17 + 7.12626876408814967e-15*V03*V04*V17 + 
      3.78036522690319113e-15*V02*V05*V17 + 1.69613932127181637e-15*V01*V06*V17 - 4.21126985370719144e-17*V09*V17 - 
      1.28067668122003484e-15*V012*V02*V18 + 9.60189184686046794e-16*V032*V18 + 
      1.05979178633247677e-15*V02*V04*V18 + 6.29005926858352959e-16*V01*V05*V18 - 2.19183431885879037e-17*V08*V18 - 
      5.62934804931883448e-17*V013*V19 + 2.81701958634663342e-16*V02*V03*V19 + 1.73672088926306661e-16*V01*V04*V19 - 
      9.96873024851350019e-18*V07*V19 + 1.85321711972813694e-17*V022*V20 + 4.17241916131655518e-17*V01*V03*V20 - 
      3.6971583673871015e-18*V06*V20 + 5.61594483967759916e-18*V01*V02*V21 - 1.20219344254302358e-18*V05*V21 + 
      3.61886660313353645e-19*V012*V22 - 2.88913630044405791e-19*V04*V22 - 6.29206230380213642e-20*V03*V23 - 
      7.44622757846406677e-21*V02*V24 - 9.30778447308008347e-22*V01*V25 + 8.02395213196558919e-25*V28) + 
   delta2*eps13*(6.26037729789820904e-8*V025*V032 + 
      4.32286855970912927e-7*V01*V023*V033 + 2.65611018375665901e-7*V012*V02*V034 - 
      1.0056479547259229e-8*V036 + 6.86627585651083939e-9*V026*V04 + 
      3.95802566746899341e-7*V01*V024*V03*V04 + 1.07162878384648343e-6*V012*V022*V032*V04 + 
      1.78563679745402434e-7*V013*V033*V04 - 2.00100852048114414e-7*V02*V034*V04 + 
      2.40940930801944652e-7*V012*V023*V042 + 
      3.71028688605719418e-7*V013*V02*V03*V042 - 3.786789464730803e-7*V022*V032*V042 - 
      2.36280973326511114e-7*V01*V033*V042 + 1.49288633236900044e-8*V014*V043 - 
      4.47785160224899766e-8*V023*V043 - 3.11478549885343524e-7*V01*V02*V03*V043 - 
      2.30545145737442503e-8*V012*V044 + 2.19249275444418889e-9*V045 + 
      3.75622637873892542e-8*V01*V025*V05 + 3.80256762866230264e-7*V012*V023*V03*V05 + 
      2.93511920167790849e-7*V013*V02*V032*V05 - 2.22910418782730152e-7*V022*V033*V05 - 
      9.93600987223710436e-8*V01*V034*V05 + 2.03066187598021165e-7*V013*V022*V04*V05 + 
      7.068880712087995e-8*V014*V03*V04*V05 - 2.71181513017230613e-7*V023*V03*V04*V05 - 
      7.99658959096722232e-7*V01*V02*V032*V04*V05 - 2.55860711226782637e-7*V01*V022*V042*V05 - 
      2.29459772380387721e-7*V012*V03*V042*V05 + 4.01679166923128863e-8*V03*V043*V05 + 
      1.93668779267081088e-8*V014*V02*V052 - 1.77379742813162922e-8*V024*V052 - 
      2.22534401542033469e-7*V01*V022*V03*V052 - 9.521874323339043e-8*V012*V032*V052 - 
      1.29568314594432361e-7*V012*V02*V04*V052 + 5.27035762312654575e-8*V032*V04*V052 + 
      3.38001761885005644e-8*V02*V042*V052 - 6.53865642029561654e-9*V013*V053 + 
      1.99735057415167033e-8*V02*V03*V053 + 1.22479913352590455e-8*V01*V04*V053 + 
      4.23093812467791226e-8*V012*V024*V06 + 1.33534491939312201e-7*V013*V022*V03*V06 + 
      2.31786657294360376e-8*V014*V032*V06 - 9.86821340376802218e-8*V023*V032*V06 - 
      1.87628983514970859e-7*V01*V02*V033*V06 + 3.22085884826606115e-8*V014*V02*V04*V06 - 
      2.54812550973248439e-8*V024*V04*V06 - 3.66514117038712385e-7*V01*V022*V03*V04*V06 - 
      1.5958495148039661e-7*V012*V032*V04*V06 - 1.08852043899466103e-7*V012*V02*V042*V06 + 
      4.34041600832955616e-8*V032*V042*V06 + 1.77200747105181666e-8*V02*V043*V06 + 
      2.28056978100745608e-9*V015*V05*V06 - 6.60077636103449389e-8*V01*V023*V05*V06 - 
      1.80647912983891509e-7*V012*V02*V03*V05*V06 + 2.51194422978490909e-8*V033*V05*V06 - 
      3.3036760746107917e-8*V013*V04*V05*V06 + 9.79806517215620028e-8*V02*V03*V04*V05*V06 + 
      3.04115383559460582e-8*V01*V042*V05*V06 + 1.36283104170069822e-8*V022*V052*V06 + 
      2.61204247533627771e-8*V01*V03*V052*V06 - 2.11807889001744888e-8*V012*V022*V062 - 
      1.1333556656753781e-8*V013*V03*V062 + 1.76746991456447859e-8*V02*V032*V062 + 
      1.06677036842741399e-8*V022*V04*V062 + 2.1702681959296302e-8*V01*V03*V04*V062 + 
      1.23289861151022954e-8*V01*V02*V05*V062 - 7.90901730498100935e-10*V052*V062 + 
      8.69955863714949038e-10*V012*V063 - 4.28930339326720835e-10*V04*V063 + 
      1.7269235611954644e-8*V013*V023*V07 + 1.80196135531394635e-8*V014*V02*V03*V07 - 
      1.8548270418758121e-8*V024*V03*V07 - 1.13948565609417724e-7*V01*V022*V032*V07 - 
      3.20680607512308394e-8*V012*V033*V07 + 1.61914634735012886e-9*V015*V04*V07 - 
      4.7288839506620564e-8*V01*V023*V04*V07 - 1.31384056746108091e-7*V012*V02*V03*V04*V07 + 
      1.83196164302877053e-8*V033*V04*V07 - 1.2047569175203672e-8*V013*V042*V07 + 
      3.54792234131722972e-8*V02*V03*V042*V07 + 7.37777134042991446e-9*V01*V043*V07 - 
      3.66318637990656579e-8*V012*V022*V05*V07 - 1.96262914574951561e-8*V013*V03*V05*V07 + 
      3.1297380532310738e-8*V02*V032*V05*V07 + 1.96511394126519307e-8*V022*V04*V05*V07 + 
      3.81400923195861699e-8*V01*V03*V04*V05*V07 + 1.08726304366174659e-8*V01*V02*V052*V07 - 
      4.66805721270364971e-10*V053*V07 - 9.37224948779954554e-9*V013*V02*V06*V07 + 
      1.43114854589958633e-8*V022*V03*V06*V07 + 1.35332733566607584e-8*V01*V032*V06*V07 + 
      1.79211033285429649e-8*V01*V02*V04*V06*V07 + 4.55414833979787922e-9*V012*V05*V06*V07 - 
      2.30576331233322882e-9*V04*V05*V06*V07 - 8.32632663866097855e-10*V03*V062*V07 - 
      3.56422123491067297e-10*V014*V072 + 9.38987455031989622e-10*V023*V072 + 
      5.64466615821918792e-9*V01*V02*V03*V072 + 1.66530240177509072e-9*V012*V04*V072 - 
      4.19734176015411067e-10*V042*V072 - 7.36328011081932439e-10*V03*V05*V072 - 
      3.45983715856640743e-10*V02*V06*V072 - 4.59703508778850503e-11*V01*V073 + 
      3.03321094528202371e-9*V014*V022*V08 - 1.04471088085659645e-9*V025*V08 + 
      7.83763996080172551e-10*V015*V03*V08 - 2.63937953457177631e-8*V01*V023*V03*V08 - 
      3.50566928973522331e-8*V012*V02*V032*V08 + 2.53313431522826346e-9*V034*V08 - 
      2.36319893513054495e-8*V012*V022*V04*V08 - 1.26474364551414176e-8*V013*V03*V04*V08 + 
      1.9953363374100479e-8*V02*V032*V04*V08 + 5.99519201575933914e-9*V022*V042*V08 + 
      1.22625520447323922e-8*V01*V03*V042*V08 - 7.16912037204157159e-9*V013*V02*V05*V08 + 
      1.11541958989999938e-8*V022*V03*V05*V08 + 1.04698608963253418e-8*V01*V032*V05*V08 + 
      1.39123975502834464e-8*V01*V02*V04*V05*V08 + 1.75830385152653858e-9*V012*V052*V08 - 
      8.97418632544638092e-10*V04*V052*V08 - 6.29395016672954164e-10*V014*V06*V08 + 
      1.5886748524893385e-9*V023*V06*V08 + 9.94336310560763942e-9*V01*V02*V03*V06*V08 + 
      2.94820165189933703e-9*V012*V04*V06*V08 - 7.29384657133766073e-10*V042*V06*V08 - 
      1.29495456392085736e-9*V03*V05*V06*V08 - 3.00324904831965124e-10*V02*V062*V08 + 
      2.02862826846065116e-9*V01*V022*V07*V08 + 1.80786199791238447e-9*V012*V03*V07*V08 - 
      9.45167289704024987e-10*V03*V04*V07*V08 - 5.39343867628521465e-10*V02*V05*V07*V08 - 
      2.43084042759038705e-10*V01*V06*V07*V08 + 3.35452430689708632e-10*V012*V02*V082 - 
      1.32292084412831336e-10*V032*V082 - 1.70110732268529292e-10*V02*V04*V082 - 
      9.43311982681580721e-11*V01*V05*V082 + 8.21637941907666639e-13*V083 + 
      2.3114395816601699e-10*V015*V02*V09 - 1.95942959641549458e-9*V01*V024*V09 - 
      1.1279391898141591e-8*V012*V022*V03*V09 - 2.96983274530447457e-9*V013*V032*V09 + 
      3.3499775104416207e-9*V02*V033*V09 - 4.14151236512458962e-9*V013*V02*V04*V09 + 
      6.37297699327406587e-9*V022*V03*V04*V09 + 6.07421868620520999e-9*V01*V032*V04*V09 + 
      4.0048526338949564e-9*V01*V02*V042*V09 - 4.30909278909142232e-10*V014*V05*V09 + 
      1.1596879253737509e-9*V023*V05*V09 + 6.93903765995887209e-9*V01*V02*V03*V05*V09 + 
      2.04341393515044019e-9*V012*V04*V05*V09 - 5.1850245911125742e-10*V042*V05*V09 - 
      4.54321365784394465e-10*V03*V052*V09 + 1.6067111920432139e-9*V01*V022*V06*V09 + 
      1.43643437206426077e-9*V012*V03*V06*V09 - 7.49981534908386298e-10*V03*V04*V06*V09 - 
      4.27517072375866469e-10*V02*V05*V06*V09 - 9.65503667363073166e-11*V01*V062*V09 + 
      6.02020936065519019e-10*V012*V02*V07*V09 - 2.38718295375480113e-10*V032*V07*V09 - 
      3.10667159008854608e-10*V02*V04*V07*V09 - 1.70043575180262805e-10*V01*V05*V07*V09 + 
      6.09077193529588257e-11*V013*V08*V09 - 1.75696170557529793e-10*V02*V03*V08*V09 - 
      1.09663819995065411e-10*V01*V04*V08*V09 + 4.46497234172275058e-12*V07*V08*V09 - 
      1.42528415799870108e-11*V022*V092 - 2.74113180136972269e-11*V01*V03*V092 + 
      1.77303866649813176e-12*V06*V092 + 6.19926324583187328e-12*V016*V10 - 
      1.08013598211852221e-9*V012*V023*V10 - 1.75570881426551545e-9*V013*V02*V03*V10 + 
      1.47307460970132083e-9*V022*V032*V10 + 9.04896052257042606e-10*V01*V033*V10 - 
      2.24642833193929071e-10*V014*V04*V10 + 5.75877358442485548e-10*V023*V04*V10 + 
      3.63624248841115733e-9*V01*V02*V03*V04*V10 + 5.39568743006184196e-10*V012*V042*V10 - 
      8.93783511579785148e-11*V043*V10 + 1.02043843621241647e-9*V01*V022*V05*V10 + 
      9.04205048358374603e-10*V012*V03*V05*V10 - 4.77151607123061347e-10*V03*V04*V05*V10 - 
      1.36304962154936436e-10*V02*V052*V10 + 4.34684552305441662e-10*V012*V02*V06*V10 - 
      1.71766859580324334e-10*V032*V06*V10 - 2.20617707752033349e-10*V02*V04*V06*V10 - 
      1.22486998470881226e-10*V01*V05*V06*V10 + 4.96346324840088191e-11*V013*V07*V10 - 
      1.4373321721592951e-10*V02*V03*V07*V10 - 8.96259820389039816e-11*V01*V04*V07*V10 + 
      1.82594934724659227e-12*V072*V10 - 2.55378844470172402e-11*V022*V08*V10 - 
      4.97209607691980023e-11*V01*V03*V08*V10 + 3.20226136731066484e-12*V06*V08*V10 - 1.66424128279075483e-11*V01*V02*V09*V10 + 
      2.25874092088892671e-12*V05*V09*V10 - 1.12653412881304331e-12*V012*V102 + 
      5.92609032826688976e-13*V04*V102 - 2.35307874331137145e-10*V013*V022*V11 - 
      8.59390346579136569e-11*V014*V03*V11 + 2.56122800222029521e-10*V023*V03*V11 + 
      7.49755212651196611e-10*V01*V02*V032*V11 + 4.86471165308878208e-10*V01*V022*V04*V11 + 
      4.3713910750440046e-10*V012*V03*V04*V11 - 1.14780689171311559e-10*V03*V042*V11 + 
      2.50421907850127219e-10*V012*V02*V05*V11 - 1.00095716619238854e-10*V032*V05*V11 - 
      1.30555855138937328e-10*V02*V04*V05*V11 - 3.56124023162364183e-11*V01*V052*V11 + 
      3.28078102742084746e-11*V013*V06*V11 - 9.47291834291967603e-11*V02*V03*V06*V11 - 
      5.91897930748147892e-11*V01*V04*V06*V11 - 1.93856434348288081e-11*V022*V07*V11 - 
      3.72456668581856948e-11*V01*V03*V07*V11 + 2.41080199563574167e-12*V06*V07*V11 - 1.38343978742014259e-11*V01*V02*V08*V11 + 
      1.87750330278607734e-12*V05*V08*V11 - 2.06379980709586934e-12*V012*V09*V11 + 
      1.09092874076500041e-12*V04*V09*V11 + 5.0298800777905358e-13*V03*V10*V11 + 7.0070765338504517e-14*V02*V112 - 
      2.1208005841003777e-11*V014*V02*V12 + 1.43260393895278697e-11*V024*V12 + 
      1.87465703907169474e-10*V01*V022*V03*V12 + 8.15053018303082035e-11*V012*V032*V12 + 
      1.11649857489976707e-10*V012*V02*V04*V12 - 4.4564767919231618e-11*V032*V04*V12 - 
      2.84835600049112391e-11*V02*V042*V12 + 1.73871521984163422e-11*V013*V05*V12 - 
      5.10750075917268583e-11*V02*V03*V05*V12 - 3.17784325607582635e-11*V01*V04*V05*V12 - 
      1.16381576566694122e-11*V022*V06*V12 - 2.27141689369831666e-11*V01*V03*V06*V12 + 
      7.31381556139377256e-13*V062*V12 - 9.56832624987960252e-12*V01*V02*V07*V12 + 
      1.29918256119366774e-12*V05*V07*V12 - 1.58491086696809916e-12*V012*V08*V12 + 
      8.33446556463244752e-13*V04*V08*V12 + 4.25530730443919345e-13*V03*V09*V12 + 1.28805732732071082e-13*V02*V10*V12 + 
      3.43922679955297765e-14*V01*V11*V12 - 6.52554025877039293e-13*V015*V13 + 
      1.40670431381859411e-11*V01*V023*V13 + 3.87184829818105716e-11*V012*V02*V03*V13 - 
      5.32620413852048442e-12*V033*V13 + 7.21263636637434183e-12*V013*V04*V13 - 
      2.10052472792949051e-11*V02*V03*V04*V13 - 6.57704165621252631e-12*V01*V042*V13 - 
      5.91280120430917342e-12*V022*V05*V13 - 1.13084914015245695e-11*V01*V03*V05*V13 - 
      5.41157832841609232e-12*V01*V02*V06*V13 + 7.34867886046282007e-13*V05*V06*V13 - 
      1.01573925615648402e-12*V012*V07*V13 + 5.37612816248197697e-13*V04*V07*V13 + 
      3.03057183654965243e-13*V03*V08*V13 + 1.01567905899118282e-13*V02*V09*V13 + 2.94634403383630342e-14*V01*V10*V13 - 
      9.6568031213594039e-17*V132 + 4.23286160535418791e-12*V012*V022*V14 + 
      2.29364971595471251e-12*V013*V03*V14 - 3.55109930502696861e-12*V02*V032*V14 - 
      2.22905375128135736e-12*V022*V04*V14 - 4.3827866246146841e-12*V01*V03*V04*V14 - 
      2.52199778603470324e-12*V01*V02*V05*V14 + 1.71668370770168171e-13*V052*V14 - 
      5.38067360972162115e-13*V012*V06*V14 + 2.8277801582513226e-13*V04*V06*V14 + 1.81793451574552243e-13*V03*V07*V14 + 
      6.72568307750133747e-14*V02*V08*V14 + 2.16039025365449634e-14*V01*V09*V14 - 1.8004300704052234e-16*V12*V14 + 
      4.77762768945689482e-13*V013*V02*V15 - 7.24117615574366523e-13*V022*V03*V15 - 
      6.80930463628860136e-13*V01*V032*V15 - 9.12230925712573974e-13*V01*V02*V04*V15 - 
      2.33698865924940589e-13*V012*V05*V15 + 1.24464156570915188e-13*V04*V05*V15 + 
      9.00859793439058392e-14*V03*V06*V15 + 3.79980993329021327e-14*V02*V07*V15 + 1.3473894818080785e-14*V01*V08*V15 - 
      1.46461479103092518e-16*V11*V15 + 1.74791256931349811e-14*V014*V16 - 4.44825721573317806e-14*V023*V16 - 
      2.69225580940119444e-13*V01*V02*V03*V16 - 8.02978247680623291e-14*V012*V04*V16 + 
      2.11371564748402071e-14*V042*V16 + 3.71537976495766168e-14*V03*V05*V16 + 1.76383558236728567e-14*V02*V06*V16 + 
      7.13233371645080865e-15*V01*V07*V16 - 1.03218422065554138e-16*V10*V16 - 2.46324186786622714e-14*V01*V022*V17 - 
      2.1924300170650675e-14*V012*V03*V17 + 1.20094852636974912e-14*V03*V04*V17 + 6.92055462711326482e-15*V02*V05*V17 + 
      3.1493186613769601e-15*V01*V06*V17 - 6.31793794463729905e-17*V09*V17 - 3.90837593138421937e-15*V012*V02*V18 + 
      1.60247936770006911e-15*V032*V18 + 2.10075206311901791e-15*V02*V04*V18 + 1.16097764211777766e-15*V01*V05*V18 - 
      3.31561898500058733e-17*V08*V18 - 1.80943330156676823e-16*V013*V19 + 5.40568198843072007e-16*V02*V03*V19 + 
      3.39494923206464888e-16*V01*V04*V19 - 1.49634270135353692e-17*V07*V19 + 4.23206344422005235e-17*V022*V20 + 
      8.13491055162726215e-17*V01*V03*V20 - 5.65926592798230618e-18*V06*V20 + 1.25906400567354289e-17*V01*V02*V21 - 
      1.81362180457965426e-18*V05*V21 + 8.29323596551435437e-19*V012*V22 - 4.60735331417464132e-19*V04*V22 - 
      9.84298208028218827e-20*V03*V23 - 1.34032096412353202e-20*V02*V24 - 1.67540120515441502e-21*V01*V25 + 
      1.20359281979483838e-24*V28) + delta4*eps12*
    (1.20882353260258126e-8*V025*V032 + 1.04426097371018395e-7*V01*V023*V033 + 
      6.9719079284711093e-8*V012*V02*V034 - 7.23344550992912055e-9*V036 + 
      5.52620037914155561e-11*V026*V04 + 7.90326424631072416e-8*V01*V024*V03*V04 + 
      2.54323416726398753e-7*V012*V022*V032*V04 + 
      4.51281960847592656e-8*V013*V033*V04 - 1.324883216725678e-7*V02*V034*V04 + 
      5.06434542722669084e-8*V012*V023*V042 + 
      8.66226005370204717e-8*V013*V02*V03*V042 - 
      2.22409766088872341e-7*V022*V032*V042 - 1.53016681070112025e-7*V01*V033*V042 + 
      3.41313722134800566e-9*V014*V043 - 1.96395897468419557e-8*V023*V043 - 
      1.82156807683404165e-7*V01*V02*V03*V043 - 1.34927607259456209e-8*V012*V044 + 
      1.73105497543500998e-9*V045 + 7.25294119561548755e-9*V01*V025*V05 + 
      8.59807307885671175e-8*V012*V023*V03*V05 + 6.99591777342322005e-8*V013*V02*V032*V05 - 
      1.39049724059185477e-7*V022*V033*V05 - 6.57865723958235981e-8*V01*V034*V05 + 
      4.46305625278255997e-8*V013*V022*V04*V05 + 1.61950340242143074e-8*V014*V03*V04*V05 - 
      1.47756732055728671e-7*V023*V03*V04*V05 - 4.89030123593119722e-7*V01*V02*V032*V04*V05 - 
      1.38963331863418844e-7*V01*V022*V042*V05 - 1.37800085223021031e-7*V012*V03*V042*V05 + 
      3.44050669150184239e-8*V03*V043*V05 + 4.18302667587798307e-9*V014*V02*V052 - 
      9.04196340258141116e-9*V024*V052 - 1.28790956572407237e-7*V01*V022*V03*V052 - 
      5.83555802365083814e-8*V012*V032*V052 - 
      7.37360574267513578e-8*V012*V02*V04*V052 + 4.69398212292297161e-8*V032*V04*V052 + 
      2.73458931028917595e-8*V02*V042*V052 - 3.72952775189787807e-9*V013*V053 + 
      1.6958793336841598e-8*V02*V03*V053 + 1.02386762080878323e-8*V01*V04*V053 + 
      8.71170327812938561e-9*V012*V024*V06 + 2.89591202453743303e-8*V013*V022*V03*V06 + 
      5.14017324083364388e-9*V014*V032*V06 - 5.41574870492825955e-8*V023*V032*V06 - 
      1.13699493062326463e-7*V01*V02*V033*V06 + 6.72413420064563855e-9*V014*V02*V04*V06 - 
      1.03756170676674664e-8*V024*V04*V06 - 2.00346967720785699e-7*V01*V022*V03*V04*V06 - 
      9.4732859862585303e-8*V012*V032*V04*V06 - 5.95676145783665186e-8*V012*V02*V042*V06 + 
      3.73178531516166455e-8*V032*V042*V06 + 1.32159742949447015e-8*V02*V043*V06 + 
      4.60713500269600487e-10*V015*V05*V06 - 3.37780054041672907e-8*V01*V023*V05*V06 - 
      1.01912862830765567e-7*V012*V02*V03*V05*V06 + 2.23348100714193579e-8*V033*V05*V06 - 
      1.83126783282942847e-8*V013*V04*V05*V06 + 7.97301498466301465e-8*V02*V03*V04*V05*V06 + 
      2.45304974411087697e-8*V01*V042*V05*V06 + 1.04873740107954018e-8*V022*V052*V06 + 
      2.17844261436320787e-8*V01*V03*V052*V06 - 1.0911096004189193e-8*V012*V022*V062 - 
      6.19369308313955983e-9*V013*V03*V062 + 1.44345788288939075e-8*V02*V032*V062 + 
      7.52095144554799776e-9*V022*V04*V062 + 1.75328066449056264e-8*V01*V03*V04*V062 + 
      9.45427784090595249e-9*V01*V02*V05*V062 - 7.70529739619229361e-10*V052*V062 + 
      6.62001241850818438e-10*V012*V063 - 3.99981412133341695e-10*V04*V063 + 
      3.33215319513658294e-9*V013*V023*V07 + 3.57136603562257157e-9*V014*V02*V03*V07 - 
      8.94594528544603356e-9*V024*V03*V07 - 6.29789259431921199e-8*V01*V022*V032*V07 - 
      1.87936322738569965e-8*V012*V033*V07 + 3.09963162291593664e-10*V015*V04*V07 - 
      2.27966376917771864e-8*V01*V023*V04*V07 - 7.15304904904188209e-8*V012*V02*V03*V04*V07 + 
      1.59574377651104258e-8*V033*V04*V07 - 6.47274061062662212e-9*V013*V042*V07 + 
      2.80661408894938849e-8*V02*V03*V042*V07 + 5.79788133003006763e-9*V01*V043*V07 - 
      1.89350223704757276e-8*V012*V022*V05*V07 - 1.07012255785477306e-8*V013*V03*V05*V07 + 
      2.59524523300590123e-8*V02*V032*V05*V07 + 1.46388001108568292e-8*V022*V04*V05*V07 + 
      3.1127191581057809e-8*V01*V03*V04*V05*V07 + 8.45935591506244628e-9*V01*V02*V052*V07 - 
      4.60775985578051114e-10*V053*V07 - 4.74234229789098545e-9*V013*V02*V06*V07 + 
      1.07393279794729315e-8*V022*V03*V06*V07 + 1.10090898685328405e-8*V01*V032*V06*V07 + 
      1.33582456330230875e-8*V01*V02*V04*V06*V07 + 3.48362573500462324e-9*V012*V05*V06*V07 - 
      2.2032984342683328e-9*V04*V05*V06*V07 - 7.99139107397828057e-10*V03*V062*V07 - 
      1.73530910238513601e-10*V014*V072 + 6.40666703698504504e-10*V023*V072 + 
      4.27646404882137475e-9*V01*V02*V03*V072 + 1.2450965718386082e-9*V012*V04*V072 - 
      3.92905777070812353e-10*V042*V072 - 7.15578374379870009e-10*V03*V05*V072 - 
      3.09694258732338897e-10*V02*V06*V072 - 4.14768341729476862e-11*V01*V073 + 
      5.32251030106422263e-10*V014*V022*V08 - 3.7599196224330001e-10*V025*V08 + 
      1.39926227548776568e-10*V015*V03*V08 - 1.29607199114575347e-8*V01*V023*V03*V08 - 
      1.87787565822432913e-8*V012*V02*V032*V08 + 2.20249261839429827e-9*V034*V08 - 
      1.16240437448587649e-8*V012*V022*V04*V08 - 6.6443470413816776e-9*V013*V03*V04*V08 + 
      1.59373880158148374e-8*V02*V032*V04*V08 + 4.10863213632520728e-9*V022*V042*V08 + 
      9.69019621454820376e-9*V01*V03*V042*V08 - 3.59849807784135024e-9*V013*V02*V05*V08 + 
      8.42325230947116132e-9*V022*V03*V05*V08 + 8.51769281088870386e-9*V01*V032*V05*V08 + 
      1.04141439935135217e-8*V01*V02*V04*V05*V08 + 1.34401063281953465e-9*V012*V052*V08 - 
      8.61241971193464998e-10*V04*V052*V08 - 3.05016292273996891e-10*V014*V06*V08 + 
      1.02953600221241218e-9*V023*V06*V08 + 7.45566703073174797e-9*V01*V02*V03*V06*V08 + 
      2.19130998543030349e-9*V012*V04*V06*V08 - 6.6905946103917063e-10*V042*V06*V08 - 
      1.24720512530691495e-9*V03*V05*V06*V08 - 2.63072992129871742e-10*V02*V062*V08 + 
      1.39859646064307274e-9*V01*V022*V07*V08 + 1.34354140443118404e-9*V012*V03*V07*V08 - 
      8.93225254027936508e-10*V03*V04*V07*V08 - 4.85337063910672764e-10*V02*V05*V07*V08 - 
      2.17489322951947217e-10*V01*V06*V07*V08 + 2.30893271575664754e-10*V012*V02*V082 - 
      1.25747164684605609e-10*V032*V082 - 1.46299824985844711e-10*V02*V04*V082 - 
      8.46083818310006371e-11*V01*V05*V082 + 8.12672495620012848e-13*V083 + 
      3.66051734515786803e-11*V015*V02*V09 - 8.29133332629294245e-10*V01*V024*V09 - 
      5.47087570944765504e-9*V012*V022*V03*V09 - 1.51631914791537193e-9*V013*V032*V09 + 
      2.69669756136912825e-9*V02*V033*V09 - 1.98663118520845969e-9*V013*V02*V04*V09 + 
      4.61220388749224967e-9*V022*V03*V04*V09 + 4.80632079808038063e-9*V01*V032*V04*V09 + 
      2.88370634770292973e-9*V01*V02*V042*V09 - 2.05719876229253226e-10*V014*V05*V09 + 
      7.89190574074530246e-10*V023*V05*V09 + 5.22812950672100975e-9*V01*V02*V03*V05*V09 + 
      1.51791882925948914e-9*V012*V04*V05*V09 - 4.84854684995298139e-10*V042*V05*V09 - 
      4.40672046256432976e-10*V03*V052*V09 + 1.09662515229161045e-9*V01*V022*V06*V09 + 
      1.0613831516673568e-9*V012*V03*V06*V09 - 7.04914834356448994e-10*V03*V04*V06*V09 - 
      3.82230795717939654e-10*V02*V05*V06*V09 - 8.5942197180477207e-11*V01*V062*V09 + 
      4.14350377197574503e-10*V012*V02*V07*V09 - 2.27728148229236456e-10*V032*V07*V09 - 
      2.71296133326879144e-10*V02*V04*V07*V09 - 1.53009091405004201e-10*V01*V05*V07*V09 + 
      4.10498544838390642e-11*V013*V08*V09 - 1.55152746080081988e-10*V02*V03*V08*V09 - 
      9.59423029015289857e-11*V01*V04*V08*V09 + 4.44773535618112588e-12*V07*V08*V09 - 
      1.15555001237355942e-11*V022*V092 - 2.41257779299523541e-11*V01*V03*V092 + 
      1.75819821034290929e-12*V06*V092 + 8.8560903511883904e-13*V016*V10 - 
      4.7028558739918174e-10*V012*V023*V10 - 8.1843740245514698e-10*V013*V02*V03*V10 + 
      1.08025794505111839e-9*V022*V032*V10 + 7.1154440620899848e-10*V01*V033*V10 - 
      1.02649078820550699e-10*V014*V04*V10 + 3.57535624229162578e-10*V023*V04*V10 + 
      2.63925751474864757e-9*V01*V02*V03*V04*V10 + 3.88468872118375081e-10*V012*V042*V10 - 
      8.02194685956035236e-11*V043*V10 + 7.01148303994630507e-10*V01*V022*V05*V10 + 
      6.66210883791491801e-10*V012*V03*V05*V10 - 4.50711553031096479e-10*V03*V04*V05*V10 - 
      1.22690085869169305e-10*V02*V052*V10 + 2.96824185621000256e-10*V012*V02*V06*V10 - 
      1.62614166065059905e-10*V032*V06*V10 - 1.88755241645819331e-10*V02*V04*V06*V10 - 
      1.09389510016645682e-10*V01*V05*V06*V10 + 3.33774532149794918e-11*V013*V07*V10 - 
      1.27115440921079826e-10*V02*V03*V07*V10 - 7.84755984592965309e-11*V01*V04*V07*V10 + 
      1.82130306750850787e-12*V072*V10 - 2.04109508615751688e-11*V022*V08*V10 - 
      4.3660858041144564e-11*V01*V03*V08*V10 + 3.15711796440761009e-12*V06*V08*V10 - 1.35716438685426404e-11*V01*V02*V09*V10 + 
      2.25146259575764275e-12*V05*V09*V10 - 9.11392969230539979e-13*V012*V102 + 
      5.74360148619121813e-13*V04*V102 - 9.9642669201331482e-11*V013*V022*V11 - 
      3.77898697485578291e-11*V014*V03*V11 + 1.68168394627053444e-10*V023*V03*V11 + 
      5.43769172804245806e-10*V01*V02*V032*V11 + 3.18163757684645535e-10*V01*V022*V04*V11 + 
      3.12142097152999357e-10*V012*V03*V04*V11 - 1.05468421638837286e-10*V03*V042*V11 + 
      1.70517703181524832e-10*V012*V02*V05*V11 - 9.51761282987384297e-11*V032*V05*V11 - 
      1.13828360332427639e-10*V02*V04*V05*V11 - 3.19184559893581372e-11*V01*V052*V11 + 
      2.1895471877193824e-11*V013*V06*V11 - 8.30677175300375597e-11*V02*V03*V06*V11 - 
      5.1450365942944162e-11*V01*V04*V06*V11 - 1.57105521096675428e-11*V022*V07*V11 - 
      3.27396475996945943e-11*V01*V03*V07*V11 + 2.39040097981453856e-12*V06*V07*V11 - 1.12578722185719423e-11*V01*V02*V08*V11 + 
      1.8688161409045364e-12*V05*V08*V11 - 1.66948591790450449e-12*V012*V09*V11 + 1.06199280278071825e-12*V04*V09*V11 + 
      4.9427418823354929e-13*V03*V10*V11 + 6.40281712049283203e-14*V02*V112 - 
      8.50650783732569078e-12*V014*V02*V12 + 7.98040773312985024e-12*V024*V12 + 
      1.23857732036580147e-10*V01*V022*V03*V12 + 5.74712727968812932e-11*V012*V032*V12 + 
      7.32396637436056347e-11*V012*V02*V04*V12 - 4.12875645130824172e-11*V032*V04*V12 - 
      2.37244082451593395e-11*V02*V042*V12 + 1.15172641174315601e-11*V013*V05*V12 - 
      4.50673354173006439e-11*V02*V03*V05*V12 - 2.77261980520601875e-11*V01*V04*V05*V12 - 
      9.22551319763251332e-12*V022*V06*V12 - 1.98248863022593421e-11*V01*V03*V06*V12 + 
      7.17967666041412286e-13*V062*V12 - 7.79601827328047531e-12*V01*V02*V07*V12 + 
      1.29534634912714369e-12*V05*V07*V12 - 1.28004691923030537e-12*V012*V08*V12 + 
      8.06898150216084409e-13*V04*V08*V12 + 4.18311280199754674e-13*V03*V09*V12 + 1.17212660295230542e-13*V02*V10*V12 + 
      3.14292422906541054e-14*V01*V11*V12 - 2.44707759703889735e-13*V015*V13 + 
      8.29470830809344407e-12*V01*V023*V13 + 2.51527855599340736e-11*V012*V02*V03*V13 - 
      4.95163469108411185e-12*V033*V13 + 4.62128662075718749e-12*V013*V04*V13 - 
      1.79399282081407719e-11*V02*V03*V04*V13 - 5.57203912826001651e-12*V01*V042*V13 - 
      4.78132194911426031e-12*V022*V05*V13 - 9.8862445917739025e-12*V01*V03*V05*V13 - 
      4.36794692598014939e-12*V01*V02*V06*V13 + 7.28040642889289817e-13*V05*V06*V13 - 
      8.19479307658213228e-13*V012*V07*V13 + 5.23260039465917009e-13*V04*V07*V13 + 
      2.97359507159829527e-13*V03*V08*V13 + 9.28014863712321666e-14*V02*V09*V13 + 2.69121310061478652e-14*V01*V10*V13 - 
      9.65673331297585579e-17*V132 + 2.51116772458039228e-12*V012*V022*V14 + 
      1.44008574460662094e-12*V013*V03*V14 - 3.06151557533819164e-12*V02*V032*V14 - 
      1.7112000522365447e-12*V022*V04*V14 - 3.72993907514810658e-12*V01*V03*V04*V14 - 
      2.0446358065653108e-12*V01*V02*V05*V14 + 1.70985078442690671e-13*V052*V14 - 
      4.31254469191205498e-13*V012*V06*V14 + 2.72387093882243787e-13*V04*V06*V14 + 1.7864407249719243e-13*V03*V07*V14 + 
      6.10919899771084163e-14*V02*V08*V14 + 1.97384141183837402e-14*V01*V09*V14 - 1.79826806083139243e-16*V12*V14 + 
      2.767528234746372e-13*V013*V02*V15 - 5.713527912711336e-13*V022*V03*V15 - 
      5.7875508238377094e-13*V01*V032*V15 - 7.14478161232486493e-13*V01*V02*V04*V15 - 
      1.87009153727962485e-13*V012*V05*V15 + 1.21020252115635927e-13*V04*V05*V15 + 
      8.79582868294079383e-14*V03*V06*V15 + 3.47072260237016761e-14*V02*V07*V15 + 1.22859180855419439e-14*V01*V08*V15 - 
      1.46460082935421556e-16*V11*V15 + 9.71062538507498948e-15*V014*V16 - 3.12672755152665796e-14*V023*V16 - 
      2.11989988841248669e-13*V01*V02*V03*V16 - 6.25139100876856569e-14*V012*V04*V16 + 
      1.99525674035381883e-14*V042*V16 + 3.64406463725905885e-14*V03*V05*V16 + 1.59224099093537048e-14*V02*V06*V16 + 
      6.50930227029003634e-15*V01*V07*V16 - 1.03053420431713173e-16*V10*V16 - 1.77282243443173395e-14*V01*V022*V17 - 
      1.69492633079928458e-14*V012*V03*V17 + 1.14998784791256728e-14*V03*V04*V17 + 
      6.31266880784708842e-15*V02*V05*V17 + 2.85571297717967464e-15*V01*V06*V17 - 6.31779832787020285e-17*V09*V17 - 
      2.80060065453612015e-15*V012*V02*V18 + 1.54455237103185521e-15*V032*V18 + 
      1.85252462056333978e-15*V02*V04*V18 + 1.05585459350036389e-15*V01*V05*V18 - 3.30612504483804565e-17*V08*V18 - 
      1.26660331109673776e-16*V013*V19 + 4.84358488410141383e-16*V02*V03*V19 + 3.01170120638557645e-16*V01*V04*V19 - 
      1.49620308458644072e-17*V07*V19 + 3.4680804946696391e-17*V022*V20 + 7.2377332062670729e-17*V01*V03*V20 - 
      5.61937542309767725e-18*V06*V20 + 1.04042414840089173e-17*V01*V02*V21 - 1.81222563690869225e-18*V05*V21 + 
      6.78537488087538085e-19*V012*V22 - 4.49565990049768031e-19*V04*V22 - 9.70336531318598701e-20*V03*V23 - 
      1.22862755044657102e-20*V02*V24 - 1.53578443805821377e-21*V01*V25 + 1.20359281979483838e-24*V28) + 
   1.13099628864477169e-31*delta28*V28 + 7.91697402051340185e-31*delta26*eps*V28 + 
   delta26*eps2*(-4.94047679986510124e-25*V142 - 1.05867359997109312e-24*V13*V15 - 
      7.47299011744301028e-25*V12*V16 - 6.07180447042244585e-25*V11*V17 - 3.19568656338023466e-25*V10*V18 - 
      1.9529195665101434e-25*V09*V19 - 7.4396935867053082e-26*V08*V20 - 3.34786211401738869e-26*V07*V21 - 
      8.73355334091492701e-27*V06*V22 - 2.77885788120020405e-27*V05*V23 - 4.44617260992032648e-28*V04*V24 - 
      9.26285960400068017e-29*V03*V25 - 6.86137748444494827e-30*V02*V26 - 7.91697402051340185e-31*V01*V27 + 
      6.38465646815596924e-33*V30) + delta24*eps3*
    (-6.42261983982463161e-24*V142 - 1.37627567996242106e-23*V13*V15 - 9.71488715267591336e-24*V12*V16 - 
      7.8933458115491796e-24*V11*V17 - 4.15439253239430505e-24*V10*V18 - 2.53879543646318642e-24*V09*V19 - 
      9.67160166271690066e-25*V08*V20 - 4.3522207482226053e-25*V07*V21 - 1.13536193431894051e-25*V06*V22 - 
      3.61251524556026527e-26*V05*V23 - 5.78002439289642442e-27*V04*V24 - 1.20417174852008842e-27*V03*V25 - 
      8.91979072977843275e-29*V02*V26 - 1.02920662266674224e-29*V01*V27 + 4.15002670430138e-32*V30) + 
   delta22*eps4*(5.50715506077594399e-19*V08*V092 + 3.5340032475567555e-19*V082*V10 + 
      8.9528082271437806e-19*V07*V09*V10 + 2.16553315883834953e-19*V06*V102 + 7.20936662501578122e-19*V07*V08*V11 + 
      5.43563356648015251e-19*V06*V09*V11 + 3.41834495945489805e-19*V05*V10*V11 + 6.94815768932680364e-20*V04*V112 + 
      2.45857887468486898e-19*V072*V12 + 2.92599934817490315e-19*V06*V08*V12 + 2.86834202046568048e-19*V05*V09*V12 + 
      9.28707543611102179e-20*V04*V10*V12 + 5.21516730993760087e-20*V03*V11*V12 + 3.55319091446298081e-21*V02*V122 + 
      2.50875395376007039e-19*V06*V07*V13 + 1.94098332211963341e-19*V05*V08*V13 + 9.79868392084549231e-20*V04*V09*V13 + 
      4.3824935377626898e-20*V03*V10*V13 + 8.9402868170358872e-21*V02*V11*V13 + 2.0058335807452311e-21*V01*V12*V13 + 
      4.36137225807519929e-20*V062*V14 + 1.13472871139301645e-19*V05*V07*V14 + 4.51814177991727375e-20*V04*V08*V14 + 
      3.15202419831393459e-20*V03*V09*V14 + 5.11740399255674086e-21*V02*V10*V14 + 1.71928592635305523e-21*V01*V11*V14 - 
      5.30277843185520866e-23*V142 + 5.01750790752014078e-20*V05*V06*V15 + 3.35954877286131165e-20*V04*V07*V15 + 
      1.84855554487584134e-20*V03*V08*V15 + 4.68300738035213139e-21*V02*V09*V15 + 1.25214101078933994e-21*V01*V10*V15 - 
      1.11925325596943901e-22*V13*V15 + 9.86061045996605206e-21*V052*V16 + 1.01400090053859715e-20*V04*V06*V16 + 
      9.39105758092004958e-21*V03*V07*V16 + 1.87425738667625411e-21*V02*V08*V16 + 7.82588131743337465e-22*V01*V09*V16 - 
      8.04107575507455763e-23*V12*V16 + 5.18753854632996652e-21*V04*V05*V17 + 3.68934404964716234e-21*V03*V06*V17 + 
      1.23961960068144654e-21*V02*V07*V17 + 4.07769605487317942e-22*V01*V08*V17 - 6.45185445394148042e-23*V11*V17 + 
      4.57805102972235216e-22*V042*V18 + 1.26861655040498915e-21*V03*V05*V18 + 3.26733487063489043e-22*V02*V06*V18 + 
      1.81230935772141308e-22*V01*V07*V18 - 3.46436095222738772e-23*V10*V18 + 3.03364827270758276e-22*V03*V04*V19 + 
      1.52233986048598698e-22*V02*V05*V19 + 6.47253342043361813e-23*V01*V06*V19 - 2.09613366805422058e-23*V09*V19 + 
      3.23626671021680907e-23*V032*V20 + 2.33686597927307674e-23*V02*V04*V20 + 1.94176002613008544e-23*V01*V05*V20 - 
      8.16506371140907575e-24*V08*V20 + 7.24923743088565231e-24*V02*V03*V21 + 4.33378324672511823e-24*V01*V04*V21 - 
      3.64730978088227734e-24*V07*V21 + 2.36388177094097358e-25*V022*V22 + 7.8796059031365786e-25*V01*V03*V22 - 
      9.74923324796947779e-25*V06*V22 + 8.59593371251263119e-26*V01*V02*V23 - 3.08710526468889335e-25*V05*V23 + 
      3.581639046880263e-27*V012*V24 - 5.07069518855450567e-26*V04*V24 - 1.05390758161074405e-26*V03*V25 - 
      8.02781165680058948e-28*V02*V26 - 9.26285960400068017e-29*V01*V27 + 2.490016022580828e-31*V30) + 
   delta20*eps5*(7.98537483812511878e-18*V08*V092 + 5.34812491463588999e-18*V082*V10 + 
      1.30095494550683062e-17*V07*V09*V10 + 3.27882067539551445e-18*V06*V102 + 1.04535816062728828e-17*V07*V08*V11 + 
      7.86807958748002075e-18*V06*V09*V11 + 4.96728251920789872e-18*V05*V10*V11 + 1.00432461145723798e-18*V04*V112 + 
      3.58250064596938051e-18*V072*V12 + 4.43336435533937491e-18*V06*V08*V12 + 4.17958408696427727e-18*V05*V09*V12 + 
      1.40838098847909328e-18*V04*V10*V12 + 7.59924379448050412e-19*V03*V11*V12 + 5.39855780874859342e-20*V02*V122 + 
      3.63142134806770189e-18*V06*V07*V13 + 2.81442581707346844e-18*V05*V08*V13 + 1.41635522128584843e-18*V04*V09*V13 + 
      6.36831092206140862e-19*V03*V10*V13 + 1.29075390920955621e-19*V02*V11*V13 + 2.92278607480019389e-20*V01*V12*V13 + 
      6.62311043792658582e-19*V062*V14 + 1.65954074041228656e-18*V05*V07*V14 + 6.86376711010421088e-19*V04*V08*V14 + 
      4.60983539003412934e-19*V03*V09*V14 + 7.78330852306653709e-20*V02*V10*V14 + 2.51445566729134328e-20*V01*V11*V14 - 
      3.45092304470577321e-22*V142 + 7.26284269613540377e-19*V05*V06*V15 + 4.8560750444086232e-19*V04*V07*V15 + 
      2.68040554006996994e-19*V03*V08*V15 + 6.7610919053833897e-20*V02*V09*V15 + 1.81951740630325961e-20*V01*V10*V15 - 
      7.11340436380576987e-22*V13*V15 + 1.44950973761500965e-19*V052*V16 + 1.54647969833178317e-19*V04*V06*V16 + 
      1.38048546439524729e-19*V03*V07*V16 + 2.86041728591055321e-20*V02*V08*V16 + 1.15040455366270607e-20*V01*V09*V16 - 
      5.25299309491539157e-22*V12*V16 + 7.49835117151331524e-20*V04*V05*V17 + 5.34032551186426748e-20*V03*V06*V17 + 
      1.78970079848383845e-20*V02*V07*V17 + 5.91265927956611016e-21*V01*V08*V17 - 4.13354955447536952e-22*V11*V17 + 
      7.0325482685493964e-21*V042*V18 + 1.87913826528739018e-20*V03*V05*V18 + 5.02061472356194891e-21*V02*V06*V18 + 
      2.68448323612484312e-21*V01*V07*V18 - 2.28882173194988807e-22*V10*V18 + 4.38500068509550599e-21*V03*V04*V19 + 
      2.19787817357664371e-21*V02*V05*V19 + 9.36899212607766225e-22*V01*V06*V19 - 1.36411431720733517e-22*V09*V19 + 
      4.8544000653252136e-22*V032*V20 + 3.63767634808230963e-22*V02*V04*V20 + 2.91264003919512816e-22*V01*V05*V20 - 
      5.49328375208353194e-23*V08*V20 + 1.04660865408411605e-22*V02*V03*V21 + 6.26428669299357998e-23*V01*V04*V21 - 
      2.42747902117210825e-23*V07*V21 + 3.78221083350555773e-24*V022*V22 + 1.21148940760724896e-23*V01*V03*V22 - 
      6.71949890101837912e-24*V06*V22 + 1.24103792974401113e-24*V01*V02*V23 - 2.11339860914945519e-24*V05*V23 + 
      5.90970442735243395e-26*V012*V24 - 3.59812693697538421e-25*V04*V24 - 7.45505817128654742e-26*V03*V25 - 
      5.88706188165376562e-27*V02*V26 - 6.79276370960049879e-28*V01*V27 + 1.3695088124194554e-30*V30) + 
   delta18*eps6*(-4.48616519584018787e-16*V064 - 8.94203167249278406e-15*V05*V062*V07 - 
      4.68756430676455096e-15*V052*V072 - 5.97195093749807253e-15*V04*V06*V072 - 
      1.47936203145323831e-15*V03*V073 - 6.90101777365995919e-15*V052*V06*V08 - 
      2.77113458677757312e-15*V04*V062*V08 - 9.26081661527549284e-15*V04*V05*V07*V08 - 
      6.57239787967615161e-15*V03*V06*V07*V08 - 1.10332073076130262e-15*V02*V072*V08 - 
      7.12558774566068427e-16*V042*V082 - 2.52308041457366025e-15*V03*V05*V082 - 
      5.05380902678429376e-16*V02*V06*V082 - 3.60440059224808607e-16*V01*V07*V082 - 
      1.81221848853021693e-15*V053*V09 - 6.96727609374775129e-15*V04*V05*V06*V09 - 
      2.48389768680355113e-15*V03*V062*V09 - 2.31331611781168147e-15*V042*V07*V09 - 
      5.14232352504223456e-15*V03*V05*V07*V09 - 1.65069972803369648e-15*V02*V06*V07*V09 - 
      3.62588733199323114e-16*V01*V072*V09 - 2.57244905979874801e-15*V03*V04*V08*V09 - 
      1.28720751922151973e-15*V02*V05*V08*V09 - 5.47699823306345967e-16*V01*V06*V08*V09 - 
      3.50880726819000322e-16*V032*V092 - 3.16781136756807561e-16*V02*V04*V092 - 
      2.0925186629108305e-16*V01*V05*V092 + 6.47900595385405175e-17*V08*V092 - 
      2.18878336926376849e-15*V04*V052*V10 - 8.67705487992327205e-16*V042*V06*V10 - 
      3.09080814108455986e-15*V03*V05*V06*V10 - 3.07417181543249318e-16*V02*V062*V10 - 
      2.08455558977501761e-15*V03*V04*V07*V10 - 1.04794169938382275e-15*V02*V05*V07*V10 - 
      4.41544020154937123e-16*V01*V06*V07*V10 - 5.60676683231374374e-16*V032*V08*V10 - 
      3.15013122383262073e-16*V02*V04*V08*V10 - 3.36406009938824624e-16*V01*V05*V08*V10 + 
      4.59978794695492182e-17*V082*V10 - 2.91094916495506318e-16*V02*V03*V09*V10 - 
      1.73712965814584801e-16*V01*V04*V09*V10 + 1.05912840428139317e-16*V07*V09*V10 - 
      8.56483107862193025e-18*V022*V102 - 3.67972626510464579e-17*V01*V03*V102 + 
      2.83060212558496971e-17*V06*V102 - 8.83266154073551106e-16*V042*V05*V11 - 
      9.69100796005463596e-16*V03*V052*V11 - 1.26677747159050023e-15*V03*V04*V06*V11 - 
      6.30267168885593203e-16*V02*V05*V06*V11 - 1.35485328371102789e-16*V01*V062*V11 - 
      4.56549526453272109e-16*V032*V07*V11 - 4.14695306299820807e-16*V02*V04*V07*V11 - 
      2.71996429415012383e-16*V01*V05*V07*V11 - 2.34037730767549042e-16*V02*V03*V08*V11 - 
      1.40315403261749892e-16*V01*V04*V08*V11 + 8.51383790375393081e-17*V07*V08*V11 - 
      2.78422604550881203e-17*V022*V09*V11 - 7.30794763610125791e-17*V01*V03*V09*V11 + 
      6.41281743874469234e-17*V06*V09*V11 - 1.58779045361185265e-17*V01*V02*V10*V11 + 4.07445354511027254e-17*V05*V10*V11 - 
      8.90066848916775158e-19*V012*V112 + 8.2559002258536699e-18*V04*V112 - 
      6.07146609342992803e-17*V043*V12 - 6.61813833733044596e-16*V03*V04*V05*V12 - 
      1.67205415189365619e-16*V02*V052*V12 - 2.31855790198954275e-16*V032*V06*V12 - 
      1.28577657496500636e-16*V02*V04*V06*V12 - 1.39113474119372565e-16*V01*V05*V06*V12 - 
      1.59243252561300589e-16*V02*V03*V07*V12 - 9.45448333904349422e-17*V01*V04*V07*V12 + 
      2.93874473238087814e-17*V072*V12 - 1.14938253020557183e-17*V022*V08*V12 - 
      4.96896749165462919e-17*V01*V03*V08*V12 + 3.84223034757161606e-17*V06*V08*V12 - 1.32702710467750491e-17*V01*V02*V09*V12 + 
      3.44130121911419594e-17*V05*V09*V12 - 1.5544213563282003e-18*V012*V10*V12 + 1.22950122296540487e-17*V04*V10*V12 + 
      6.32654238749765499e-18*V03*V11*V12 + 4.78129678540683892e-19*V02*V122 - 
      1.13239250522250142e-16*V03*V042*V13 - 1.2043230636304643e-16*V032*V05*V13 - 
      1.11648736311490217e-16*V02*V04*V05*V13 - 3.5731738429929615e-17*V01*V052*V13 - 
      8.0803483190460667e-17*V02*V03*V06*V13 - 4.87222104457884705e-17*V01*V04*V06*V13 - 
      1.28502740561945171e-17*V022*V07*V13 - 3.32668823746511836e-17*V01*V03*V07*V13 + 
      2.98222184467548409e-17*V06*V07*V13 - 9.00145118336727083e-18*V01*V02*V08*V13 + 2.31821913954806098e-17*V05*V08*V13 - 
      1.24629541770092667e-18*V012*V09*V13 + 1.16868394101382844e-17*V04*V09*V13 + 
      5.30188590081608009e-18*V03*V10*V13 + 1.07830062601667895e-18*V02*V11*V13 + 2.47792084135634085e-19*V01*V12*V13 - 
      3.5709051611878866e-17*V032*V04*V14 - 9.59963275489394107e-18*V02*V042*V14 - 
      3.63607867100278612e-17*V02*V03*V05*V14 - 2.14254309671273196e-17*V01*V04*V05*V14 - 
      3.34953107171274943e-18*V022*V06*V14 - 1.47827306418680236e-17*V01*V03*V06*V14 + 
      5.80715783574750585e-18*V062*V14 - 5.1943981014325516e-18*V01*V02*V07*V14 + 1.38256377767680936e-17*V05*V07*V14 - 
      7.55408505672181901e-19*V012*V08*V14 + 6.03944361528490781e-18*V04*V08*V14 + 
      3.86839333429437427e-18*V03*V09*V14 + 6.92096131220533651e-19*V02*V10*V14 + 2.14051097830955376e-19*V01*V11*V14 - 
      1.89356124546829668e-21*V142 - 3.66013997885416585e-18*V033*V15 - 
      1.06332129820466874e-17*V02*V03*V04*V15 - 3.23540715777857548e-18*V01*V042*V15 - 
      2.57005481123890341e-18*V022*V05*V15 - 6.43558302164304669e-18*V01*V03*V05*V15 - 
      2.3086709482988762e-18*V01*V02*V06*V15 + 6.05428348883193408e-18*V05*V06*V15 - 
      4.17158943881495489e-19*V012*V07*V15 + 4.05207394035795021e-18*V04*V07*V15 + 
      2.24914840530658248e-18*V03*V08*V15 + 5.69023573403384661e-19*V02*V09*V15 + 1.54835061865419317e-19*V01*V10*V15 - 
      3.80383188925613711e-21*V13*V15 - 1.47350206309834647e-18*V02*V032*V16 - 
      3.71375281741910713e-19*V022*V04*V16 - 1.71067504894039623e-18*V01*V03*V04*V16 - 
      8.84101237859007882e-19*V01*V02*V05*V16 + 1.2315902464497599e-18*V052*V16 - 
      1.69050640967072785e-19*V012*V06*V16 + 1.38238068358027677e-18*V04*V06*V16 + 
      1.17707515719251901e-18*V03*V07*V16 + 2.57422856685301392e-19*V02*V08*V16 + 9.91226127666111233e-20*V01*V09*V16 - 
      2.89406903444333095e-21*V12*V16 - 1.8897461847344878e-19*V022*V03*V17 - 
      2.20195586963151689e-19*V01*V032*V17 - 2.34556168721618103e-19*V01*V02*V04*V17 - 
      6.11760782910669257e-20*V012*V05*V17 + 6.37309321605777932e-19*V04*V05*V17 + 
      4.55076705003925214e-19*V03*V06*V17 + 1.52847117882936513e-19*V02*V07*V17 + 5.08896467648172792e-20*V01*V08*V17 - 
      2.22924951841677783e-21*V11*V17 - 3.61673910953968958e-21*V023*V18 - 5.45702106821723751e-20*V01*V02*V03*V18 - 
      1.51583918561589931e-20*V012*V04*V18 + 6.43738193567073277e-20*V042*V18 + 
      1.64120470048554016e-19*V03*V05*V18 + 4.61046435143389756e-20*V02*V06*V18 + 2.36030639976242536e-20*V01*V07*V18 - 
      1.27617896511908607e-21*V10*V18 - 3.31534418374471544e-21*V01*V022*V19 - 
      3.19124039077031433e-21*V012*V03*V19 + 3.82210133839018665e-20*V03*V04*V19 + 1.9180241204193692e-20*V02*V05*V19 + 
      8.21558667055639149e-21*V01*V06*V19 - 7.47995534847316065e-22*V09*V19 - 3.79403024236026259e-22*V012*V02*V20 + 
      4.37963973893640771e-21*V032*V20 + 3.43894143062534349e-21*V02*V04*V20 + 2.63593923547159098e-21*V01*V05*V20 - 
      3.12286346087466005e-22*V08*V20 - 1.06374679692343811e-23*V013*V21 + 9.39347518727669376e-22*V02*V03*V21 + 
      5.63490317148054577e-22*V01*V04*V21 - 1.36341126616339151e-22*V07*V21 + 3.72311378923203339e-23*V022*V22 + 
      1.14057295447901975e-22*V01*V03*V22 - 3.92087540068889534e-23*V06*V22 + 1.15239236333372462e-23*V01*V02*V23 - 
      1.22373336419380386e-23*V05*V23 + 5.90970442735243395e-25*V012*V24 - 2.16757089973351916e-24*V04*V24 - 
      4.47473309369932858e-25*V03*V25 - 3.67941367603360351e-26*V02*V26 - 4.24547731850031174e-27*V01*V27 + 
      6.84754406209727701e-30*V30) + delta16*eps7*
    (-7.34206382378028133e-15*V064 - 1.26850963458063282e-13*V05*V062*V07 - 
      6.55247959665185957e-14*V052*V072 - 8.45494331555300777e-14*V04*V06*V072 - 
      2.07110684403453363e-14*V03*V073 - 9.82765845876355675e-14*V052*V06*V08 - 
      4.54709966735524697e-14*V04*V062*V08 - 1.31480939504825697e-13*V04*V05*V07*V08 - 
      9.35967472263195881e-14*V03*V06*V07*V08 - 1.56430238338706235e-14*V02*V072*V08 - 
      1.17259622953321769e-14*V042*V082 - 3.61090033102099245e-14*V03*V05*V082 - 
      8.33714019981313481e-15*V02*V06*V082 - 5.15842904431570351e-15*V01*V07*V082 - 
      2.5371058839423037e-14*V053*V09 - 9.8641005348118424e-14*V04*V05*V06*V09 - 
      3.52363787383509116e-14*V03*V062*V09 - 3.27320935750135619e-14*V042*V07*V09 - 
      7.21224891624196487e-14*V03*V05*V07*V09 - 2.33708877377919834e-14*V02*V06*V07*V09 - 
      5.10283210522514063e-15*V01*V072*V09 - 3.6522483195784916e-14*V03*V04*V08*V09 - 
      1.82501944728490607e-14*V02*V05*V08*V09 - 7.79972893552663234e-15*V01*V06*V08*V09 - 
      4.94418043201276432e-15*V032*V092 - 4.49312020502002561e-15*V02*V04*V092 - 
      2.95331703793771478e-15*V01*V05*V092 + 3.79750736470270608e-16*V08*V092 - 
      3.12313497958389332e-14*V04*V052*V10 - 1.43212533605983009e-14*V042*V06*V10 - 
      4.42842469492141436e-14*V03*V05*V06*V10 - 5.08775746460910372e-15*V02*V062*V10 - 
      2.97441426627037459e-14*V03*V04*V07*V10 - 1.49166848148849441e-14*V02*V05*V07*V10 - 
      6.32632099274487766e-15*V01*V06*V07*V10 - 8.08521985387725728e-15*V032*V08*V10 - 
      5.23418054551202919e-15*V02*V04*V08*V10 - 4.85113191232635437e-15*V01*V05*V08*V10 + 
      2.86640883007379905e-16*V082*V10 - 4.14352355969026224e-15*V02*V03*V09*V10 - 
      2.47867855522531216e-15*V01*V04*V09*V10 + 6.23018090819736941e-16*V07*V09*V10 - 
      1.44378242369284632e-16*V022*V102 - 5.36268736401798886e-16*V01*V03*V102 + 
      1.77476156057167523e-16*V06*V102 - 1.24977084559142691e-14*V042*V05*V11 - 
      1.36384785357835577e-14*V03*V052*V11 - 1.79347282451124407e-14*V03*V04*V06*V11 - 
      8.92342986352057548e-15*V02*V05*V06*V11 - 1.92198429481914063e-15*V01*V062*V11 - 
      6.44360081004592315e-15*V032*V07*V11 - 5.88190281384439716e-15*V02*V04*V07*V11 - 
      3.84618319263906144e-15*V01*V05*V07*V11 - 3.3182171768816474e-15*V02*V03*V08*V11 - 
      1.9921354470428136e-15*V01*V04*V08*V11 + 5.02325342009665761e-16*V07*V08*V11 - 
      3.97980546505083131e-16*V022*V09*V11 - 1.04280831740192632e-15*V01*V03*V09*V11 + 
      3.79448276278040429e-16*V06*V09*V11 - 2.26010375983105213e-16*V01*V02*V10*V11 + 2.42826407126078001e-16*V05*V10*V11 - 
      1.31199082797811721e-17*V012*V112 + 4.96118762076116878e-17*V04*V112 - 
      1.01180421757528827e-15*V043*V12 - 9.51670270746231298e-15*V03*V04*V05*V12 - 
      2.39601757314829602e-15*V02*V052*V12 - 3.3527522090915847e-15*V032*V06*V12 - 
      2.15097048744028581e-15*V02*V04*V06*V12 - 2.01165132545495082e-15*V01*V05*V06*V12 - 
      2.2819214982364724e-15*V02*V03*V07*V12 - 1.35952895820890185e-15*V01*V04*V07*V12 + 
      1.74604354164330062e-16*V072*V12 - 1.94446677797083224e-16*V022*V08*V12 - 
      7.25320499429494088e-16*V01*V03*V08*V12 + 2.42360576913313143e-16*V06*V08*V12 - 1.90160124853039367e-16*V01*V02*V09*V12 + 
      2.0579014386556974e-16*V05*V09*V12 - 2.31440927460396376e-17*V012*V10*V12 + 7.84854587587295795e-17*V04*V10*V12 + 
      3.85536974340224988e-17*V03*V11*V12 + 3.12336320357788239e-18*V02*V122 - 
      1.60227031486080373e-15*V03*V042*V13 - 1.70913857306692002e-15*V032*V05*V13 - 
      1.58358921911195308e-15*V02*V04*V05*V13 - 5.08629385970571426e-16*V01*V052*V13 - 
      1.14402946968212506e-15*V02*V03*V06*V13 - 6.89797240196632336e-16*V01*V04*V06*V13 - 
      1.83683329156192214e-16*V022*V07*V13 - 4.76521043771045156e-16*V01*V03*V07*V13 + 
      1.78736043395954438e-16*V06*V07*V13 - 1.27623737572371054e-16*V01*V02*V08*V13 + 1.39439100106179099e-16*V05*V08*V13 - 
      1.84101884509505308e-17*V012*V09*V13 + 7.06679175536846871e-17*V04*V09*V13 + 
      3.23999938493564539e-17*V03*V10*V13 + 6.6556548271607382e-18*V02*V11*V13 + 1.55573885260872085e-18*V01*V12*V13 - 
      5.19573506998252725e-16*V032*V04*V14 - 1.63128039200778097e-16*V02*V042*V14 - 
      5.2646913923462922e-16*V02*V03*V05*V14 - 3.11744104198951635e-16*V01*V04*V05*V14 - 
      5.73340801598107289e-17*V022*V06*V14 - 2.16913204746820974e-16*V01*V03*V06*V14 + 
      3.72838824329503798e-17*V062*V14 - 7.520987703351846e-17*V01*V02*V07*V14 + 8.39982928608680429e-17*V05*V07*V14 - 
      1.1289970254467218e-17*V012*V08*V14 + 3.90013947631343566e-17*V04*V08*V14 + 2.37938426670223137e-17*V03*V09*V14 + 
      4.54630205875946513e-18*V02*V10*V14 + 1.34813507700158943e-18*V01*V11*V14 - 8.97659932151489569e-21*V142 - 
      5.25729196962689277e-17*V033*V15 - 1.50818020867805055e-16*V02*V03*V04*V15 - 
      4.57791518531658209e-17*V01*V042*V15 - 3.67366658312384429e-17*V022*V05*V15 - 
      9.30536764035747341e-17*V01*V03*V05*V15 - 3.26865562766321446e-17*V01*V02*V06*V15 + 3.71896365708575066e-17*V05*V06*V15 - 
      6.20726040915139994e-18*V012*V07*V15 + 2.49515214428033644e-17*V04*V07*V15 + 
      1.39462098311928584e-17*V03*V08*V15 + 3.55329547765984752e-18*V02*V09*V15 + 9.80074246788768674e-19*V01*V10*V15 - 
      1.76222043419988291e-20*V13*V15 - 2.16829892097685931e-17*V02*V032*V16 - 
      6.50910920024639473e-18*V022*V04*V16 - 2.53626170299423963e-17*V01*V03*V04*V16 - 
      1.30097935258611558e-17*V01*V02*V05*V16 + 7.6893040366815274e-18*V052*V16 - 
      2.54869477555668077e-18*V012*V06*V16 + 9.12964400060918768e-18*V04*V06*V16 + 
      7.39235879597283543e-18*V03*V07*V16 + 1.71889491055298644e-18*V02*V08*V16 + 6.33332923257248144e-19*V01*V09*V16 - 
      1.37678571153793654e-20*V12*V16 - 2.70122542876753257e-18*V022*V03*V17 - 
      3.25155483415587327e-18*V01*V032*V17 - 3.32686810737805269e-18*V01*V02*V04*V17 - 
      9.25012939668683312e-19*V012*V05*V17 + 4.03875139818214825e-18*V04*V05*V17 + 
      2.89362341237922317e-18*V03*V06*V17 + 9.76048851618077564e-19*V02*V07*V17 + 3.28213755456742212e-19*V01*V08*V17 - 
      1.03994426280195746e-20*V11*V17 - 6.63778001280225381e-20*V023*V18 - 8.24935641014126255e-19*V01*V02*V03*V18 - 
      2.32481862467617399e-19*V012*V04*V18 + 4.39027805114913171e-19*V042*V18 + 
      1.063340800229279e-18*V03*V05*V18 + 3.16082736330017946e-19*V02*V06*V18 + 1.54605845920516598e-19*V01*V07*V18 - 
      6.13607824904285805e-21*V10*V18 - 4.73899198029391678e-20*V01*V022*V19 - 
      5.0102474135093935e-20*V012*V03*V19 + 2.51407690896213569e-19*V03*V04*V19 + 1.26399713144427533e-19*V02*V05*V19 + 
      5.44867572132232625e-20*V01*V06*V19 - 3.5391823902471404e-21*V09*V19 - 6.03144433855589409e-21*V012*V02*V20 + 
      2.95370826374777947e-20*V032*V20 + 2.44281853722060966e-20*V02*V04*V20 + 1.78690466404621113e-20*V01*V05*V20 - 
      1.5288112779523826e-21*V08*V20 - 1.9147442344621886e-22*V013*V21 + 6.43389521005859484e-21*V02*V03*V21 + 
      3.87115188513721186e-21*V01*V04*V21 - 6.59309551492957433e-22*V07*V21 + 2.76574167200093909e-22*V022*V22 + 
      8.07561109997710099e-22*V01*V03*V22 - 1.96911642637827796e-22*V06*V22 + 8.24403767615664536e-23*V01*V02*V23 - 
      6.09519782235234957e-23*V05*V23 + 4.43227832051432546e-24*V012*V24 - 1.12498356176548661e-23*V04*V24 - 
      2.31293604311896984e-24*V03*V25 - 1.9868833850581459e-25*V02*V26 - 2.29255775199016834e-26*V01*V27 + 
      3.08139482794377465e-29*V30) + delta14*eps8*
    (2.35507378426005005e-12*V043*V052 + 5.39330385626284643e-12*V03*V04*V053 + 
      6.88466707637125585e-13*V02*V054 + 3.1637336346366468e-13*V044*V06 + 
      1.0128598222905747e-11*V03*V042*V05*V06 + 5.60203400580988479e-12*V032*V052*V06 + 
      5.00458911220634749e-12*V02*V04*V052*V06 + 1.1016481335927049e-12*V01*V053*V06 + 
      3.59755664865051297e-12*V032*V04*V062 + 6.61421923585583323e-13*V02*V042*V062 + 
      3.5956297266427196e-12*V02*V03*V05*V062 + 2.15853398919030778e-12*V01*V04*V05*V062 + 
      7.63853768139394869e-14*V022*V063 + 5.04755377957519226e-13*V01*V03*V063 - 
      6.2256926751198383e-14*V064 + 2.24292741358100004e-12*V03*V043*V07 + 
      7.59694726657796423e-12*V032*V04*V05*V07 + 3.29027994910963913e-12*V02*V042*V05*V07 + 
      3.88847318858481207e-12*V02*V03*V052*V07 + 2.24675242154841578e-12*V01*V04*V052*V07 + 
      1.74864783109953159e-12*V033*V06*V07 + 4.76627534495842619e-12*V02*V03*V04*V06*V07 + 
      1.44694260327224958e-12*V01*V042*V06*V07 + 1.15692431047412348e-12*V022*V05*V06*V07 + 
      3.07762258254794945e-12*V01*V03*V05*V06*V07 + 5.13661389520388515e-13*V01*V02*V062*V07 - 
      9.42006032871439169e-13*V05*V062*V07 + 9.13017171480372307e-13*V02*V032*V072 + 
      3.76241252751854662e-13*V022*V04*V072 + 1.04684224853117798e-12*V01*V03*V04*V072 + 
      5.41292833798604223e-13*V01*V02*V05*V072 - 4.75911104879919518e-13*V052*V072 + 
      1.01723480862693579e-13*V012*V06*V072 - 6.29308193489189785e-13*V04*V06*V072 - 
      1.51545961948382109e-13*V03*V073 + 1.85358347412499737e-12*V032*V042*V08 + 
      2.23657512618854329e-13*V02*V043*V08 + 1.32637060567983116e-12*V033*V05*V08 + 
      3.69646701706884502e-12*V02*V03*V04*V05*V08 + 1.11215008447499842e-12*V01*V042*V05*V08 + 
      4.52270181011196878e-13*V022*V052*V08 + 1.16357203439198338e-12*V01*V03*V052*V08 + 
      1.31660051684880815e-12*V02*V032*V06*V08 + 2.31925124161845252e-13*V022*V04*V06*V08 + 
      1.56122149013202281e-12*V01*V03*V04*V06*V08 + 7.8996031010928489e-13*V01*V02*V05*V06*V08 - 
      7.3328091220647616e-13*V052*V06*V08 + 8.00286287486456962e-14*V012*V062*V08 - 
      3.87975902269054153e-13*V04*V062*V08 + 4.30733505724949408e-13*V022*V03*V07*V08 + 
      5.39719296986723196e-13*V01*V032*V07*V08 + 5.28066716724120717e-13*V01*V02*V04*V07*V08 + 
      1.5292828601852896e-13*V012*V05*V07*V08 - 9.82752412489036078e-13*V04*V05*V07*V08 - 
      7.02569620265405834e-13*V03*V06*V07*V08 - 1.17931399348594738e-13*V02*V072*V08 + 
      6.69504784238175546e-15*V023*V082 + 1.42768095707150999e-13*V01*V02*V03*V082 + 
      4.12321448947806462e-14*V012*V04*V082 - 1.00684561450507463e-13*V042*V082 - 
      2.7244245951980103e-13*V03*V05*V082 - 7.20150591440760036e-14*V02*V06*V082 - 
      3.93805813103512825e-14*V01*V07*V082 + 6.83463167630692065e-13*V033*V04*V09 + 
      9.13966652530455315e-13*V02*V03*V042*V09 + 1.8691061779841667e-13*V01*V043*V09 + 
      1.05251384349728599e-12*V02*V032*V05*V09 + 4.38948128210497106e-13*V022*V04*V05*V09 + 
      1.20335386860583348e-12*V01*V03*V04*V05*V09 + 3.11270730685248432e-13*V01*V02*V052*V09 - 
      1.85663164695406226e-13*V053*V09 + 3.21367864020589857e-13*V022*V03*V06*V09 + 
      4.10289288341899865e-13*V01*V032*V06*V09 + 3.97189612079868849e-13*V01*V02*V04*V06*V09 + 
      1.1644421962918155e-13*V012*V05*V06*V09 - 7.3867914771912083e-13*V04*V05*V06*V09 - 
      2.64857061775150264e-13*V03*V062*V09 + 3.28144186416223419e-14*V023*V07*V09 + 
      2.89513621919572316e-13*V01*V02*V03*V07*V09 + 7.95621864156627378e-14*V012*V04*V07*V09 - 
      2.45860160648114288e-13*V042*V07*V09 - 5.31756052052083213e-13*V03*V05*V07*V09 - 
      1.76653134013751701e-13*V02*V06*V07*V09 - 3.81738632799045893e-14*V01*V072*V09 + 
      3.58944588104124506e-14*V01*V022*V08*V09 + 4.00863087575386264e-14*V012*V03*V08*V09 - 
      2.76287578102280811e-13*V03*V04*V08*V09 - 1.38414799522561442e-13*V02*V05*V08*V09 - 
      5.95991800393076211e-14*V01*V06*V08*V09 + 5.46573122039895515e-15*V012*V02*V092 - 
      3.70205749417367073e-14*V032*V092 - 3.43136211819166243e-14*V02*V04*V092 - 
      2.22694838787587368e-14*V01*V05*V092 + 1.75815601364974319e-15*V08*V092 + 
      7.13960256425088574e-14*V034*V10 + 4.12382840676584542e-13*V02*V032*V04*V10 + 
      3.52902630852678872e-14*V022*V042*V10 + 2.45227411077153522e-13*V01*V03*V042*V10 + 
      2.03543540650939398e-13*V022*V03*V05*V10 + 2.48086925858791731e-13*V01*V032*V05*V10 + 
      2.47429704405950725e-13*V01*V02*V04*V05*V10 + 3.49710714692579749e-14*V012*V052*V10 - 
      2.36083996391657882e-13*V04*V052*V10 + 8.052229042807684e-15*V023*V06*V10 + 
      1.74006404430094811e-13*V01*V02*V03*V06*V10 + 5.02953956410009868e-14*V012*V04*V06*V10 - 
      1.23751897475290984e-13*V042*V06*V10 - 3.36313607147811151e-13*V03*V05*V06*V10 - 
      4.42315251698325436e-14*V02*V062*V10 + 2.90776486644199139e-14*V01*V022*V07*V10 + 
      3.20288157153542396e-14*V012*V03*V07*V10 - 2.26174512961892422e-13*V03*V04*V07*V10 - 
      1.13658394798520683e-13*V02*V05*V07*V10 - 4.86081734818727821e-14*V01*V06*V07*V10 + 
      9.16444207788403927e-15*V012*V02*V08*V10 - 6.21136505345846184e-14*V032*V08*V10 - 
      4.58131085651719322e-14*V02*V04*V08*V10 - 3.74819600969795208e-14*V01*V05*V08*V10 + 
      1.40272626093548825e-15*V082*V10 + 7.35595415710697318e-16*V013*V09*V10 - 
      3.19446931879264903e-14*V02*V03*V09*V10 - 1.91810289892836924e-14*V01*V04*V09*V10 + 2.89231312706572991e-15*V07*V09*V10 - 
      1.29087015069869918e-15*V022*V102 - 4.22201059214955624e-15*V01*V03*V102 + 
      8.7531860031276066e-16*V06*V102 + 6.12091820913871831e-14*V02*V033*V11 + 
      7.98087505837267465e-14*V022*V03*V04*V11 + 1.03686350858970266e-13*V01*V032*V04*V11 + 
      4.9852726501661199e-14*V01*V02*V042*V11 + 1.25291416631648942e-14*V023*V05*V11 + 
      1.0752873588460693e-13*V01*V02*V03*V05*V11 + 2.93985391034053639e-14*V012*V04*V05*V11 - 
      9.50165954753263758e-14*V042*V05*V11 - 1.0207624806039861e-13*V03*V052*V11 + 
      1.75291562193049013e-14*V01*V022*V06*V11 + 1.97058943271430255e-14*V012*V03*V06*V11 - 
      1.36752347938967104e-13*V03*V04*V06*V11 - 6.82645199531197787e-14*V02*V05*V06*V11 - 
      1.4794609112556735e-14*V01*V062*V11 + 7.0563895204977358e-15*V012*V02*V07*V11 - 
      4.86066102769434268e-14*V032*V07*V11 - 4.51897795363406399e-14*V02*V04*V07*V11 - 
      2.92199066434005037e-14*V01*V05*V07*V11 + 5.94536014549359353e-16*V013*V08*V11 - 
      2.56180546127571243e-14*V02*V03*V08*V11 - 1.54303184625236455e-14*V01*V04*V08*V11 + 2.34408338056338325e-15*V07*V08*V11 - 
      3.11648381170519151e-15*V022*V09*V11 - 8.05853468833981609e-15*V01*V03*V09*V11 + 
      1.77963751824100912e-15*V06*V09*V11 - 1.78311964897825348e-15*V01*V02*V10*V11 + 1.1459049713302062e-15*V05*V10*V11 - 
      1.05459850752079744e-16*V012*V112 + 2.37547917906263567e-16*V04*V112 + 
      1.52525141068358642e-14*V022*V032*V12 + 1.17596105971387453e-14*V01*V033*V12 + 
      1.62032944752791867e-15*V023*V04*V12 + 3.66192626889360174e-14*V01*V02*V03*V04*V12 + 
      5.30808529895446134e-15*V012*V042*V12 - 8.91213407167000147e-15*V043*V12 + 
      9.15150846410151852e-15*V01*V022*V05*V12 + 9.80679950661887164e-15*V012*V03*V05*V12 - 
      7.36852272780232135e-14*V03*V04*V05*V12 - 1.85802239602777975e-14*V02*V052*V12 + 
      3.75473724082799042e-15*V012*V02*V06*V12 - 2.60928654740262308e-14*V032*V06*V12 - 
      1.90697685334469798e-14*V02*V04*V06*V12 - 1.57439574873784056e-14*V01*V05*V06*V12 + 
      3.93004735476517777e-16*V013*V07*V12 - 1.77969527992233029e-14*V02*V03*V07*V12 - 
      1.0646790530117513e-14*V01*V04*V07*V12 + 8.18619305942503411e-16*V072*V12 - 
      1.7496502802931511e-15*V022*V08*V12 - 5.74719224038411533e-15*V01*V03*V08*V12 + 
      1.20375159168186655e-15*V06*V08*V12 - 1.50845475205591107e-15*V01*V02*V09*V12 + 9.73061545993915613e-16*V05*V09*V12 - 
      1.88581051499437961e-16*V012*V10*V12 + 3.9600806983082428e-16*V04*V10*V12 + 1.86845920911636295e-16*V03*V11*V12 + 
      1.62416456368852207e-17*V02*V122 + 1.60630021322626848e-15*V023*V03*V13 + 
      6.4254987020082125e-15*V01*V02*V032*V13 + 3.0695673301433364e-15*V01*V022*V04*V13 + 
      3.45546360666068958e-15*V012*V03*V04*V13 - 1.24746188955898646e-14*V03*V042*V13 + 
      1.81050555833806705e-15*V012*V02*V05*V13 - 1.3182339638802919e-14*V032*V05*V13 - 
      1.23846610202144402e-14*V02*V04*V05*V13 - 3.95227360913456059e-15*V01*V052*V13 + 
      2.02879916602831963e-16*V013*V06*V13 - 8.96087217642702106e-15*V02*V03*V06*V13 - 
      5.41656776391363267e-15*V01*V04*V06*V13 - 1.45533965028767569e-15*V022*V07*V13 - 
      3.73673003834541619e-15*V01*V03*V07*V13 + 8.50569575782453662e-16*V06*V07*V13 - 1.01426667913404723e-15*V01*V02*V08*V13 + 
      6.65816973411454945e-16*V05*V08*V13 - 1.49055682538065716e-16*V012*V09*V13 + 
      3.40638052108108738e-16*V04*V09*V13 + 1.57745758916597785e-16*V03*V10*V13 + 3.29867430439438251e-17*V02*V11*V13 + 
      7.83601936716412597e-18*V01*V12*V13 + 1.94336611494474191e-17*V024*V14 + 
      9.68033413128579765e-16*V01*V022*V03*V14 + 4.87276452248782066e-16*V012*V032*V14 + 
      5.65577151975441268e-16*V012*V02*V04*V14 - 4.14782248581965959e-15*V032*V04*V14 - 
      1.48441281213257568e-15*V02*V042*V14 + 8.50891062859058144e-17*V013*V05*V14 - 
      4.20642581189548862e-15*V02*V03*V05*V14 - 2.50222130134117737e-15*V01*V04*V05*V14 - 
      5.25947800152932185e-16*V022*V06*V14 - 1.75182054295518458e-15*V01*V03*V06*V14 + 
      1.89031595263368786e-16*V062*V14 - 6.07493346661976358e-16*V01*V02*V07*V14 + 
      4.03522144097446741e-16*V05*V07*V14 - 9.31577804673769177e-17*V012*V08*V14 + 
      1.99320373596417201e-16*V04*V08*V14 + 1.16245219695545947e-16*V03*V09*V14 + 2.3778878613523285e-17*V02*V10*V14 + 
      6.8008036727040445e-18*V01*V11*V14 - 3.69652918266080612e-20*V142 + 
      4.58942918064648138e-17*V01*V023*V15 + 1.54226265605147751e-16*V012*V02*V03*V15 - 
      4.20893758885493681e-16*V033*V15 + 2.57533099535164367e-17*V013*V04*V15 - 
      1.21412357561987932e-15*V02*V03*V04*V15 - 3.6897500091946079e-16*V01*V042*V15 - 
      2.97852932627031595e-16*V022*V05*V15 - 7.51525836310361637e-16*V01*V03*V05*V15 - 
      2.64982518354019204e-16*V01*V02*V06*V15 + 1.81997009349986521e-16*V05*V06*V15 - 
      5.13606738464949776e-17*V012*V07*V15 + 1.22654111747908539e-16*V04*V07*V15 + 
      6.90465812794839058e-17*V03*V08*V15 + 1.78208791724052304e-17*V02*V09*V15 + 4.98398737326352444e-18*V01*V10*V15 - 
      7.12953494384185117e-20*V13*V15 + 1.1137428963788397e-17*V012*V022*V16 + 
      6.10803410793438163e-18*V013*V03*V16 - 1.79641304077242534e-16*V02*V032*V16 - 
      6.17156106664664935e-17*V022*V04*V16 - 2.11308620722934517e-16*V01*V03*V04*V16 - 
      1.08337292532667554e-16*V01*V02*V05*V16 + 3.80219780308867073e-17*V052*V16 - 
      2.15593818319660896e-17*V012*V06*V16 + 4.78338732852947527e-17*V04*V06*V16 + 
      3.68625447919736493e-17*V03*V07*V16 + 9.14643664831279325e-18*V02*V08*V16 + 3.2361788577276163e-18*V01*V09*V16 - 
      5.6845179760082636e-20*V12*V16 + 8.36104982381822355e-19*V013*V02*V17 - 
      2.26492968000938442e-17*V022*V03*V17 - 2.74893447260954876e-17*V01*V032*V17 - 
      2.78516568851276107e-17*V01*V02*V04*V17 - 7.94172083647100424e-18*V012*V05*V17 + 
      2.04835189590256935e-17*V04*V05*V17 + 1.4730218574014496e-17*V03*V06*V17 + 5.00934322873200858e-18*V02*V07*V17 + 
      1.7028990598548859e-18*V01*V08*V17 - 4.22620822393289065e-20*V11*V17 + 1.9147442344621886e-20*V014*V18 - 
      6.61650507686378505e-19*V023*V18 - 7.1707171580608963e-18*V01*V02*V03*V18 - 
      2.03984085778038492e-18*V012*V04*V18 + 2.38412250860465566e-18*V042*V18 + 
      5.47547707514385916e-18*V03*V05*V18 + 1.72956111350063122e-18*V02*V06*V18 + 8.09085813739967027e-19*V01*V07*V18 - 
      2.55481496550053068e-20*V10*V18 - 4.14861250800140863e-19*V01*V022*V19 - 
      4.54751755684769792e-19*V012*V03*V19 + 1.3286197493573742e-18*V03*V04*V19 + 6.70532793440689213e-19*V02*V05*V19 + 
      2.91185489274977991e-19*V01*V06*V19 - 1.45291153206743851e-20*V09*V19 - 5.55275827994034694e-20*V012*V02*V20 + 
      1.58730017579493456e-19*V032*V20 + 1.38834153381321865e-19*V02*V04*V20 + 9.67857621372196761e-20*V01*V05*V20 - 
      6.46373776182450114e-21*V08*V20 - 1.9147442344621886e-21*V013*V21 + 3.55823303570890048e-20*V02*V03*V21 + 
      2.14876852978534498e-20*V01*V04*V21 - 2.75476796222807948e-21*V07*V21 + 1.64880753523132907e-21*V022*V22 + 
      4.57411122677078387e-21*V01*V03*V22 - 8.52473408053365111e-22*V06*V22 + 4.7868605861554715e-22*V01*V02*V23 - 
      2.6161140693877141e-22*V05*V23 + 2.65936699230859528e-23*V012*V24 - 5.03323412590268159e-23*V04*V24 - 
      1.03012261656091564e-23*V03*V25 - 9.27212246360468085e-25*V02*V26 - 1.06986028426207856e-25*V01*V27 + 
      1.23255793117750986e-28*V30) + delta12*eps9*
    (2.99274705639916675e-11*V043*V052 + 6.58249687646379103e-11*V03*V04*V053 + 
      8.38355745128408355e-12*V02*V054 + 5.91350753111858379e-12*V044*V06 + 
      1.29112358279710881e-10*V03*V042*V05*V06 + 6.87725617938263416e-11*V032*V052*V06 + 
      6.37949307878690797e-11*V02*V04*V052*V06 + 1.35878554204104533e-11*V01*V053*V06 + 
      4.60783274315401983e-11*V032*V04*V062 + 1.24775010640780169e-11*V02*V042*V062 + 
      4.5956102350150425e-11*V02*V03*V05*V062 + 2.7646996458924119e-11*V01*V04*V05*V062 + 
      1.45662197747842583e-12*V022*V063 + 6.5030447635881829e-12*V01*V03*V063 - 
      3.50616975686924707e-13*V064 + 2.85023529180873024e-11*V03*V043*V07 + 
      9.31233517847333218e-11*V032*V04*V05*V07 + 4.19179686773922271e-11*V02*V042*V05*V07 + 
      4.7546133452372778e-11*V02*V03*V052*V07 + 2.76633101717094601e-11*V01*V04*V052*V07 + 
      2.15680244768419894e-11*V033*V06*V07 + 6.0757076940827695e-11*V02*V03*V04*V06*V07 + 
      1.84446226113872687e-11*V01*V042*V06*V07 + 1.48093880265108019e-11*V022*V05*V06*V07 + 
      3.81885381911825697e-11*V01*V03*V05*V06*V07 + 6.56515747859291785e-12*V01*V02*V062*V07 - 
      4.7504363079003252e-12*V05*V062*V07 + 1.12180398817314233e-11*V02*V032*V072 + 
      4.82828651882513257e-12*V022*V04*V072 + 1.29708627581858364e-11*V01*V03*V04*V072 + 
      6.67940833955408062e-12*V01*V02*V05*V072 - 2.33622696927972026e-12*V052*V072 + 
      1.28726504296064179e-12*V012*V06*V072 - 3.19493265130704942e-12*V04*V06*V072 - 
      7.53032381752962175e-13*V03*V073 + 2.38132382141785785e-11*V032*V042*V08 + 
      4.25662720272345912e-12*V02*V043*V08 + 1.64457007008087424e-11*V033*V05*V08 + 
      4.74111459426845681e-11*V02*V03*V04*V05*V08 + 1.42879429285071471e-11*V01*V042*V05*V08 + 
      5.81308164503694043e-12*V022*V052*V08 + 1.45202422111765354e-11*V01*V03*V052*V08 + 
      1.69597472347494122e-11*V02*V032*V06*V08 + 4.46521874484051658e-12*V022*V04*V06*V08 + 
      2.01747533438157336e-11*V01*V03*V04*V06*V08 + 1.01758483408496473e-11*V01*V02*V05*V06*V08 - 
      3.71345497569127969e-12*V052*V06*V08 + 1.03943458475259342e-12*V012*V062*V08 - 
      2.20757693571267634e-12*V04*V062*V08 + 5.53626823336851469e-12*V022*V03*V07*V08 + 
      6.78064466267866795e-12*V01*V032*V07*V08 + 6.7730208489549383e-12*V01*V02*V04*V07*V08 + 
      1.94795764325240098e-12*V012*V05*V07*V08 - 5.0094286982996104e-12*V04*V05*V07*V08 - 
      3.59771978939794215e-12*V03*V06*V07*V08 - 6.11503626802998923e-13*V02*V072*V08 + 
      1.32049579085802776e-13*V023*V082 + 1.85627442163221303e-12*V01*V02*V03*V082 + 
      5.37293571340890865e-13*V012*V04*V082 - 5.78765396274511515e-13*V042*V082 - 
      1.40113686956856952e-12*V03*V05*V082 - 4.18231179472413647e-13*V02*V06*V082 - 
      2.06931258449005453e-13*V01*V07*V082 + 8.45358481728361841e-12*V033*V04*V09 + 
      1.16438801881645075e-11*V02*V03*V042*V09 + 2.3751960765072752e-12*V01*V043*V09 + 
      1.29877384380218234e-11*V02*V032*V05*V09 + 5.63300093862932133e-12*V022*V04*V05*V09 + 
      1.49806202380442889e-11*V01*V03*V04*V05*V09 + 3.8604577023148137e-12*V01*V02*V052*V09 - 
      9.2230203265481826e-13*V053*V09 + 4.11371889625300052e-12*V022*V03*V06*V09 + 
      5.14978745042163907e-12*V01*V032*V06*V09 + 5.06308974506897458e-12*V01*V02*V04*V06*V09 + 
      1.48196910507850886e-12*V012*V05*V06*V09 - 3.79139809589677287e-12*V04*V05*V06*V09 - 
      1.3653837904260381e-12*V03*V062*V09 + 4.2657375191981404e-13*V023*V07*V09 + 
      3.61884510384372809e-12*V01*V02*V03*V07*V09 + 1.01146544171423152e-12*V012*V04*V07*V09 - 
      1.27036881179183744e-12*V042*V07*V09 - 2.67329456629419149e-12*V03*V05*V07*V09 - 
      9.22306872596369582e-13*V02*V06*V07*V09 - 1.96466069544989172e-13*V01*V072*V09 + 
      4.61355686114042891e-13*V01*V022*V08*V09 + 5.18806613637465929e-13*V012*V03*V08*V09 - 
      1.43902158379398903e-12*V03*V04*V08*V09 - 7.25267774033968481e-13*V02*V05*V08*V09 - 
      3.15083983206152218e-13*V01*V06*V08*V09 + 7.0485888718273877e-14*V012*V02*V092 - 
      1.90459173684033928e-13*V032*V092 - 1.8224445417882732e-13*V02*V04*V092 - 
      1.1590010335608468e-13*V01*V05*V092 + 6.66293197487206057e-15*V08*V092 + 
      8.98486392168483228e-13*V034*V10 + 5.3505977617576787e-12*V02*V032*V04*V10 + 
      6.92130118710875523e-13*V022*V042*V10 + 3.19014976317693238e-12*V01*V03*V042*V10 + 
      2.64221084431906982e-12*V022*V03*V05*V10 + 3.1487892345961313e-12*V01*V032*V05*V10 + 
      3.21035865705460722e-12*V01*V02*V04*V05*V10 + 4.50486713382125994e-13*V012*V052*V10 - 
      1.22086069399478844e-12*V04*V052*V10 + 1.60245330251889559e-13*V023*V06*V10 + 
      2.2707190824963045e-12*V01*V02*V03*V06*V10 + 6.57692559761716392e-13*V012*V04*V06*V10 - 
      7.18267362471191286e-13*V042*V06*V10 - 1.74734351445411948e-12*V03*V05*V06*V10 - 
      2.59351340588797288e-13*V02*V062*V10 + 3.77458692045581402e-13*V01*V022*V07*V10 + 
      4.1678328266720452e-13*V012*V03*V07*V10 - 1.18216262517081052e-12*V03*V04*V07*V10 - 
      5.97523377217129259e-13*V02*V05*V07*V10 - 2.57927361435616765e-13*V01*V06*V07*V10 + 
      1.20749385687371266e-13*V012*V02*V08*V10 - 3.27626770755060952e-13*V032*V08*V10 - 
      2.71341121964510637e-13*V02*V04*V08*V10 - 1.99780448697639718e-13*V01*V05*V08*V10 + 
      5.5606575809184384e-15*V082*V10 + 1.0081873984243812e-14*V013*V09*V10 - 
      1.7137744656538277e-13*V02*V03*V09*V10 - 1.03373090772463402e-13*V01*V04*V09*V10 + 1.09739905445472126e-14*V07*V09*V10 - 
      7.87879228963516412e-15*V022*V102 - 2.30636426462300249e-14*V01*V03*V102 + 
      3.50048518125410756e-15*V06*V102 + 7.66586150711844289e-13*V02*V033*V11 + 
      1.02418198884169479e-12*V022*V03*V04*V11 + 1.31278925866360826e-12*V01*V032*V04*V11 + 
      6.35120737536245865e-13*V01*V02*V042*V11 + 1.62873614369383543e-13*V023*V05*V11 + 
      1.35779312827081092e-12*V01*V02*V03*V05*V11 + 3.77902097026932749e-13*V012*V04*V05*V11 - 
      5.01242840122766278e-13*V042*V05*V11 - 5.24745050938145996e-13*V03*V052*V11 + 
      2.24384667068345483e-13*V01*V022*V06*V11 + 2.56237000807609342e-13*V012*V03*V06*V11 - 
      7.24241473456803361e-13*V03*V04*V06*V11 - 3.6371964082039179e-13*V02*V05*V06*V11 - 
      7.94738230424327435e-14*V01*V062*V11 + 9.14934120571831756e-14*V012*V02*V07*V11 - 
      2.52748391469663746e-13*V032*V07*V11 - 2.4238944525262867e-13*V02*V04*V07*V11 - 
      1.5367966920862549e-13*V01*V05*V07*V11 + 8.15645688805532779e-15*V013*V08*V11 - 
      1.38328800422795945e-13*V02*V03*V08*V11 - 8.3675389520846374e-14*V01*V04*V08*V11 + 8.95086340497616003e-15*V07*V08*V11 - 
      1.71730482603146296e-14*V022*V09*V11 - 4.33420930802019802e-14*V01*V03*V09*V11 + 
      6.84543656472515582e-15*V06*V09*V11 - 9.93681315866477881e-15*V01*V02*V10*V11 + 4.4240463229207593e-15*V05*V10*V11 - 
      5.94163351315726398e-16*V012*V112 + 9.3665674474549308e-16*V04*V112 + 
      2.01270218202110796e-13*V022*V032*V12 + 1.52799514246731647e-13*V01*V033*V12 + 
      3.32065678848475826e-14*V023*V04*V12 + 4.83607299216812802e-13*V01*V02*V03*V04*V12 + 
      7.02057716553328008e-14*V012*V042*V12 - 5.32089848910127126e-14*V043*V12 + 
      1.20762130921266477e-13*V01*V022*V05*V12 + 1.29790110531419956e-13*V012*V03*V05*V12 - 
      3.94246334572618666e-13*V03*V04*V05*V12 - 9.99410226990819012e-14*V02*V052*V12 + 
      4.98706797625107438e-14*V012*V02*V06*V12 - 1.40282084301902682e-13*V032*V06*V12 - 
      1.15008179472858505e-13*V02*V04*V06*V12 - 8.55001637105705976e-14*V01*V05*V06*V12 + 
      5.44434314048299544e-15*V013*V07*V12 - 9.66769172545415174e-14*V02*V03*V07*V12 - 
      5.81098215819723718e-14*V01*V04*V07*V12 + 3.1305300129232274e-15*V072*V12 - 
      1.07705648115281712e-14*V022*V08*V12 - 3.16775769328511526e-14*V01*V03*V08*V12 + 
      4.8471969496679166e-15*V06*V08*V12 - 8.43015748982767218e-15*V01*V02*V09*V12 + 3.75792799881330772e-15*V05*V09*V12 - 
      1.07661086695732196e-15*V012*V10*V12 + 1.62508303589957569e-15*V04*V10*V12 + 
      7.42606428117459797e-16*V03*V11*V12 + 6.91148457300207282e-17*V02*V122 + 
      2.08812326114594285e-14*V023*V03*V13 + 8.32526963655690678e-14*V01*V02*V032*V13 + 
      3.93916149554497995e-14*V01*V022*V04*V13 + 4.57365013933917663e-14*V012*V03*V04*V13 - 
      6.84139359557092387e-14*V03*V042*V13 + 2.39215124392911501e-14*V012*V02*V05*V13 - 
      7.06946037695791054e-14*V032*V05*V13 - 6.83399517277351354e-14*V02*V04*V05*V13 - 
      2.14304816562599629e-14*V01*V052*V13 + 2.82215301563922655e-15*V013*V06*V13 - 
      4.95963918095970232e-14*V02*V03*V06*V13 - 3.00923877683344605e-14*V01*V04*V06*V13 - 
      8.16551007923820238e-15*V022*V07*V13 - 2.04912253403889833e-14*V01*V03*V07*V13 + 
      3.31414088223259229e-15*V06*V07*V13 - 5.7345649147626554e-15*V01*V02*V08*V13 + 2.60071064651362746e-15*V05*V08*V13 - 
      8.47393424709072174e-16*V012*V09*V13 + 1.35032310931830388e-15*V04*V09*V13 + 
      6.30052494144506083e-16*V03*V10*V13 + 1.35429493274973811e-16*V02*V11*V13 + 3.25870090660667398e-17*V01*V12*V13 + 
      4.22720155402648721e-16*V024*V14 + 1.30944372200882539e-14*V01*V022*V03*V14 + 
      6.68593617069795287e-15*V012*V032*V14 + 7.65069503078662727e-15*V012*V02*V04*V14 - 
      2.31183957278804889e-14*V032*V04*V14 - 9.2720456855547129e-15*V02*V042*V14 + 
      1.20986603543987295e-15*V013*V05*V14 - 2.35498271527213396e-14*V02*V03*V05*V14 - 
      1.40780188347643777e-14*V01*V04*V05*V14 - 3.31993282381864712e-15*V022*V06*V14 - 
      9.90907097838467691e-15*V01*V03*V06*V14 + 7.77103483977842813e-16*V062*V14 - 
      3.4636178802245616e-15*V01*V02*V07*V14 + 1.57864644075648917e-15*V05*V07*V14 - 
      5.40570669636768498e-16*V012*V08*V14 + 8.27767841122725696e-16*V04*V08*V14 + 4.6449732961539699e-16*V03*V09*V14 + 
      1.01702824367818314e-16*V02*V10*V14 + 2.82857341081140983e-17*V01*V11*V14 - 1.31462543389314789e-19*V142 + 
      5.96606646041697958e-16*V01*V023*V15 + 2.12968065726135081e-15*V012*V02*V03*V15 - 
      2.36877902480583199e-15*V033*V15 + 3.70840004353698839e-16*V013*V04*V15 - 
      6.99765491517326585e-15*V02*V03*V04*V15 - 2.13262817198601003e-15*V01*V042*V15 - 
      1.72889713794637442e-15*V022*V05*V15 - 4.27665294420541087e-15*V01*V03*V05*V15 - 
      1.5441398500240083e-15*V01*V02*V06*V15 + 7.27963100135749636e-16*V05*V06*V15 - 
      2.99764272871743629e-16*V012*V07*V15 + 4.94288703046505278e-16*V04*V07*V15 + 
      2.79989233213771876e-16*V03*V08*V15 + 7.38235073570117765e-17*V02*V09*V15 + 2.09010108073024989e-17*V01*V10*V15 - 
      2.50523536821150808e-19*V13*V15 + 1.55959747385414186e-16*V012*V022*V16 + 
      9.17851796231794727e-17*V013*V03*V16 - 1.05216684929212956e-15*V02*V032*V16 - 
      4.05666904285484695e-16*V022*V04*V16 - 1.24447282488443941e-15*V01*V03*V04*V16 - 
      6.39992835650376689e-16*V01*V02*V05*V16 + 1.52749966371494767e-16*V052*V16 - 
      1.29046102425813663e-16*V012*V06*V16 + 2.03527003449825917e-16*V04*V06*V16 + 
      1.49780046963446622e-16*V03*V07*V16 + 3.97317255248549377e-17*V02*V08*V16 + 1.35841698946364935e-17*V01*V09*V16 - 
      2.02519366355126002e-19*V12*V16 + 1.30904680829398294e-17*V013*V02*V17 - 
      1.37690428021652598e-16*V022*V03*V17 - 1.64877349533382752e-16*V01*V032*V17 - 
      1.69464225721716617e-16*V01*V02*V04*V17 - 4.83275062297474862e-17*V012*V05*V17 + 
      8.49423943276741339e-17*V04*V05*V17 + 6.13083950957692399e-17*V03*V06*V17 + 2.11481798701473653e-17*V02*V07*V17 + 
      7.26677349382308276e-18*V01*V08*V17 - 1.48835991452750896e-19*V11*V17 + 3.35080241030883005e-19*V014*V18 - 
      4.59879015245940764e-18*V023*V18 - 4.44785511944394101e-17*V01*V02*V03*V18 - 
      1.27509201053618679e-17*V012*V04*V18 + 1.05246469839526813e-17*V042*V18 + 
      2.29119491810892027e-17*V03*V05*V18 + 7.7165894643701278e-18*V02*V06*V18 + 3.46361275812256066e-18*V01*V07*V18 - 
      9.15650428368490872e-20*V10*V18 - 2.66277098205875028e-18*V01*V022*V19 - 
      2.92860130660991746e-18*V012*V03*V19 + 5.74150685221944949e-18*V03*V04*V19 + 
      2.91758088979379064e-18*V02*V05*V19 + 1.27718759172612597e-18*V01*V06*V19 - 5.14786812698952865e-20*V09*V19 - 
      3.66354396860432085e-19*V012*V02*V20 + 6.9325708438996616e-19*V032*V20 + 
      6.43737011626187807e-19*V02*V04*V20 + 4.2762621236322212e-19*V01*V05*V20 - 2.34489837383993854e-20*V08*V20 - 
      1.34032096412353202e-20*V013*V21 + 1.61452829470047128e-19*V02*V03*V21 + 9.79178926568024781e-20*V01*V04*V21 - 
      9.88618151018885634e-21*V07*V21 + 8.04192578474119211e-21*V022*V22 + 2.11286707538917895e-20*V01*V03*V22 - 
      3.15801358708480349e-21*V06*V22 + 2.28971498037770053e-21*V01*V02*V23 - 9.60681042253133442e-22*V05*V23 + 
      1.30308982623121169e-22*V012*V24 - 1.92553453961488899e-22*V04*V24 - 3.92103794182051792e-23*V03*V25 - 
      3.70884898544187234e-24*V02*V26 - 4.27944113704831424e-25*V01*V27 + 4.31395275912128451e-28*V30) + 
   delta10*eps10*(-2.83147397803971713e-10*V034*V042 - 
      5.06254614839170405e-10*V02*V032*V043 - 1.14623038722347948e-11*V022*V044 - 
      1.54810757003022798e-10*V01*V03*V044 - 1.09529688867210913e-10*V035*V05 - 
      1.1541005125191192e-9*V02*V033*V04*V05 - 7.30524805740573423e-10*V022*V03*V042*V05 - 
      9.83508372811947777e-10*V01*V032*V042*V05 - 3.03752768903502243e-10*V01*V02*V043*V05 - 
      4.36594739373776737e-10*V022*V032*V052 - 3.10252614595279692e-10*V01*V033*V052 - 
      1.14908473825788093e-10*V023*V04*V052 - 1.00816232934700338e-9*V01*V02*V03*V04*V052 - 
      1.39639358019218935e-10*V012*V042*V052 + 1.86642603593877716e-10*V043*V052 - 
      8.53257609945033718e-11*V01*V022*V053 - 8.5597727110223257e-11*V012*V03*V053 + 
      3.91377601529063344e-10*V03*V04*V053 + 5.00934710005086973e-11*V02*V054 - 
      1.99096974289751206e-10*V02*V034*V06 - 5.31131576240508968e-10*V022*V032*V04*V06 - 
      4.46808032689607542e-10*V01*V033*V04*V06 - 1.5429439176868032e-11*V023*V042*V06 - 
      6.53366437479125617e-10*V01*V02*V03*V042*V06 - 6.5359057922723474e-11*V012*V043*V06 + 
      4.79079742525889495e-11*V044*V06 - 1.69233958038536371e-10*V023*V03*V05*V06 - 
      6.90041724024096878e-10*V01*V02*V032*V05*V06 - 3.18678945744305381e-10*V01*V022*V04*V05*V06 - 
      3.76942641940912647e-10*V012*V03*V04*V05*V06 + 8.08647268213460881e-10*V03*V042*V05*V06 - 
      9.76725501388835622e-11*V012*V02*V052*V06 + 4.12341529647321837e-10*V032*V052*V06 + 
      4.02719371915161521e-10*V02*V04*V052*V06 + 8.26330431252899527e-11*V01*V053*V06 - 
      1.29070701481524603e-12*V024*V062 - 1.14464374269921289e-10*V01*V022*V03*V062 - 
      6.33206080539851901e-11*V012*V032*V062 - 6.90498148639599e-11*V012*V02*V04*V062 + 
      2.89910887081657422e-10*V032*V04*V062 + 1.02209999015727333e-10*V02*V042*V062 - 
      1.142007595082246e-11*V013*V05*V062 + 2.91231750057451425e-10*V02*V03*V05*V062 + 
      1.7583202327727012e-10*V01*V04*V05*V062 + 1.20738847348225361e-11*V022*V063 + 
      4.15428266827867303e-11*V01*V03*V063 - 1.42760703378761961e-12*V064 - 
      1.35437715864291066e-10*V022*V033*V07 - 7.08526174689070824e-11*V01*V034*V07 - 
      1.09436641738845803e-10*V023*V03*V04*V07 - 4.65540094012761655e-10*V01*V02*V032*V04*V07 - 
      1.04360686534367632e-10*V01*V022*V042*V07 - 1.27872399168444168e-10*V012*V03*V042*V07 + 
      1.79727254021590893e-10*V03*V043*V07 - 1.26606282934859687e-11*V024*V05*V07 - 
      2.36897739508122665e-10*V01*V022*V03*V05*V07 - 1.16393161739913878e-10*V012*V032*V05*V07 - 
      1.32254650451981218e-10*V012*V02*V04*V05*V07 + 5.61661612493264455e-10*V032*V04*V05*V07 + 
      2.666416824335273e-10*V02*V042*V05*V07 - 1.02689340983093492e-11*V013*V052*V07 + 
      2.88100796208181595e-10*V02*V03*V052*V07 + 1.69178248851878072e-10*V01*V04*V052*V07 - 
      2.41762797197909101e-11*V01*V023*V06*V07 - 8.92061358343166122e-11*V012*V02*V03*V06*V07 + 
      1.31194537764959105e-10*V033*V06*V07 - 1.55511174753068746e-11*V013*V04*V06*V07 + 
      3.87738650698101693e-10*V02*V03*V04*V06*V07 + 1.18054076106699637e-10*V01*V042*V06*V07 + 
      9.54200122661066923e-11*V022*V05*V06*V07 + 2.35682116756852721e-10*V01*V03*V05*V06*V07 + 
      4.25042085868382114e-11*V01*V02*V062*V07 - 1.77540839305428114e-11*V05*V062*V07 - 
      7.77259687480252758e-12*V012*V022*V072 - 4.59651872487241882e-12*V013*V03*V072 + 
      6.89322026462861178e-11*V02*V032*V072 + 3.13805915832851226e-11*V022*V04*V072 + 
      8.04890627969764801e-11*V01*V03*V04*V072 + 4.15936567180707272e-11*V01*V02*V05*V072 - 
      8.48599897372070743e-12*V052*V072 + 8.2002675722444813e-12*V012*V06*V072 - 
      1.20762474939533595e-11*V04*V06*V072 - 2.77896531802062462e-12*V03*V073 - 
      3.1406770411793385e-11*V023*V032*V08 - 7.98266942205689067e-11*V01*V02*V033*V08 - 
      1.28161804561128541e-12*V024*V04*V08 - 1.16873026333121435e-10*V01*V022*V03*V04*V08 - 
      6.44993064794030546e-11*V012*V032*V04*V08 - 3.53283964846833836e-11*V012*V02*V042*V08 + 
      1.51602595389973449e-10*V032*V042*V08 + 3.52405353526509445e-11*V02*V043*V08 - 
      1.8844062247076031e-11*V01*V023*V05*V08 - 6.69581899549187723e-11*V012*V02*V03*V05*V08 + 
      1.00764892659486774e-10*V033*V05*V08 - 1.16017842317448639e-11*V013*V04*V05*V08 + 
      3.04080770992841975e-10*V02*V03*V04*V05*V08 + 9.19333218147416301e-11*V01*V042*V05*V08 + 
      3.76182883364071839e-11*V022*V052*V08 + 9.02789308548414284e-11*V01*V03*V052*V08 - 
      1.23777258930322607e-11*V012*V022*V06*V08 - 7.6577477249667976e-12*V013*V03*V06*V08 + 
      1.09212690827840409e-10*V02*V032*V06*V08 + 3.74163458071209689e-11*V022*V04*V06*V08 + 
      1.30371084812711088e-10*V01*V03*V04*V06*V08 + 6.62179747756822236e-11*V01*V02*V05*V06*V08 - 
      1.39138776739401995e-11*V052*V06*V08 + 6.81113143208472836e-12*V012*V062*V08 - 
      9.11527037083692531e-12*V04*V062*V08 - 2.72316763179677546e-12*V013*V02*V07*V08 + 
      3.62077053204156496e-11*V022*V03*V07*V08 + 4.27859951220466131e-11*V01*V032*V07*V08 + 
      4.43658895932414209e-11*V01*V02*V04*V07*V08 + 1.25063243117776522e-11*V012*V05*V07*V08 - 
      1.89791484872501004e-11*V04*V05*V07*V08 - 1.36874210104183073e-11*V03*V06*V07*V08 - 
      2.37702872190506103e-12*V02*V072*V08 - 7.92151622321874899e-14*V014*V082 + 
      1.13353984756073838e-12*V023*V082 + 1.22688215292282076e-11*V01*V02*V03*V082 + 
      3.56058950679644889e-12*V012*V04*V082 - 2.42287900363913201e-12*V042*V082 - 
      5.34578088957031999e-12*V03*V05*V082 - 1.77694022465065124e-12*V02*V06*V082 - 
      8.14192771338936449e-13*V01*V07*V082 - 3.51684119263499131e-12*V024*V03*V09 - 
      3.11545515003692533e-11*V01*V022*V032*V09 - 9.91132733697322221e-12*V012*V033*V09 - 
      9.11972014490381693e-12*V01*V023*V04*V09 - 3.43145352906135209e-11*V012*V02*V03*V04*V09 + 
      5.24478092747042114e-11*V033*V04*V09 - 2.99256308014199351e-12*V013*V042*V09 + 
      7.56891251299102765e-11*V02*V03*V042*V09 + 1.54703695324641749e-11*V01*V043*V09 - 
      8.83074553485866602e-12*V012*V022*V05*V09 - 5.17758147319585576e-12*V013*V03*V05*V09 + 
      8.09178799563830596e-11*V02*V032*V05*V09 + 3.70058109033106848e-11*V022*V04*V05*V09 + 
      9.42675261719759545e-11*V01*V03*V04*V05*V09 + 2.43743465493817395e-11*V01*V02*V052*V09 - 
      3.39585461230969546e-12*V053*V09 - 2.06330471385501017e-12*V013*V02*V06*V09 + 
      2.70776609945128878e-11*V022*V03*V06*V09 + 3.27086838033074454e-11*V01*V032*V06*V09 + 
      3.33606521576621069e-11*V01*V02*V04*V06*V09 + 9.57451088234425317e-12*V012*V05*V06*V09 - 
      1.45206027634999439e-11*V04*V05*V06*V09 - 5.24961158700746602e-12*V03*V062*V09 - 
      1.42335628479819232e-13*V014*V07*V09 + 2.86858561012979369e-12*V023*V07*V09 + 
      2.3176605664144501e-11*V01*V02*V03*V07*V09 + 6.56563869675572709e-12*V012*V04*V07*V09 - 
      4.91902242363934911e-12*V042*V07*V09 - 9.99781704581917746e-12*V03*V05*V07*V09 - 
      3.62306438031649679e-12*V02*V06*V07*V09 - 7.58651502437713266e-13*V01*V072*V09 + 
      3.11249978861302989e-12*V01*V022*V08*V09 + 3.43074524903875492e-12*V012*V03*V08*V09 - 
      5.60577627792254974e-12*V03*V04*V08*V09 - 2.855180461060563e-12*V02*V05*V08*V09 - 
      1.2517058538252239e-12*V01*V06*V08*V09 + 4.71724460539165804e-13*V012*V02*V092 - 
      7.32769969810313421e-13*V032*V092 - 7.32583790015828685e-13*V02*V04*V092 - 
      4.53301268054394796e-13*V01*V05*V092 + 2.08431369621129702e-14*V08*V092 - 
      2.50109090726160402e-14*V025*V10 - 4.18886355110222943e-12*V01*V023*V03*V10 - 
      6.87689618785493251e-12*V012*V02*V032*V10 + 5.69751173864715897e-12*V034*V10 - 
      3.83208484261073027e-12*V012*V022*V04*V10 - 2.33988305434653777e-12*V013*V03*V04*V10 + 
      3.52631050361651277e-11*V02*V032*V04*V10 + 5.9222970446754979e-12*V022*V042*V10 + 
      2.10885965835992367e-11*V01*V03*V042*V10 - 1.22205123720504815e-12*V013*V02*V05*V10 + 
      1.75606500821715209e-11*V022*V03*V05*V10 + 2.0270218289170958e-11*V01*V032*V05*V10 + 
      2.13742921698198171e-11*V01*V02*V04*V05*V10 + 2.95140459100951693e-12*V012*V052*V10 - 
      4.69130966557547262e-12*V04*V052*V10 - 9.51994401387715332e-14*V014*V06*V10 + 
      1.38948133380905834e-12*V023*V06*V10 + 1.51773425231397669e-11*V01*V02*V03*V06*V10 + 
      4.40720670726728527e-12*V012*V04*V06*V10 - 3.0427377813810252e-12*V042*V06*V10 - 
      6.74419985568290098e-12*V03*V05*V06*V10 - 1.11483113055115267e-12*V02*V062*V10 + 
      2.55983962018950329e-12*V01*V022*V07*V10 + 2.7732047011699478e-12*V012*V03*V07*V10 - 
      4.61001271959722056e-12*V03*V04*V07*V10 - 2.35421510610348157e-12*V02*V05*V07*V10 - 
      1.02615652192418426e-12*V01*V06*V07*V10 + 8.27290853592509651e-13*V012*V02*V08*V10 - 
      1.28739533983589227e-12*V032*V08*V10 - 1.18185338357454263e-12*V02*V04*V08*V10 - 
      7.97433834392765342e-13*V01*V05*V08*V10 + 1.79838061478275356e-14*V082*V10 + 
      7.07667942690225346e-14*V013*V09*V10 - 6.93266595037648323e-13*V02*V03*V09*V10 - 
      4.20343673537467043e-13*V01*V04*V09*V10 + 3.43127327957938456e-14*V07*V09*V10 - 
      3.56620081849067188e-14*V022*V102 - 9.47289723171371046e-14*V01*V03*V102 + 
      1.14227646427996491e-14*V06*V102 - 1.91827701416454072e-13*V01*V024*V11 - 
      1.45805132639047492e-12*V012*V022*V03*V11 - 4.12892092087527572e-13*V013*V032*V11 + 
      4.97504660232350187e-12*V02*V033*V11 - 5.05026505741119072e-13*V013*V02*V04*V11 + 
      6.94384964940814728e-12*V022*V03*V04*V11 + 8.61220411311333573e-12*V01*V032*V04*V11 + 
      4.30544222024206645e-12*V01*V02*V042*V11 - 5.06432234368291832e-14*V014*V05*V11 + 
      1.11830112714242857e-12*V023*V05*V11 + 8.93255102955499645e-12*V01*V02*V03*V05*V11 + 
      2.52069915148951116e-12*V012*V04*V05*V11 - 1.98640000143620835e-12*V042*V05*V11 - 
      2.00955788888641668e-12*V03*V052*V11 + 1.53937445770493643e-12*V01*V022*V06*V11 + 
      1.7276704271902925e-12*V012*V03*V06*V11 - 2.88037708353703038e-12*V03*V04*V06*V11 - 
      1.46165874516332932e-12*V02*V05*V06*V11 - 3.22050403429014343e-13*V01*V062*V11 + 
      6.20392232335052706e-13*V012*V02*V07*V11 - 9.82589150691560702e-13*V032*V07*V11 - 
      9.84312166513688056e-13*V02*V04*V07*V11 - 6.07256462944098659e-13*V01*V05*V07*V11 + 
      5.7643268997213004e-14*V013*V08*V11 - 5.64729490641266178e-13*V02*V03*V08*V11 - 
      3.43243938216667035e-13*V01*V04*V08*V11 + 2.81675723048505771e-14*V07*V08*V11 - 
      7.22873015865764146e-14*V022*V09*V11 - 1.75988706085494922e-13*V01*V03*V09*V11 + 
      2.17404411903046408e-14*V06*V09*V11 - 4.22232998182778095e-14*V01*V02*V10*V11 + 1.40581481641081888e-14*V05*V10*V11 - 
      2.5456729818479927e-15*V012*V112 + 3.05713520165617753e-15*V04*V112 - 
      9.18623106269282349e-14*V012*V023*V12 - 1.61969532137189844e-13*V013*V02*V03*V12 + 
      1.3878422469854658e-12*V022*V032*V12 + 1.0302241901089193e-12*V01*V033*V12 - 
      1.90513221840518841e-14*V014*V04*V12 + 2.96922204744444057e-13*V023*V04*V12 + 
      3.34057350116526412e-12*V01*V02*V03*V04*V12 + 4.86041584682261339e-13*V012*V042*V12 - 
      2.33307524072229123e-13*V043*V12 + 8.40732798509608141e-13*V01*V022*V05*V12 + 
      8.91481723719246785e-13*V012*V03*V05*V12 - 1.57370827229456183e-12*V03*V04*V05*V12 - 
      4.02799456284057844e-13*V02*V052*V12 + 3.49059614851123976e-13*V012*V02*V06*V12 - 
      5.62604433823534657e-13*V032*V06*V12 - 5.1145449319346481e-13*V02*V04*V06*V12 - 
      3.48171946516168537e-13*V01*V05*V06*V12 + 3.89147976407890454e-14*V013*V07*V12 - 
      3.95056942445859434e-13*V02*V03*V07*V12 - 2.38775055165300741e-13*V01*V04*V07*V12 + 
      9.83816916868575191e-15*V072*V12 - 4.92019150679978326e-14*V022*V08*V12 - 
      1.31271558584103721e-13*V01*V03*V08*V12 + 1.59101406322255024e-14*V06*V08*V12 - 3.58303645343328356e-14*V01*V02*V09*V12 + 
      1.19308055858564106e-14*V05*V09*V12 - 4.65810520796089365e-15*V012*V10*V12 + 
      5.44895773954939066e-15*V04*V10*V12 + 2.43100075755068269e-15*V03*V11*V12 + 2.41628575888465093e-16*V02*V122 - 
      1.43976205709378511e-14*V013*V022*V13 - 5.38616021358826083e-15*V014*V03*V13 + 
      1.49275268888226993e-13*V023*V03*V13 + 5.77482000854680938e-13*V01*V02*V032*V13 + 
      2.80886550250361437e-13*V01*V022*V04*V13 + 3.22151830262168042e-13*V012*V03*V04*V13 - 
      2.8328680477699054e-13*V03*V042*V13 + 1.68640684865502617e-13*V012*V02*V05*V13 - 
      2.83422711088884393e-13*V032*V05*V13 - 2.85869921228774187e-13*V02*V04*V05*V13 - 
      8.72941443715518424e-14*V01*V052*V13 + 2.05783856003702008e-14*V013*V06*V13 - 
      2.08090712199965333e-13*V02*V03*V06*V13 - 1.2680389091150609e-13*V01*V04*V06*V13 - 
      3.49718824504750984e-14*V022*V07*V13 - 8.46870590547369439e-14*V01*V03*V07*V13 + 
      1.06219391275561935e-14*V06*V07*V13 - 2.47578183972894002e-14*V01*V02*V08*V13 + 8.34401027553271522e-15*V05*V08*V13 - 
      3.65805829890077738e-15*V012*V09*V13 + 4.42115660397718329e-15*V04*V09*V13 + 
      2.07093407511499004e-15*V03*V10*V13 + 4.62363159206493138e-16*V02*V11*V13 + 1.12206352754376923e-16*V01*V12*V13 - 
      8.87828606635427609e-16*V014*V02*V14 + 3.99211739812803882e-15*V024*V14 + 
      9.53601265889606092e-14*V01*V022*V03*V14 + 4.86331950191297589e-14*V012*V032*V14 + 
      5.58051747595388596e-14*V012*V02*V04*V14 - 9.64521471645753854e-14*V032*V04*V14 - 
      4.29266509808032957e-14*V02*V042*V14 + 9.02435424502445861e-15*V013*V05*V14 - 
      9.91053011406376153e-14*V02*V03*V05*V14 - 5.95908660361035031e-14*V01*V04*V05*V14 - 
      1.55838885364026884e-14*V022*V06*V14 - 4.21589680955393128e-14*V01*V03*V06*V14 + 
      2.598712458397398e-15*V062*V14 - 1.49747351593544257e-14*V01*V02*V07*V14 + 5.05576992588472146e-15*V05*V07*V14 - 
      2.37489897771310463e-15*V012*V08*V14 + 2.80249121973150038e-15*V04*V08*V14 + 
      1.52464088464662998e-15*V03*V09*V14 + 3.56902535545661175e-16*V02*V10*V14 + 9.73421414696800047e-17*V01*V11*V14 - 
      3.97796467101277375e-19*V142 - 1.84964293049047419e-17*V015*V15 + 
      4.51800751870616667e-15*V01*V023*V15 + 1.60147178141528924e-14*V012*V02*V03*V15 - 
      9.98391124498909381e-15*V033*V15 + 2.85418668668177896e-15*V013*V04*V15 - 
      3.06748893910163551e-14*V02*V03*V04*V15 - 9.38258741377643886e-15*V01*V042*V15 - 
      7.65815838468852181e-15*V022*V05*V15 - 1.8308165588415677e-14*V01*V03*V05*V15 - 
      6.87680710931134112e-15*V01*V02*V06*V15 + 2.38355627618465332e-15*V05*V06*V15 - 
      1.32382608079171842e-15*V012*V07*V15 + 1.63649620317106183e-15*V04*V07*V15 + 
      9.31012724243195772e-16*V03*V08*V15 + 2.53305692642547847e-16*V02*V09*V15 + 7.23939531063726578e-17*V01*V10*V15 - 
      7.52489723265375153e-19*V13*V15 + 1.20665075437149217e-15*V012*V022*V16 + 
      7.3296792244059472e-16*V013*V03*V16 - 4.64329625469588737e-15*V02*V032*V16 - 
      1.99012465138218982e-15*V022*V04*V16 - 5.52581294596366606e-15*V01*V03*V04*V16 - 
      2.86243971301836961e-15*V01*V02*V05*V16 + 4.99966872963872092e-16*V052*V16 - 
      5.84427968525741054e-16*V012*V06*V16 + 7.04003833968776113e-16*V04*V06*V16 + 
      4.97326189233487643e-16*V03*V07*V16 + 1.41170457293979315e-16*V02*V08*V16 + 4.69976522923450451e-17*V01*V09*V16 - 
      6.13465562735739467e-19*V12*V16 + 1.08565998094006094e-16*V013*V02*V17 - 
      6.4005687320755148e-16*V022*V03*V17 - 7.44038973604255094e-16*V01*V032*V17 - 
      7.89546221138659315e-16*V01*V02*V04*V17 - 2.21803014747982696e-16*V012*V05*V17 + 
      2.87834373819183209e-16*V04*V05*V17 + 2.08417237257381959e-16*V03*V06*V17 + 7.35056908400392968e-17*V02*V07*V17 + 
      2.55024385682970053e-17*V01*V08*V17 - 4.47427087160175417e-19*V11*V17 + 3.01572216927794704e-18*V014*V18 - 
      2.39694065750758309e-17*V023*V18 - 2.09157086451477172e-16*V01*V02*V03*V18 - 
      6.03982134458166616e-17*V012*V04*V18 + 3.77410183257556608e-17*V042*V18 + 
      7.79570696207480467e-17*V03*V05*V18 + 2.80752670993088866e-17*V02*V06*V18 + 1.21528151719567033e-17*V01*V07*V18 - 
      2.78446831189661083e-19*V10*V18 - 1.31518994604621579e-17*V01*V022*V19 - 
      1.42074022197094394e-17*V012*V03*V19 + 2.02337272768051394e-17*V03*V04*V19 + 
      1.03973164923609457e-17*V02*V05*V19 + 4.58941588381151984e-18*V01*V06*V19 - 1.55209193627826197e-19*V09*V19 - 
      1.8395905232595477e-18*V012*V02*V20 + 2.45776038062168067e-18*V032*V20 + 
      2.43226768863341047e-18*V02*V04*V20 + 1.54116965621763868e-18*V01*V05*V20 - 7.19439622289528542e-20*V08*V20 - 
      7.0366850616485431e-20*V013*V21 + 5.99104855394272652e-19*V02*V03*V21 + 3.65144384878931674e-19*V01*V04*V21 - 
      3.00494103435625461e-20*V07*V21 + 3.20560097252878075e-20*V022*V22 + 7.94884794001039128e-20*V01*V03*V22 - 
      9.86103979350869749e-21*V06*V22 + 8.99131980099536063e-21*V01*V02*V23 - 2.97373015312066046e-21*V05*V23 + 
      5.21235930492484674e-22*V012*V24 - 6.20005431935559767e-22*V04*V24 - 1.25548104358154919e-22*V03*V25 - 
      1.25173653258663191e-23*V02*V26 - 1.44431138375380606e-24*V01*V27 + 1.29418582773638535e-27*V30) + 
   delta8*eps11*(-2.70769233078483378e-9*V034*V042 - 
      5.2849037735279136e-9*V02*V032*V043 - 3.15709843216944468e-10*V022*V044 - 
      1.61037939893695159e-9*V01*V03*V044 - 1.00986373135568462e-9*V035*V05 - 
      1.1057785719031284e-8*V02*V033*V04*V05 - 7.66974404297867338e-9*V022*V03*V042*V05 - 
      9.51540934945386793e-9*V01*V032*V042*V05 - 3.17094226411674816e-9*V01*V02*V043*V05 - 
      4.19369923254413275e-9*V022*V032*V052 - 2.90983540450796314e-9*V01*V033*V052 - 
      1.21852959418989951e-9*V023*V04*V052 - 9.77152738667720209e-9*V01*V02*V03*V04*V052 - 
      1.37159931983338818e-9*V012*V042*V052 + 7.34782729020672138e-10*V043*V052 - 
      8.28491729834760568e-10*V01*V022*V053 - 8.21336321588804959e-10*V012*V03*V053 + 
      1.46453395338214103e-9*V03*V04*V053 + 1.89782847320951886e-10*V02*V054 - 
      1.92357192532689145e-9*V02*V034*V06 - 5.58835387896902411e-9*V022*V032*V04*V06 - 
      4.36051478170372235e-9*V01*V033*V04*V06 - 4.3569327826351269e-10*V023*V042*V06 - 
      6.83968891953341714e-9*V01*V02*V03*V042*V06 - 6.77992580765286073e-10*V012*V043*V06 + 
      2.26257954018371214e-10*V044*V06 - 1.79365774695378641e-9*V023*V03*V05*V06 - 
      6.75297478382221273e-9*V01*V02*V032*V05*V06 - 3.35301232738141446e-9*V01*V022*V04*V05*V06 - 
      3.74016205972046605e-9*V012*V03*V04*V05*V06 + 3.19520179769643088e-9*V03*V042*V05*V06 - 
      9.72039096167003577e-10*V012*V02*V052*V06 + 1.55664001306521241e-9*V032*V052*V06 + 
      1.6175969284219239e-9*V02*V04*V052*V06 + 3.19314200223651209e-10*V01*V053*V06 - 
      3.74309240912914694e-11*V024*V062 - 1.20684284142954094e-9*V01*V022*V03*V062 - 
      6.3413946401022949e-10*V012*V032*V062 - 
      7.20202163712626555e-10*V012*V02*V04*V062 + 1.1497464459863449e-9*V032*V04*V062 + 
      4.92267262977367602e-10*V02*V042*V062 - 1.17205990640662389e-10*V013*V05*V062 + 
      1.17381796268426579e-9*V02*V03*V05*V062 + 7.12011064353481034e-10*V01*V04*V05*V062 + 
      5.93013262597060489e-11*V022*V063 + 1.68814100807082011e-10*V01*V03*V063 - 
      4.32974712630363354e-12*V064 - 1.31506623783295328e-9*V022*V033*V07 - 
      6.7454712747304742e-10*V01*V034*V07 - 1.16050437541895192e-9*V023*V03*V04*V07 - 
      4.56716553629821362e-9*V01*V02*V032*V04*V07 - 1.09567772042552477e-9*V01*V022*V042*V07 - 
      1.27310177488348393e-9*V012*V03*V042*V07 + 7.22286779408660039e-10*V03*V043*V07 - 
      1.36344455668646115e-10*V024*V05*V07 - 2.32927025459899152e-9*V01*V022*V03*V05*V07 - 
      1.13596860395683898e-9*V012*V032*V05*V07 - 1.31967414597038001e-9*V012*V02*V04*V05*V07 + 
      2.14846013369944086e-9*V032*V04*V05*V07 + 1.08891690401549956e-9*V02*V042*V05*V07 - 
      1.03574214004454016e-10*V013*V052*V07 + 1.11508967056077928e-9*V02*V03*V052*V07 + 
      6.61937463231797974e-10*V01*V04*V052*V07 - 2.56236820993398059e-10*V01*V023*V06*V07 - 
      9.01196641965537243e-10*V012*V02*V03*V06*V07 + 5.06221494252538875e-10*V033*V06*V07 - 
      1.60550455814033235e-10*V013*V04*V06*V07 + 1.58863211987852681e-9*V02*V03*V04*V06*V07 + 
      4.85765929649484683e-10*V01*V042*V06*V07 + 3.97280172036646943e-10*V022*V05*V06*V07 + 
      9.302970874451516e-10*V01*V03*V05*V06*V07 + 1.78140977416299296e-10*V01*V02*V062*V07 - 
      5.05575733027045824e-11*V05*V062*V07 - 7.8930631473357521e-11*V012*V022*V072 - 
      4.73259067769259649e-11*V013*V03*V072 + 2.72368016632682124e-10*V02*V032*V072 + 
      1.32717469230699681e-10*V022*V04*V072 + 3.21496242822697314e-10*V01*V03*V04*V072 + 
      1.67889888642869614e-10*V01*V02*V05*V072 - 2.35208557414920747e-11*V052*V072 + 
      3.38045756691589119e-11*V012*V06*V072 - 3.4929126803506077e-11*V04*V06*V072 - 
      7.8456365347813506e-12*V03*V073 - 3.3606077243994217e-10*V023*V032*V08 - 
      7.97558643198112695e-10*V01*V02*V033*V08 - 3.79125297581047968e-11*V024*V04*V08 - 
      1.24138886084073368e-9*V01*V022*V03*V04*V08 - 6.53786770772800742e-10*V012*V032*V04*V08 - 
      3.70952627427921929e-10*V012*V02*V042*V08 + 6.12638869143912934e-10*V032*V042*V08 + 
      1.72768087835016637e-10*V02*V043*V08 - 2.01636463463965302e-10*V01*V023*V05*V08 - 
      6.82315412603310794e-10*V012*V02*V03*V05*V08 + 3.91350565437022265e-10*V033*V05*V08 - 
      1.20697537152166511e-10*V013*V04*V05*V08 + 1.24824322132544079e-9*V02*V03*V04*V05*V08 + 
      3.79063693721972457e-10*V01*V042*V05*V08 + 1.56899850601904995e-10*V022*V052*V08 + 
      3.5870249760142936e-10*V01*V03*V052*V08 - 1.30822250667700514e-10*V012*V022*V06*V08 - 
      8.05230798728697216e-11*V013*V03*V06*V08 + 4.49879017717270193e-10*V02*V032*V06*V08 + 
      1.87017356849217665e-10*V022*V04*V06*V08 + 5.39452386670568975e-10*V01*V03*V04*V06*V08 + 
      2.78119084952677826e-10*V01*V02*V05*V06*V08 - 3.96354560188055355e-11*V052*V06*V08 + 
      2.88090219036862163e-11*V012*V062*V08 - 2.81085044764062211e-11*V04*V062*V08 - 
      2.91114609549204539e-11*V013*V02*V07*V08 + 1.53836256560521283e-10*V022*V03*V07*V08 + 
      1.7353844815332962e-10*V01*V032*V07*V08 + 1.89133487527127768e-10*V01*V02*V04*V07*V08 + 
      5.19059393198766873e-11*V012*V05*V07*V08 - 5.48898304568036419e-11*V04*V05*V07*V08 - 
      3.97070283494940312e-11*V03*V06*V07*V08 - 7.11612428347958144e-12*V02*V072*V08 - 
      8.96751732530399836e-13*V014*V082 + 5.87597767868451872e-12*V023*V082 + 
      5.26019657389852216e-11*V01*V02*V03*V082 + 1.53193584740453577e-11*V012*V04*V082 - 
      7.59515759376866709e-12*V042*V082 - 1.55236972611883851e-11*V03*V05*V082 - 
      5.68265534731106992e-12*V02*V06*V082 - 2.46116741375142167e-12*V01*V07*V082 - 
      3.78734599079572541e-11*V024*V03*V09 - 3.14186242742249013e-10*V01*V022*V032*V09 - 
      9.99691694792499952e-11*V012*V033*V09 - 9.67086979515793265e-11*V01*V023*V04*V09 - 
      3.52252361146458457e-10*V012*V02*V03*V04*V09 + 2.08892379826975924e-10*V033*V04*V09 - 
      3.14944508532419064e-11*V013*V042*V09 + 3.20821332750362179e-10*V02*V03*V042*V09 + 
      6.58139909884409326e-11*V01*V043*V09 - 9.08657228291473481e-11*V012*V022*V05*V09 - 
      5.41728749948350846e-11*V013*V03*V05*V09 + 3.25758686854994221e-10*V02*V032*V05*V09 + 
      1.59282849594574961e-10*V022*V04*V05*V09 + 3.83582639290067379e-10*V01*V03*V04*V05*V09 + 
      1.0018185639911531e-10*V01*V02*V052*V09 - 9.53000374697754342e-12*V053*V09 - 
      2.21867621467716394e-11*V013*V02*V06*V09 + 1.16860626687187126e-10*V022*V03*V06*V09 + 
      1.34252881626236139e-10*V01*V032*V06*V09 + 1.44401914144765153e-10*V01*V02*V04*V06*V09 + 
      4.01855462494203005e-11*V012*V05*V06*V09 - 4.25198473038538317e-11*V04*V05*V06*V09 - 
      1.54117389351079318e-11*V03*V062*V09 - 1.60096404346460718e-12*V014*V07*V09 + 
      1.27580139152221315e-11*V023*V07*V09 + 9.70894929477466002e-11*V01*V02*V03*V07*V09 + 
      2.78385224692644464e-11*V012*V04*V07*V09 - 1.46329303132615509e-11*V042*V07*V09 - 
      2.85819369795551925e-11*V03*V05*V07*V09 - 1.09841618384869999e-11*V02*V06*V07*V09 - 
      2.2592770034367596e-12*V01*V072*V09 + 1.39216449006725716e-11*V01*V022*V08*V09 + 
      1.47802408512010082e-11*V012*V03*V08*V09 - 1.6713873136280412e-11*V03*V04*V08*V09 - 
      8.65385818649188504e-12*V02*V05*V08*V09 - 3.82596696541192332e-12*V01*V06*V08*V09 + 
      2.08973196445988763e-12*V012*V02*V092 - 2.16106844250979952e-12*V032*V092 - 
      2.28384166378228319e-12*V02*V04*V092 - 1.36716828894291613e-12*V01*V05*V092 + 
      5.32252711422059609e-14*V08*V092 - 7.90314933119651833e-13*V025*V10 - 
      4.55865268533332244e-11*V01*V023*V03*V10 - 7.26771740633275153e-11*V012*V02*V032*V10 + 
      2.31335411714399361e-11*V034*V10 - 4.11072267643068035e-11*V012*V022*V04*V10 - 
      2.52936187739062626e-11*V013*V03*V04*V10 + 1.50234688757787613e-10*V02*V032*V04*V10 + 
      3.05757962507838267e-11*V022*V042*V10 + 9.0229736448768765e-11*V01*V03*V042*V10 - 
      1.33466964293355892e-11*V013*V02*V05*V10 + 7.59248434520164238e-11*V022*V03*V05*V10 + 
      8.41214926683626087e-11*V01*V032*V05*V10 + 9.27395871431695045e-11*V01*V02*V04*V05*V10 + 
      1.25303992223556671e-11*V012*V052*V10 - 1.37210528476302462e-11*V04*V052*V10 - 
      1.09379027043054598e-12*V014*V06*V10 + 7.31106688615551354e-12*V023*V06*V10 + 
      6.60849329722809952e-11*V01*V02*V03*V06*V10 + 1.92572466566963193e-11*V012*V04*V06*V10 - 
      9.65377752972800324e-12*V042*V06*V10 - 1.97981237688494499e-11*V03*V05*V06*V10 - 
      3.60790224457745026e-12*V02*V062*V10 + 1.14546291076524415e-11*V01*V022*V07*V10 + 
      1.20054634519351767e-11*V012*V03*V07*V10 - 1.37301661786255464e-11*V03*V04*V07*V10 - 
      7.12459506348421325e-12*V02*V05*V07*V10 - 3.13550385611748061e-12*V01*V06*V07*V10 + 
      3.73553117385012201e-12*V012*V02*V08*V10 - 3.85483594627473664e-12*V032*V08*V10 - 
      3.88619480703953173e-12*V02*V04*V08*V10 - 2.44102095064815417e-12*V01*V05*V08*V10 + 
      4.69649607688543926e-14*V082*V10 + 3.25472637589004965e-13*V013*V09*V10 - 
      2.16213993830881259e-12*V02*V03*V09*V10 - 1.31851796934635121e-12*V01*V04*V09*V10 + 8.74729103498187793e-14*V07*V09*V10 - 
      1.22842961118007378e-13*V022*V102 - 2.99027520708754681e-13*V01*V03*V102 + 
      3.00797036495938604e-14*V06*V102 - 2.0658250858885775e-12*V01*V024*V11 - 
      1.57257505117001011e-11*V012*V022*V03*V11 - 4.5708191133987549e-12*V013*V032*V11 + 
      2.11112938649033068e-11*V02*V033*V11 - 5.63430214366642788e-12*V013*V02*V04*V11 + 
      3.13855011037910835e-11*V022*V03*V04*V11 + 3.69339070498637689e-11*V01*V032*V04*V11 + 
      1.95005543283774608e-11*V01*V02*V042*V11 - 5.90375196030384519e-13*V014*V05*V11 + 
      5.12988824279130284e-12*V023*V05*V11 + 3.86494704849125462e-11*V01*V02*V03*V05*V11 + 
      1.10382124643695347e-11*V012*V04*V05*V11 - 6.02574402553772853e-12*V042*V05*V11 - 
      5.86065950487755921e-12*V03*V052*V11 + 7.08385491133828903e-12*V01*V022*V06*V11 + 
      7.63429429891017533e-12*V012*V03*V06*V11 - 8.75762270419255321e-12*V03*V04*V06*V11 - 
      4.51908922194792723e-12*V02*V05*V06*V11 - 1.00319318895153867e-12*V01*V062*V11 + 
      2.78856534194745054e-12*V012*V02*V07*V11 - 2.91931345055065142e-12*V032*V07*V11 - 
      3.09097195181517997e-12*V02*V04*V07*V11 - 1.84530720111911496e-12*V01*V05*V07*V11 + 
      2.67537093328460769e-13*V013*V08*V11 - 1.77672651862831385e-12*V02*V03*V08*V11 - 
      1.08549916667667726e-12*V01*V04*V08*V11 + 7.21969685808930552e-14*V07*V08*V11 - 
      2.37718869184732011e-13*V022*V09*V11 - 5.51568550731522464e-13*V01*V03*V09*V11 + 
      5.62759032607874966e-14*V06*V09*V11 - 1.39485595689417132e-13*V01*V02*V10*V11 + 3.63036838344687864e-14*V05*V10*V11 - 
      8.4762325330435429e-15*V012*V112 + 8.13619376933364333e-15*V04*V112 - 
      1.01814211656491648e-12*V012*V023*V12 - 1.87567973747534509e-12*V013*V02*V03*V12 + 
      6.29198029883627969e-12*V022*V032*V12 + 4.5179317601098536e-12*V01*V033*V12 - 
      2.30243551987454227e-13*V014*V04*V12 + 1.63183234523232524e-12*V023*V04*V12 + 
      1.51983607990053672e-11*V01*V02*V03*V04*V12 + 2.21899508353305481e-12*V012*V042*V12 - 
      7.67622409575923744e-13*V043*V12 + 3.87421497906201032e-12*V01*V022*V05*V12 + 
      3.9974675075661919e-12*V012*V03*V05*V12 - 4.77688649044064251e-12*V03*V04*V05*V12 - 
      1.24167226614877991e-12*V02*V052*V12 + 1.61928091951465818e-12*V012*V02*V06*V12 - 
      1.71501986259447189e-12*V032*V06*V12 - 1.71570347365917145e-12*V02*V04*V06*V12 - 
      1.08491507130179143e-12*V01*V05*V06*V12 + 1.822452783408343e-13*V013*V07*V12 - 
      1.23955218846814539e-12*V02*V03*V07*V12 - 7.53992943398918739e-13*V01*V04*V07*V12 + 
      2.514108289774699e-14*V072*V12 - 1.70860271545318255e-13*V022*V08*V12 - 
      4.17272476972729539e-13*V01*V03*V08*V12 + 4.20775619553044381e-14*V06*V08*V12 - 1.18222543305119371e-13*V01*V02*V09*V12 + 
      3.07695292892914839e-14*V05*V09*V12 - 1.55943732580682249e-14*V012*V10*V12 + 
      1.47395049716510006e-14*V04*V10*V12 + 6.46014360006089842e-15*V03*V11*V12 + 6.84806977386757954e-16*V02*V122 - 
      1.75611265297200587e-13*V013*V022*V13 - 6.84922777160622591e-14*V014*V03*V13 + 
      7.23997612170711996e-13*V023*V03*V13 + 2.65331298483672984e-12*V01*V02*V032*V13 + 
      1.36258228576674328e-12*V01*V022*V04*V13 + 1.49844947815938967e-12*V012*V03*V04*V13 - 
      8.95974776441620578e-13*V03*V042*V13 + 7.9019326108408995e-13*V012*V02*V05*V13 - 
      8.6310803951469148e-13*V032*V05*V13 - 9.19356878384301417e-13*V02*V04*V05*V13 - 
      2.7192294469240702e-13*V01*V052*V13 + 9.8852323478737723e-14*V013*V06*V13 - 
      6.70585221398290731e-13*V02*V03*V06*V13 - 4.1056167171177864e-13*V01*V04*V06*V13 - 
      1.16335394741710843e-13*V022*V07*V13 - 2.68634844375280028e-13*V01*V03*V07*V13 + 
      2.76345042190096508e-14*V06*V07*V13 - 8.28360300089827386e-14*V01*V02*V08*V13 + 2.16940773074746741e-14*V05*V08*V13 - 
      1.22343703058866892e-14*V012*V09*V13 + 1.17814293524730856e-14*V04*V09*V13 + 
      5.51810263502300414e-15*V03*V10*V13 + 1.29201754511031737e-15*V02*V11*V13 + 3.14988372293160695e-16*V01*V12*V13 - 
      1.20226790481880822e-14*V014*V02*V14 + 2.35311275767894987e-14*V024*V14 + 
      4.63845526109898326e-13*V01*V022*V03*V14 + 2.32187093336954648e-13*V012*V032*V14 + 
      2.72272029967499923e-13*V012*V02*V04*V14 - 3.05483133968956297e-13*V032*V04*V14 - 
      1.50047739995673031e-13*V02*V042*V14 + 4.4166334595188201e-14*V013*V05*V14 - 
      3.18481901590034896e-13*V02*V03*V05*V14 - 1.92823333578249204e-13*V01*V04*V05*V14 - 
      5.55022048180016092e-14*V022*V06*V14 - 1.37060588895774704e-13*V01*V03*V06*V14 + 
      6.97791424950739716e-15*V062*V14 - 4.99776947621698893e-14*V01*V02*V07*V14 + 
      1.31000250534010513e-14*V05*V07*V14 - 8.04238829701328171e-15*V012*V08*V14 + 
      7.63265362252156149e-15*V04*V08*V14 + 4.05508994062944655e-15*V03*V09*V14 + 1.01396710076047469e-15*V02*V10*V14 + 
      2.73107322985628684e-16*V01*V11*V14 - 9.99010714395400467e-19*V142 - 2.77446439573571128e-16*V015*V15 + 
      2.35279160188349072e-14*V01*V023*V15 + 8.00606549734606702e-14*V012*V02*V03*V15 - 
      3.18661002063482126e-14*V033*V15 + 1.44958727992129266e-14*V013*V04*V15 - 
      1.03115616401421854e-13*V02*V03*V04*V15 - 3.16736787025350229e-14*V01*V042*V15 - 
      2.61676664298677674e-14*V022*V05*V15 - 5.97501107375548902e-14*V01*V03*V05*V15 - 
      2.36292459591238514e-14*V01*V02*V06*V15 + 6.29646953310172236e-15*V05*V06*V15 - 
      4.49715324143854128e-15*V012*V07*V15 + 4.38688044831203657e-15*V04*V07*V15 + 
      2.49993389888186668e-15*V03*V08*V15 + 7.09232706371279065e-16*V02*V09*V15 + 2.03937042180346142e-16*V01*V10*V15 - 
      1.88185619821475976e-18*V13*V15 + 6.30972847873204242e-15*V012*V022*V16 + 
      3.84303528438319718e-15*V013*V03*V16 - 1.56196704962529859e-14*V02*V032*V16 - 
      7.41008061130717081e-15*V022*V04*V16 - 1.87214323359545695e-14*V01*V03*V04*V16 - 
      9.82547302075418786e-15*V01*V02*V05*V16 + 1.31609881312271195e-15*V052*V16 - 
      2.03093139329541282e-15*V012*V06*V16 + 1.95087014910293091e-15*V04*V06*V16 + 
      1.33140296669692414e-15*V03*V07*V16 + 4.04612857892306656e-16*V02*V08*V16 + 1.3218544889613861e-16*V01*V09*V16 - 
      1.54156523737838203e-18*V12*V16 + 5.94767427829817333e-16*V013*V02*V17 - 
      2.29051638062083273e-15*V022*V03*V17 - 2.55243185102262243e-15*V01*V032*V17 - 
      2.83479280079797984e-15*V01*V02*V04*V17 - 7.77877051744758815e-16*V012*V05*V17 + 
      7.84540541187959212e-16*V04*V05*V17 + 5.69382765977192195e-16*V03*V06*V17 + 2.07275949967380283e-16*V02*V07*V17 + 
      7.24776167919506862e-17*V01*V08*V17 - 1.11919960795176042e-18*V11*V17 + 1.75917126541213578e-17*V014*V18 - 
      9.52521431837123422e-17*V023*V18 - 7.53578708066404334e-16*V01*V02*V03*V18 - 
      2.19226247694455206e-16*V012*V04*V18 + 1.08173395744931576e-16*V042*V18 + 
      2.1251235659833308e-16*V03*V05*V18 + 8.20474286947829355e-17*V02*V06*V18 + 3.44742319671513401e-17*V01*V07*V18 - 
      7.01323707274126518e-19*V10*V18 - 5.02787901666839949e-17*V01*V022*V19 - 
      5.2523827781590911e-17*V012*V03*V19 + 5.71416523532977674e-17*V03*V04*V19 + 2.9865562266315506e-17*V02*V05*V19 + 
      1.32911372677619552e-17*V01*V06*V19 - 3.88654874120887369e-19*V09*V19 - 7.10705191226502853e-18*V012*V02*V20 + 
      6.95676443511218904e-18*V032*V20 + 7.36713800411280915e-18*V02*V04*V20 + 4.46314913901670774e-18*V01*V05*V20 - 
      1.82286287562215143e-19*V08*V20 - 2.81467402465941724e-19*V013*V21 + 1.78625691822879882e-18*V02*V03*V21 + 
      1.09487468756841022e-18*V01*V04*V21 - 7.55642739076560618e-20*V07*V21 + 1.02757940582804121e-19*V022*V22 + 
      2.39582372337081348e-19*V01*V03*V22 - 2.53337718849022358e-20*V06*V22 + 2.84818204876250554e-20*V01*V02*V23 - 
      7.57589464491663069e-21*V05*V23 + 1.67540120515441502e-21*V012*V24 - 1.63881198343265194e-21*V04*V24 - 
      3.29784432623785716e-22*V03*V25 - 3.47704592385175532e-23*V02*V26 - 4.0119760659827946e-24*V01*V27 + 
      3.23546456934096338e-27*V30) + eps15*(-6.94206524686864971e-10*V028 - 
      4.54639386231988551e-8*V01*V026*V03 - 2.53851546801452458e-7*V012*V024*V032 - 
      2.2386601636791296e-7*V013*V022*V033 - 1.7497802026109877e-8*V014*V034 + 
      5.82321609376665683e-8*V023*V034 + 5.68952526355953279e-8*V01*V02*V035 - 
      8.02033267037497897e-8*V012*V025*V04 - 3.42381597943718625e-7*V013*V023*V03*V04 - 
      1.57460316491376832e-7*V014*V02*V032*V04 + 1.23015905721350914e-7*V024*V032*V04 + 
      4.20140204066269924e-7*V01*V022*V033*V04 + 8.03264375297130437e-8*V012*V034*V04 - 
      5.8539769345966825e-8*V014*V022*V042 + 1.55258266251201437e-8*V025*V042 - 
      1.38203085397588199e-8*V015*V03*V042 + 3.06655008449177551e-7*V01*V023*V03*V042 + 
      3.61660918326332802e-7*V012*V02*V032*V042 - 1.80890848399191371e-8*V034*V042 + 
      9.08700312449270914e-8*V012*V022*V043 + 4.3865201265538045e-8*V013*V03*V043 - 
      5.19912794462820501e-8*V02*V032*V043 - 8.87063997906019346e-9*V022*V044 - 
      1.60972767434028839e-8*V01*V03*V044 - 5.27147785356624448e-8*V013*V024*V05 - 
      9.4583154597524929e-8*V014*V022*V03*V05 + 2.91617791598488678e-8*V025*V03*V05 - 
      1.10898943522270631e-8*V015*V032*V05 + 2.55904363772325924e-7*V01*V023*V032*V05 + 
      1.97413677627478624e-7*V012*V02*V033*V05 - 6.07572300720626769e-9*V035*V05 - 
      1.61646843431536475e-8*V015*V02*V04*V05 + 9.23641668053448817e-8*V01*V024*V04*V05 + 
      4.44160770415495624e-7*V012*V022*V03*V04*V05 + 1.06946035281486025e-7*V013*V032*V04*V05 - 
      8.82916460558425759e-8*V02*V033*V04*V05 + 8.11535252964248265e-8*V013*V02*V042*V05 - 
      9.42461290386927715e-8*V022*V03*V042*V05 - 8.08199662875465147e-8*V01*V032*V042*V05 - 
      3.9343271570668984e-8*V01*V02*V043*V05 - 4.4215788239092005e-10*V016*V052 + 
      4.54036675918749289e-8*V012*V023*V052 + 
      6.58069309998302386e-8*V013*V02*V03*V052 - 
      4.02737285295749096e-8*V022*V032*V052 - 2.245245242685755e-8*V01*V033*V052 + 
      8.48207471303910781e-9*V014*V04*V052 - 1.88785363563949947e-8*V023*V04*V052 - 
      9.91840918028478183e-8*V01*V02*V03*V04*V052 - 1.46710678526782349e-8*V012*V042*V052 + 
      2.06176703909365558e-9*V043*V052 - 1.01178869715510899e-8*V01*V022*V053 - 
      8.0857279035660943e-9*V012*V03*V053 + 3.50820802817152802e-9*V03*V04*V053 + 
      5.36491683617947045e-10*V02*V054 - 1.56362709521994069e-8*V014*V023*V06 + 
      2.18414198041136536e-9*V026*V06 - 1.08113464132955263e-8*V015*V02*V03*V06 + 
      6.53452271788922513e-8*V01*V024*V03*V06 + 1.54115501019122208e-7*V012*V022*V032*V06 + 
      2.45674819171181349e-8*V013*V033*V06 - 1.56446306688506395e-8*V02*V034*V06 - 
      7.37965357406884018e-10*V016*V04*V06 + 7.75054431271121163e-8*V012*V023*V04*V06 + 
      1.11688681151582586e-7*V013*V02*V03*V04*V06 - 6.72961703587403294e-8*V022*V032*V04*V06 - 
      3.79433180973422844e-8*V01*V033*V04*V06 + 7.17244087745385852e-9*V014*V042*V06 - 
      1.52458893817500879e-8*V023*V042*V06 - 8.35490099178811725e-8*V01*V02*V03*V042*V06 - 
      8.29670664585292318e-9*V012*V043*V06 + 8.54108890191812222e-10*V044*V06 + 
      3.44275149917664599e-8*V013*V022*V05*V06 + 1.16192374107110268e-8*V014*V03*V05*V06 - 
      2.70668530957032087e-8*V023*V03*V05*V06 - 6.99456808524552684e-8*V01*V02*V032*V05*V06 - 
      5.10000496945692542e-8*V01*V022*V04*V05*V06 - 4.11083020764441806e-8*V012*V03*V04*V05*V06 + 
      8.83086349348011714e-9*V03*V042*V05*V06 - 1.26930442310423802e-8*V012*V02*V052*V06 + 
      3.74332101481123714e-9*V032*V052*V06 + 5.38614315013184056e-9*V02*V04*V052*V06 + 
      9.49993437743467316e-10*V01*V053*V06 + 3.0114948425280142e-9*V014*V02*V062 - 
      1.63620013152507348e-9*V024*V062 - 1.80584740578789607e-8*V01*V022*V03*V062 - 
      7.1929056405474561e-9*V012*V032*V062 - 1.07684886489502604e-8*V012*V02*V04*V062 + 
      3.14672738103771724e-9*V032*V04*V062 + 2.22930859597044076e-9*V02*V042*V062 - 
      1.66798448619505426e-9*V013*V05*V062 + 3.84844365382511371e-9*V02*V03*V05*V062 + 
      2.40407175189785005e-9*V01*V04*V05*V062 + 3.23109770393266229e-10*V022*V063 + 
      5.67857461620184775e-10*V01*V03*V063 - 8.24720775442092173e-12*V064 - 
      2.22730672332388019e-9*V015*V022*V07 + 5.74832684711426961e-9*V01*V025*V07 - 
      4.18007464576092027e-10*V016*V03*V07 + 4.6434845998860201e-8*V012*V023*V03*V07 + 
      3.33343996582832413e-8*V013*V02*V032*V07 - 1.40280482779142205e-8*V022*V033*V07 - 
      5.82303383547719375e-9*V01*V034*V07 + 2.53665641824400394e-8*V013*V022*V04*V07 + 
      8.530772859016492e-9*V014*V03*V04*V07 - 1.98269640247326998e-8*V023*V03*V04*V07 - 
      5.15631486875711777e-8*V01*V02*V032*V04*V07 - 1.87539200523709339e-8*V01*V022*V042*V07 - 
      1.51747452738871774e-8*V012*V03*V042*V07 + 2.16718128580535291e-9*V03*V043*V07 + 
      5.23129368023274051e-9*V014*V02*V05*V07 - 2.96604718038281032e-9*V024*V05*V07 - 
      3.15981234782751671e-8*V01*V022*V03*V05*V07 - 1.25314642189172153e-8*V012*V032*V05*V07 - 
      1.87396397034696155e-8*V012*V02*V04*V05*V07 + 5.5211014707465104e-9*V032*V04*V05*V07 + 
      3.96041468981929047e-9*V02*V042*V05*V07 - 1.45062232163661665e-9*V013*V052*V07 + 
      3.38170717130058158e-9*V02*V03*V052*V07 + 2.10457748122992872e-9*V01*V04*V052*V07 + 
      3.43631842626725668e-10*V015*V06*V07 - 5.39783543705181403e-9*V01*V023*V06*V07 - 
      1.31260650334553307e-8*V012*V02*V03*V06*V07 + 1.30836224655562808e-9*V033*V06*V07 - 
      2.46435173785586098e-9*V013*V04*V06*V07 + 5.66570096524915792e-9*V02*V03*V04*V06*V07 + 
      1.77427655588753536e-9*V01*V042*V06*V07 + 1.72322372090584275e-9*V022*V05*V06*V07 + 
      2.98020226518573325e-9*V01*V03*V05*V06*V07 + 7.74976901766769758e-10*V01*V02*V062*V07 - 
      8.71776361934645449e-11*V05*V062*V07 - 1.49511564735614854e-9*V012*V022*V072 - 
      7.45256511956404467e-10*V013*V03*V072 + 8.87980713987765631e-10*V02*V032*V072 + 
      6.32997636546799913e-10*V022*V04*V072 + 1.10078412033046672e-9*V01*V03*V04*V072 + 
      6.78931013741368324e-10*V01*V02*V05*V072 - 3.82721782951213454e-11*V052*V072 + 
      1.43978074925781938e-10*V012*V06*V072 - 6.43123832372462254e-11*V04*V06*V072 - 
      1.34477087404639948e-11*V03*V073 - 1.46715896818021001e-10*V016*V02*V08 + 
      4.67786220396497877e-9*V012*V024*V08 + 1.33664331694032427e-8*V013*V022*V03*V08 + 
      2.23978478446155502e-9*V014*V032*V08 - 5.50717848709859038e-9*V023*V032*V08 - 
      9.35981329925486542e-9*V01*V02*V033*V08 + 3.39152044441936349e-9*V014*V02*V04*V08 - 
      1.85912736904691369e-9*V024*V04*V08 - 2.05812179693864974e-8*V01*V022*V03*V04*V08 - 
      8.19813509983616513e-9*V012*V032*V04*V08 - 6.1382480463705707e-9*V012*V02*V042*V08 + 
      1.79774164950644287e-9*V032*V042*V08 + 8.48045452956239672e-10*V02*V043*V08 + 
      2.63371396729710816e-10*V015*V05*V08 - 4.18223509668411617e-9*V01*V023*V05*V08 - 
      1.01322501728694028e-8*V012*V02*V03*V05*V08 + 1.01345303804956742e-9*V033*V05*V08 - 
      1.8997957778747097e-9*V013*V04*V05*V08 + 4.39621114644282016e-9*V02*V03*V04*V05*V08 + 
      1.37430016250060562e-9*V01*V042*V05*V08 + 6.69231294397409884e-10*V022*V052*V08 + 
      1.15333970536551651e-9*V01*V03*V052*V08 - 2.65391812960214649e-9*V012*V022*V06*V08 - 
      1.3211813507329157e-9*V013*V03*V06*V08 + 1.56837918999985064e-9*V02*V032*V06*V08 + 
      1.10629910626498957e-9*V022*V04*V06*V08 + 1.94821463148274307e-9*V01*V03*V04*V06*V08 + 
      1.20080021374790508e-9*V01*V02*V05*V06*V08 - 6.76310012259065884e-11*V052*V06*V08 + 
      1.27634421168221221e-10*V012*V062*V08 - 5.66401102840554386e-11*V04*V062*V08 - 
      6.05110657245563602e-10*V013*V02*V07*V08 + 7.04806175345157051e-10*V022*V03*V07*V08 + 
      6.02854330585281706e-10*V01*V032*V07*V08 + 8.86224786502716822e-10*V01*V02*V04*V07*V08 + 
      2.22670865768818283e-10*V012*V05*V07*V08 - 9.98173085443164546e-11*V04*V05*V07*V08 - 
      7.13165068345512982e-11*V03*V06*V07*V08 - 1.61779418183039124e-11*V02*V072*V08 - 
      2.1515879747530703e-11*V014*V082 + 4.57369966971094349e-11*V023*V082 + 
      2.43542008755544192e-10*V01*V02*V03*V082 + 7.30330831775538141e-11*V012*V04*V082 - 
      1.62117180060434137e-11*V042*V082 - 2.76589309412361286e-11*V03*V05*V082 - 
      1.42437756285810815e-11*V02*V06*V082 - 5.64273854878146676e-12*V01*V07*V082 - 
      3.54243614047535616e-12*V017*V09 + 1.6090617241645087e-9*V013*V023*V09 + 
      1.59583030346124509e-9*V014*V02*V03*V09 - 9.62818371692481156e-10*V024*V03*V09 - 
      5.05625715084009515e-9*V01*V022*V032*V09 - 1.32487387979222179e-9*V012*V033*V09 + 
      1.52457040502828994e-10*V015*V04*V09 - 2.4440274769942435e-9*V01*V023*V04*V09 - 
      5.95530002485853638e-9*V012*V02*V03*V04*V09 + 5.95146924057484682e-10*V033*V04*V09 - 
      5.58696871612924697e-10*V013*V042*V09 + 1.286303864806352e-9*V02*V03*V042*V09 + 
      2.69059187025538313e-10*V01*V043*V09 - 1.83782961588857547e-9*V012*V022*V05*V09 - 
      9.14650866732722728e-10*V013*V03*V05*V09 + 1.09535713420573542e-9*V02*V032*V05*V09 + 
      7.81703691827714168e-10*V022*V04*V05*V09 + 1.35682439590345054e-9*V01*V03*V04*V05*V09 + 
      4.18551100180693069e-10*V01*V02*V052*V09 - 1.57475509151900846e-11*V053*V09 - 
      4.81760810253798968e-10*V013*V02*V06*V09 + 5.60297060359912343e-10*V022*V03*V06*V09 + 
      4.80021826540252563e-10*V01*V032*V06*V09 + 7.05251608405353447e-10*V01*V02*V04*V06*V09 + 
      1.77360964063524029e-10*V012*V05*V06*V09 - 7.94125479229651329e-11*V04*V05*V06*V09 - 
      2.83782175221970736e-11*V03*V062*V09 - 3.86516654716933898e-11*V014*V07*V09 + 
      8.31912471394392337e-11*V023*V07*V09 + 4.38232746904444785e-10*V01*V02*V03*V07*V09 + 
      1.31238727592392633e-10*V012*V04*V07*V09 - 2.9289154646082385e-11*V042*V07*V09 - 
      4.98077375263285322e-11*V03*V05*V07*V09 - 2.57386696300187456e-11*V02*V06*V07*V09 - 
      5.07729690116426888e-12*V01*V072*V09 + 8.80826733090481605e-11*V01*V022*V08*V09 + 
      7.14320907923061499e-11*V012*V03*V08*V09 - 3.25160503607965922e-11*V03*V04*V08*V09 - 
      1.99887537618312879e-11*V02*V05*V08*V09 - 8.98843796485071897e-12*V01*V06*V08*V09 + 
      1.30883673907849959e-11*V012*V02*V092 - 4.05326230632449257e-12*V032*V092 - 
      5.86359466285590627e-12*V02*V04*V092 - 3.13447692082000853e-12*V01*V05*V092 + 
      8.14222107503231745e-14*V08*V092 + 2.57242234950944531e-10*V014*V022*V10 - 
      5.87301313679052441e-11*V025*V10 + 6.460284856182689e-11*V015*V03*V10 - 
      1.09713114453516043e-9*V01*V023*V03*V10 - 1.3119364205979096e-9*V012*V02*V032*V10 + 
      6.68681476847252555e-11*V034*V10 - 9.82804181968081521e-10*V012*V022*V04*V10 - 
      4.88387406314574565e-10*V013*V03*V04*V10 + 5.8256690412993581e-10*V02*V032*V04*V10 + 
      2.0505713664970509e-10*V022*V042*V10 + 3.621811975504736e-10*V01*V03*V042*V10 - 
      3.02814254531642585e-10*V013*V02*V05*V10 + 3.55598901672197009e-10*V022*V03*V05*V10 + 
      3.03353265594763652e-10*V01*V032*V05*V10 + 4.46412441089847844e-10*V01*V02*V04*V05*V10 + 
      5.59799407823170449e-11*V012*V052*V10 - 2.51745013553585784e-11*V04*V052*V10 - 
      2.79153744073092494e-11*V014*V06*V10 + 5.94184616169428093e-11*V023*V06*V10 + 
      3.1669088230577897e-10*V01*V02*V03*V06*V10 + 9.49799676693291079e-11*V012*V04*V06*V10 - 
      2.107428769023373e-11*V042*V06*V10 - 3.59669998312640944e-11*V03*V05*V06*V10 - 
      9.25931070080285951e-12*V02*V062*V10 + 7.19612109412063777e-11*V01*V022*V07*V10 + 
      5.83105868595580086e-11*V012*V03*V07*V10 - 2.65648270006084215e-11*V03*V04*V07*V10 - 
      1.63347006978280897e-11*V02*V05*V07*V10 - 7.34124330143065495e-12*V01*V06*V07*V10 + 
      2.37844377442280042e-11*V012*V02*V08*V10 - 7.35572861887589855e-12*V032*V08*V10 - 
      1.06068293236070169e-11*V02*V04*V08*V10 - 5.69038571165579452e-12*V01*V05*V08*V10 + 
      7.38118704042372502e-14*V082*V10 + 2.21424581520748837e-12*V013*V09*V10 - 
      5.33325309661845308e-12*V02*V03*V09*V10 - 3.35493174987895847e-12*V01*V04*V09*V10 + 1.33055696769074783e-13*V07*V09*V10 - 
      4.34122908129308479e-13*V022*V102 - 7.54941039233087581e-13*V01*V03*V102 + 
      4.80271780163465663e-14*V06*V102 + 1.86521692396520398e-11*V015*V02*V11 - 
      8.10942926747239152e-11*V01*V024*V11 - 3.96477722595544085e-10*V012*V022*V03*V11 - 
      9.77436962938848269e-11*V013*V032*V11 + 8.0375823741328775e-11*V02*V033*V11 - 
      1.4824222216426174e-10*V013*V02*V04*V11 + 1.7298258566256559e-10*V022*V03*V04*V11 + 
      1.48590409606267406e-10*V01*V032*V04*V11 + 1.09067321886929221e-10*V01*V02*V042*V11 - 
      1.60624841726723269e-11*V014*V05*V11 + 3.49526394288851528e-11*V023*V05*V11 + 
      1.83606679979698007e-10*V01*V02*V03*V05*V11 + 5.49248057153216295e-11*V012*V04*V05*V11 - 
      1.22923391293521476e-11*V042*V05*V11 - 1.0446792304868878e-11*V03*V052*V11 + 
      4.76413757370896413e-11*V01*V022*V06*V11 + 3.8658068197123744e-11*V012*V03*V06*V11 - 
      1.75847032334727575e-11*V03*V04*V06*V11 - 1.08076661904845378e-11*V02*V05*V06*V11 - 
      2.43224858269392821e-12*V01*V062*V11 + 1.77843616743720234e-11*V012*V02*V07*V11 - 
      5.50850002975259586e-12*V032*V07*V11 - 7.97072545840528282e-12*V02*V04*V07*V11 - 
      4.25971711984207076e-12*V01*V05*V07*V11 + 1.84277925954200593e-12*V013*V08*V11 - 
      4.43579732906346624e-12*V02*V03*V08*V11 - 2.79114913508688147e-12*V01*V04*V08*V11 + 1.10664397215694492e-13*V07*V08*V11 - 
      7.98333217385680069e-13*V022*V09*V11 - 1.38379684282090099e-12*V01*V03*V09*V11 + 
      8.81269760956428437e-14*V06*V09*V11 - 4.60197858864066942e-13*V01*V02*V10*V11 + 5.59270822439706111e-14*V05*V10*V11 - 
      2.87074769954414473e-14*V012*V112 + 1.3707384175085021e-14*V04*V112 + 
      4.8941551940777947e-13*V016*V12 - 3.68939674505308105e-11*V012*V023*V12 - 
      5.46897890062243706e-11*V013*V02*V03*V12 + 3.32330990814048066e-11*V022*V032*V12 + 
      1.8721759496117176e-11*V01*V033*V12 - 7.23538697441937466e-12*V014*V04*V12 + 
      1.55021592504695736e-11*V023*V04*V12 + 8.29336363766594459e-11*V01*V02*V03*V04*V12 + 
      1.24423928025188784e-11*V012*V042*V12 - 1.83942195507536128e-12*V043*V12 + 
      2.5529052654857421e-11*V01*V022*V05*V12 + 2.06395758967976596e-11*V012*V03*V05*V12 - 
      9.42960630802113288e-12*V03*V04*V05*V12 - 2.90095001374260037e-12*V02*V052*V12 + 
      1.08881724313547913e-11*V012*V02*V06*V12 - 3.36603551200924369e-12*V032*V06*V12 - 
      4.85085477426325783e-12*V02*V04*V06*V12 - 2.60477467870958926e-12*V01*V05*V06*V12 + 
      1.27177044032302656e-12*V013*V07*V12 - 3.06610095035663138e-12*V02*V03*V07*V12 - 
      1.92812417912411146e-12*V01*V04*V07*V12 + 3.82298429511408287e-14*V072*V12 - 
      6.10756068809190184e-13*V022*V08*V12 - 1.06242185727121409e-12*V01*V03*V08*V12 + 
      6.75539400924665015e-14*V06*V08*V12 - 3.89206143623505356e-13*V01*V02*V09*V12 + 4.72915247454560573e-14*V05*V09*V12 - 
      5.2991199283453253e-14*V012*V10*V12 + 2.52667401380365162e-14*V04*V10*V12 + 1.05459953346924882e-14*V03*V11*V12 + 
      1.4766341583303441e-15*V02*V122 - 7.11555785716754929e-12*V013*V022*V13 - 
      2.46339144768582333e-12*V014*V03*V13 + 5.62440125972049555e-12*V023*V03*V13 + 
      1.46009104023688775e-11*V01*V02*V032*V13 + 1.06921309271487798e-11*V01*V022*V04*V13 + 
      8.6847501660786755e-12*V012*V03*V04*V13 - 1.97549110248894333e-12*V03*V042*V13 + 
      5.3986102204678356e-12*V012*V02*V05*V13 - 1.67557339451327477e-12*V032*V05*V13 - 
      2.42717978677294722e-12*V02*V04*V05*V13 - 6.4764122026905492e-13*V01*V052*V13 + 
      7.22983502990573396e-13*V013*V06*V13 - 1.73922308420895268e-12*V02*V03*V06*V13 - 
      1.09495221645456034e-12*V01*V04*V06*V13 - 3.93396483661090429e-13*V022*V07*V13 - 
      6.81518970387004692e-13*V01*V03*V07*V13 + 4.33824756032214481e-14*V06*V07*V13 - 2.77472319191368747e-13*V01*V02*V08*V13 + 
      3.36948446010558919e-14*V05*V08*V13 - 4.16044141348250533e-14*V012*V09*V13 + 
      1.98581958233045517e-14*V04*V09*V13 + 9.03400927755136257e-15*V03*V10*V13 + 2.74481174903921748e-15*V02*V11*V13 + 
      6.6957340331953677e-16*V01*V12*V13 - 5.94290273566589356e-13*V014*V02*V14 + 
      3.26526205412169494e-13*V024*V14 + 3.53165157621617237e-12*V01*V022*V03*V14 + 
      1.41422904995290895e-12*V012*V032*V14 + 2.1222078205886351e-12*V012*V02*V04*V14 - 
      6.56529547573298755e-13*V032*V04*V14 - 4.72246285669338679e-13*V02*V042*V14 + 
      3.34290021298459873e-13*V013*V05*V14 - 8.09457743294230293e-13*V02*V03*V05*V14 - 
      5.08530535522526643e-13*V01*V04*V05*V14 - 2.07562923318431888e-13*V022*V06*V14 - 
      3.61469907005137093e-13*V01*V03*V06*V14 + 1.14763722080072174e-14*V062*V14 - 
      1.66218031724160062e-13*V01*V02*V07*V14 + 2.01778356332199215e-14*V05*V07*V14 - 
      2.77021573058864015e-14*V012*V08*V14 + 1.3193158382616169e-14*V04*V08*V14 + 6.62064796499135065e-15*V03*V09*V14 + 
      2.19238390252560255e-15*V02*V10*V14 + 5.8025038393457835e-16*V01*V11*V14 - 1.50517840249464591e-18*V142 - 
      1.74791256931349811e-14*V015*V15 + 2.65481762915105492e-13*V01*V023*V15 + 
      6.48795028717106641e-13*V012*V02*V03*V15 - 6.8066566646838548e-14*V033*V15 + 
      1.23328862829272428e-13*V013*V04*V15 - 2.96958128500775342e-13*V02*V03*V04*V15 - 
      9.36089208510382596e-14*V01*V042*V15 - 9.10448282076277624e-14*V022*V05*V15 - 
      1.57393480343731102e-13*V01*V03*V05*V15 - 8.26574011863596269e-14*V01*V02*V06*V15 + 1.00222724476427083e-14*V05*V06*V15 - 
      1.55511745103155895e-14*V012*V07*V15 + 7.41676406594806596e-15*V04*V07*V15 + 
      4.12915890603179722e-15*V03*V08*V15 + 1.50809968969394093e-15*V02*V09*V15 + 4.35022301807857333e-16*V01*V10*V15 - 
      2.82305945583492788e-18*V13*V15 + 7.00422583869988146e-14*V012*V022*V16 + 
      3.52314758148065441e-14*V013*V03*V16 - 4.36975629226566795e-14*V02*V032*V16 - 
      3.12776227931096133e-14*V022*V04*V16 - 5.46391859924164651e-14*V01*V03*V04*V16 - 
      3.39318000839200582e-14*V01*V02*V05*V16 + 2.05813842385241595e-15*V052*V16 - 
      7.29186541920561205e-15*V012*V06*V16 + 3.46486059113790441e-15*V04*V06*V16 + 
      2.18328689576093845e-15*V03*V07*V16 + 8.84553654206952134e-16*V02*V08*V16 + 2.81413332699775377e-16*V01*V09*V16 - 
      2.32407253900997186e-18*V12*V16 + 7.22265459542068317e-15*V013*V02*V17 - 
      8.78123007453968083e-15*V022*V03*V17 - 7.52219119988421526e-15*V01*V032*V17 - 
      1.11206514163389709e-14*V01*V02*V04*V17 - 2.82233898517299869e-15*V012*V05*V17 + 
      1.34680644218868476e-15*V04*V05*V17 + 9.65298560004194491e-16*V03*V06*V17 + 4.42539636628884607e-16*V02*V07*V17 + 
      1.56176711841481682e-16*V01*V08*V17 - 1.67907457044042887e-18*V11*V17 + 2.48797078965430631e-16*V014*V18 - 
      5.5087191625477166e-16*V023*V18 - 2.91318761552249684e-15*V01*V02*V03*V18 - 
      8.80213908158000793e-16*V012*V04*V18 + 2.08558130520634468e-16*V042*V18 + 
      3.55172489983697327e-16*V03*V05*V18 + 1.85183531263893339e-16*V02*V06*V18 + 7.39438321894901071e-17*V01*V07*V18 - 
      1.0599208202361611e-18*V10*V18 - 2.67017067071484894e-16*V01*V022*V19 - 
      2.17131996188012187e-16*V012*V03*V19 + 1.04869644185134165e-16*V03*V04*V19 + 
      6.49398072626889921e-17*V02*V05*V19 + 2.9490651356157321e-17*V01*V06*V19 - 5.83257469694119294e-19*V09*V19 - 
      3.84253266402165086e-17*V012*V02*V20 + 1.25254190812490606e-17*V032*V20 + 
      1.822142416423011e-17*V02*V04*V20 + 9.82353545915093166e-18*V01*V05*V20 - 2.77454967888408531e-19*V08*V20 - 
      1.65864719310287087e-18*V013*V21 + 4.18347680927057431e-18*V02*V03*V21 + 2.64922815565041876e-18*V01*V04*V21 - 
      1.13621569374272333e-19*V07*V21 + 3.31729438620574175e-19*V022*V22 + 5.75919164271830164e-19*V01*V03*V22 - 
      3.94083799893853967e-20*V06*V22 + 8.92151141744726e-20*V01*V02*V23 - 1.15268084351751672e-20*V05*V23 + 
      5.44505391675184883e-21*V012*V24 - 2.73504432370179073e-21*V04*V24 - 5.31988026349318564e-22*V03*V25 - 
      7.30179644008868617e-23*V02*V26 - 8.42514973856386865e-24*V01*V27 + 4.85319685401144508e-27*V30) + 
   delta6*eps12*(5.11979806754947562e-9*V023*V034 + 
      6.28439861063648883e-9*V01*V02*V035 + 6.53023637886137954e-9*V024*V032*V04 + 
      3.49980746918015368e-8*V01*V022*V033*V04 + 8.12007747685893213e-9*V012*V034*V04 + 
      3.28023733515722384e-11*V025*V042 + 1.68287738767928895e-8*V01*V023*V03*V042 + 
      2.86971448111571193e-8*V012*V02*V032*V042 - 1.14011502994645109e-8*V034*V042 + 
      5.31442780537228258e-9*V012*V022*V043 + 3.3217247603230432e-9*V013*V03*V043 - 
      2.44669543095360546e-8*V02*V032*V043 - 2.2483490443839068e-9*V022*V044 - 
      7.44902850484399929e-9*V01*V03*V044 + 1.1932876828753958e-9*V025*V03*V05 + 
      1.75728789142813378e-8*V01*V023*V032*V05 + 1.68148565221743299e-8*V012*V02*V033*V05 - 
      4.1049971768015793e-9*V035*V05 + 3.91814182731682773e-9*V01*V024*V04*V05 + 
      2.92665774374379783e-8*V012*V022*V03*V04*V05 + 8.38741865123177882e-9*V013*V032*V04*V05 - 
      4.74196353548498438e-8*V02*V033*V04*V05 + 5.15464435388368656e-9*V013*V02*V042*V05 - 
      3.63871166639014982e-8*V022*V03*V042*V05 - 4.13378911271000792e-8*V01*V032*V042*V05 - 
      1.50406776685619115e-8*V01*V02*V043*V05 + 2.47093865671367944e-9*V012*V023*V052 + 
      4.35277990005716866e-9*V013*V02*V03*V052 - 
      1.83047795249389219e-8*V022*V032*V052 - 1.22535420198100562e-8*V01*V033*V052 + 
      5.20406508665299024e-10*V014*V04*V052 - 5.92348005622407077e-9*V023*V04*V052 - 
      4.31842619130223981e-8*V01*V02*V03*V04*V052 - 6.14380375992455298e-9*V012*V042*V052 + 
      1.95886723402046206e-9*V043*V052 - 3.72248018267106585e-9*V01*V022*V053 - 
      3.58469188452092172e-9*V012*V03*V053 + 3.71483687960949889e-9*V03*V04*V053 + 
      4.91686207259443451e-10*V02*V054 + 3.53516909891734025e-12*V026*V06 + 
      2.89822592784347662e-9*V01*V024*V03*V06 + 9.8192521769111579e-9*V012*V022*V032*V06 + 
      1.81960754075656323e-9*V013*V033*V06 - 8.34065762220297975e-9*V02*V034*V06 + 
      3.68238259078683943e-9*V012*V023*V04*V06 + 6.78462467642534162e-9*V013*V02*V03*V04*V06 - 
      2.65313239174880345e-8*V022*V032*V04*V06 - 1.91516830337312622e-8*V01*V033*V04*V06 + 
      4.11328034025504827e-10*V014*V042*V06 - 3.16575486934029777e-9*V023*V042*V06 - 
      3.24246916566614558e-8*V01*V02*V03*V042*V06 - 3.19738692173967551e-9*V012*V043*V06 + 
      6.84929102303401647e-10*V044*V06 + 1.75213121024745504e-9*V013*V022*V05*V06 + 
      6.69738984358509069e-10*V014*V03*V05*V06 - 8.7274680127617514e-9*V023*V03*V05*V06 - 
      3.01789381324240246e-8*V01*V02*V032*V05*V06 - 1.62986003298929212e-8*V01*V022*V04*V05*V06 - 
      1.69439953449533837e-8*V012*V03*V04*V05*V06 + 8.53085614730325306e-9*V03*V042*V05*V06 - 
      4.4749593140078434e-9*V012*V02*V052*V06 + 3.97697790915409732e-9*V032*V052*V06 + 
      4.43407216018668314e-9*V02*V04*V052*V06 + 8.43257909093604133e-10*V01*V053*V06 + 
      1.37410959782366922e-10*V014*V02*V062 - 2.77651142359177797e-10*V024*V062 - 
      5.86181969526591239e-9*V01*V022*V03*V062 - 
      2.90489936779296046e-9*V012*V032*V062 - 
      3.47910405228289676e-9*V012*V02*V04*V062 + 3.07630464250431054e-9*V032*V04*V062 + 
      1.53447542271686522e-9*V02*V042*V062 - 5.54327998196170465e-10*V013*V05*V062 + 
      3.22275771746109623e-9*V02*V03*V05*V062 + 1.96603510686366572e-9*V01*V04*V05*V062 + 
      1.90167457525560969e-10*V022*V063 + 4.67302790292369799e-10*V01*V03*V063 - 
      9.74159399052878431e-12*V064 + 1.704696689821994e-10*V01*V025*V07 + 
      2.23064717845634598e-9*V012*V023*V03*V07 + 1.91530648761817301e-9*V013*V02*V032*V07 - 
      5.91122341729889937e-9*V022*V033*V07 - 2.9345597027074377e-9*V01*V034*V07 + 
      1.18110466033672231e-9*V013*V022*V04*V07 + 4.53053758965853336e-10*V014*V03*V04*V07 - 
      5.77498970741263911e-9*V023*V03*V04*V07 - 2.07863171360354468e-8*V01*V02*V032*V04*V07 - 
      5.44857058956791019e-9*V01*V022*V042*V07 - 5.87404784004939108e-9*V012*V03*V042*V07 + 
      1.97545842080561341e-9*V03*V043*V07 + 2.3500403965242191e-10*V014*V02*V05*V07 - 
      6.95192346142862497e-10*V024*V05*V07 - 1.07656539437527827e-8*V01*V022*V03*V05*V07 - 
      5.11715779114514648e-9*V012*V032*V05*V07 - 6.1791537751692598e-9*V012*V02*V04*V05*V07 + 
      5.59153958991555632e-9*V032*V04*V05*V07 + 3.05700850431379675e-9*V02*V042*V05*V07 - 
      4.84061761895630746e-10*V013*V052*V07 + 2.96246128582513109e-9*V02*V03*V052*V07 + 
      1.77927481862708762e-9*V01*V04*V052*V07 + 1.34343265327384121e-11*V015*V06*V07 - 
      1.30512177049964425e-9*V01*V023*V06*V07 - 4.26971068766919061e-9*V012*V02*V03*V06*V07 + 
      1.3270401978967495e-9*V033*V06*V07 - 7.72603172167892948e-10*V013*V04*V06*V07 + 
      4.46415591730487322e-9*V02*V03*V04*V06*V07 + 1.37165986795685994e-9*V01*V042*V06*V07 + 
      1.14508847898528788e-9*V022*V05*V06*V07 + 2.51878644127009434e-9*V01*V03*V05*V06*V07 + 
      5.16319316726959078e-10*V01*V02*V062*V07 - 1.08850614769310101e-10*V05*V062*V07 - 
      3.84773749074983452e-10*V012*V022*V072 - 2.27884497215983798e-10*V013*V03*V072 + 
      7.41772174069159035e-10*V02*V032*V072 + 3.9144279022788022e-10*V022*V04*V072 + 
      8.85677405563816411e-10*V01*V03*V04*V072 + 4.71370770236882858e-10*V01*V02*V05*V072 - 
      4.94855862918812107e-11*V052*V072 + 9.67103795229027201e-11*V012*V06*V072 - 
      7.6625570113420455e-11*V04*V06*V072 - 1.68312526894861991e-11*V03*V073 + 
      1.61156100279536366e-10*V012*V024*V08 + 5.73405955238421412e-10*V013*V022*V03*V08 + 
      1.06432770053926362e-10*V014*V032*V08 - 1.673633831909941e-9*V023*V032*V08 - 
      3.70147417166368546e-9*V01*V02*V033*V08 + 1.36352717407068972e-10*V014*V02*V04*V08 - 
      2.86027394978351203e-10*V024*V04*V08 - 6.16804076535413498e-9*V01*V022*V03*V04*V08 - 
      3.07698365846992364e-9*V012*V032*V04*V08 - 1.83312092233597914e-9*V012*V02*V042*V08 + 
      1.67630450366641758e-9*V032*V042*V08 + 5.5157774023424302e-10*V02*V043*V08 + 
      9.79694205516454494e-12*V015*V05*V08 - 1.0268241252494614e-9*V01*V023*V05*V08 - 
      3.26109401547046174e-9*V012*V02*V03*V05*V08 + 1.02963562449849968e-9*V033*V05*V08 - 
      5.86127182393026158e-10*V013*V04*V05*V08 + 3.50203179509138935e-9*V02*V03*V04*V05*V08 + 
      1.06953985887064151e-9*V01*V042*V05*V08 + 4.51264040776772681e-10*V022*V052*V08 + 
      9.74958549557480348e-10*V01*V03*V052*V08 - 6.61751944627894005e-10*V012*V022*V06*V08 - 
      3.95913008205852347e-10*V013*V03*V06*V08 + 1.26516276710161553e-9*V02*V032*V06*V08 + 
      6.13746680956556656e-10*V022*V04*V06*V08 + 1.52608371743575697e-9*V01*V03*V04*V06*V08 + 
      8.05647184182053699e-10*V01*V02*V05*V06*V08 - 8.51846151754080845e-11*V052*V06*V08 + 
      8.40794836246013737e-11*V012*V062*V08 - 6.4371827522933752e-11*V04*V062*V08 - 
      1.47386887486764788e-10*V013*V02*V07*V08 + 4.53075924877154874e-10*V022*V03*V07*V08 + 
      4.83526849808222882e-10*V01*V032*V07*V08 + 5.59542013331216125e-10*V01*V02*V04*V07*V08 + 
      1.49151659534563166e-10*V012*V05*V07*V08 - 1.20125921231230535e-10*V04*V05*V07*V08 - 
      8.70140862613131953e-11*V03*V06*V07*V08 - 1.62674219902326489e-11*V02*V072*V08 - 
      4.7563091534383478e-12*V014*V082 + 2.02446178250942866e-11*V023*V082 + 
      1.559941386553093e-10*V01*V02*V03*V082 + 4.56477230215849797e-11*V012*V04*V082 - 
      1.77076067842490649e-11*V042*V082 - 3.39867060567049583e-11*V03*V05*V082 - 
      1.3599319053460568e-11*V02*V06*V082 - 5.66297273293752118e-12*V01*V07*V082 + 
      4.98262978091958905e-11*V013*V023*V09 + 5.61403622262468725e-11*V014*V02*V03*V09 - 
      2.01899918293381204e-10*V024*V03*V09 - 1.53316860284183457e-9*V01*V022*V032*V09 - 
      4.77549691948423172e-10*V012*V033*V09 + 4.9842697976512906e-12*V015*V04*V09 - 
      5.14644174798481903e-10*V01*V023*V04*V09 - 1.74223362108663988e-9*V012*V02*V03*V04*V09 + 
      5.67132202535366518e-10*V033*V04*V09 - 1.58258307111341508e-10*V013*V042*V09 + 
      9.38739487460745643e-10*V02*V03*V042*V09 + 1.93317012840331813e-10*V01*V043*V09 - 
      4.54691469248870354e-10*V012*V022*V05*V09 - 2.68115364654485169e-10*V013*V03*V05*V09 + 
      9.02147166076120031e-10*V02*V032*V05*V09 + 4.77820900689788176e-10*V022*V04*V05*V09 + 
      1.07451264921469746e-9*V01*V03*V04*V05*V09 + 2.85961725017197014e-10*V01*V02*V052*V09 - 
      2.02339587700019931e-11*V053*V09 - 1.14219378179443237e-10*V013*V02*V06*V09 + 
      3.50740721736689704e-10*V022*V03*V06*V09 + 3.78863656404391676e-10*V01*V032*V06*V09 + 
      4.34933526502581131e-10*V01*V02*V04*V06*V09 + 1.16892418034049972e-10*V012*V05*V06*V09 - 
      9.41191151745447931e-11*V04*V05*V06*V09 - 3.41386592126541537e-11*V03*V062*V09 - 
      8.48420562756683746e-12*V014*V07*V09 + 4.01108025868168489e-11*V023*V07*V09 + 
      2.83803228930310805e-10*V01*V02*V03*V07*V09 + 8.22932008262253215e-11*V012*V04*V07*V09 - 
      3.30369962928504209e-11*V042*V07*V09 - 6.19049816386646244e-11*V03*V05*V07*V09 - 
      2.54234090504837223e-11*V02*V06*V07*V09 - 5.14561535828993438e-12*V01*V072*V09 + 
      4.38188657597689247e-11*V01*V022*V08*V09 + 4.42347429883074868e-11*V012*V03*V08*V09 - 
      3.76567929567064099e-11*V03*V04*V08*V09 - 1.99748141911944075e-11*V02*V05*V08*V09 - 
      8.89594472467524737e-12*V01*V06*V08*V09 + 6.53698262961084901e-12*V012*V02*V092 - 
      4.82472953064684911e-12*V032*V092 - 5.44781387945981346e-12*V02*V04*V092 - 
      3.14651554524169159e-12*V01*V05*V092 + 1.07575291861976373e-13*V08*V092 + 
      6.56127536018746889e-12*V014*V022*V10 - 6.28774044833033701e-12*V025*V10 + 
      1.79296987110024606e-12*V015*V03*V10 - 2.41757644247508925e-10*V01*V023*V03*V10 - 
      3.68971152625495764e-10*V012*V02*V032*V10 + 6.36323062085581609e-11*V034*V10 - 
      2.16798786742613556e-10*V012*V022*V04*V10 - 1.30720790092825723e-10*V013*V03*V04*V10 + 
      4.38357008930931796e-10*V02*V032*V04*V10 + 1.0446570949042646e-10*V022*V042*V10 + 
      2.64822088351250341e-10*V01*V03*V042*V10 - 6.98241988643341569e-11*V013*V02*V05*V10 + 
      2.26747723384300617e-10*V022*V03*V05*V10 + 2.38870613282232708e-10*V01*V032*V05*V10 + 
      2.78428969089413285e-10*V01*V02*V04*V05*V10 + 3.67017671466749688e-11*V012*V052*V10 - 
      3.02380994200035547e-11*V04*V052*V10 - 5.9430069882674303e-12*V014*V06*V10 + 
      2.56284495868919324e-11*V023*V06*V10 + 1.98967827109950021e-10*V01*V02*V03*V06*V10 + 
      5.8256138568474289e-11*V012*V04*V06*V10 - 2.27353181971655497e-11*V042*V06*V10 - 
      4.3724148612602726e-11*V03*V05*V06*V10 - 8.72301578279986702e-12*V02*V062*V10 + 
      3.59582341691263453e-11*V01*V022*V07*V10 + 3.60209595550557504e-11*V012*V03*V07*V10 - 
      3.08701492905044799e-11*V03*V04*V07*V10 - 1.6400310605246681e-11*V02*V05*V07*V10 - 
      7.28110082862992133e-12*V01*V06*V07*V10 + 1.18147269427759815e-11*V012*V02*V08*V10 - 
      8.68518815762356603e-12*V032*V08*V10 - 9.56691528282165788e-12*V02*V04*V08*V10 - 
      5.66887034209853768e-12*V01*V05*V08*V10 + 9.62247634512707986e-14*V082*V10 + 
      1.04787292123532807e-12*V013*V09*V10 - 5.12984446506550949e-12*V02*V03*V09*V10 - 
      3.14826839683573533e-12*V01*V04*V09*V10 + 1.76413003057521021e-13*V07*V09*V10 - 
      3.19252624712480135e-13*V022*V102 - 7.15818092995833094e-13*V01*V03*V102 + 
      6.20539464634700527e-14*V06*V102 + 3.78067014992252924e-13*V015*V02*V11 - 
      1.19717337164059396e-11*V01*V024*V11 - 8.46960314502890135e-11*V012*V022*V03*V11 - 
      2.44333268665229764e-11*V013*V032*V11 + 6.15338385818178016e-11*V02*V033*V11 - 
      3.08448921279165463e-11*V013*V02*V04*V11 + 9.89506946202887356e-11*V022*V03*V04*V11 + 
      1.08874762208412445e-10*V01*V032*V04*V11 + 6.1640059570193134e-11*V01*V02*V042*V11 - 
      3.28346763377738487e-12*V014*V05*V11 + 1.65657775138424744e-11*V023*V05*V11 + 
      1.16013706631553032e-10*V01*V02*V03*V05*V11 + 3.35097210103525611e-11*V012*V04*V05*V11 - 
      1.3775121634296125e-11*V042*V05*V11 - 1.28639116910717489e-11*V03*V052*V11 + 
      2.29290783794404451e-11*V01*V022*V06*V11 + 2.33583671552289551e-11*V012*V03*V06*V11 - 
      2.00275499582776916e-11*V03*V04*V06*V11 - 1.05972587995833547e-11*V02*V05*V06*V11 - 
      2.36722937397376589e-12*V01*V062*V11 + 8.81100105228480801e-12*V012*V02*V07*V11 - 
      6.5419696088928592e-12*V032*V07*V11 - 7.39754261427104556e-12*V02*V04*V07*V11 - 
      4.2642394709697889e-12*V01*V05*V07*V11 + 8.67444323067818835e-13*V013*V08*V11 - 
      4.24148487064918072e-12*V02*V03*V08*V11 - 2.60631376470732166e-12*V01*V04*V08*V11 + 1.46154500206913671e-13*V07*V08*V11 - 
      6.01627874460204652e-13*V022*V09*V11 - 1.31544886072074995e-12*V01*V03*V09*V11 + 
      1.14951150502220865e-13*V06*V09*V11 - 3.52765740749065523e-13*V01*V02*V10*V11 + 7.38298834827120743e-14*V05*V10*V11 - 
      2.16031149964390739e-14*V012*V112 + 1.70547328854261923e-14*V04*V112 + 
      7.76850030805999158e-15*V016*V12 - 5.80492553852773915e-12*V012*V023*V12 - 
      1.06214388878599787e-11*V013*V02*V03*V12 + 1.97197142892801617e-11*V022*V032*V12 + 
      1.35352057718260657e-11*V01*V033*V12 - 1.33915997810440822e-12*V014*V04*V12 + 
      6.01591230281355151e-12*V023*V04*V12 + 4.7889397352850306e-11*V01*V02*V03*V04*V12 + 
      7.02444858191099965e-12*V012*V042*V12 - 1.87036436876604568e-12*V043*V12 + 
      1.24670955283429506e-11*V01*V022*V05*V12 + 1.23472438047503549e-11*V012*V03*V05*V12 - 
      1.08735697945315405e-11*V03*V04*V05*V12 - 2.89291843869845839e-12*V02*V052*V12 + 
      5.24950725762423915e-12*V012*V02*V06*V12 - 3.91570200497004835e-12*V032*V06*V12 - 
      4.29197145083369922e-12*V02*V04*V06*V12 - 2.55405751841666671e-12*V01*V05*V06*V12 + 
      5.94197492894031914e-13*V013*V07*V12 - 2.94768185112356462e-12*V02*V03*V07*V12 - 
      1.80584512202607689e-12*V01*V04*V07*V12 + 5.07296905825507555e-14*V072*V12 - 
      4.46579170970001173e-13*V022*V08*V12 - 1.00327225406175927e-12*V01*V03*V08*V12 + 
      8.70451114595495944e-14*V06*V08*V12 - 2.98609512458644278e-13*V01*V02*V09*V12 + 6.25058680994150899e-14*V05*V09*V12 - 
      3.98329661776719889e-14*V012*V10*V12 + 3.11752051737664818e-14*V04*V10*V12 + 
      1.34757903197493909e-14*V03*V11*V12 + 1.5242600261923723e-15*V02*V122 - 
      1.05457391681914386e-12*V013*V022*V13 - 4.1561476648120955e-13*V014*V03*V13 + 
      2.46716357999120439e-12*V023*V03*V13 + 8.4271512529546842e-12*V01*V02*V032*V13 + 
      4.64959415930984757e-12*V01*V022*V04*V13 + 4.81392178513526814e-12*V012*V03*V04*V13 - 
      2.121851497377257e-12*V03*V042*V13 + 2.58010539095283279e-12*V012*V02*V05*V13 - 
      1.96569597824408638e-12*V032*V05*V13 - 2.23359220316250296e-12*V02*V04*V05*V13 - 
      6.39027559710706371e-13*V01*V052*V13 + 3.2953117820731517e-13*V013*V06*V13 - 
      1.62961536632294704e-12*V02*V03*V06*V13 - 1.00300437532686563e-12*V01*V04*V06*V13 - 
      2.95880855578268284e-13*V022*V07*V13 - 6.44690952420211278e-13*V01*V03*V07*V13 + 
      5.65583100846434713e-14*V06*V07*V13 - 2.11163145684643087e-13*V01*V02*V08*V13 + 4.43021613255248087e-14*V05*V08*V13 - 
      3.12441950867249054e-14*V012*V09*V13 + 2.47039189381940438e-14*V04*V09*V13 + 
      1.15280407549107147e-14*V03*V10*V13 + 2.85359927240368288e-15*V02*V11*V13 + 6.96948686726006253e-16*V01*V12*V13 - 
      7.76850030805999158e-14*V014*V02*V14 + 9.40120931201604073e-14*V024*V14 + 
      1.57530362297593423e-12*V01*V022*V03*V14 + 7.61492253441465227e-13*V012*V032*V14 + 
      9.2858843731490628e-13*V012*V02*V04*V14 - 7.21538883562920543e-13*V032*V04*V14 - 
      3.90055797864802146e-13*V02*V042*V14 + 1.49319909022559885e-13*V013*V05*V14 - 
      7.69518552471470787e-13*V02*V03*V05*V14 - 4.69609309231927464e-13*V01*V04*V05*V14 - 
      1.48032747489434744e-13*V022*V06*V14 - 3.3506035137855168e-13*V01*V03*V06*V14 + 
      1.45962351557873286e-14*V062*V14 - 1.26969285076618503e-13*V01*V02*V07*V14 + 
      2.66592566671645643e-14*V05*V07*V14 - 2.06883186243081459e-14*V012*V08*V14 + 
      1.62116115495872565e-14*V04*V08*V14 + 8.45993826501182513e-15*V03*V09*V14 + 2.26003067224343582e-15*V02*V10*V14 + 
      6.04094333616496415e-16*V01*V11*V14 - 2.00270726228861898e-18*V142 - 1.9421250770149979e-15*V015*V15 + 
      8.68225295600984184e-14*V01*V023*V15 + 2.77836472974131076e-13*V012*V02*V03*V15 - 
      7.55807605983034929e-14*V033*V15 + 5.0945599846335452e-14*V013*V04*V15 - 
      2.60303008435242253e-13*V02*V03*V04*V15 - 8.03462851894543522e-14*V01*V042*V15 - 
      6.77323235479431739e-14*V022*V05*V15 - 1.4623953982237985e-13*V01*V03*V05*V15 - 
      6.14571865194268863e-14*V01*V02*V06*V15 + 1.3005073880775731e-14*V05*V06*V15 - 
      1.15858695629143599e-14*V012*V07*V15 + 9.21976298918643866e-15*V04*V07*V15 + 
      5.24658998541442498e-15*V03*V08*V15 + 1.56728430766123504e-15*V02*V09*V15 + 4.52070968700141329e-16*V01*V10*V15 - 
      3.76401171276961936e-18*V13*V15 + 2.32351340735634893e-14*V012*V022*V16 + 
      1.38693062565092785e-14*V013*V03*V16 - 3.92994616343351408e-14*V02*V032*V16 - 
      2.06111743188892094e-14*V022*V04*V16 - 4.74978352666795154e-14*V01*V03*V04*V16 - 
      2.54617947711181351e-14*V01*V02*V05*V16 + 2.70437149860113534e-15*V052*V16 - 
      5.32649917667271211e-15*V012*V06*V16 + 4.19608175913933472e-15*V04*V06*V16 + 
      2.78561256612454225e-15*V03*V07*V16 + 9.0681178229854095e-16*V02*V08*V16 + 2.9268286813651306e-16*V01*V09*V16 - 
      3.09136437900701946e-18*V12*V16 + 2.2634670281636147e-15*V013*V02*V17 - 
      6.17770127909519067e-15*V022*V03*V17 - 6.53047934152318814e-15*V01*V032*V17 - 
      7.67783317950771849e-15*V01*V02*V04*V17 - 2.0511501350392163e-15*V012*V05*V17 + 
      1.66542502867832306e-15*V04*V05*V17 + 1.20968981248612763e-15*V03*V06*V17 + 4.59361781662771704e-16*V02*V07*V17 + 
      1.61506163075077877e-16*V01*V08*V17 - 2.23869853224362068e-18*V11*V17 + 7.0366850616485431e-17*V014*V18 - 
      2.84125705711453396e-16*V023*V18 - 2.0406386678780775e-15*V01*V02*V03*V18 - 
      5.98352786408847782e-16*V012*V04*V18 + 2.39743769319844557e-16*V042*V18 + 
      4.49730179367873164e-16*V03*V05*V18 + 1.8656693397329227e-16*V02*V06*V18 + 7.66568652077034898e-17*V01*V07*V18 - 
      1.40818661755944889e-18*V10*V18 - 1.45659380776124842e-16*V01*V022*V19 - 
      1.45307546523042415e-16*V012*V03*V19 + 1.24989118407532247e-16*V03*V04*V19 + 
      6.69560129963252344e-17*V02*V05*V19 + 3.00247453260576178e-17*V01*V06*V19 - 7.77609064581874575e-19*V09*V19 - 
      2.07347653149910403e-17*V012*V02*V20 + 1.52043457177860856e-17*V032*V20 + 
      1.73045010189520295e-17*V02*V04*V20 + 1.006317766724534e-17*V01*V05*V20 - 3.67331530825485335e-19*V08*V20 - 
      8.44402207397825172e-19*V013*V21 + 4.13600710845786589e-18*V02*V03*V21 + 2.55163603545017408e-18*V01*V04*V21 - 
      1.5142786415541196e-19*V07*V21 + 2.56336384388625499e-19*V022*V22 + 5.59584002521574618e-19*V01*V03*V22 - 
      5.15649425762435032e-20*V06*V22 + 7.0366850616485431e-20*V01*V02*V23 - 1.53015162366157393e-20*V05*V23 + 
      4.18850301288603756e-21*V012*V24 - 3.42109223098484861e-21*V04*V24 - 6.83640721643468199e-22*V03*V25 - 
      7.6495010324738617e-23*V02*V26 - 8.82634734516214811e-24*V01*V27 + 6.47092913868192677e-27*V30) + 
   delta2*eps14*(-6.77936059264516573e-13*V028 - 1.48040897261592484e-8*V01*V026*V03 - 
      1.0920431292139003e-7*V012*V024*V032 - 
      1.07964182500246926e-7*V013*V022*V033 - 8.92507451554681558e-9*V014*V034 + 
      7.16508135962120041e-8*V023*V034 + 7.57774721395485856e-8*V01*V02*V035 - 
      2.96224161095630517e-8*V012*V025*V04 - 1.4644677288380603e-7*V013*V023*V03*V04 - 
      7.2639238722338629e-8*V014*V02*V032*V04 + 1.2940615229427052e-7*V024*V032*V04 + 
      5.05016599550344609e-7*V01*V022*V033*V04 + 1.03441260132924524e-7*V012*V034*V04 - 
      2.46279691325938992e-8*V014*V022*V042 + 1.18453251754498057e-8*V025*V042 - 
      6.12267071585173826e-9*V015*V03*V042 + 3.22712172227540327e-7*V01*V023*V03*V042 + 
      4.25770866093976561e-7*V012*V02*V032*V042 - 3.30997366463326056e-8*V034*V042 + 
      9.65038343425999201e-8*V012*V022*V043 + 5.06341396258389646e-8*V013*V03*V043 - 
      8.6350273137192877e-8*V02*V032*V043 - 1.26192122113177278e-8*V022*V044 - 
      2.64956794647521221e-8*V01*V03*V044 - 1.88743499761483344e-8*V013*V024*V05 - 
      3.74446296044101833e-8*V014*V022*V03*V05 + 2.63101690059325117e-8*V025*V03*V05 - 
      4.65396263472438387e-9*V015*V032*V05 + 2.76000471266865928e-7*V01*V023*V032*V05 + 
      2.32938477713765083e-7*V012*V02*V033*V05 - 1.12923567412594535e-8*V035*V05 - 
      6.30933179733950042e-9*V015*V02*V04*V05 + 8.41258680984350279e-8*V01*V024*V04*V05 + 
      4.7303392047082652e-7*V012*V022*V03*V04*V05 + 1.22747958597260093e-7*V013*V032*V04*V05 - 
      1.50625866327595507e-7*V02*V033*V04*V05 + 8.56954301256626993e-8*V013*V02*V042*V05 - 
      1.43644128220758013e-7*V022*V03*V042*V05 - 1.35481906677124622e-7*V01*V032*V042*V05 - 
      5.97025578326132457e-8*V01*V02*V043*V05 - 1.6179936498758472e-10*V016*V052 + 
      4.30610085160696067e-8*V012*V023*V052 + 
      6.89960454252874742e-8*V013*V02*V03*V052 - 
      6.35442194507606639e-8*V022*V032*V052 - 3.81480440064081809e-8*V01*V033*V052 + 
      8.73826353934827941e-9*V014*V04*V052 - 2.60823277846440233e-8*V023*V04*V052 - 
      1.54285479010351589e-7*V01*V02*V03*V04*V052 - 2.25413187427161668e-8*V012*V042*V052 + 
      3.90532729857493823e-9*V043*V052 - 1.44700335087487811e-8*V01*V022*V053 - 
      1.2548990277193841e-8*V012*V03*V053 + 6.82133692581095513e-9*V03*V04*V053 + 
      9.76207031356627678e-10*V02*V054 - 5.19540431859526164e-9*V014*V023*V06 + 
      1.38886154515450825e-9*V026*V06 - 3.8735695758921716e-9*V015*V02*V03*V06 + 
      6.05037934744465566e-8*V01*V024*V03*V06 + 1.62813979656106218e-7*V012*V022*V032*V06 + 
      2.77706287178561103e-8*V013*V033*V06 - 2.68152680018224238e-8*V02*V034*V06 - 
      2.61381180936503065e-10*V016*V04*V06 + 7.28294581997430096e-8*V012*V023*V04*V06 + 
      1.1605961161004761e-7*V013*V02*V03*V04*V06 - 1.03812989500712505e-7*V022*V032*V04*V06 - 
      6.37045359727982307e-8*V01*V033*V04*V06 + 7.32743954930033309e-9*V014*V042*V06 - 
      1.98537041988457781e-8*V023*V042*V06 - 1.27794949774625604e-7*V01*V02*V03*V042*V06 - 
      1.26114910845384246e-8*V012*V043*V06 + 1.57281609314195526e-9*V044*V06 + 
      3.23875808705728429e-8*V013*V022*V05*V06 + 1.17184474854237752e-8*V014*V03*V05*V06 - 
      3.80028671413827997e-8*V023*V03*V05*V06 - 1.09151784957895969e-7*V01*V02*V032*V05*V06 - 
      7.13545647343056767e-8*V01*V022*V04*V05*V06 - 6.31167276173674111e-8*V012*V03*V04*V05*V06 + 
      1.68878402086659347e-8*V03*V042*V05*V06 - 1.80483951533649046e-8*V012*V02*V052*V06 + 
      7.32499751470139244e-9*V032*V052*V06 + 9.60483973802659006e-9*V02*V04*V052*V06 + 
      1.7207268319421702e-9*V01*V053*V06 + 2.754461247299629e-9*V014*V02*V062 - 
      1.93139129787781293e-9*V024*V062 - 2.54888909561111366e-8*V01*V022*V03*V062 - 
      1.10211399583123908e-8*V012*V032*V062 - 
      1.51314059819809196e-8*V012*V02*V04*V062 + 6.06637024576421478e-9*V032*V04*V062 + 
      3.8565665577134839e-9*V02*V042*V062 - 2.33763648977358349e-9*V013*V05*V062 + 
      6.93392617221292808e-9*V02*V03*V05*V062 + 4.29258599213449928e-9*V01*V04*V05*V062 + 
      5.22374495747423834e-10*V022*V063 + 1.01967876714698683e-9*V01*V03*V063 - 
      1.61981873814974697e-11*V064 - 6.76014896807380468e-10*V015*V022*V07 + 
      4.33593802567739913e-9*V01*V025*V07 - 1.34612573338063534e-10*V016*V03*V07 + 
      4.29779447460624464e-8*V012*V023*V03*V07 + 3.38617434007307793e-8*V013*V02*V032*V07 - 
      2.19839631920941821e-8*V022*V033*V07 - 9.78909311560696705e-9*V01*V034*V07 + 
      2.35149281507133859e-8*V013*V022*V04*V07 + 8.47854989254558951e-9*V014*V03*V04*V07 - 
      2.73069340166947404e-8*V023*V03*V04*V07 - 7.9489428303064087e-8*V01*V02*V032*V04*V07 - 
      2.5800452177153592e-8*V01*V022*V042*V07 - 2.30477711618587558e-8*V012*V03*V042*V07 + 
      4.09879309868663075e-9*V03*V043*V07 + 4.75385163937119807e-9*V014*V02*V05*V07 - 
      3.64980746805947723e-9*V024*V05*V07 - 4.48016354102446272e-8*V01*V022*V03*V05*V07 - 
      1.91957479173865686e-8*V012*V032*V05*V07 - 2.6321071798170227e-8*V012*V02*V04*V05*V07 + 
      1.07016491827136303e-8*V032*V04*V05*V07 + 6.97162671891715349e-9*V02*V042*V05*V07 - 
      2.02895847836695065e-9*V013*V052*V07 + 6.13683665942584858e-9*V02*V03*V052*V07 + 
      3.77504031698813832e-9*V01*V04*V052*V07 + 3.00013932968485403e-10*V015*V06*V07 - 
      6.77525654269573126e-9*V01*V023*V06*V07 - 1.84281357169532686e-8*V012*V02*V03*V06*V07 + 
      2.55043702902929874e-9*V033*V06*V07 - 3.41800311567959914e-9*V013*V04*V06*V07 + 
      1.0085871061286609e-8*V02*V03*V04*V06*V07 + 3.13455186563870756e-9*V01*V042*V06*V07 + 
      2.83842094588102551e-9*V022*V05*V06*V07 + 5.3701181453537078e-9*V01*V03*V05*V06*V07 + 
      1.28296863415100783e-9*V01*V02*V062*V07 - 1.72806439901323266e-10*V05*V062*V07 - 
      1.89915492800495541e-9*V012*V022*V072 - 1.0244667592580363e-9*V013*V03*V072 + 
      1.60608676981416515e-9*V02*V032*V072 + 1.02721000574645548e-9*V022*V04*V072 + 
      1.96454191897263409e-9*V01*V03*V04*V072 + 1.13026648804552892e-9*V01*V02*V05*V072 - 
      7.6328448375778562e-11*V052*V072 + 2.3815653771309217e-10*V012*V06*V072 - 
      1.26247187420585492e-10*V04*V06*V072 - 2.6781123079734594e-11*V03*V073 - 
      4.04428126037603162e-11*V016*V02*V08 + 3.70619912339080818e-9*V012*V024*V08 + 
      1.20260728100298047e-8*V013*V022*V03*V08 + 2.15443241954833434e-9*V014*V032*V08 - 
      7.71747719679084377e-9*V023*V032*V08 - 1.44395558776375155e-8*V01*V02*V033*V08 + 
      3.02428678807099327e-9*V014*V02*V04*V08 - 2.15236742635870427e-9*V024*V04*V08 - 
      2.86230162779463422e-8*V01*V022*V03*V04*V08 - 1.23979177772740746e-8*V012*V032*V04*V08 - 
      8.50286385362641119e-9*V012*V02*V042*V08 + 3.43557114958981696e-9*V032*V042*V08 + 
      1.45164007832770004e-9*V02*V043*V08 + 2.27482774949404145e-10*V015*V05*V08 - 
      5.2602606225267868e-9*V01*V023*V05*V08 - 1.4191644784518425e-8*V012*V02*V03*V05*V08 + 
      1.97693136346455981e-9*V033*V05*V08 - 2.62535428067254653e-9*V013*V04*V05*V08 + 
      7.84435726611310563e-9*V02*V03*V04*V05*V08 + 2.43079260218527503e-9*V01*V042*V05*V08 + 
      1.10593892775909009e-9*V022*V052*V08 + 2.07867591963896903e-9*V01*V03*V052*V08 - 
      3.3660280812323271e-9*V012*V022*V06*V08 - 1.81316226771450397e-9*V013*V03*V06*V08 + 
      2.82333895319990764e-9*V02*V032*V06*V08 + 1.76789753886470859e-9*V022*V04*V06*V08 + 
      3.46571021569908854e-9*V01*V03*V04*V06*V08 + 1.99041597847113882e-9*V01*V02*V05*V06*V08 - 
      1.34333730514286088e-10*V052*V06*V08 + 2.10717422450450759e-10*V012*V062*V08 - 
      1.10394309545070329e-10*V04*V062*V08 - 7.59700899347595125e-10*V013*V02*V07*V08 + 
      1.1623311866377635e-9*V022*V03*V07*V08 + 1.07988656194421328e-9*V01*V032*V07*V08 + 
      1.4516277931883932e-9*V01*V02*V04*V07*V08 + 3.68058935720497847e-10*V012*V05*V07*V08 - 
      1.96387338771770464e-10*V04*V05*V07*V08 - 1.41486611519128464e-10*V03*V06*V07*V08 - 
      2.97897738597556043e-11*V02*V072*V08 - 2.6304195850885473e-11*V014*V082 + 
      6.69250966893665661e-11*V023*V082 + 4.01963981237859868e-10*V01*V02*V03*V082 + 
      1.19344716084984716e-10*V012*V04*V082 - 3.13507667480873498e-11*V042*V082 - 
      5.49646827795237187e-11*V03*V05*V082 - 2.60236645579306164e-11*V02*V06*V082 - 
      1.04049193000107398e-11*V01*V07*V082 - 8.8560903511883904e-13*V017*V09 + 
      1.26348276242485571e-9*V013*V023*V09 + 1.36659295722797768e-9*V014*V02*V03*V09 - 
      1.17867330162185437e-9*V024*V03*V09 - 7.06709184954519616e-9*V01*V022*V032*V09 - 
      1.98966279088787719e-9*V012*V033*V09 + 1.28624502322035063e-10*V015*V04*V09 - 
      2.99767945928471044e-9*V01*V023*V04*V09 - 8.21467894032972682e-9*V012*V02*V03*V04*V09 + 
      1.14767620547007992e-9*V033*V04*V09 - 7.61934606059657645e-10*V013*V042*V09 + 
      2.25942171059143868e-9*V02*V03*V042*V09 + 4.69453392948443198e-10*V01*V043*V09 - 
      2.32137801159080445e-9*V012*V022*V05*V09 - 1.24889421106117333e-9*V013*V03*V05*V09 + 
      1.97845454436777427e-9*V02*V032*V05*V09 + 1.26790266671206678e-9*V022*V04*V05*V09 + 
      2.4168111085869988e-9*V01*V03*V04*V05*V09 + 6.95470218757794505e-10*V01*V02*V052*V09 - 
      3.13955417032004739e-11*V053*V09 - 6.03075372380114091e-10*V013*V02*V06*V09 + 
      9.20556279457317563e-10*V022*V03*V06*V09 + 8.58027639641721463e-10*V01*V032*V06*V09 + 
      1.15164715012412271e-9*V01*V02*V04*V06*V09 + 2.92551756297764259e-10*V012*V05*V06*V09 - 
      1.5587211714914697e-10*V04*V05*V06*V09 - 5.61799912315210078e-11*V03*V062*V09 - 
      4.71894390005186623e-11*V014*V07*V09 + 1.23183751740294702e-10*V023*V07*V09 + 
      7.24053685037420673e-10*V01*V02*V03*V07*V09 + 2.14416071472199152e-10*V012*V04*V07*V09 - 
      5.69109190781872441e-11*V042*V07*V09 - 9.91441248502297078e-11*V03*V05*V07*V09 - 
      4.72626720917242638e-11*V02*V06*V07*V09 - 9.37359839638285725e-12*V01*V072*V09 + 
      1.32215555519699599e-10*V01*V022*V08*V09 + 1.16668487953866229e-10*V012*V03*V08*V09 - 
      6.38887627485246274e-11*V03*V04*V08*V09 - 3.67997757187780279e-11*V02*V05*V08*V09 - 
      1.65412582801487421e-11*V01*V06*V08*V09 + 1.96601932915358918e-11*V012*V02*V092 - 
      8.04602612395276514e-12*V032*V092 - 1.06428913065741181e-11*V02*V04*V092 - 
      5.78054069214448597e-12*V01*V05*V092 + 1.62632558940427334e-13*V08*V092 + 
      1.9412705419811113e-10*V014*V022*V10 - 5.89145968178609168e-11*V025*V10 + 
      5.19246560590729837e-11*V015*V03*V10 - 1.36312053847988926e-9*V01*V023*V03*V10 - 
      1.79732212015054018e-9*V012*V02*V032*V10 + 1.29601038036394919e-10*V034*V10 - 
      1.22012956609610616e-9*V012*V022*V04*V10 - 6.57258348854173704e-10*V013*V03*V04*V10 + 
      1.03588313558849776e-9*V02*V032*V04*V10 + 3.2271738633025647e-10*V022*V042*V10 + 
      6.3658428055647338e-10*V01*V03*V042*V10 - 3.765897500234988e-10*V013*V02*V05*V10 + 
      5.86238396084506771e-10*V022*V03*V05*V10 + 5.42017894611096117e-10*V01*V032*V05*V10 + 
      7.30121262429277007e-10*V01*V02*V04*V05*V10 + 9.22147741274854067e-11*V012*V052*V10 - 
      4.95502197888923637e-11*V04*V052*V10 - 3.39419945042495016e-11*V014*V06*V10 + 
      8.66163518400452365e-11*V023*V06*V10 + 5.21265209735285932e-10*V01*V02*V03*V06*V10 + 
      1.54798501770924273e-10*V012*V04*V06*V10 - 4.06784605136035292e-11*V042*V06*V10 - 
      7.13592261235662384e-11*V03*V05*V06*V10 - 1.68821023675533033e-11*V02*V062*V10 + 
      1.08049422230365136e-10*V01*V022*V07*V10 + 9.51787234038196936e-11*V012*V03*V07*V10 - 
      5.22225283382564195e-11*V03*V04*V07*V10 - 3.0094626591773042e-11*V02*V05*V07*V10 - 
      1.35129524767109043e-11*V01*V06*V07*V10 + 3.57152687395549535e-11*V012*V02*V08*V10 - 
      1.45855281201946647e-11*V032*V08*V10 - 1.91696225099222167e-11*V02*V04*V08*V10 - 
      1.04839019807551887e-11*V01*V05*V08*V10 + 1.4713929172631016e-13*V082*V10 + 
      3.27819589554603023e-12*V013*V09*V10 - 9.80933643597082688e-12*V02*V03*V09*V10 - 
      6.11262980200101886e-12*V01*V04*V09*V10 + 2.65918018350277643e-13*V07*V09*V10 - 
      7.28143247993447997e-13*V022*V102 - 1.38379506279499121e-12*V01*V03*V102 + 
      9.56054332045064385e-14*V06*V102 + 1.32957882772446756e-11*V015*V02*V11 - 
      8.68807341148996196e-11*V01*V024*V11 - 4.88946218755240774e-10*V012*V022*V03*V11 - 
      1.29527858681071958e-10*V013*V032*V11 + 1.44206716454350163e-10*V02*V033*V11 - 
      1.81419637337055474e-10*V013*V02*V04*V11 + 2.79732194370144444e-10*V022*V03*V04*V11 + 
      2.62230714485338964e-10*V01*V032*V04*V11 + 1.75445358954831996e-10*V01*V02*V042*V11 - 
      1.93660851697481006e-11*V014*V05*V11 + 5.16989741219468034e-11*V023*V05*V11 + 
      3.02356972436665113e-10*V01*V02*V03*V05*V11 + 8.93626099442325906e-11*V012*V04*V05*V11 - 
      2.38801446825827763e-11*V042*V05*V11 - 2.07784261180881639e-11*V03*V052*V11 + 
      7.11866337992756831e-11*V01*V022*V06*V11 + 6.29234847190653318e-11*V012*V03*V06*V11 - 
      3.44669003995249385e-11*V03*V04*V06*V11 - 1.98395331355610534e-11*V02*V05*V06*V11 - 
      4.46521002108368282e-12*V01*V062*V11 + 2.66763769286107457e-11*V012*V02*V07*V11 - 
      1.09315029182250901e-11*V032*V07*V11 - 1.44657640966603623e-11*V02*V04*V07*V11 - 
      7.85227128068329769e-12*V01*V05*V07*V11 + 2.72634164282573239e-12*V013*V08*V11 - 
      8.15182677906967336e-12*V02*V03*V08*V11 - 5.08212081601418996e-12*V01*V04*V08*V11 + 2.21038981336943604e-13*V07*V08*V11 - 
      1.34370108884726639e-12*V022*V09*V11 - 2.5371484700633984e-12*V01*V03*V09*V11 + 
      1.75676362412669289e-13*V06*V09*V11 - 7.79611618767132229e-13*V01*V02*V10*V11 + 1.11766482746642467e-13*V05*V10*V11 - 
      4.83756686640468386e-14*V012*V112 + 2.70814602647639111e-14*V04*V112 + 
      3.26277012938519646e-13*V016*V12 - 4.02756511239172396e-11*V012*V023*V12 - 
      6.57591528398230099e-11*V013*V02*V03*V12 + 5.44939173456632224e-11*V022*V032*V12 + 
      3.30799528352632082e-11*V01*V033*V12 - 8.57822774195545892e-12*V014*V04*V12 + 
      2.21675498707230582e-11*V023*V04*V12 + 1.34501481579439527e-10*V01*V02*V03*V04*V12 + 
      1.99894366419085294e-11*V012*V042*V12 - 3.51285763980346816e-12*V043*V12 + 
      3.82125520792679901e-11*V01*V022*V05*V12 + 3.35204196381054197e-11*V012*V03*V05*V12 - 
      1.85276925409456902e-11*V03*V04*V05*V12 - 5.34314323034669448e-12*V02*V052*V12 + 
      1.62804051213802143e-11*V012*V02*V06*V12 - 6.66003485802059185e-12*V032*V06*V12 - 
      8.74143070000553672e-12*V02*V04*V06*V12 - 4.78773954294365829e-12*V01*V05*V06*V12 + 
      1.8785836646914791e-12*V013*V07*V12 - 5.63893970098855739e-12*V02*V03*V07*V12 - 
      3.51171089485861346e-12*V01*V04*V07*V12 + 7.64176113497140217e-14*V072*V12 - 
      1.02349834383406234e-12*V022*V08*V12 - 1.94627804910327678e-12*V01*V03*V08*V12 + 
      1.34421930926666523e-13*V06*V08*V12 - 6.5937823064122352e-13*V01*V02*V09*V12 + 9.45263141379961822e-14*V05*V09*V12 - 
      8.92900822274547796e-14*V012*V10*V12 + 4.98582285777993878e-14*V04*V10*V12 + 
      2.10554191507460786e-14*V03*V11*V12 + 2.73367901264936733e-15*V02*V122 - 
      7.67883886700446585e-12*V013*V022*V13 - 2.84812642544249441e-12*V014*V03*V13 + 
      8.28486616371376446e-12*V023*V03*V13 + 2.37708585199823394e-11*V01*V02*V032*V13 + 
      1.56915366812789102e-11*V01*V022*V04*V13 + 1.39250811534182378e-11*V012*V03*V04*V13 - 
      3.8317759348780895e-12*V03*V042*V13 + 8.05162484985795154e-12*V012*V02*V05*V13 - 
      3.32098005943193082e-12*V032*V05*V13 - 4.40302957590590206e-12*V02*V04*V05*V13 - 
      1.19163275497142891e-12*V01*V052*V13 + 1.0645704326658664e-12*V013*V06*V13 - 
      3.18661047020081131e-12*V02*V03*V06*V13 - 1.98819927437716755e-12*V01*V04*V06*V13 - 
      6.61923698739859333e-13*V022*V07*V13 - 1.24857508865107947e-12*V01*V03*V07*V13 + 
      8.64789162414414022e-14*V06*V07*V13 - 4.69573425370452756e-13*V01*V02*V08*V13 + 6.72970639484009865e-14*V05*V08*V13 - 
      7.00838913454008995e-14*V012*V09*V13 + 3.92328863562626869e-14*V04*V09*V13 + 
      1.80332553128012751e-14*V03*V10*V13 + 5.08665613983146216e-15*V02*V11*V13 + 1.24192598405031732e-15*V01*V12*V13 - 
      6.21480024644799327e-13*V014*V02*V14 + 4.18259528017247027e-13*V024*V14 + 
      5.23025907843860777e-12*V01*V022*V03*V14 + 2.25848421073776013e-12*V012*V032*V14 + 
      3.11904302232700031e-12*V012*V02*V04*V14 - 1.28593290472853242e-12*V032*V04*V14 - 
      8.40404354685060075e-13*V02*V042*V14 + 4.90003317166595845e-13*V013*V05*V14 - 
      1.48716504495359629e-12*V02*V03*V05*V14 - 9.24523562360027521e-13*V01*V04*V05*V14 - 
      3.46489932206207614e-13*V022*V06*V14 - 6.60401436972625256e-13*V01*V03*V06*V14 + 
      2.27906452953688396e-14*V062*V14 - 2.81370861279224713e-13*V01*V02*V07*V14 + 
      4.03313985028964391e-14*V05*V07*V14 - 4.66334872556251264e-14*V012*V08*V14 + 
      2.60180000244437969e-14*V04*V08*V14 + 1.32184006254634684e-14*V03*V09*V14 + 4.05787048516569194e-15*V02*V10*V14 + 
      1.07626420210453919e-15*V01*V11*V14 - 3.00945075209797647e-18*V142 - 1.74791256931349811e-14*V015*V15 + 
      3.50887818941635426e-13*V01*V023*V15 + 9.50691335254026416e-13*V012*V02*V03*V15 - 
      1.34268202327189588e-13*V033*V15 + 1.78420075417641964e-13*V013*V04*V15 - 
      5.3755497302158974e-13*V02*V03*V04*V15 - 1.68020548512624352e-13*V01*V042*V15 - 
      1.53067225843757269e-13*V022*V05*V15 - 2.87650864332847304e-13*V01*V03*V05*V15 - 
      1.39401480833674252e-13*V01*V02*V06*V15 + 1.99767692321399744e-14*V05*V06*V15 - 
      2.61603343157269433e-14*V012*V07*V15 + 1.46521399827194866e-14*V04*V07*V15 + 8.2374395207120285e-15*V03*V08*V15 + 
      2.79456488207778428e-15*V02*V09*V15 + 8.06693305159312762e-16*V01*V10*V15 - 5.64611770807703596e-18*V13*V15 + 
      9.30348278740800477e-14*V012*V022*V16 + 5.0419255803724141e-14*V013*V03*V16 - 
      7.99581874357534261e-14*V02*V032*V16 - 5.1449212045395228e-14*V022*V04*V16 - 
      9.86891159457388108e-14*V01*V03*V04*V16 - 5.72981683338832929e-14*V01*V02*V05*V16 + 
      4.11288111408038484e-15*V052*V16 - 1.22350361509414043e-14*V012*V06*V16 + 
      6.81791291295605637e-15*V04*V06*V16 + 4.35826189767930515e-15*V03*V07*V16 + 1.63579949301951267e-15*V02*V08*V16 + 
      5.21877956080570993e-16*V01*V09*V16 - 4.6465463027520719e-18*V12*V16 + 9.45730472285564193e-15*V013*V02*V17 - 
      1.47208372960350357e-14*V022*V03*V17 - 1.36339794032332893e-14*V01*V032*V17 - 
      1.85038680862556275e-14*V01*V02*V04*V17 - 4.72902932669898071e-15*V012*V05*V17 + 
      2.66027784544871341e-15*V04*V05*V17 + 1.92177254251781137e-15*V03*V06*V17 + 8.1988815581430706e-16*V02*V07*V17 + 
      2.89404615675360765e-16*V01*V08*V17 - 3.35814793728803795e-18*V11*V17 + 3.1665082777418444e-16*V014*V18 - 
      8.29424120623744702e-16*V023*V18 - 4.8804939726509656e-15*V01*V02*V03*V18 - 
      1.45787548968319155e-15*V012*V04*V18 + 4.0645987167588428e-16*V042*V18 + 
      7.08583714450476075e-16*V03*V05*V18 + 3.41523594722877577e-16*V02*V06*V18 + 1.37054101336150478e-16*V01*V07*V18 - 
      2.11874812168677405e-18*V10*V18 - 4.08102602557538184e-16*V01*V022*V19 - 
      3.59172510361003493e-16*V012*V03*V19 + 2.06870163806441395e-16*V03*V04*V19 + 
      1.20265743559900662e-16*V02*V05*V19 + 5.45211453611642815e-17*V01*V06*V19 - 1.16651373579541879e-18*V09*V19 - 
      5.85804031382241213e-17*V012*V02*V20 + 2.49212937478852888e-17*V032*V20 + 
      3.32330189624136686e-17*V02*V04*V20 + 1.81795989698585766e-17*V01*V05*V20 - 5.54337713361920317e-19*V08*V20 - 
      2.48797078965430631e-18*V013*V21 + 7.73323311269149115e-18*V02*V03*V21 + 4.84819223741558848e-18*V01*V04*V21 - 
      2.27241935155724871e-19*V07*V21 + 5.6209710432930624e-19*V022*V22 + 1.0596912622601675e-18*V01*V03*V22 - 
      7.85935794816145506e-20*V06*V22 + 1.52042659367763163e-19*V01*V02*V23 - 2.30524132775305395e-20*V05*V23 + 
      9.21470662834928263e-21*V012*V24 - 5.40846469503008574e-21*V04*V24 - 1.06277245987884229e-21*V03*V25 - 
      1.35604791030218457e-22*V02*V26 - 1.56467066573328989e-23*V01*V27 + 9.70639370802289015e-27*V30) + 
   delta4*eps13*(3.18505244927949122e-8*V023*V034 + 
      3.63721924280541002e-8*V01*V02*V035 + 4.86280695245372734e-8*V024*V032*V04 + 
      2.20211288493910388e-7*V01*V022*V033*V04 + 4.81455433084979275e-8*V012*V034*V04 + 
      2.55551047231023315e-9*V025*V042 + 1.22467626134807859e-7*V01*V023*V03*V042 + 
      1.82618989316787222e-7*V012*V02*V032*V042 - 2.63043652949928417e-8*V034*V042 + 
      3.73852520711127092e-8*V012*V022*V043 + 2.13886804421684309e-8*V013*V03*V043 - 
      6.22302068234421287e-8*V02*V032*V043 - 7.48454109323006102e-9*V022*V044 - 
      1.89889705506979006e-8*V01*V03*V044 + 9.08877376716545462e-9*V025*V03*V05 + 
      1.127081971564928e-7*V01*V023*V032*V05 + 1.02227016938670972e-7*V012*V02*V033*V05 - 
      9.18722452646237804e-9*V035*V05 + 2.91768417147223641e-8*V01*V024*V04*V05 + 
      1.90491982020819433e-7*V012*V022*V03*V04*V05 + 5.2436987914532368e-8*V013*V032*V04*V05 - 
      1.1342515053938193e-7*V02*V033*V04*V05 + 3.41235578420273205e-8*V013*V02*V042*V05 - 
      9.68540158679057273e-8*V022*V03*V042*V05 - 1.00369376300120491e-7*V01*V032*V042*V05 - 
      4.01248891726478198e-8*V01*V02*V043*V05 + 1.63956984563859441e-8*V012*V023*V052 + 
      2.79747121631947565e-8*V013*V02*V03*V052 - 
      4.53148478367601859e-8*V022*V032*V052 - 2.89100329191507154e-8*V01*V033*V052 + 
      3.45255048570379637e-9*V014*V04*V052 - 1.64487535725404588e-8*V023*V04*V052 - 
      1.08434403511903222e-7*V01*V02*V03*V04*V052 - 1.56374099398400389e-8*V012*V042*V052 + 
      3.51432810587743948e-9*V043*V052 - 9.6527288121086455e-9*V01*V022*V053 - 
      8.89236660403888461e-9*V012*V03*V053 + 6.37070244243975691e-9*V03*V04*V053 + 
      8.70665404797237582e-10*V02*V054 + 2.88337306258509828e-10*V026*V06 + 
      2.14127839125225537e-8*V01*V024*V03*V06 + 6.46748847236896075e-8*V012*V022*V032*V06 + 
      1.15939507572439985e-8*V013*V033*V06 - 2.01311269479684964e-8*V02*V034*V06 + 
      2.62297576837808744e-8*V012*V023*V04*V06 + 4.53983681217831457e-8*V013*V02*V03*V04*V06 - 
      7.04622926468160372e-8*V022*V032*V04*V06 - 4.69515380809358884e-8*V01*V033*V04*V06 + 
      2.81550684672345435e-9*V014*V042*V06 - 1.10057452915525098e-8*V023*V042*V06 - 
      8.62832503087032985e-8*V01*V02*V03*V042*V06 - 8.49593548288469685e-9*V012*V043*V06 + 
      1.33994572989674115e-9*V044*V06 + 1.20600599618847086e-8*V013*V022*V05*V06 + 
      4.53345299684557244e-9*V014*V03*V05*V06 - 2.41832286704071995e-8*V023*V03*V05*V06 - 
      7.64383659411645021e-8*V01*V02*V032*V05*V06 - 4.52448497920386642e-8*V01*V022*V04*V05*V06 - 
      4.35333307398547151e-8*V012*V03*V04*V05*V06 + 1.52791783583975097e-8*V03*V042*V05*V06 - 
      1.18566082543781223e-8*V012*V02*V052*V06 + 6.84649330739555099e-9*V032*V052*V06 + 
      8.24900618460748895e-9*V02*V04*V052*V06 + 1.51752357682272738e-9*V01*V053*V06 + 
      9.89573025098675417e-10*V014*V02*V062 - 1.00621175759930092e-9*V024*V062 - 
      1.62398406121865215e-8*V01*V022*V03*V062 - 
      7.54303035550392635e-9*V012*V032*V062 - 
      9.62212950083595293e-9*V012*V02*V04*V062 + 5.50852218256165074e-9*V032*V04*V062 + 
      3.12314385202035802e-9*V02*V042*V062 - 1.50463180780930825e-9*V013*V05*V062 + 
      5.98730146085247858e-9*V02*V03*V05*V062 + 3.67732894685077508e-9*V01*V04*V05*V062 + 
      4.02216236474883255e-10*V022*V063 + 8.74923136859372532e-10*V01*V03*V063 - 
      1.56326322935584384e-11*V064 + 1.2983962524522078e-9*V01*V025*V07 + 
      1.53358521940482015e-8*V012*V023*V03*V07 + 1.28821030582685537e-8*V013*V02*V032*V07 - 
      1.52057234858673829e-8*V022*V033*V07 - 7.1966015555823278e-9*V01*V034*V07 + 
      8.33788698921045719e-9*V013*V022*V04*V07 + 3.1524744417257051e-9*V014*V03*V04*V07 - 
      1.66690503320626575e-8*V023*V03*V04*V07 - 5.41831353659940985e-8*V01*V02*V032*V04*V07 - 
      1.57423995044342967e-8*V01*V022*V042*V07 - 1.55071770654304034e-8*V012*V03*V042*V07 + 
      3.63056176385854998e-9*V03*V043*V07 + 1.68644227601874988e-9*V014*V02*V05*V07 - 
      2.08275626822208695e-9*V024*V05*V07 - 2.89353723479750314e-8*V01*V022*V03*V05*V07 - 
      1.31723789622309176e-8*V012*V032*V05*V07 - 1.68135074683681121e-8*V012*V02*V04*V05*V07 + 
      9.82556959504886347e-9*V032*V04*V05*V07 + 5.84401911197995448e-9*V02*V042*V05*V07 - 
      1.30597937309827061e-9*V013*V052*V07 + 5.37533867082611707e-9*V02*V03*V052*V07 + 
      3.26748690758610518e-9*V01*V04*V052*V07 + 1.01868714468176768e-10*V015*V06*V07 - 
      3.90428078727924281e-9*V01*V023*V06*V07 - 1.17152393177145516e-8*V012*V02*V03*V06*V07 + 
      2.34193868762891403e-9*V033*V06*V07 - 2.14733137714440164e-9*V013*V04*V06*V07 + 
      8.51170268603944697e-9*V02*V03*V04*V06*V07 + 2.62917968353437623e-9*V01*V042*V06*V07 + 
      2.26767323426982697e-9*V022*V05*V06*V07 + 4.64599993088529148e-9*V01*V03*V05*V06*V07 + 
      1.02554412273967743e-9*V01*V02*V062*V07 - 1.69692547625464458e-10*V05*V062*V07 - 
      1.11385142759241345e-9*V012*V022*V072 - 6.36928455389441702e-10*V013*V03*V072 + 
      1.38039185954295375e-9*V02*V032*V072 + 7.97930242680080783e-10*V022*V04*V072 + 
      1.66777940865396535e-9*V01*V03*V04*V072 + 9.15168885829463326e-10*V01*V02*V05*V072 - 
      7.5808356099106596e-11*V052*V072 + 1.90681145709286893e-10*V012*V06*V072 - 
      1.21840726101504731e-10*V04*V06*V072 - 2.6258350610958125e-11*V03*V073 + 
      1.17873064363543779e-9*V012*V024*V08 + 4.1417004738106205e-9*V013*V022*V03*V08 + 
      7.69598135768425156e-10*V014*V032*V08 - 4.78582454024383036e-9*V023*V032*V08 - 
      9.78364364295661489e-9*V01*V02*V033*V08 + 1.02236238518465225e-9*V014*V02*V04*V08 - 
      1.07335922095479893e-9*V024*V04*V08 - 1.7666598363670202e-8*V01*V022*V03*V04*V08 - 
      8.25645236091534951e-9*V012*V032*V04*V08 - 5.24241953228154301e-9*V012*V02*V042*V08 + 
      3.06749469303890093e-9*V032*V042*V08 + 1.15147301410125573e-9*V02*V043*V08 + 
      7.5684614251274468e-11*V015*V05*V08 - 3.05268802684342601e-9*V01*V023*V05*V08 - 
      9.00080673055107691e-9*V012*V02*V03*V05*V08 + 1.81776654893730941e-9*V033*V05*V08 - 
      1.64167928677275453e-9*V013*V04*V05*V08 + 6.64996784730874228e-9*V02*V03*V04*V05*V08 + 
      2.04479743791149181e-9*V01*V042*V05*V08 + 8.88924442047801394e-10*V022*V052*V08 + 
      1.79996744733944907e-9*V01*V03*V052*V08 - 1.96127162358134322e-9*V012*V022*V06*V08 - 
      1.12213642527512182e-9*V013*V03*V06*V08 + 2.40249365253839521e-9*V02*V032*V06*V08 + 
      1.33104575196264348e-9*V022*V04*V06*V08 + 2.92046432769812936e-9*V01*V03*V04*V06*V08 + 
      1.59613241280570689e-9*V01*V02*V05*V06*V08 - 1.32373220655687102e-10*V052*V06*V08 + 
      1.67849912174092015e-10*V012*V062*V08 - 1.05064239499054197e-10*V04*V062*V08 - 
      4.38134433995168848e-10*V013*V02*V07*V08 + 9.1562977374539827e-10*V022*V03*V07*V08 + 
      9.16073224999735284e-10*V01*V032*V07*V08 + 1.13678748467010487e-9*V01*V02*V04*V07*V08 + 
      2.94635690820664217e-10*V012*V05*V07*V08 - 1.90277073571282235e-10*V04*V05*V07*V08 - 
      1.37676614479106501e-10*V03*V06*V07*V08 - 2.71602960967982247e-11*V02*V072*V08 - 
      1.46974476899703569e-11*V014*V082 + 4.67020500796749011e-11*V023*V082 + 
      3.16437915317272677e-10*V01*V02*V03*V082 + 9.31924276075612557e-11*V012*V04*V082 - 
      2.9411372146011677e-11*V042*V082 - 5.36415084260776916e-11*V03*V05*V082 - 
      2.33647418122495086e-11*V02*V06*V082 - 9.48457735842490118e-12*V01*V07*V082 + 
      3.91230923728553628e-10*V013*V023*V09 + 4.42135871640047214e-10*V014*V02*V03*V09 - 
      6.43958473146301573e-10*V024*V03*V09 - 4.37396336505996984e-9*V01*V022*V032*V09 - 
      1.30616120901256233e-9*V012*V033*V09 + 4.06848568776442996e-11*V015*V04*V09 - 
      1.63998021246363375e-9*V01*V023*V04*V09 - 5.02644834460716071e-9*V012*V02*V03*V04*V09 + 
      1.0317800007922306e-9*V033*V04*V09 - 4.61641505642926528e-10*V013*V042*V09 + 
      1.85715228858623926e-9*V02*V03*V042*V09 + 3.83987891618186205e-10*V01*V043*V09 - 
      1.34869854465960826e-9*V012*V022*V05*V09 - 7.67563284728317524e-10*V013*V03*V05*V09 + 
      1.69535068127518958e-9*V02*V032*V05*V09 + 9.83370620053382776e-10*V022*V04*V05*V09 + 
      2.04414704178147889e-9*V01*V03*V04*V05*V09 + 5.61122958220973023e-10*V01*V02*V052*V09 - 
      3.11475340296209412e-11*V053*V09 - 3.45447052772571488e-10*V013*V02*V06*V09 + 
      7.19545429367092386e-10*V022*V03*V06*V09 + 7.24520732552396125e-10*V01*V032*V06*V09 + 
      8.95806134417942697e-10*V01*V02*V04*V06*V09 + 2.33114762235612664e-10*V012*V05*V06*V09 - 
      1.50326399455284042e-10*V04*V05*V06*V09 - 5.44357367725202814e-11*V03*V062*V09 - 
      2.63007328148715229e-11*V014*V07*V09 + 8.808547805048216e-11*V023*V07*V09 + 
      5.71606658686828422e-10*V01*V02*V03*V07*V09 + 1.6750913293993274e-10*V012*V04*V07*V09 - 
      5.38933383863524193e-11*V042*V07*V09 - 9.70805070320080759e-11*V03*V05*V07*V09 - 
      4.28576455668270535e-11*V02*V06*V07*V09 - 8.56808169350499234e-12*V01*V072*V09 + 
      9.56567284175025444e-11*V01*V022*V08*V09 + 9.07855616440092102e-11*V012*V03*V08*V09 - 
      6.10575889780192126e-11*V03*V04*V08*V09 - 3.35235469163562455e-11*V02*V05*V08*V09 - 
      1.50159266354684833e-11*V01*V06*V08*V09 + 1.4237649197214055e-11*V012*V02*V092 - 
      7.75804452920970187e-12*V032*V092 - 9.44547422724473388e-12*V02*V04*V092 - 
      5.27275798192250623e-12*V01*V05*V092 + 1.62209010435199681e-13*V08*V092 + 
      5.66129459949871887e-11*V014*V022*V10 - 2.60147233692765675e-11*V025*V10 + 
      1.55641903671981931e-11*V015*V03*V10 - 7.58058485366556084e-10*V01*V023*V03*V10 - 
      1.08531681094815636e-9*V012*V02*V032*V10 + 1.16495112081095023e-10*V034*V10 - 
      6.78578220258866758e-10*V012*V022*V04*V10 - 3.90624018049454307e-10*V013*V03*V04*V10 + 
      8.60439499924655013e-10*V02*V032*V04*V10 + 2.35713014144629767e-10*V022*V042*V10 + 
      5.23776101821119376e-10*V01*V03*V042*V10 - 2.13815204239396951e-10*V013*V02*V05*V10 + 
      4.61452611775551575e-10*V022*V03*V05*V10 + 4.5768945085936976e-10*V01*V032*V05*V10 + 
      5.70409450823507391e-10*V01*V02*V04*V05*V10 + 7.34056698297882596e-11*V012*V052*V10 - 
      4.80236999816768472e-11*V04*V052*V10 - 1.87661492815095823e-11*V014*V06*V10 + 
      5.99864583279271968e-11*V023*V06*V10 + 4.08055882260348244e-10*V01*V02*V03*V06*V10 + 
      1.20220118169600808e-10*V012*V04*V06*V10 - 3.80214936113489014e-11*V042*V06*V10 - 
      6.9418737144367214e-11*V03*V05*V06*V10 - 1.50966009032377833e-11*V02*V062*V10 + 
      7.82649779494927435e-11*V01*V022*V07*V10 + 7.40002881260226992e-11*V012*V03*V07*V10 - 
      4.9960064984061922e-11*V03*V04*V07*V10 - 2.74551878188769003e-11*V02*V05*V07*V10 - 
      1.22743487738676006e-11*V01*V06*V07*V10 + 2.58338107903474653e-11*V012*V02*V08*V10 - 
      1.4031300967953815e-11*V032*V08*V10 - 1.68679055416063672e-11*V02*V04*V08*V10 - 
      9.54269372783091531e-12*V01*V05*V08*V10 + 1.46184206223479291e-13*V082*V10 + 
      2.33285777480705712e-12*V013*V09*V10 - 8.80977169171704396e-12*V02*V03*V09*V10 - 
      5.44534025109327628e-12*V01*V04*V09*V10 + 2.65515777874997473e-13*V07*V09*V10 - 
      5.98556989462812633e-13*V022*V102 - 1.23709872544326281e-12*V01*V03*V102 + 
      9.4728248490629138e-14*V06*V102 + 3.6006998927858061e-12*V015*V02*V11 - 
      4.22611965687255014e-11*V01*V024*V11 - 2.69223481997489627e-10*V012*V022*V03*V11 - 
      7.52158684916149196e-11*V013*V032*V11 + 1.20466492812944193e-10*V02*V033*V11 - 
      9.90726554912275802e-11*V013*V02*V04*V11 + 2.11889475625539213e-10*V022*V03*V04*V11 + 
      2.15882504608447582e-10*V01*V032*V04*V11 + 1.3239082818032087e-10*V01*V02*V042*V11 - 
      1.05676574369177507e-11*V014*V05*V11 + 3.68766460694458115e-11*V023*V05*V11 + 
      2.37258763444041042e-10*V01*V02*V03*V05*V11 + 6.93111458769612241e-11*V012*V04*V05*V11 - 
      2.25927798366105915e-11*V042*V05*V11 - 2.03066668092039309e-11*V03*V052*V11 + 
      5.10166528102996563e-11*V01*V022*V06*V11 + 4.86208624060895373e-11*V012*V03*V06*V11 - 
      3.27779746623279576e-11*V03*V04*V06*V11 - 1.79715269198994481e-11*V02*V05*V06*V11 - 
      4.03359948842296111e-12*V01*V062*V11 + 1.92723621175207832e-11*V012*V02*V07*V11 - 
      1.05337095924375969e-11*V032*V07*V11 - 1.28352990708805977e-11*V02*V04*V07*V11 - 
      7.15694508662561397e-12*V01*V05*V07*V11 + 1.93735860627909373e-12*V013*V08*V11 - 
      7.308725112011296e-12*V02*V03*V08*V11 - 4.52103645943165979e-12*V01*V04*V08*V11 + 2.20451685999036251e-13*V07*V08*V11 - 
      1.11236124366589006e-12*V022*V09*V11 - 2.26969308599313256e-12*V01*V03*V09*V11 + 
      1.74545415140438758e-13*V06*V09*V11 - 6.49342593590556008e-13*V01*V02*V10*V11 + 1.11535517267321896e-13*V05*V10*V11 - 
      4.00456907400402159e-14*V012*V112 + 2.6471027975282667e-14*V04*V112 + 
      8.15692532346299116e-14*V016*V12 - 2.00220764487376347e-11*V012*V023*V12 - 
      3.51011363026503513e-11*V013*V02*V03*V12 + 4.17954534326439906e-11*V022*V032*V12 + 
      2.71142029427501048e-11*V01*V033*V12 - 4.50989187526839868e-12*V014*V04*V12 + 
      1.47773497138961349e-11*V023*V04*V12 + 1.02231643770260481e-10*V01*V02*V03*V04*V12 + 
      1.50829757112720278e-11*V012*V042*V12 - 3.21772792392402653e-12*V043*V12 + 
      2.75369411008746056e-11*V01*V022*V05*V12 + 2.58349588575002053e-11*V012*V03*V05*V12 - 
      1.76999490677589296e-11*V03*V04*V05*V12 - 4.86997794082214239e-12*V02*V052*V12 + 
      1.16751937284455787e-11*V012*V02*V06*V12 - 6.37893891160118162e-12*V032*V06*V12 - 
      7.64809430805109003e-12*V02*V04*V06*V12 - 4.33755560748989182e-12*V01*V05*V06*V12 + 
      1.33162343252392584e-12*V013*V07*V12 - 5.06384511615505956e-12*V02*V03*V07*V12 - 
      3.12657910430170865e-12*V01*V04*V07*V12 + 7.6325566608852036e-14*V072*V12 - 
      8.39941755135893245e-13*V022*V08*V12 - 1.73792092326055824e-12*V01*V03*V08*V12 + 
      1.33082218080737001e-13*V06*V08*V12 - 5.49319219559307979e-13*V01*V02*V09*V12 + 9.43649626429614981e-14*V05*V09*V12 - 
      7.38962920359087716e-14*V012*V10*V12 + 4.86168110418902168e-14*V04*V10*V12 + 
      2.07659253560811614e-14*V03*V11*V12 + 2.51193328373489934e-15*V02*V122 - 
      3.74830139863894594e-12*V013*V022*V13 - 1.45173849506871093e-12*V014*V03*V13 + 
      5.74286457874053768e-12*V023*V03*V13 + 1.80651852232010083e-11*V01*V02*V032*V13 + 
      1.08460109051957683e-11*V01*V022*V04*V13 + 1.04432046814520366e-11*V012*V03*V04*V13 - 
      3.57219783345162278e-12*V03*V042*V13 + 5.76120195662436643e-12*V012*V02*V05*V13 - 
      3.19113738750312649e-12*V032*V05*V13 - 3.90162991167765306e-12*V02*V04*V05*V13 - 
      1.08233472484424937e-12*V01*V052*V13 + 7.49500111372576426e-13*V013*V06*V13 - 
      2.83998617873802873e-12*V02*V03*V06*V13 - 1.75880291043392719e-12*V01*V04*V06*V13 - 
      5.47705382846011738e-13*V022*V07*V13 - 1.11537468855877233e-12*V01*V03*V07*V13 + 
      8.5915233489542932e-14*V06*V07*V13 - 3.90304155294798801e-13*V01*V02*V08*V13 + 6.70794781977199116e-14*V05*V08*V13 - 
      5.79802142644036248e-14*V012*V09*V13 + 3.83471522803672365e-14*V04*V09*V13 + 
      1.77783711966391176e-14*V03*V10*V13 + 4.68364899080586693e-15*V02*V11*V13 + 1.14416186673276144e-15*V01*V12*V13 - 
      2.91318761552249684e-13*V014*V02*V14 + 2.52540059289842007e-13*V024*V14 + 
      3.64672614610554305e-12*V01*V022*V03*V14 + 1.67736648427608526e-12*V012*V032*V14 + 
      2.16095643264539821e-12*V012*V02*V04*V14 - 1.20810668715732339e-12*V032*V04*V14 - 
      7.18035830608108554e-13*V02*V042*V14 + 3.42893139470879588e-13*V013*V05*V14 - 
      1.33245749293661185e-12*V02*V03*V05*V14 - 8.20379330291747371e-13*V01*V04*V05*V14 - 
      2.82251563338370215e-13*V022*V06*V14 - 5.86499596277395136e-13*V01*V03*V06*V14 + 
      2.24758463681045585e-14*V062*V14 - 2.34106216881593815e-13*V01*V02*V07*V14 + 
      4.02608362610552551e-14*V05*V07*V14 - 3.85218541191054779e-14*V012*V08*V14 + 
      2.53398129021924342e-14*V04*V08*V14 + 1.3036682773732178e-14*V03*V09*V14 + 3.72723483358878026e-15*V02*V10*V14 + 
      9.91590347838307129e-16*V01*V11*V14 - 3.00764386188423156e-18*V142 - 7.76850030805999158e-15*V015*V15 + 
      2.20677982838721506e-13*V01*V023*V15 + 6.54111143757109806e-13*V012*V02*V03*V15 - 
      1.26586780996767497e-13*V033*V15 + 1.21334063138367375e-13*V013*V04*V15 - 
      4.68214925541707296e-13*V02*V03*V04*V15 - 1.45347384212898577e-13*V01*V042*V15 - 
      1.26430357163248255e-13*V022*V05*V15 - 2.55796628759366927e-13*V01*V03*V05*V15 - 
      1.1508045222300198e-13*V01*V02*V06*V15 + 1.98341955813692e-14*V05*V06*V15 - 2.1591020985915333e-14*V012*V07*V15 + 
      1.43192025798299961e-14*V04*V07*V15 + 8.11096627607026363e-15*V03*V08*V15 + 2.57288500931838043e-15*V02*V09*V15 + 
      7.42846303717552481e-16*V01*V10*V15 - 5.64610486975362482e-18*V13*V15 + 
      5.88020587176660504e-14*V012*V022*V16 + 3.37409048706047642e-14*V013*V03*V16 - 
      7.02484835213412716e-14*V02*V032*V16 - 4.07633155139853916e-14*V022*V04*V16 - 
      8.57325247053663237e-14*V01*V03*V04*V16 - 4.74695276879172264e-14*V01*V02*V05*V16 + 
      4.10209108608402237e-15*V052*V16 - 1.00416846632135019e-14*V012*V06*V16 + 
      6.61145782073216814e-15*V04*V06*V16 + 4.2966690724044799e-15*V03*V07*V16 + 1.50007808449502892e-15*V02*V08*V16 + 
      4.80674763472474975e-16*V01*V09*V16 - 4.64335918335409983e-18*V12*V16 + 5.86859534141488495e-15*V013*V02*V17 - 
      1.19149926357267822e-14*V022*V03*V17 - 1.18390969611332872e-14*V01*V032*V17 - 
      1.4884523993778622e-14*V01*V02*V04*V17 - 3.87688676573334214e-15*V012*V05*V17 + 
      2.59785490964646764e-15*V04*V05*V17 + 1.8845229885090693e-15*V03*V06*V17 + 7.54640493580170944e-16*V02*V07*V17 + 
      2.66124915929740168e-16*V01*V08*V17 - 3.3581350989646268e-18*V11*V17 + 1.89990496664510664e-16*V014*V18 - 
      6.05825075783836473e-16*V023*V18 - 3.94506721777710106e-15*V01*V02*V03*V18 - 
      1.16688343136594698e-15*V012*V04*V18 + 3.87179633840501464e-16*V042*V18 + 
      6.97503727813721544e-16*V03*V05*V18 + 3.11560799350905788e-16*V02*V06*V18 + 1.26116523801834072e-16*V01*V07*V18 - 
      2.11657151525344931e-18*V10*V18 - 3.03582698373980002e-16*V01*V022*V19 - 
      2.85990985719858645e-16*V012*V03*V19 + 1.99407647605149438e-16*V03*V04*V19 + 
      1.10578573791697835e-16*V02*V05*V19 + 4.99049164096528102e-17*V01*V06*V19 - 1.16650089747200765e-18*V09*V19 - 
      4.34263992376024374e-17*V012*V02*V20 + 2.41702552671699376e-17*V032*V20 + 
      2.97024699370947006e-17*V02*V04*V20 + 1.66810124276052793e-17*V01*V05*V20 - 5.5320369966989838e-19*V08*V20 - 
      1.80943330156676823e-18*V013*V21 + 7.00387512138093581e-18*V02*V03*V21 + 4.35325079805955504e-18*V01*V04*V21 - 
      2.27229096832313726e-19*V07*V21 + 4.69112337443236207e-19*V022*V22 + 9.54280603102535557e-19*V01*V03*V22 - 
      7.81576496250736201e-20*V06*V22 + 1.27749341893024146e-19*V01*V02*V23 - 2.30395749541193945e-20*V05*V23 + 
      7.67892219029106886e-21*V012*V24 - 5.29564792805464956e-21*V04*V24 - 1.04993413646769735e-21*V03*V25 - 
      1.25173653258663191e-22*V02*V26 - 1.44431138375380606e-23*V01*V27 + 9.70639370802289015e-27*V30) + 
   1.21612504155351795e-34*delta30*V30 + 9.12093781165138462e-34*delta28*eps*V30;
}
#endif


#ifdef p17 /* Uses: V00 - V32. */
double Vp(void)
{

   V012 = V01 * V01;
   V013 = V01 * V012;
   V014 = V01 * V013;
   V015 = V01 * V014;
   V016 = V01 * V015;
   V017 = V01 * V016;
   V018 = V01 * V017;
   V022 = V02 * V02;
   V023 = V02 * V022;
   V024 = V02 * V023;
   V025 = V02 * V024;
   V026 = V02 * V025;
   V027 = V02 * V026;
   V028 = V02 * V027;
   V032 = V03 * V03;
   V033 = V03 * V032;
   V034 = V03 * V033;
   V035 = V03 * V034;
   V036 = V03 * V035;
   V042 = V04 * V04;
   V043 = V04 * V042;
   V044 = V04 * V043;
   V045 = V04 * V044;
   V052 = V05 * V05;
   V053 = V05 * V052;
   V054 = V05 * V053;
   V062 = V06 * V06;
   V063 = V06 * V062;
   V064 = V06 * V063;
   V072 = V07 * V07;
   V073 = V07 * V072;
   V082 = V08 * V08;
   V083 = V08 * V082;
   V092 = V09 * V09;
   V102 = V10 * V10;
   V112 = V11 * V11;
   V122 = V12 * V12;
   V132 = V13 * V13;
   V142 = V14 * V14;
   V152 = V15 * V15;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;
   delta8 = delta2 * delta6;
   delta10 = delta2 * delta8;
   delta12 = delta2 * delta10;
   delta14 = delta2 * delta12;
   delta16 = delta2 * delta14;
   delta18 = delta2 * delta16;
   delta20 = delta2 * delta18;
   delta22 = delta2 * delta20;
   delta24 = delta2 * delta22;
   delta26 = delta2 * delta24;
   delta28 = delta2 * delta26;
   delta30 = delta2 * delta28;
   delta32 = delta2 * delta30;

   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 + 
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) + 
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 + 
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) + 
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 
      0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 + 
   0.000297619047619047619*delta4*eps*V06 + 
   eps4*(0.00416666666666666667*V012*V02 - 0.000570436507936507937*V032 - 
      0.000595238095238095238*V02*V04 - 0.000446428571428571429*V01*V05 + 4.1335978835978836e-6*V08) + 
   delta2*eps3*(-0.000992063492063492063*V032 - 0.000793650793650793651*V02*V04 - 
      0.000595238095238095238*V01*V05 + 8.2671957671957672e-6*V08) + 
   delta4*eps2*(-0.000496031746031746032*V032 - 0.000396825396825396825*V02*V04 - 
      0.000297619047619047619*V01*V05 + 8.2671957671957672e-6*V08) + 2.75573192239858907e-6*delta8*V08 + 
   5.51146384479717813e-6*delta6*eps*V08 + eps5*
    (0.0001763668430335097*V023 + 0.00143849206349206349*V01*V02*V03 + 0.000446428571428571429*V012*V04 - 
      0.0000388558201058201058*V042 - 0.0000785383597883597884*V03*V05 - 0.0000330687830687830688*V02*V06 - 
      0.0000165343915343915344*V01*V07 + 9.39454064454064454e-8*V10) + 
   delta6*eps2*(-0.0000154320987654320988*V042 - 0.0000385802469135802469*V03*V05 - 
      0.0000110229276895943563*V02*V06 - 5.51146384479717813e-6*V01*V07 + 1.25260541927208594e-7*V10) + 
   delta2*eps4*(0.0000661375661375661376*V023 + 0.00119047619047619048*V01*V02*V03 + 
      0.000297619047619047619*V012*V04 - 0.0000644841269841269841*V042 - 0.00014880952380952381*V03*V05 - 
      0.0000496031746031746032*V02*V06 - 0.0000248015873015873016*V01*V07 + 1.87890812890812891e-7*V10) + 
   delta4*eps3*(-0.0000462962962962962963*V042 - 0.000115740740740740741*V03*V05 - 
      0.0000330687830687830688*V02*V06 - 0.0000165343915343915344*V01*V07 + 1.87890812890812891e-7*V10) + 
   2.50521083854417188e-8*delta10*V10 + 6.26302709636042969e-8*delta8*eps*V10 + 
   delta8*eps2*(-7.89141414141414141e-7*V052 - 9.01875901875901876e-7*V04*V06 - 
      7.51563251563251563e-7*V03*V07 - 1.67014055902944792e-7*V02*V08 - 6.26302709636042969e-8*V01*V09 + 
      1.20442828776162109e-9*V12) + eps6*(-0.000421626984126984127*V012*V022 - 
      0.00014880952380952381*V013*V03 + 0.000144675925925925926*V02*V032 + 
      0.0000793650793650793651*V022*V04 + 0.000188492063492063492*V01*V03*V04 + 0.000111607142857142857*V01*V02*V05 - 
      3.33506192881192881e-6*V052 + 0.0000248015873015873016*V012*V06 - 5.11063011063011063e-6*V04*V06 - 
      3.56992544492544493e-6*V03*V07 - 1.25260541927208594e-6*V02*V08 - 4.69727032227032227e-7*V01*V09 + 
      1.80664243164243164e-9*V12) + delta6*eps3*
    (-3.15656565656565657e-6*V052 - 3.6075036075036075e-6*V04*V06 - 3.00625300625300625e-6*V03*V07 - 
      6.68056223611779167e-7*V02*V08 - 2.50521083854417188e-7*V01*V09 + 2.40885657552324219e-9*V12) + 
   delta2*eps5*(0.00020667989417989418*V02*V032 + 0.0000727513227513227513*V022*V04 + 
      0.000243055555555555556*V01*V03*V04 + 0.000124007936507936508*V01*V02*V05 - 6.57617845117845118e-6*V052 + 
      0.0000248015873015873016*V012*V06 - 9.16907166907166907e-6*V04*V06 - 6.95196007696007696e-6*V03*V07 - 
      2.0041686708353375e-6*V02*V08 - 7.51563251563251563e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   delta4*eps4*(0.000082671957671957672*V02*V032 + 0.0000198412698412698413*V022*V04 + 
      0.0000925925925925925926*V01*V03*V04 + 0.0000496031746031746032*V01*V02*V05 - 6.1377665544332211e-6*V052 + 
      8.2671957671957672e-6*V012*V06 - 7.56573673240339907e-6*V04*V06 - 6.0751362834696168e-6*V03*V07 - 
      1.50312650312650313e-6*V02*V08 - 5.63672438672438672e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   1.60590438368216146e-10*delta12*V12 + 4.81771315104648438e-10*delta10*eps*V12 + 
   delta10*eps2*(-1.3627245770102913e-8*V062 - 3.17969067969067969e-8*V05*V07 - 
      1.41319585764030208e-8*V04*V08 - 8.83247411025188803e-9*V03*V09 - 1.60590438368216146e-9*V02*V10 - 
      4.81771315104648438e-10*V01*V11 + 8.0295219184108073e-12*V14) + 
   delta8*eps3*(-6.81362288505145648e-8*V062 - 1.58984533984533985e-7*V05*V07 - 
      7.06597928820151042e-8*V04*V08 - 4.41623705512594401e-8*V03*V09 - 8.0295219184108073e-9*V02*V10 - 
      2.40885657552324219e-9*V01*V11 + 2.00738047960270182e-11*V14) + 
   eps7*(-0.0000132275132275132275*V024 - 0.000203373015873015873*V01*V022*V03 - 
      0.0000777116402116402116*V012*V032 - 0.000124007936507936508*V012*V02*V04 + 
      0.0000224842672759339426*V032*V04 + 0.000013452982202982203*V02*V042 - 
      0.0000165343915343915344*V013*V05 + 0.0000264299743466410133*V02*V03*V05 + 0.0000173485850569183903*V01*V04*V05 + 
      5.71188071188071188e-6*V022*V06 + 0.0000124383718133718134*V01*V03*V06 - 1.95667978406073644e-7*V062 + 
      5.44883357383357383e-6*V01*V02*V07 - 3.61569371986038653e-7*V05*V07 + 9.39454064454064454e-7*V012*V08 - 
      2.24023661523661524e-7*V04*V08 - 1.20442828776162109e-7*V03*V09 - 3.61328486328486328e-8*V02*V10 - 
      1.08398545898545899e-8*V01*V11 + 3.01107071940405274e-11*V14) + 
   delta6*eps4*(6.76406926406926407e-6*V032*V04 + 1.90396023729357063e-6*V02*V042 + 
      7.01459034792368126e-6*V02*V03*V05 + 4.05844155844155844e-6*V01*V04*V05 + 6.51354818021484688e-7*V022*V06 + 
      2.70562770562770563e-6*V01*V03*V06 - 1.88303759732331161e-7*V062 + 1.00208433541766875e-6*V01*V02*V07 - 
      4.20586358086358086e-7*V05*V07 + 1.25260541927208594e-7*V012*V08 - 1.99453324453324453e-7*V04*V08 - 
      1.22048733159844271e-7*V03*V09 - 2.40885657552324219e-8*V02*V10 - 7.22656972656972657e-9*V01*V11 + 
      4.01476095920540365e-11*V14) + delta2*eps6*
    (-1.65343915343915344e-6*V024 - 0.000133928571428571429*V01*V022*V03 - 
      0.0000562169312169312169*V012*V032 - 0.0000744047619047619048*V012*V02*V04 + 
      0.0000395197009780343114*V032*V04 + 0.0000179623617123617124*V02*V042 - 
      8.2671957671957672e-6*V013*V05 + 0.0000417743907327240661*V02*V03*V05 + 0.0000256408329324995992*V01*V04*V05 + 
      6.68891293891293891e-6*V022*V06 + 0.0000185636123136123136*V01*V03*V06 - 3.70998324867372486e-7*V062 + 
      6.95196007696007696e-6*V01*V02*V07 - 7.19525459108792442e-7*V05*V07 + 1.12734487734487734e-6*V012*V08 - 
      4.17213958880625547e-7*V04*V08 - 2.37272372689039356e-7*V03*V09 - 6.02214143880810547e-8*V02*V10 - 
      1.80664243164243164e-8*V01*V11 + 6.02214143880810547e-11*V14) + 
   delta4*eps5*(0.0000263047138047138047*V032*V04 + 9.11896745230078563e-6*V02*V042 + 
      0.0000267431257014590348*V02*V03*V05 + 0.0000157828282828282828*V01*V04*V05 + 3.20666987333654e-6*V022*V06 + 
      0.0000109352453102453102*V01*V03*V06 - 3.36345202416630988e-7*V062 + 3.82044652877986211e-6*V01*V02*V07 - 
      7.00254606504606505e-7*V05*V07 + 5.63672438672438672e-7*V012*V08 - 3.67591513424846758e-7*V04*V08 - 
      2.18001520084853418e-7*V03*V09 - 4.81771315104648438e-8*V02*V10 - 1.44531394531394531e-8*V01*V11 + 
      6.02214143880810547e-11*V14) + 7.64716373181981648e-13*delta14*V14 + 
   2.67650730613693577e-12*delta12*eps*V14 + 
   delta12*eps2*(-3.28063324095070127e-10*V072 - 4.37417765460093502e-10*V06*V08 - 
      3.82740544777581815e-10*V05*V09 - 1.3917837991912066e-10*V04*V10 - 6.95891899595603299e-11*V03*V11 - 
      1.07060292245477431e-11*V02*V12 - 2.67650730613693577e-12*V01*V13 + 3.93604015608372907e-14*V16) + 
   delta10*eps3*(-1.96837994457042076e-9*V072 - 2.62450659276056101e-9*V06*V08 - 
      2.29644326866549089e-9*V05*V09 - 8.35070279514723959e-10*V04*V10 - 4.1753513975736198e-10*V03*V11 - 
      6.42361753472864584e-11*V02*V12 - 1.60590438368216146e-11*V01*V13 + 1.18081204682511872e-13*V16) + 
   delta8*eps4*(5.93542260208926876e-8*V043 + 5.93542260208926876e-7*V03*V04*V05 + 
      1.51757964257964258e-7*V02*V052 + 2.04408686551543694e-7*V032*V06 + 1.2498524403286308e-7*V02*V04*V06 + 
      1.22645211930926217e-7*V01*V05*V06 + 1.44531394531394531e-7*V02*V03*V07 + 8.47917514584181251e-8*V01*V04*V07 - 
      6.52972193150764579e-9*V072 + 1.09201498090386979e-8*V022*V08 + 4.23958757292090625e-8*V01*V03*V08 - 
      9.08483051340194197e-9*V06*V08 + 1.20442828776162109e-8*V01*V02*V09 - 7.72841484647040203e-9*V05*V09 + 
      1.20442828776162109e-9*V012*V10 - 2.9709231098119987e-9*V04*V10 - 1.46538775010997233e-9*V03*V11 - 
      2.40885657552324219e-10*V02*V12 - 6.02214143880810547e-11*V01*V13 + 2.9520301170627968e-13*V16) + 
   eps8*(0.0000427138447971781305*V012*V023 + 0.0000454695767195767196*V013*V02*V03 - 
      0.0000265865500240500241*V022*V032 - 0.0000157201980118646785*V01*V033 + 
      4.1335978835978836e-6*V014*V04 - 0.0000100208433541766875*V023*V04 - 
      0.000068329625621292288*V01*V02*V03*V04 - 0.0000103840989257655924*V012*V042 + 
      8.50711788211788212e-7*V043 - 0.0000202922077922077922*V01*V022*V05 - 
      0.0000166283369408369408*V012*V03*V05 + 4.77122221913888581e-6*V03*V04*V05 + 
      1.40881976819476819e-6*V02*V052 - 8.83086820586820587e-6*V012*V02*V06 + 
      1.726031766954386e-6*V032*V06 + 2.18586528110337634e-6*V02*V04*V06 + 1.33467860402384212e-6*V01*V05*V06 - 
      9.39454064454064454e-7*V013*V07 + 1.49830878997545664e-6*V02*V03*V07 + 9.8088639755306422e-7*V01*V04*V07 - 
      1.13969026729443396e-8*V072 + 2.66580127691238802e-7*V022*V08 + 5.46810442643775977e-7*V01*V03*V08 - 
      1.96493872089110184e-8*V06*V08 + 1.92708526041859375e-7*V01*V02*V09 - 1.41821430883930884e-8*V05*V09 + 
      2.70996364746364746e-8*V012*V10 - 7.34701255534588868e-9*V04*V10 - 3.22184566976233643e-9*V03*V11 - 
      8.43099801433134766e-10*V02*V12 - 2.10774950358283692e-10*V01*V13 + 4.4280451755941952e-13*V16) + 
   delta6*eps5*(3.56125356125356125e-7*V043 + 3.07900047483380817e-6*V03*V04*V05 + 
      7.79024216524216524e-7*V02*V052 + 1.07882362346648061e-6*V032*V06 + 7.57069209450161831e-7*V02*V04*V06 + 
      6.47294174079888366e-7*V01*V05*V06 + 7.41927825261158594e-7*V02*V03*V07 + 4.39857210690544024e-7*V01*V04*V07 - 
      1.45735822819156152e-8*V072 + 6.83044664526146008e-8*V022*V08 + 2.31410821688599466e-7*V01*V03*V08 - 
      2.17026506709046392e-8*V06*V08 + 6.18273187717632162e-8*V01*V02*V09 - 1.76649482205037761e-8*V05*V09 + 
      7.22656972656972657e-9*V012*V10 - 7.38716016493794272e-9*V04*V10 - 3.57313725369280925e-9*V03*V11 - 
      6.42361753472864584e-10*V02*V12 - 1.60590438368216146e-10*V01*V13 + 5.9040602341255936e-13*V16) + 
   delta2*eps7*(-0.0000311898749398749399*V022*V032 - 
      0.0000202922077922077922*V01*V033 - 6.91438191438191438e-6*V023*V04 - 
      0.0000756072631072631073*V01*V02*V03*V04 - 0.0000108976671476671477*V012*V042 + 
      1.41486599819933153e-6*V043 - 0.0000187139249639249639*V01*V022*V05 - 
      0.0000174362674362674363*V012*V03*V05 + 8.83134997718331052e-6*V03*V04*V05 + 
      2.36067944401277735e-6*V02*V052 - 7.89141414141414141e-6*V012*V02*V06 + 
      3.2333737690880548e-6*V032*V06 + 3.3093559879274165e-6*V02*V04*V06 + 2.16549323692180835e-6*V01*V05*V06 - 
      7.51563251563251563e-7*V013*V07 + 2.48834884251550918e-6*V02*V03*V07 + 1.55419426252759586e-6*V01*V04*V07 - 
      2.27636946386946387e-8*V072 + 3.52656602656602657e-7*V022*V08 + 8.77305564805564806e-7*V01*V03*V08 - 
      3.81287583668536049e-8*V06*V08 + 2.67383079883079883e-7*V01*V02*V09 - 2.83040647623980957e-8*V05*V09 + 
      3.61328486328486328e-8*V012*V10 - 1.39713681380348047e-8*V04*V10 - 6.3834699251365918e-9*V03*V11 - 
      1.44531394531394531e-9*V02*V12 - 3.61328486328486328e-10*V01*V13 + 8.8560903511883904e-13*V16) + 
   delta4*eps6*(-0.0000102087341670675004*V022*V032 - 7.13985088985088985e-6*V01*V033 - 
      9.01875901875901876e-7*V023*V04 - 0.0000239999198332531666*V01*V02*V03*V04 - 
      3.34445646945646946e-6*V012*V042 + 9.90714532381199048e-7*V043 - 
      6.12524050024050024e-6*V01*V022*V05 - 5.59914622414622415e-6*V012*V03*V05 + 
      7.18272853689520356e-6*V03*V04*V05 + 1.84751269820714265e-6*V02*V052 - 
      2.31732002565335899e-6*V012*V02*V06 + 2.5855634114562686e-6*V032*V06 + 
      2.17219215235088251e-6*V02*V04*V06 + 1.60770529074100503e-6*V01*V05*V06 - 1.87890812890812891e-7*V013*V07 + 
      1.8291250930139819e-6*V02*V03*V07 + 1.10662871079537746e-6*V01*V04*V07 - 2.25830303955303955e-8*V072 + 
      2.09088750755417422e-7*V022*V08 + 6.12813112813112813e-7*V01*V03*V08 - 3.60296119224690653e-8*V06*V08 + 
      1.69824388574388574e-7*V01*V02*V09 - 2.79427362760696094e-8*V05*V09 + 2.16797091797091797e-8*V012*V10 - 
      1.27669398502731836e-8*V04*V10 - 6.02214143880810547e-9*V03*V11 - 1.20442828776162109e-9*V02*V12 - 
      3.01107071940405274e-10*V01*V13 + 8.8560903511883904e-13*V16) + 2.81145725434552076e-15*delta16*V16 + 
   1.12458290173820831e-14*delta14*eps*V16 + 
   delta14*eps2*(-3.57367455441252861e-12*V082 - 8.04076774742818938e-12*V07*V09 - 
      4.38587331677901239e-12*V06*V10 - 3.07011132174530867e-12*V05*V11 - 9.44649637460094976e-13*V04*V12 - 
      3.93604015608372907e-13*V03*V13 - 5.24805354144497209e-14*V02*V14 - 1.12458290173820831e-14*V01*V15 + 
      1.47971434439237935e-16*V18) + delta12*eps3*
    (-2.50157218808877003e-11*V082 - 5.62853742319973257e-11*V07*V09 - 3.07011132174530867e-11*V06*V10 - 
      2.14907792522171607e-11*V05*V11 - 6.61254746222066484e-12*V04*V12 - 2.75522810925861035e-12*V03*V13 - 
      3.67363747901148046e-13*V02*V14 - 7.87208031216745814e-14*V01*V15 + 5.17900020537332772e-16*V18) + 
   delta10*eps4*(1.31523569023569024e-8*V04*V052 + 5.84549195660306771e-9*V042*V06 + 
      1.83715461493239271e-8*V03*V05*V06 + 2.06932250583044234e-9*V02*V062 + 1.25260541927208594e-8*V03*V04*V07 + 
      6.35938135938135938e-9*V02*V05*V07 + 2.62450659276056101e-9*V01*V06*V07 + 3.28063324095070127e-9*V032*V08 + 
      2.11061718998226935e-9*V02*V04*V08 + 1.96837994457042076e-9*V01*V05*V08 - 1.03457878350242703e-10*V082 + 
      1.76649482205037761e-9*V02*V03*V09 + 1.04383784939340495e-9*V01*V04*V09 - 2.25945573702732122e-10*V07*V09 + 
      1.12413306857751302e-10*V022*V10 + 4.1753513975736198e-10*V01*V03*V10 - 1.28213696627173129e-10*V06*V10 + 
      9.63542630209296876e-11*V01*V02*V11 - 8.8009857890032182e-11*V05*V11 + 8.0295219184108073e-12*V012*V12 - 
      2.84182099269245239e-11*V04*V12 - 1.17293996651295126e-11*V03*V13 - 1.65313686555516621e-12*V02*V14 - 
      3.54243614047535616e-13*V01*V15 + 1.55370006161199832e-15*V18) + 
   delta8*eps5*(8.54903198653198653e-8*V04*V052 + 4.25885842552509219e-8*V042*V06 + 
      1.20563271604938272e-7*V03*V05*V06 + 1.51413841890032366e-8*V02*V062 + 8.1419352252685586e-8*V03*V04*V07 + 
      4.10710046126712793e-8*V02*V05*V07 + 1.72233245149911817e-8*V01*V06*V07 + 2.18708882730046751e-8*V032*V08 + 
      1.55696253579851463e-8*V02*V04*V08 + 1.31225329638028051e-8*V01*V05*V08 - 3.06889302360175895e-10*V082 + 
      1.14086123924086887e-8*V02*V03*V09 + 6.78494602105713217e-9*V01*V04*V09 - 6.39241035920541056e-10*V07*V09 + 
      8.56482337963819445e-10*V022*V10 + 2.87055408583186361e-9*V01*V03*V10 - 3.8595685187655309e-10*V06*V10 + 
      6.22287948676837566e-10*V01*V02*V11 - 2.57121823196169601e-10*V05*V11 + 6.02214143880810547e-11*V012*V12 - 
      8.91513095352964634e-11*V04*V12 - 3.63099704398724007e-11*V03*V13 - 5.5104562185172207e-12*V02*V14 - 
      1.18081204682511872e-12*V01*V15 + 3.88425015402999579e-15*V18) + 
   eps9*(1.06888995777884667e-6*V025 + 0.0000263923961840628507*V01*V023*V03 + 
      0.0000299748476831810165*V012*V02*V032 - 1.21518211175949271e-6*V034 + 
      0.0000238245550745550746*V012*V022*V04 + 0.0000102212602212602213*V013*V03*V04 - 
      0.0000101287830702513242*V02*V032*V04 - 3.09484386865339246e-6*V022*V042 - 
      6.45033978367311701e-6*V01*V03*V042 + 6.32565736732403399e-6*V013*V02*V05 - 
      5.97243869813314258e-6*V022*V03*V05 - 5.42102848650467698e-6*V01*V032*V05 - 
      7.74114737408388202e-6*V01*V02*V04*V05 - 9.78856075582266058e-7*V012*V052 + 
      2.90447881593714927e-7*V04*V052 + 4.69727032227032227e-7*V014*V06 - 
      8.74346112441350537e-7*V023*V06 - 5.52347371543800115e-6*V01*V02*V03*V06 - 
      1.67601358077548554e-6*V012*V04*V06 + 2.3201418290704005e-7*V042*V06 + 
      4.20311060192012573e-7*V03*V05*V06 + 1.000249016122032e-7*V02*V062 - 
      1.21213662880329547e-6*V01*V022*V07 - 1.0095517908017908e-6*V012*V03*V07 + 
      3.08183088131004798e-7*V03*V04*V07 + 1.83444465128492906e-7*V02*V05*V07 + 8.64564434132886514e-8*V01*V06*V07 - 
      4.09505617838951172e-7*V012*V02*V08 + 8.67546827988296242e-8*V032*V08 + 
      1.14248626153388058e-7*V02*V04*V08 + 6.72587168122882409e-8*V01*V05*V08 - 5.58025064485634825e-10*V082 - 
      3.61328486328486328e-8*V013*V09 + 6.05727059720115276e-8*V02*V03*V09 + 3.94450264241930909e-8*V01*V04*V09 - 
      1.01977880393934316e-9*V07*V09 + 9.15365498698832032e-9*V022*V10 + 1.79760921948421948e-8*V01*V03*V10 - 
      7.27717595714794594e-10*V06*V10 + 5.32959517334517335e-9*V01*V02*V11 - 4.32620013655552871e-10*V05*V11 + 
      6.32324851074851075e-10*V012*V12 - 1.92177160620788072e-10*V04*V12 - 7.12915273270665428e-11*V03*V13 - 
      1.65313686555516621e-11*V02*V14 - 3.54243614047535616e-12*V01*V15 + 5.82637523104499369e-15*V18) + 
   delta6*eps6*(-3.02827683780064732e-7*V034 - 1.85757254209635162e-6*V02*V032*V04 - 
      1.58222876476844731e-7*V022*V042 - 1.08321462488129155e-6*V01*V03*V042 - 
      9.25161515439293217e-7*V022*V03*V05 - 1.03112826327112041e-6*V01*V032*V05 - 
      1.11454352525781097e-6*V01*V02*V04*V05 - 1.39369559012416155e-7*V012*V052 + 
      2.68161943509165731e-7*V04*V052 - 3.51463645114438765e-8*V023*V06 - 
      7.62712816284244856e-7*V01*V02*V03*V06 - 2.12598798908322718e-7*V012*V04*V06 + 
      1.55031715051556321e-7*V042*V06 + 3.8440189109831967e-7*V03*V05*V06 + 5.61607704464847322e-8*V02*V062 - 
      1.32165930777041888e-7*V01*V022*V07 - 1.24296999296999297e-7*V012*V03*V07 + 
      2.6128064322508767e-7*V03*V04*V07 + 1.32968882968882969e-7*V02*V05*V07 + 5.73479926158497587e-8*V01*V06*V07 - 
      3.77387530165307943e-8*V012*V02*V08 + 7.26576144069530313e-8*V032*V08 + 
      5.89825738635262445e-8*V02*V04*V08 + 4.44778160551970076e-8*V01*V05*V08 - 6.7521831725198257e-10*V082 - 
      2.40885657552324219e-9*V013*V09 + 3.86086178910252984e-8*V02*V03*V09 + 2.32454659537992871e-8*V01*V04*V09 - 
      1.33786004905285951e-9*V07*V09 + 3.45269442491664714e-9*V022*V10 + 1.03580832747499414e-8*V01*V03*V10 - 
      8.61655419311815204e-10*V06*V10 + 2.28841374674708008e-9*V01*V02*V11 - 5.54981662007805799e-10*V05*V11 + 
      2.40885657552324219e-10*V012*V12 - 2.07822920241220895e-10*V04*V12 - 8.32472493011708698e-11*V03*V13 - 
      1.37761405462930517e-11*V02*V14 - 2.9520301170627968e-12*V01*V15 + 7.76850030805999158e-15*V18) + 
   delta2*eps8*(4.1753513975736198e-8*V025 + 0.0000140291806958473625*V01*V023*V03 + 
      0.0000188517115600448934*V012*V02*V032 - 2.104308279903518e-6*V034 + 
      0.0000125886844636844637*V012*V022*V04 + 5.82461519961519962e-6*V013*V03*V04 - 
      0.0000153405163325798246*V02*V032*V04 - 3.46221514376276281e-6*V022*V042 - 
      9.37767864851198185e-6*V01*V03*V042 + 2.94362273528940196e-6*V013*V02*V05 - 
      7.97973888251666029e-6*V022*V03*V05 - 8.09444633849395754e-6*V01*V032*V05 - 
      9.9663114296050804e-6*V01*V02*V04*V05 - 1.24727152256914162e-6*V012*V052 + 
      5.53495019640852974e-7*V04*V052 + 1.87890812890812891e-7*V014*V06 - 
      8.40346822489679633e-7*V023*V06 - 7.21314895422038279e-6*V01*V02*V03*V06 - 
      2.10547829595448643e-6*V012*V04*V06 + 4.143130073189597e-7*V042*V06 + 
      8.11973933253695158e-7*V03*V05*V06 + 1.64565051717829496e-7*V02*V062 - 
      1.3248711165377832e-6*V01*V022*V07 - 1.25380984755984756e-6*V012*V03*V07 + 
      5.84147719564386231e-7*V03*V04*V07 + 3.1668434446212224e-7*V02*V05*V07 + 1.46458479791813125e-7*V01*V06*V07 - 
      4.40820753320753321e-7*V012*V02*V08 + 1.6699971747094763e-7*V032*V08 + 
      1.84426647720298514e-7*V02*V04*V08 + 1.14231420034991464e-7*V01*V05*V08 - 1.09940630202554417e-9*V082 - 
      3.61328486328486328e-8*V013*V09 + 1.03781570795459684e-7*V02*V03*V09 + 6.52800131966798633e-8*V01*V04*V09 - 
      2.03867199884356747e-9*V07*V09 + 1.30479731174175619e-8*V022*V10 + 3.01107071940405274e-8*V01*V03*V10 - 
      1.42836085807024182e-9*V06*V10 + 7.82878387045053712e-9*V01*V02*V11 - 8.64354418275986903e-10*V05*V11 + 
      9.03321215821215821e-10*V012*V12 - 3.70184576679674719e-10*V04*V12 - 1.41697445619014246e-10*V03*V13 - 
      2.89298951472154087e-11*V02*V14 - 6.19926324583187328e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   delta4*eps7*(-1.3248711165377832e-6*V034 - 8.6670659587326254e-6*V02*V032*V04 - 
      1.31581381581381581e-6*V022*V042 - 5.14897910731244065e-6*V01*V03*V042 - 
      4.27957459207459207e-6*V022*V03*V05 - 4.63174942341609008e-6*V01*V032*V05 - 
      5.20023957523957524e-6*V01*V02*V04*V05 - 6.59063159063159063e-7*V012*V052 + 
      5.00520248784137673e-7*V04*V052 - 3.03928875357446786e-7*V023*V06 - 
      3.68334817739579644e-6*V01*V02*V03*V06 - 1.04922909982433792e-6*V012*V04*V06 + 
      3.34278174059920092e-7*V042*V06 + 7.29246916002868384e-7*V03*V05*V06 + 1.25604664295140486e-7*V02*V062 - 
      6.11367798867798868e-7*V01*V022*V07 - 6.07995399662066329e-7*V012*V03*V07 + 
      5.08188442216219994e-7*V03*V04*V07 + 2.63408466533466533e-7*V02*V05*V07 + 1.17724262069500165e-7*V01*V06*V07 - 
      1.95117382617382617e-7*V012*V02*V08 + 1.4478948630734345e-7*V032*V08 + 
      1.36065984280269995e-7*V02*V04*V08 + 9.21731762505572029e-8*V01*V05*V08 - 1.06818506921603716e-9*V082 - 
      1.44531394531394531e-8*V013*V09 + 8.19011235677902345e-8*V02*V03*V09 + 5.02246595996595997e-8*V01*V04*V09 - 
      2.03276793860944188e-9*V07*V09 + 8.67188367188367188e-9*V022*V10 + 2.30045802962469629e-8*V01*V03*V10 - 
      1.37834503351543501e-9*V06*V10 + 5.41992729492729493e-9*V01*V02*V11 - 8.5845035804186131e-10*V05*V11 + 
      6.02214143880810547e-10*V012*V12 - 3.45977929719759785e-10*V04*V12 - 1.35793385384888653e-10*V03*V13 - 
      2.47970529833274931e-11*V02*V14 - 5.31365421071303424e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   8.22063524662432972e-18*delta18*V18 + 3.69928586098094837e-17*delta16*eps*V18 + 
   delta16*eps2*(-4.99609107113593639e-14*V092 - 7.26704155801590747e-14*V08*V10 - 
      6.54033740221431672e-14*V07*V11 - 3.01861726256045387e-14*V06*V12 - 1.76086006982693143e-14*V05*V13 - 
      4.69562685287181713e-15*V04*V14 - 1.67700959031136326e-15*V03*V15 - 1.97295245918983913e-16*V02*V16 - 
      3.69928586098094837e-17*V01*V17 + 4.40391173926303378e-19*V20) + 
   delta14*eps3*(-3.99687285690874911e-13*V092 - 5.81363324641272598e-13*V08*V10 - 
      5.23226992177145338e-13*V07*V11 - 2.4148938100483631e-13*V06*V12 - 1.40868805586154514e-13*V05*V13 - 
      3.75650148229745371e-14*V04*V14 - 1.34160767224909061e-14*V03*V15 - 1.57836196735187131e-15*V02*V16 - 
      2.9594286887847587e-16*V01*V17 + 1.76156469570521351e-18*V20) + 
   delta12*eps4*(4.14465028435616671e-10*V052*V06 + 1.9311337588648513e-10*V04*V062 + 
      5.61121884651296416e-10*V04*V05*V07 + 3.94728598510111115e-10*V03*V06*V07 + 6.75424490783967908e-11*V02*V072 + 
      9.9293173004138872e-11*V042*V08 + 3.00188662570652404e-10*V03*V05*V08 + 7.05638284744001105e-11*V02*V06*V08 + 
      4.28840946529503434e-11*V01*V07*V08 + 1.55867190180915671e-10*V03*V04*V09 + 7.8799523924796256e-11*V02*V05*V09 + 
      3.28940498758425929e-11*V01*V06*V09 - 1.87500359022631024e-12*V092 + 3.28940498758425929e-11*V032*V10 + 
      2.19068749258602978e-11*V02*V04*V10 + 1.97364299255055558e-11*V01*V05*V10 - 2.808497825656736e-12*V08*V10 + 
      1.43271861681447738e-11*V02*V03*V11 + 8.50184673714085479e-12*V01*V04*V11 - 2.47282462663132475e-12*V07*V11 + 
      7.87208031216745814e-13*V022*V12 + 2.83394891238028493e-12*V01*V03*V12 - 1.183475532645025e-12*V06*V12 + 
      5.5104562185172207e-13*V01*V02*V13 - 6.80520626986055263e-13*V05*V13 + 3.93604015608372907e-14*V012*V14 - 
      1.89344247508448862e-13*V04*V14 - 6.71543693296741495e-14*V03*V15 - 8.28640032859732435e-15*V02*V16 - 
      1.55370006161199832e-15*V01*V17 + 6.16547643496824729e-18*V20) + 
   delta10*eps5*(3.26045822369351781e-9*V052*V06 + 1.65543101467471215e-9*V04*V062 + 
      4.38766140359277614e-9*V04*V05*V07 + 3.10519830827954077e-9*V03*V06*V07 + 5.25866210681803586e-10*V02*V072 + 
      8.54383116547241456e-10*V042*V08 + 2.38274750915455345e-9*V03*V05*V08 + 6.08564288665958964e-10*V02*V06*V08 + 
      3.40392501307793351e-10*V01*V07*V08 + 1.21879483433132671e-9*V03*V04*V09 + 6.1351057912877085e-10*V02*V05*V09 + 
      2.58766525689961731e-10*V01*V06*V09 - 6.38324106265132578e-12*V092 + 2.64979846222065332e-10*V032*V10 + 
      1.91044143347286827e-10*V02*V04*V10 + 1.58987907733239199e-10*V01*V05*V10 - 1.00156931590772184e-11*V08*V10 + 
      1.11547378023412882e-10*V02*V03*V11 + 6.6479718236254184e-11*V01*V04*V11 - 8.52071309503185762e-12*V07*V11 + 
      7.08487228095071232e-12*V022*V12 + 2.34981597318198625e-11*V01*V03*V12 - 4.3121835424282719e-12*V06*V12 + 
      4.29028377013126468e-12*V01*V02*V13 - 2.42687949623794137e-12*V05*V13 + 3.54243614047535616e-13*V012*V14 - 
      7.18016588472958155e-13*V04*V14 - 2.5221731000168106e-13*V03*V15 - 3.31456013143892974e-14*V02*V16 - 
      6.21480024644799327e-15*V01*V17 + 1.84964293049047419e-17*V20) + 
   delta8*eps6*(-8.45508658008658009e-8*V032*V042 - 1.14340392118169896e-8*V02*V043 - 
      5.74110817166372722e-8*V033*V05 - 1.70707635985413763e-7*V02*V03*V04*V05 - 
      5.07305194805194805e-8*V01*V042*V05 - 2.09931850556850557e-8*V022*V052 - 
      4.97910654160654161e-8*V01*V03*V052 - 5.99346457481378116e-8*V02*V032*V06 - 
      1.17185137026406868e-8*V022*V04*V06 - 6.97283683394794506e-8*V01*V03*V04*V06 - 
      3.5960787448882687e-8*V01*V02*V05*V06 + 1.29533113516637482e-8*V052*V06 - 
      3.43835599291948498e-9*V012*V062 + 7.392378229602008e-9*V04*V062 - 
      1.99935095768429102e-8*V022*V03*V07 - 2.28153129938844225e-8*V01*V032*V07 - 
      2.43868051407733947e-8*V01*V02*V04*V07 - 6.24582097796383511e-9*V012*V05*V07 + 
      1.75019961580419097e-8*V04*V05*V07 + 1.2518744403859561e-8*V03*V06*V07 + 2.14039052230578841e-9*V02*V072 - 
      6.57656080936504217e-10*V023*V08 - 1.26407616486981566e-8*V01*V02*V03*V08 - 
      3.52151889850302549e-9*V012*V04*V08 + 3.86929241225589394e-9*V042*V08 + 
      9.72664871847229976e-9*V03*V05*V08 + 2.79046504017974087e-9*V02*V06*V08 + 1.42857640312640831e-9*V01*V07*V08 - 
      1.66612579807024251e-9*V01*V022*V09 - 1.58583057888613444e-9*V012*V03*V09 + 
      5.00664307853850338e-9*V03*V04*V09 + 2.53392425148280268e-9*V02*V05*V09 + 1.08879305089038983e-9*V01*V06*V09 - 
      1.6748072821287926e-11*V092 - 3.81402291124513347e-10*V012*V02*V10 + 
      1.12917963434906323e-9*V032*V10 + 9.01690570613695419e-10*V02*V04*V10 + 6.8620642935438298e-10*V01*V05*V10 - 
      2.760150625644289e-11*V08*V10 - 2.00738047960270182e-11*V013*V11 + 4.80787305065627506e-10*V02*V03*V11 + 
      2.88905347456545714e-10*V01*V04*V11 - 2.26228347113945505e-11*V07*V11 + 3.54243614047535616e-11*V022*V12 + 
      1.07453896261085804e-10*V01*V03*V12 - 1.21478628817236775e-11*V06*V12 + 1.97786017843207386e-11*V01*V02*V13 - 
      6.6713291145516521e-12*V05*V13 + 1.77121807023767808e-12*V012*V14 - 2.11096048371016838e-12*V04*V14 - 
      7.32828529060325873e-13*V03*V15 - 1.03580004107466554e-13*V02*V16 - 1.9421250770149979e-14*V01*V17 + 
      4.62410732622618547e-17*V20) + eps10*(-4.32775172358505692e-6*V012*V024 - 
      9.24422799422799423e-6*V013*V022*V03 - 1.23068482443482443e-6*V014*V032 + 
      4.22450354245989167e-6*V023*V032 + 7.39166243258505163e-6*V01*V02*V033 - 
      1.69101731601731602e-6*V014*V02*V04 + 1.21747740795359843e-6*V024*V04 + 
      0.0000161214859875574161*V01*V022*V03*V04 + 6.33712696584720394e-6*V012*V032*V04 + 
      4.84675707889993604e-6*V012*V02*V042 - 1.07324812418438411e-6*V032*V042 - 
      4.62417873132158846e-7*V02*V043 - 9.39454064454064454e-8*V015*V05 + 
      3.19858299769014055e-6*V01*V023*V05 + 7.76295326146516623e-6*V012*V02*V03*V05 - 
      6.14896486982300474e-7*V033*V05 + 1.39724005051386004e-6*V013*V04*V05 - 
      2.56161679617780808e-6*V02*V03*V04*V05 - 8.20972733175114127e-7*V01*V042*V05 - 
      3.79289523169731503e-7*V022*V052 - 6.95468437903953777e-7*V01*V03*V052 + 
      2.05559775872275872e-6*V012*V022*V06 + 9.52221004304337638e-7*V013*V03*V06 - 
      9.2266376058538757e-7*V02*V032*V06 - 5.93101783577974054e-7*V022*V04*V06 - 
      1.16940150577303355e-6*V01*V03*V04*V06 - 7.07132752333645191e-7*V01*V02*V05*V06 + 
      2.89604486589270086e-8*V052*V06 - 7.63370950312914599e-8*V012*V062 + 
      2.35668492554580323e-8*V04*V062 + 4.33594183594183594e-7*V013*V02*V07 - 
      4.0140583760375427e-7*V022*V03*V07 - 3.62902846161774733e-7*V01*V032*V07 - 
      5.19422603685996543e-7*V01*V02*V04*V07 - 1.32534428479368956e-7*V012*V05*V07 + 
      4.25063111758883818e-8*V04*V05*V07 + 3.06977183828184645e-8*V03*V06*V07 + 6.76143520976766775e-9*V02*V072 + 
      2.70996364746364746e-8*V014*V08 - 4.80241882358284475e-8*V023*V08 - 
      2.87815345479035955e-7*V01*V02*V03*V08 - 8.72350202707345564e-8*V012*V04*V08 + 
      1.34766641195601669e-8*V042*V08 + 2.39151691290706619e-8*V03*V05*V08 + 1.16898143469883277e-8*V02*V06*V08 + 
      4.92813313471090471e-9*V01*V07*V08 - 5.07365416219582886e-8*V01*V022*V09 - 
      4.2305543607626941e-8*V012*V03*V09 + 1.39815526419386714e-8*V03*V04*V09 + 8.39144081076270619e-9*V02*V05*V09 + 
      3.92546204816425405e-9*V01*V06*V09 - 2.56298084717075669e-11*V092 - 1.40014788452288452e-8*V012*V02*V10 + 
      3.21391736030508206e-9*V032*V10 + 4.35416007894999492e-9*V02*V04*V10 + 2.49794462727031588e-9*V01*V05*V10 - 
      4.62118489039601052e-11*V08*V10 - 1.05387475179141846e-9*V013*V11 + 1.88841366588507111e-9*V02*V03*V11 + 
      1.22273087448741044e-9*V01*V04*V11 - 3.49496505466431814e-11*V07*V11 + 2.47970529833274931e-10*V022*V12 + 
      4.71144006683222369e-10*V01*V03*V12 - 2.1239079842236017e-11*V06*V12 + 1.20885633293721529e-10*V01*V02*V13 - 
      1.07535465514320433e-11*V05*V13 + 1.23985264916637466e-11*V012*V14 - 4.17634576561305147e-12*V04*V14 - 
      1.34395055329437854e-12*V03*V15 - 2.79666011090159697e-13*V02*V16 - 5.24373770794049432e-14*V01*V17 + 
      6.9361609893392782e-17*V20) + delta6*eps7*
    (-5.30269627491849714e-7*V032*V042 - 1.06760523427190094e-7*V02*V043 - 
      3.44466490299823633e-7*V033*V05 - 1.06134220717554051e-6*V02*V03*V04*V05 - 
      3.18161776495109828e-7*V01*V042*V05 - 1.30511849261849262e-7*V022*V052 - 
      3.03130511463844797e-7*V01*V03*V052 - 3.78534604725080916e-7*V02*V032*V06 - 
      1.11853534472582092e-7*V022*V04*V06 - 4.46345064400619956e-7*V01*V03*V04*V06 - 
      2.27120762835048549e-7*V01*V02*V05*V06 + 3.26639377224889207e-8*V052*V06 - 
      2.2585898081929828e-8*V012*V062 + 2.10193091164924343e-8*V04*V062 - 
      1.24296999296999297e-7*V022*V03*V07 - 1.41067229360880155e-7*V01*V032*V07 - 
      1.51620315310791501e-7*V01*V02*V04*V07 - 4.0124668100858577e-8*V012*V05*V07 + 4.4787492448848658e-8*V04*V05*V07 + 
      3.24298782831501475e-8*V03*V06*V07 + 5.68358575623981786e-9*V02*V072 - 6.5918551368286818e-9*V023*V08 - 
      8.25205438300676396e-8*V01*V02*V03*V08 - 2.34003210193686384e-8*V012*V04*V08 + 
      1.12529063924436888e-8*V042*V08 + 2.54356286410311724e-8*V03*V05*V08 + 8.30444495178907462e-9*V02*V06*V08 + 
      3.92657491666076582e-9*V01*V07*V08 - 1.03580832747499414e-8*V01*V022*V09 - 
      1.05989689323022656e-8*V012*V03*V09 + 1.3470310226165346e-8*V03*V04*V09 + 6.88846387716213424e-9*V02*V05*V09 + 
      3.03283139855268707e-9*V01*V06*V09 - 3.40039836055713167e-11*V092 - 2.64974223307556641e-9*V012*V02*V10 + 
      3.11981788600213748e-9*V032*V10 + 2.79278917817666651e-9*V02*V04*V10 + 1.94147992156084282e-9*V01*V05*V10 - 
      5.8329550274963918e-11*V08*V10 - 1.60590438368216146e-10*V013*V11 + 1.39296461123803172e-9*V02*V03*V11 + 
      8.47035841589218496e-10*V01*V04*V11 - 4.62613453487800303e-11*V07*V11 + 1.18081204682511872e-10*V022*V12 + 
      3.24723312876907648e-10*V01*V03*V12 - 2.6147736236888857e-11*V06*V12 + 6.25830384817312922e-11*V01*V02*V13 - 
      1.39998733551651795e-11*V05*V13 + 5.9040602341255936e-12*V012*V14 - 4.73567778779337087e-12*V04*V14 - 
      1.62102706428185158e-12*V03*V15 - 2.48592009857919731e-13*V02*V16 - 4.66110018483599495e-14*V01*V17 + 
      9.24821465245237093e-17*V20) + delta2*eps9*
    (4.15642466733736575e-6*V023*V032 + 8.35529109338633148e-6*V01*V02*V033 + 
      6.79829796893288957e-7*V024*V04 + 0.0000154207702570797809*V01*V022*V03*V04 + 
      6.74263732299446585e-6*V012*V032*V04 + 4.56072256667494763e-6*V012*V02*V042 - 
      1.91435273280511376e-6*V032*V042 - 6.72419695237155555e-7*V02*V043 + 
      2.49385480040241945e-6*V01*V023*V05 + 7.25582012784393737e-6*V012*V02*V03*V05 - 
      1.13434203215949248e-6*V033*V05 + 1.24703063691158929e-6*V013*V04*V05 - 
      4.15228372817658532e-6*V02*V03*V04*V05 - 1.29452411198442944e-6*V01*V042*V05 - 
      5.49420037267259489e-7*V022*V052 - 1.13306877939814448e-6*V01*V03*V052 + 
      1.63031413031413031e-6*V012*V022*V06 + 8.24792491459158126e-7*V013*V03*V06 - 
      1.51755096571564826e-6*V02*V032*V06 - 7.77042071684928828e-7*V022*V04*V06 - 
      1.86239140232195788e-6*V01*V03*V04*V06 - 1.01627938309485929e-6*V01*V02*V05*V06 + 
      5.68838491377298567e-8*V052*V06 - 1.07641476689095737e-7*V012*V062 + 
      4.41557917412842716e-8*V04*V062 + 3.20377924544591211e-7*V013*V02*V07 - 
      5.77443068762513207e-7*V022*V03*V07 - 5.83046527987004177e-7*V01*V032*V07 - 
      7.28552935894205735e-7*V01*V02*V04*V07 - 1.86531529537481918e-7*V012*V05*V07 + 
      8.20730498018079717e-8*V04*V05*V07 + 6.00686679154524626e-8*V03*V06*V07 + 1.19181468478999992e-8*V02*V072 + 
      1.80664243164243164e-8*V014*V08 - 5.42489795135297781e-8*V023*V08 - 
      4.0979812185169328e-7*V01*V02*V03*V08 - 1.20546065486541677e-7*V012*V04*V08 + 
      2.49040458005988663e-8*V042*V08 + 4.6958392905278604e-8*V03*V05*V08 + 2.00429912245193913e-8*V02*V06*V08 + 
      8.62016691568998603e-9*V01*V07*V08 - 6.16667283333950001e-8*V01*V022*V09 - 
      5.79330006413339747e-8*V012*V03*V09 + 2.68752821857397021e-8*V03*V04*V09 + 1.4780224390110011e-8*V02*V05*V09 + 
      6.83399189285918978e-9*V01*V06*V09 - 5.12537905681840888e-11*V092 - 1.68619960286626953e-8*V012*V02*V10 + 
      6.27264228017029137e-9*V032*V10 + 7.31125081907061366e-9*V02*V04*V10 + 4.36078106078397862e-9*V01*V05*V10 - 
      9.16586854918693502e-11*V08*V10 - 1.20442828776162109e-9*V013*V11 + 3.30686413713374498e-9*V02*V03*V11 + 
      2.08501887168145338e-9*V01*V04*V11 - 6.98876483428242728e-11*V07*V11 + 3.71955794749912397e-10*V022*V12 + 
      8.121034852039754e-10*V01*V03*V12 - 4.19521212350405431e-11*V06*V12 + 1.85092288339837359e-10*V01*V02*V13 - 
      2.14954403524019967e-11*V05*V13 + 1.85977897374956198e-11*V012*V14 - 8.11342172173785521e-12*V04*V14 - 
      2.6762483561266671e-12*V03*V15 - 4.97184019715839461e-13*V02*V16 - 9.3222003696719899e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + delta4*eps8*
    (1.12355953129762654e-6*V023*V032 + 2.5791971476495286e-6*V01*V02*V033 + 
      3.77616945077262538e-8*V024*V04 + 4.13625909657655689e-6*V01*V022*V03*V04 + 
      1.98785727059536583e-6*V012*V032*V04 + 1.22404326273373892e-6*V012*V02*V042 - 
      1.42409880133094419e-6*V032*V042 - 3.91505723846993688e-7*V02*V043 + 
      6.74135718778575921e-7*V01*V023*V05 + 2.06180916746392937e-6*V012*V02*V03*V05 - 
      8.81354738001563398e-7*V033*V05 + 3.3207808505427553e-7*V013*V04*V05 - 
      2.91372423688891943e-6*V02*V03*V04*V05 - 8.88464306123036282e-7*V01*V042*V05 - 
      3.66935769134843209e-7*V022*V052 - 8.12937475883904455e-7*V01*V03*V052 + 
      4.23557281196170085e-7*V012*V022*V06 + 2.13183806933806934e-7*V013*V03*V06 - 
      1.05803289707059548e-6*V02*V032*V06 - 4.22574620656631239e-7*V022*V04*V06 - 
      1.26838342984176318e-6*V01*V03*V04*V06 - 6.5878786116881355e-7*V01*V02*V05*V06 + 
      5.45632582627067921e-8*V052*V06 - 6.76716636538065109e-8*V012*V062 + 
      3.90218908615850726e-8*V04*V062 + 7.34701255534588868e-8*V013*V02*V07 - 
      3.63268954125435607e-7*V022*V03*V07 - 3.97088535729408745e-7*V01*V032*V07 - 
      4.49314840435872182e-7*V01*V02*V04*V07 - 1.17990956904647381e-7*V012*V05*V07 + 
      7.65859343014163276e-8*V04*V05*V07 + 5.59869380444485487e-8*V03*V06*V07 + 1.02824269600355035e-8*V02*V072 + 
      3.61328486328486328e-9*V014*V08 - 2.64209506934374659e-8*V023*V08 - 
      2.52155665102093674e-7*V01*V02*V03*V08 - 7.26442318704223466e-8*V012*V04*V08 + 
      2.14728983840795232e-8*V042*V08 + 4.39814532769423059e-8*V03*V05*V08 + 1.64109258267755e-8*V02*V06*V08 + 
      7.31276900598796024e-9*V01*V07*V08 - 3.37239920573253907e-8*V01*V022*V09 - 
      3.40250991292657959e-8*V012*V03*V09 + 2.42509274116708757e-8*V03*V04*V09 + 1.27037664057680398e-8*V02*V05*V09 + 
      5.74203595255766124e-9*V01*V06*V09 - 5.12110638164897588e-11*V092 - 9.03321215821215821e-9*V012*V02*V10 + 
      5.67822993017028965e-9*V032*V10 + 5.76472441260022959e-9*V02*V04*V10 + 3.68295277404754529e-9*V01*V05*V10 - 
      9.01908088622321099e-11*V08*V10 - 6.02214143880810547e-10*V013*V11 + 2.72767582816602424e-9*V02*V03*V11 + 
      1.68501879081944441e-9*V01*V04*V11 - 6.98021948394356129e-11*V07*V11 + 2.65682710535651712e-10*V022*V12 + 
      6.5535068598794089e-10*V01*V03*V12 - 4.09621923386420413e-11*V06*V12 + 1.35793385384888653e-10*V01*V02*V13 - 
      2.14099868490133368e-11*V05*V13 + 1.32841355267825856e-11*V012*V14 - 7.69703010522583966e-12*V04*V14 - 
      2.59079485273800719e-12*V03*V15 - 4.35036017251359529e-13*V02*V16 - 8.15692532346299116e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + 1.95729410633912612e-20*delta20*V20 + 
   9.78647053169563062e-20*delta18*eps*V20 + 
   delta18*eps2*(-3.73576270568999572e-16*V102 - 8.21867795251799059e-16*V09*V11 - 
      5.0576479707803019e-16*V08*V12 - 3.79323597808522643e-16*V07*V13 - 1.51729439123409057e-16*V06*V14 - 
      7.58647195617045285e-17*V05*V15 - 1.78505222498128302e-17*V04*V16 - 5.57828820306650945e-18*V03*V17 - 
      5.87188231901737837e-19*V02*V18 - 9.78647053169563062e-20*V01*V19 + 1.06374679692343811e-21*V22) + 
   delta16*eps3*(-3.36218643512099615e-15*V102 - 7.39681015726619153e-15*V09*V11 - 
      4.55188317370227171e-15*V08*V12 - 3.41391238027670378e-15*V07*V13 - 1.36556495211068151e-15*V06*V14 - 
      6.82782476055340757e-16*V05*V15 - 1.60654700248315472e-16*V04*V16 - 5.02045938275985851e-17*V03*V17 - 
      5.28469408711564053e-18*V02*V18 - 8.80782347852606755e-19*V01*V19 + 4.7868605861554715e-21*V22) + 
   delta14*eps4*(2.13459363566774952e-12*V063 + 1.7930586539609096e-11*V05*V06*V07 + 
      6.04327175964602865e-12*V04*V072 + 6.86735427232503256e-12*V052*V08 + 
      6.60875939349902034e-12*V04*V06*V08 + 6.54033740221431672e-12*V03*V07*V08 + 6.07011706610740506e-13*V02*V082 + 
      7.05048371958703343e-12*V04*V05*V09 + 4.98071848322474889e-12*V03*V06*V09 + 1.69279320998488198e-12*V02*V07*V09 + 
      5.4502811685119306e-13*V01*V08*V09 + 1.03773353448467159e-12*V042*V10 + 3.05215745436668114e-12*V03*V05*V10 + 
      7.38870695966594755e-13*V02*V06*V10 + 4.36022493480954448e-13*V01*V07*V10 - 1.85215182566314525e-14*V102 + 
      1.28190613083400608e-12*V03*V04*V11 + 6.463392256305913e-13*V02*V05*V11 + 2.71675553630440848e-13*V01*V06*V11 - 
      3.9838959969837207e-14*V09*V11 + 2.2639629469203404e-13*V032*V12 + 1.54600554702115794e-13*V02*V04*V12 + 
      1.35837776815220424e-13*V01*V05*V12 - 2.52150370543244262e-14*V08*V12 + 8.28640032859732435e-14*V02*V03*V13 + 
      4.93040819551540799e-14*V01*V04*V13 - 1.8596838492559939e-14*V07*V13 + 4.00509349215537344e-15*V022*V14 + 
      1.40868805586154514e-14*V01*V03*V14 - 7.6902868355706801e-15*V06*V14 + 2.36754295102780696e-15*V01*V02*V15 - 
      3.80321817802755597e-15*V05*V15 + 1.47971434439237935e-16*V012*V16 - 9.29401533454070648e-16*V04*V16 - 
      2.88896610095655016e-16*V03*V17 - 3.17081645226938432e-17*V02*V18 - 5.28469408711564053e-18*V01*V19 + 
      1.9147442344621886e-20*V22) + delta12*eps5*
    (2.10613238719217953e-11*V063 + 1.64612745870577951e-10*V05*V06*V07 + 5.52527703739065477e-11*V04*V072 + 
      6.34085711144678006e-11*V052*V08 + 6.53389768538752109e-11*V04*V06*V08 + 6.03891153471121911e-11*V03*V07*V08 + 
      6.02167012238729901e-12*V02*V082 + 6.44615654362243056e-11*V04*V05*V09 + 4.57257627418272085e-11*V03*V06*V09 + 
      1.54291047785080388e-11*V02*V07*V09 + 5.03242627892601592e-12*V01*V08*V09 + 1.03162921957593822e-11*V042*V10 + 
      2.84232162937897181e-11*V03*V05*V10 + 7.35516676785972028e-12*V02*V06*V10 + 4.0604594705413883e-12*V01*V07*V10 - 
      7.67994164653953858e-14*V102 + 1.17202846247680556e-11*V03*V04*V11 + 5.89111273361216028e-12*V02*V05*V11 + 
      2.49413251319057501e-12*V01*V06*V11 - 1.5942072417897397e-13*V09*V11 + 2.13818722764698816e-12*V032*V12 + 
      1.55808001607139976e-12*V02*V04*V12 + 1.2829123365881929e-12*V01*V05*V12 - 1.05441977990826965e-13*V08*V12 + 
      7.55270863283610293e-13*V02*V03*V13 + 4.50780177875694445e-13*V01*V04*V13 - 7.57798708621947274e-14*V07*V13 + 
      4.16161438725110068e-14*V022*V14 + 1.36760132089891674e-13*V01*V03*V14 - 3.29532384496182881e-14*V06*V14 + 
      2.15791675223888655e-14*V01*V02*V15 - 1.60364042073524112e-14*V05*V15 + 1.55370006161199832e-15*V012*V16 - 
      4.13580159257670028e-15*V04*V16 - 1.27625362203842719e-15*V03*V17 - 1.47971434439237935e-16*V02*V18 - 
      2.46619057398729892e-17*V01*V19 + 6.7016048206176601e-20*V22) + 
   delta10*eps6*(-2.95801289810004407e-10*V044 - 7.84358338143741194e-9*V03*V042*V05 - 
      4.09348176232707823e-9*V032*V052 - 3.92005983305002913e-9*V02*V04*V052 - 
      8.01299054975525564e-10*V01*V053 - 5.49887301462931715e-9*V032*V04*V06 - 
      1.23515189263710895e-9*V02*V042*V06 - 5.57736890117064409e-9*V02*V03*V05*V06 - 
      3.29932380877759029e-9*V01*V04*V05*V06 - 2.13153443195460002e-10*V022*V062 - 
      1.13590745155871206e-9*V01*V03*V062 + 1.11077632135397347e-10*V063 - 
      1.27190326186591359e-9*V033*V07 - 3.73339031719050393e-9*V02*V03*V04*V07 - 
      1.12051191163391599e-9*V01*V042*V07 - 9.11823062558356676e-10*V022*V05*V07 - 
      2.2213661141454481e-9*V01*V03*V05*V07 - 7.96766985881520584e-10*V01*V02*V06*V07 + 7.90818238274194341e-10*V05*V06*V07 - 
      7.07587561773680666e-11*V012*V072 + 2.66182291692605467e-10*V04*V072 - 
      1.0063142665720734e-9*V02*V032*V08 - 2.14750350915928258e-10*V022*V04*V08 - 
      1.16958121224642648e-9*V01*V03*V04*V08 - 6.03788559943244039e-10*V01*V02*V05*V08 + 
      3.07308867141893107e-10*V052*V08 - 1.15543395934255982e-10*V012*V06*V08 + 
      3.48020435329644263e-10*V04*V06*V08 + 2.95653173692384828e-10*V03*V07*V08 + 3.2678175994266238e-11*V02*V082 - 
      2.53284184043987966e-10*V022*V03*V09 - 2.92166637871586518e-10*V01*V032*V09 - 
      3.11115859765875328e-10*V01*V02*V04*V09 - 8.04807753628948774e-11*V012*V05*V09 + 
      3.13793240103475455e-10*V04*V05*V09 + 2.24240350892254344e-10*V03*V06*V09 + 7.61580611867156797e-11*V02*V07*V09 + 
      2.53822800065346792e-11*V01*V08*V09 - 7.30978886129835398e-12*V023*V10 - 
      1.29608179425328507e-10*V01*V02*V03*V10 - 3.60822424022704135e-11*V012*V04*V10 + 
      5.60804732543481649e-11*V042*V10 + 1.42000663750085985e-10*V03*V05*V10 + 4.03355333137918687e-11*V02*V06*V10 + 
      2.06774049390104097e-11*V01*V07*V10 - 2.53132042505487258e-13*V102 - 
      1.3815500947853889e-11*V01*V022*V11 - 1.32250949244413297e-11*V012*V03*V11 + 
      5.88245344526877608e-11*V03*V04*V11 + 2.96754985434489887e-11*V02*V05*V11 + 1.27296865619387611e-11*V01*V06*V11 - 
      5.05754031960445325e-13*V09*V11 - 2.63714690457609848e-12*V012*V02*V12 + 
      1.11352203701387527e-11*V032*V12 + 8.81730210584071817e-12*V02*V04*V12 + 6.74017282442450755e-12*V01*V05*V12 - 
      3.50568990092294541e-13*V08*V12 - 1.18081204682511872e-13*V013*V13 + 3.95761932360611793e-12*V02*V03*V13 + 
      2.37602171422117529e-12*V01*V04*V13 - 2.44874227567633878e-13*V07*V13 + 2.48384849849704798e-13*V022*V14 + 
      7.57584150042010379e-13*V01*V03*V14 - 1.12391703028323173e-13*V06*V14 + 1.1963490474412387e-13*V01*V02*V15 - 
      5.36951342721384656e-14*V05*V15 + 9.3222003696719899e-15*V012*V16 - 1.46935634398163269e-14*V04*V16 - 
      4.49463232109185227e-15*V03*V17 - 5.54892879147142256e-16*V02*V18 - 9.24821465245237093e-17*V01*V19 + 
      2.01048144618529803e-19*V22) + delta8*eps7*
    (-3.12288574815807931e-9*V044 - 6.13302756208529629e-8*V03*V042*V05 - 
      3.11053445414828857e-8*V032*V052 - 3.05407589414942356e-8*V02*V04*V052 - 
      6.13408242084712673e-9*V01*V053 - 4.34778369389713928e-8*V032*V04*V06 - 
      1.31957658023639972e-8*V02*V042*V06 - 4.3769553743682284e-8*V02*V03*V05*V06 - 
      2.60867021633828357e-8*V01*V04*V05*V06 - 2.31124277965236571e-9*V022*V062 - 
      9.11367606483152702e-9*V01*V03*V062 + 3.89361294085025683e-10*V063 - 
      9.73663876324940751e-9*V033*V07 - 2.90864370871373672e-8*V02*V03*V04*V07 - 
      8.76146794583613756e-9*V01*V042*V07 - 7.13092395077689195e-9*V022*V05*V07 - 
      1.71856509877829517e-8*V01*V03*V05*V07 - 6.252793391954612e-9*V01*V02*V06*V07 + 2.5282819527162001e-9*V05*V06*V07 - 
      5.70894510067401446e-10*V012*V072 + 8.58885837973415987e-10*V04*V072 - 
      8.03345795856689103e-9*V02*V032*V08 - 2.36162409365023744e-9*V022*V04*V08 - 
      9.43862429428878231e-9*V01*V03*V04*V08 - 4.82007477514013462e-9*V01*V02*V05*V08 + 
      9.90550771013638422e-10*V052*V08 - 9.52465488627175524e-10*V012*V06*V08 + 
      1.24013655702525207e-9*V04*V06*V08 + 9.70630955157051171e-10*V03*V07*V08 + 1.20233202577373189e-10*V02*V082 - 
      1.98081220854913665e-9*V022*V03*V09 - 2.30511380283789247e-9*V01*V032*V09 - 
      2.42386975726144727e-9*V01*V02*V04*V09 - 6.55688060858462352e-10*V012*V05*V09 + 
      1.03082561137740446e-9*V04*V05*V09 + 7.43326732405203706e-10*V03*V06*V09 + 2.56405271524897592e-10*V02*V07*V09 + 
      8.76982300491031469e-11*V01*V08*V09 - 8.45686342107132646e-11*V023*V10 - 1.06762277776516805e-9*V01*V02*V03*V10 - 
      3.02034852834339296e-10*V012*V04*V10 + 2.06123073726194409e-10*V042*V10 + 
      4.7748951503009169e-10*V03*V05*V10 + 1.50591515305042041e-10*V02*V06*V10 + 7.19068418752763738e-11*V01*V07*V10 - 
      6.67076525370678137e-13*V102 - 1.08044302284498363e-10*V01*V022*V11 - 
      1.12177144448386278e-10*V012*V03*V11 + 2.03127638655029436e-10*V03*V04*V11 + 
      1.03144968090215195e-10*V02*V05*V11 + 4.50206788567242398e-11*V01*V06*V11 - 1.29003346187058122e-12*V09*V11 - 
      2.30258349130898151e-11*V012*V02*V12 + 3.95028240664850572e-11*V032*V12 + 
      3.43243417611322668e-11*V02*V04*V12 + 2.42921004633035937e-11*V01*V05*V12 - 9.30432048801058198e-13*V08*V12 - 
      1.18081204682511872e-12*V013*V13 + 1.45685275777151709e-11*V02*V03*V13 + 8.81931944973023978e-12*V01*V04*V13 - 
      6.32855328667315743e-13*V07*V13 + 1.03165684091036688e-12*V022*V14 + 2.90075801502960086e-12*V01*V03*V14 - 
      3.05117097813708622e-13*V06*V14 + 4.73878518791659487e-13*V01*V02*V15 - 1.4295890209760875e-13*V05*V15 + 
      3.88425015402999579e-14*V012*V16 - 4.15429802188160502e-14*V04*V16 - 1.25775719273352245e-14*V03*V17 - 
      1.66467863744142677e-15*V02*V18 - 2.77446439573571128e-16*V01*V19 + 5.02620361546324507e-19*V22) + 
   eps11*(-9.01835117002665504e-8*V026 - 3.25916459348999032e-6*V01*V024*V03 - 
      7.35068548808628174e-6*V012*V022*V032 - 1.0854789500622834e-6*V013*V033 + 
      6.78100295225791258e-7*V02*V034 - 3.88445328921519398e-6*V012*V023*V04 - 
      4.99063464093225998e-6*V013*V02*V03*V04 + 2.84278006510562727e-6*V022*V032*V04 + 
      1.64707575731881287e-6*V01*V033*V04 - 2.84933320647606362e-7*V014*V042 + 
      5.87400058299529199e-7*V023*V042 + 3.58815504059799695e-6*V01*V02*V03*V042 + 
      3.5912954439740154e-7*V012*V043 - 2.81868399275952575e-8*V044 - 
      1.54110614180058625e-6*V013*V022*V05 - 4.60814262897596231e-7*V014*V03*V05 + 
      1.12000694579646299e-6*V023*V03*V05 + 3.00648528885136028e-6*V01*V02*V032*V05 + 
      2.15679602202006303e-6*V01*V022*V04*V05 + 1.75801937489685506e-6*V012*V03*V04*V05 - 
      3.02837308803974984e-7*V03*V042*V05 + 5.39000298734921751e-7*V012*V02*V052 - 
      1.30260107162109282e-7*V032*V052 - 1.81474604951678073e-7*V02*V04*V052 - 
      3.30907815972154207e-8*V01*V053 - 2.28841374674708008e-7*V014*V02*V06 + 
      1.2426335177657929e-7*V024*V06 + 1.53341242595954898e-6*V01*V022*V03*V06 + 
      6.11779025097477478e-7*V012*V032*V06 + 9.21724593289573448e-7*V012*V02*V04*V06 - 
      2.1732776138249265e-7*V032*V04*V06 - 1.45683102372722665e-7*V02*V042*V06 + 
      1.38048989425477521e-7*V013*V05*V06 - 2.61595716210939036e-7*V02*V03*V05*V06 - 
      1.66642922459441776e-7*V01*V04*V05*V06 - 3.13513920345541883e-8*V022*V062 - 
      5.92808427693683879e-8*V01*V03*V062 + 8.84509142307875836e-10*V063 - 
      1.08398545898545899e-8*V015*V07 + 2.24590985483015906e-7*V01*V023*V07 + 
      5.54011203192750812e-7*V012*V02*V03*V07 - 4.56228874516762589e-8*V033*V07 + 
      1.01933346911025482e-7*V013*V04*V07 - 1.91754429908024679e-7*V02*V03*V04*V07 - 
      6.13420781184067054e-8*V01*V042*V07 - 5.72043116871378037e-8*V022*V05*V07 - 
      1.03916952302356811e-7*V01*V03*V05*V07 - 5.3133259730785894e-8*V01*V02*V06*V07 + 4.73703555517935601e-9*V05*V06*V07 - 
      5.00584884186415077e-9*V012*V072 + 1.741265174578467e-9*V04*V072 + 
      1.12062015273820829e-7*V012*V022*V08 + 5.3898165877332544e-8*V013*V03*V08 - 
      5.36809105180029939e-8*V02*V032*V08 - 3.57374452845974788e-8*V022*V04*V08 - 
      6.77966188714758976e-8*V01*V03*V04*V08 - 4.12668507250089883e-8*V01*V02*V05*V08 + 
      1.84415328275492498e-9*V052*V08 - 8.89450891456902195e-9*V012*V06*V08 + 
      3.03796541544199087e-9*V04*V06*V08 + 1.95419862124377447e-9*V03*V07*V08 + 3.79246470634262349e-10*V02*V082 + 
      1.95719596761263428e-8*V013*V02*V09 - 1.87589213813852975e-8*V022*V03*V09 - 
      1.67786011778556713e-8*V01*V032*V09 - 2.41704845909809145e-8*V01*V02*V04*V09 - 
      6.17402338833098637e-9*V012*V05*V09 + 2.15772698503969466e-9*V04*V05*V09 + 1.55508035764887683e-9*V03*V06*V09 + 
      6.91653165373944804e-10*V02*V07*V09 + 2.50103168132130448e-10*V01*V08*V09 + 1.05387475179141846e-9*V014*V10 - 
      1.89829593813409562e-9*V023*V10 - 1.09471819705392301e-8*V01*V02*V03*V10 - 
      3.31517199332033599e-9*V012*V04*V10 + 5.66213951638936691e-10*V042*V10 + 
      9.90709445715168765e-10*V03*V05*V10 + 4.93857621869645393e-10*V02*V06*V10 + 2.04600194881280817e-10*V01*V07*V10 - 
      1.0592820988240287e-12*V102 - 1.62155014330259428e-9*V01*V022*V11 - 
      1.34701134241575418e-9*V012*V03*V11 + 4.83293552740012793e-10*V03*V04*V11 + 2.92311187466604348e-10*V02*V05*V11 + 
      1.35732624614622041e-10*V01*V06*V11 - 1.95010166215273807e-12*V09*V11 - 3.7815505799574427e-10*V012*V02*V12 + 
      9.37949305944393234e-11*V032*V12 + 1.29817854947928907e-10*V02*V04*V12 + 7.30666296474582508e-11*V01*V05*V12 - 
      1.49261560383255041e-12*V08*V12 - 2.47970529833274931e-11*V013*V13 + 4.77180131422584983e-11*V02*V03*V13 + 
      3.07298566685929087e-11*V01*V04*V13 - 9.64334462347839848e-13*V07*V13 + 5.53945861966731133e-12*V022*V14 + 
      1.02559741067008009e-11*V01*V03*V14 - 5.09835577360394305e-13*V06*V14 + 2.32278159210993748e-12*V01*V02*V15 - 
      2.25009062494166185e-13*V05*V15 + 2.09749508317619773e-13*V012*V16 - 7.75740245047704874e-14*V04*V16 - 
      2.20569919460989047e-14*V03*V17 - 4.16169659360356692e-15*V02*V18 - 6.9361609893392782e-16*V01*V19 + 
      7.53930542319486761e-19*V22) + delta6*eps8*
    (1.16714836456899949e-7*V02*V034 + 3.3167660895835499e-7*V022*V032*V04 + 
      2.55740273101384212e-7*V01*V033*V04 + 1.0639753805538638e-8*V023*V042 + 
      4.0211845767401323e-7*V01*V02*V03*V042 + 3.92643621810288477e-8*V012*V043 - 
      1.44647796358943781e-8*V044 + 1.06435773874045479e-7*V023*V03*V05 + 
      3.97805457329266853e-7*V01*V02*V032*V05 + 1.99005965375012994e-7*V01*V022*V04*V05 + 
      2.09450079241745908e-7*V012*V03*V04*V05 - 2.23205463736282545e-7*V03*V042*V05 + 
      5.46638381459810031e-8*V012*V02*V052 - 1.08785983451243074e-7*V032*V052 - 
      1.12518714013131224e-7*V02*V04*V052 - 2.20587498467400428e-8*V01*V053 + 
      1.74482785814355479e-9*V024*V06 + 1.40126628221866317e-7*V01*V022*V03*V06 + 
      6.90710946167295374e-8*V012*V032*V06 + 8.25320145756653693e-8*V012*V02*V04*V06 - 
      1.60306931018687944e-7*V032*V04*V06 - 6.23141806988030663e-8*V02*V042*V06 + 
      1.17976618472650219e-8*V013*V05*V06 - 1.63158892000544402e-7*V02*V03*V05*V06 - 
      9.83588207974490265e-8*V01*V04*V05*V06 - 1.11381689475890119e-8*V022*V062 - 
      3.48030855806882884e-8*V01*V03*V062 + 9.53886585144753617e-10*V063 + 
      1.52051105534350684e-8*V01*V023*V07 + 4.88653762463286273e-8*V012*V02*V03*V07 - 
      3.50760218509401516e-8*V033*V07 + 8.00084505441648299e-9*V013*V04*V07 - 
      1.0966831245289851e-7*V02*V03*V04*V07 - 3.33776917471737993e-8*V01*V042*V07 - 
      2.72838431539411932e-8*V022*V05*V07 - 6.36466502471469273e-8*V01*V03*V05*V07 - 
      2.43659066418494264e-8*V01*V02*V06*V07 + 5.73454430680343706e-9*V05*V06*V07 - 
      2.24285876770250149e-9*V012*V072 + 1.97943651812315506e-9*V04*V072 + 
      7.29348240922314996e-9*V012*V022*V08 + 3.81402291124513347e-9*V013*V03*V08 - 
      3.10448607244177324e-8*V02*V032*V08 - 1.1607382420290917e-8*V022*V04*V08 - 
      3.68885683428167088e-8*V01*V03*V04*V08 - 1.90217012623058375e-8*V01*V02*V05*V08 + 
      2.25567676854889474e-9*V052*V08 - 3.85231495904931946e-9*V012*V06*V08 + 
      3.10327793500338834e-9*V04*V06*V08 + 2.26552478541084656e-9*V03*V07*V08 + 3.14616699492002765e-10*V02*V082 + 
      1.00369023980135091e-9*V013*V02*V09 - 7.92456084758190786e-9*V022*V03*V09 - 
      9.03546132401563463e-9*V01*V032*V09 - 9.76593414783968783e-9*V01*V02*V04*V09 - 
      2.6475492964171769e-9*V012*V05*V09 + 2.41967965015243137e-9*V04*V05*V09 + 1.75967541052281089e-9*V03*V06*V09 + 
      6.25456165059616089e-10*V02*V07*V09 + 2.19248139960954814e-10*V01*V08*V09 + 4.01476095920540365e-11*V014*V10 - 
      4.41323816738797546e-10*V023*V10 - 4.45295468686769652e-9*V01*V02*V03*V10 - 
      1.27550192715147586e-9*V012*V04*V10 + 5.34938290003461784e-10*V042*V10 + 
      1.1361175216718043e-9*V03*V05*V10 + 4.00148693505997441e-10*V02*V06*V10 + 1.80018298529104411e-10*V01*V07*V10 - 
      1.37352914624220985e-12*V102 - 4.69963194636397251e-10*V01*V022*V11 - 
      4.90627405455836828e-10*V012*V03*V11 + 5.02893349542243018e-10*V03*V04*V11 + 
      2.59112630875115109e-10*V02*V05*V11 + 1.15332635287803027e-10*V01*V06*V11 - 2.59545595292284319e-12*V09*V11 - 
      1.05092272167435566e-10*V012*V02*V12 + 9.92078181483731716e-11*V032*V12 + 
      9.54439427562594958e-11*V02*V04*V12 + 6.26440027127202582e-11*V01*V05*V12 - 1.92513302396022541e-12*V08*V12 - 
      5.9040602341255936e-12*V013*V13 + 3.87855325380408513e-11*V02*V03*V13 + 2.3732250541102737e-11*V01*V04*V13 - 
      1.28109968651631223e-12*V07*V13 + 3.08841045580429443e-12*V022*V14 + 7.94458631504268473e-12*V01*V03*V14 - 
      6.42639939769610351e-13*V06*V14 + 1.37243505442393185e-12*V01*V02*V15 - 2.95332486711414013e-13*V05*V15 + 
      1.16527504620899874e-13*V012*V16 - 9.08914536043019015e-14*V04*V16 - 2.71897510782099705e-14*V03*V17 - 
      3.88425015402999579e-15*V02*V18 - 6.47375025671665965e-16*V01*V19 + 1.00524072309264901e-18*V22) + 
   delta2*eps10*(-1.05683802773749864e-9*V026 - 1.43624287969526065e-6*V01*V024*V03 - 
      4.03239837763647287e-6*V012*V022*V032 - 6.39695952195952196e-7*V013*V033 + 
      1.03731386283469617e-6*V02*V034 - 1.80719302743112267e-6*V012*V023*V04 - 
      2.58256954685526114e-6*V013*V02*V03*V04 + 3.76126895224117446e-6*V022*V032*V04 + 
      2.41349362443112443e-6*V01*V033*V04 - 1.39266322302036588e-7*V014*V042 + 
      5.67501373552960855e-7*V023*V042 + 4.64213503648027458e-6*V01*V02*V03*V042 + 
      4.56605646337789195e-7*V012*V043 - 4.8511255774108832e-8*V044 - 
      6.58099616432949766e-7*V013*V022*V05 - 2.11015836015836016e-7*V014*V03*V05 + 
      1.29053917496377814e-6*V023*V03*V05 + 3.9946842867229772e-6*V01*V02*V032*V05 + 
      2.44500548319992764e-6*V01*V022*V04*V05 + 2.24826843130414559e-6*V012*V03*V04*V05 - 
      5.60125414233724224e-7*V03*V042*V05 + 6.19076139909473243e-7*V012*V02*V052 - 
      2.49438911785360782e-7*V032*V052 - 3.07119530720429413e-7*V02*V04*V052 - 
      5.691691187504096e-8*V01*V053 - 8.67188367188367188e-8*V014*V02*V06 + 
      1.01721424886107426e-7*V024*V06 + 1.76647646885742124e-6*V01*V022*V03*V06 + 
      7.76630845455250217e-7*V012*V032*V06 + 1.04599434956577814e-6*V012*V02*V04*V06 - 
      4.0652457348302353e-7*V032*V04*V06 - 2.31405524903132279e-7*V02*V042*V06 + 
      1.52463415112224636e-7*V013*V05*V06 - 4.49494829929295382e-7*V02*V03*V05*V06 - 
      2.8006164438601997e-7*V01*V04*V05*V06 - 4.55565553349458578e-8*V022*V062 - 
      1.00457618621134027e-7*V01*V03*V062 + 1.71256554412201539e-9*V063 - 
      3.61328486328486328e-9*V015*V07 + 2.13711461231302501e-7*V01*V023*V07 + 
      6.20745133393942918e-7*V012*V02*V03*V07 - 8.67051308647217844e-8*V033*V07 + 
      1.10772990237275952e-7*V013*V04*V07 - 3.23151314667712894e-7*V02*V03*V04*V07 - 
      1.01333081107021933e-7*V01*V042*V07 - 8.70315157488360103e-8*V022*V05*V07 - 
      1.77061130153304523e-7*V01*V03*V05*V07 - 8.07420722001137501e-8*V01*V02*V06*V07 + 9.36414228087805413e-9*V05*V06*V07 - 
      7.52927932914510879e-9*V012*V072 + 3.39053821003755583e-9*V04*V072 + 
      1.08217881655381655e-7*V012*V022*V08 + 5.69694580111246778e-8*V013*V03*V08 - 
      9.20055009399080361e-8*V02*V032*V08 - 5.09313924784279593e-8*V022*V04*V08 - 
      1.13208170487071631e-7*V01*V03*V04*V08 - 6.28664755448281359e-8*V01*V02*V05*V08 + 
      3.65860240983193125e-9*V052*V08 - 1.33508092355693896e-8*V012*V06*V08 + 
      5.81472070492569043e-9*V04*V06*V08 + 3.86604911270109038e-9*V03*V07*V08 + 6.69355072471856466e-10*V02*V082 + 
      1.80664243164243164e-8*V013*V02*V09 - 2.83619245526925265e-8*V022*V03*V09 - 
      2.81638855036964281e-8*V01*V032*V09 - 3.58774136840050706e-8*V01*V02*V04*V09 - 
      9.23462495591347132e-9*V012*V05*V09 + 4.20004124525269606e-9*V04*V05*V09 + 3.06443310291299597e-9*V03*V06*V09 + 
      1.23744774342815094e-9*V02*V07*V09 + 4.45845885430025007e-10*V01*V08*V09 + 9.03321215821215821e-10*V014*V10 - 
      2.36809044533523214e-9*V023*V10 - 1.64647371186236732e-8*V01*V02*V03*V10 - 
      4.8689519595069315e-9*V012*V04*V10 + 1.06738757717012689e-9*V042*V10 + 
      1.95993066468536445e-9*V03*V05*V10 + 8.68331150576541423e-10*V02*V06*V10 + 3.64912169506311622e-10*V01*V07*V10 - 
      2.10980781986575818e-12*V102 - 2.1210336391096195e-9*V01*V022*V11 - 
      1.96605205796382267e-9*V012*V03*V11 + 9.3749562552640253e-10*V03*V04*V11 + 5.22594784223503694e-10*V02*V05*V11 + 
      2.40847369943663066e-10*V01*V06*V11 - 3.90006460108568935e-12*V09*V11 - 4.91513014490955667e-10*V012*V02*V12 + 
      1.84496333387633329e-10*V032*V12 + 2.23917921136611244e-10*V02*V04*V12 + 1.29959796546414746e-10*V01*V05*V12 - 
      2.97043406422117702e-12*V08*V12 - 3.09963162291593664e-11*V013*V13 + 8.4929129617865858e-11*V02*V03*V13 + 
      5.3556817973796388e-11*V01*V04*V13 - 1.92853020147589291e-12*V07*V13 + 8.62458904200820265e-12*V022*V14 + 
      1.80431188155001364e-11*V01*V03*V14 - 1.01084835794234905e-12*V06*V14 + 3.67061639555834602e-12*V01*V02*V15 - 
      4.49879401768545584e-13*V05*V15 + 3.26277012938519646e-13*V012*V16 - 1.51596734582999264e-13*V04*V16 - 
      4.39752606724110238e-14*V03*V17 - 7.49105386848642045e-15*V02*V18 - 1.24850897808107008e-15*V01*V19 + 
      1.50786108463897352e-18*V22) + delta4*eps9*
    (5.77265272205748396e-7*V02*V034 + 1.82975598402185704e-6*V022*V032*V04 + 
      1.29435893324782214e-6*V01*V033*V04 + 1.71045640622360199e-7*V023*V042 + 
      2.22836898184120406e-6*V01*V02*V03*V042 + 2.17760634427301094e-7*V012*V043 - 
      3.60906857706966639e-8*V044 + 5.88336453498490536e-7*V023*V03*V05 + 
      2.02834900255535176e-6*V01*V02*V032*V05 + 1.09785359041311422e-6*V01*V022*V04*V05 + 
      1.10349719724719725e-6*V012*V03*V04*V05 - 4.68083420578654783e-7*V03*V042*V05 + 
      2.91282378335949765e-7*V012*V02*V052 - 2.17885800504264557e-7*V032*V052 - 
      2.43074095879106772e-7*V02*V04*V052 - 4.63433304017454344e-8*V01*V053 + 
      2.92978136893480809e-8*V024*V06 + 7.90223105451280054e-7*V01*V022*V03*V06 + 
      3.71694599125154681e-7*V012*V032*V06 + 4.64519313725662932e-7*V012*V02*V04*V06 - 
      3.39387086707542668e-7*V032*V04*V06 - 1.61809756133596781e-7*V02*V042*V06 + 
      6.75684269434269434e-8*V013*V05*V06 - 3.55806643708089008e-7*V02*V03*V05*V06 - 
      2.17671871098866897e-7*V01*V04*V05*V06 - 3.00604608299908642e-8*V022*V062 - 
      7.77819282174149121e-8*V01*V03*V062 + 1.60833310225194172e-9*V063 + 
      8.40480647854986479e-8*V01*V023*V07 + 2.70296649264903233e-7*V012*V02*V03*V07 - 
      7.32294648124869102e-8*V033*V07 + 4.66974053283577093e-8*V013*V04*V07 - 
      2.46677484412856339e-7*V02*V03*V04*V07 - 7.61219370190736515e-8*V01*V042*V07 - 
      6.29359832025273202e-8*V022*V05*V07 - 1.38998120525801042e-7*V01*V03*V05*V07 - 
      5.7467395205441813e-8*V01*V02*V06*V07 + 9.13001277706507386e-9*V05*V06*V07 - 
      5.30907153538845104e-9*V012*V072 + 3.22444623072974743e-9*V04*V072 + 
      4.26367613867613868e-8*V012*V022*V08 + 2.3125023125023125e-8*V013*V03*V08 - 
      7.06136849830438377e-8*V02*V032*V08 - 3.23479074354424494e-8*V022*V04*V08 - 
      8.51545756400059232e-8*V01*V03*V04*V08 - 4.4997879418105842e-8*V01*V02*V05*V08 + 
      3.58588104686483122e-9*V052*V08 - 9.33831149945373413e-9*V012*V06*V08 + 
      5.35219682347953734e-9*V04*V06*V08 + 3.70330815615235731e-9*V03*V07*V08 + 5.74573573165675699e-10*V02*V082 + 
      6.62435558268891602e-9*V013*V02*V09 - 1.95347640966513516e-8*V022*V03*V09 - 
      2.10785071604399335e-8*V01*V032*V09 - 2.43510434044981197e-8*V01*V02*V04*V09 - 
      6.44571558874780163e-9*V012*V05*V09 + 3.98584660105880436e-9*V04*V05*V09 + 2.91333022299243766e-9*V03*V06*V09 + 
      1.09040704931153581e-9*V02*V07*V09 + 3.89198166147944597e-10*V01*V08*V09 + 3.01107071940405274e-10*V014*V10 - 
      1.34500115047889713e-9*V023*V10 - 1.12181361634267797e-8*V01*V02*V03*V10 - 
      3.25870387436680621e-9*V012*V04*V10 + 9.5573417761393829e-10*V042*V10 + 
      1.87501133817503019e-9*V03*V05*V10 + 7.39981468201118634e-10*V02*V06*V10 + 3.1894243886195272e-10*V01*V07*V10 - 
      2.09271123396052009e-12*V102 - 1.28944675513302964e-9*V01*V022*V11 - 
      1.29121797320326732e-9*V012*V03*V11 + 8.658560693855349e-10*V03*V04*V11 + 4.59043272703367589e-10*V02*V05*V11 + 
      2.08292359616979377e-10*V01*V06*V11 - 3.89895481532739506e-12*V09*V11 - 2.9520301170627968e-10*V012*V02*V12 + 
      1.71398086975365036e-10*V032*V12 + 1.84287767650791223e-10*V02*V04*V12 + 1.129495553361591e-10*V01*V05*V12 - 
      2.94167211665205015e-12*V08*V12 - 1.77121807023767808e-11*V013*V13 + 7.22146841136743384e-11*V02*V03*V13 + 
      4.47838505759042395e-11*V01*V04*V13 - 1.92742041571759863e-12*V07*V13 + 6.47582185679880898e-12*V022*V14 + 
      1.51042951489610416e-11*V01*V03*V14 - 9.94035103704190637e-13*V06*V14 + 2.80831286136368696e-12*V01*V02*V15 - 
      4.48769616010251299e-13*V05*V15 + 2.44707759703889735e-13*V012*V16 - 1.45326445048636557e-13*V04*V16 - 
      4.28654749141167393e-14*V03*V17 - 6.65871454976570707e-15*V02*V18 - 1.10978575829428451e-15*V01*V19 + 
      1.50786108463897352e-18*V22) + 3.86817017063068404e-23*delta22*V22 + 
   2.12749359384687622e-22*delta20*eps*V22 + 
   delta20*eps2*(-3.41091377476043088e-18*V112 - 5.24755965347758597e-18*V10*V12 - 
      4.81026301568778714e-18*V09*V13 - 2.56547360836681981e-18*V08*V14 - 1.64923303395009845e-18*V07*V15 - 
      5.82082247276505334e-19*V06*V16 - 2.54660983183471084e-19*V05*V17 - 5.36128385649412808e-20*V04*V18 - 
      1.48924551569281335e-20*V03*V19 - 1.41832906256458415e-21*V02*V20 - 2.12749359384687622e-22*V01*V21 + 
      2.12749359384687622e-24*V24) + delta18*eps3*
    (-3.41091377476043088e-17*V112 - 5.24755965347758597e-17*V10*V12 - 4.81026301568778714e-17*V09*V13 - 
      2.56547360836681981e-17*V08*V14 - 1.64923303395009845e-17*V07*V15 - 5.82082247276505334e-18*V06*V16 - 
      2.54660983183471084e-18*V05*V17 - 5.36128385649412808e-19*V04*V18 - 1.48924551569281335e-19*V03*V19 - 
      1.41832906256458415e-20*V02*V20 - 2.12749359384687622e-21*V01*V21 + 1.06374679692343811e-23*V24) + 
   delta16*eps4*(1.95275788151827456e-13*V06*V072 + 1.10155572803594975e-13*V062*V08 + 
      3.00424289464349933e-13*V05*V07*V08 + 5.69431659769029285e-14*V04*V082 + 2.27821752843798699e-13*V05*V06*V09 + 
      1.53157480903394083e-13*V04*V07*V09 + 8.34511915178749814e-14*V03*V08*V09 + 1.07059094381484351e-14*V02*V092 + 
      7.06059151375409192e-14*V052*V10 + 6.95537485590207015e-14*V04*V06*V10 + 6.7243728702419923e-14*V03*V07*V10 + 
      1.28135148350630137e-14*V02*V08*V10 + 5.60364405853499358e-15*V01*V09*V10 + 5.84783108903868319e-14*V04*V05*V11 + 
      4.14221368806906726e-14*V03*V06*V11 + 1.40150087190306787e-14*V02*V07*V11 + 4.55188317370227171e-15*V01*V08*V11 - 
      2.06888162885766611e-16*V112 + 7.37226568917269889e-15*V042*V12 + 2.1242121477277268e-14*V03*V05*V12 + 
      5.25463004964227156e-15*V02*V06*V12 + 3.03458878246818114e-15*V01*V07*V12 - 3.25473640412121701e-16*V10*V12 + 
      7.4972193449213887e-15*V03*V04*V13 + 3.77327157820056734e-15*V02*V05*V13 + 1.5931591107957951e-15*V01*V06*V13 - 
      2.93082453741548745e-16*V09*V13 + 1.13797079342556793e-15*V032*V14 + 7.91999487189063994e-16*V02*V04*V14 + 
      6.82782476055340757e-16*V01*V05*V14 - 1.60525348637809582e-16*V08*V14 + 3.59359197923863556e-16*V02*V03*V15 + 
      2.14206266997753963e-16*V01*V04*V15 - 1.01840139846418579e-16*V07*V15 + 1.55017693222058789e-17*V022*V16 + 
      5.35515667494384907e-17*V01*V03*V16 - 3.70592364099375063e-17*V06*V16 + 7.9270411306734608e-18*V01*V02*V17 - 
      1.60739587242709963e-17*V05*V17 + 4.40391173926303378e-19*V012*V18 - 3.50142895675318888e-18*V04*V18 - 
      9.68541458598790399e-19*V03*V19 - 9.57372117231094299e-20*V02*V20 - 1.43605817584664145e-20*V01*V21 + 
      4.7868605861554715e-23*V24) + delta14*eps5*
    (2.05039577559418829e-12*V06*V072 + 1.23173958680383473e-12*V062*V08 + 
      3.16697271810335554e-12*V05*V07*V08 + 6.37501651281648877e-13*V04*V082 + 2.39212840485988634e-12*V05*V06*V09 + 
      1.60336737820740681e-12*V04*V07*V09 + 8.79714643917598762e-13*V03*V08*V09 + 1.11817276353994767e-13*V02*V092 + 
      7.48422700457933743e-13*V052*V10 + 7.8015382937856978e-13*V04*V06*V10 + 7.12783524245651184e-13*V03*V07*V10 + 
      1.44021970804301276e-13*V02*V08*V10 + 5.9398627020470932e-14*V01*V09*V10 + 6.12194817133737146e-13*V04*V05*V11 + 
      4.34932437247252062e-13*V03*V06*V11 + 1.46378979954320422e-13*V02*V07*V11 + 4.79844351227781143e-14*V01*V08*V11 - 
      9.47746755987005437e-16*V112 + 8.32191347286274146e-14*V042*V12 + 2.27025173288400802e-13*V03*V05*V12 + 
      5.93661394970222595e-14*V02*V06*V12 + 3.24321676126286859e-14*V01*V07*V12 - 1.54428184088054673e-15*V10*V12 + 
      7.8486515017145788e-14*V03*V04*V13 + 3.94097253723170367e-14*V02*V05*V13 + 1.67281706633558485e-14*V01*V06*V13 - 
      1.35237108783908073e-15*V09*V13 + 1.23280169287769859e-14*V032*V14 + 9.06336779704970386e-15*V02*V04*V14 + 
      7.39681015726619153e-15*V01*V05*V14 - 7.71841059888646073e-16*V08*V14 + 3.75330717831590825e-15*V02*V03*V15 + 
      2.2424718576327368e-15*V01*V04*V15 - 4.79926812879478648e-16*V07*V15 + 1.82732977767820815e-16*V022*V16 + 
      5.95761180087503209e-16*V01*V03*V16 - 1.82773825644822675e-16*V06*V16 + 8.2793540698145035e-17*V01*V02*V17 - 
      7.82900622586899674e-17*V05*V17 + 5.28469408711564053e-18*V012*V18 - 1.78913701268146903e-17*V04*V18 - 
      4.9208926825678247e-18*V03*V19 - 5.10598462523250293e-19*V02*V20 - 7.65897693784875439e-20*V01*V21 + 
      1.9147442344621886e-22*V24) + delta12*eps6*
    (-1.81710194045720362e-10*V042*V052 - 1.29792995746943115e-10*V03*V053 - 
      4.18662090202051216e-11*V043*V06 - 5.14805050014601672e-10*V03*V04*V05*V06 - 
      1.29420107732156236e-10*V02*V052*V06 - 9.01865811069624174e-11*V032*V062 - 
      4.40269978275238859e-11*V02*V04*V062 - 5.41119486641774504e-11*V01*V05*V062 - 
      1.7305732766259082e-10*V03*V042*V07 - 1.82550878953343448e-10*V032*V05*V07 - 
      1.71981279391348682e-10*V02*V04*V05*V07 - 5.3904957766173305e-11*V01*V052*V07 - 
      1.23257245459196415e-10*V02*V03*V06*V07 - 7.35435785735145245e-11*V01*V04*V06*V07 - 
      9.95785605773606822e-12*V022*V072 - 2.49971695512631185e-11*V01*V03*V072 + 
      1.15250268045761243e-11*V06*V072 - 9.3124342549990002e-11*V032*V04*V08 - 
      2.23761745508195875e-11*V02*V042*V08 - 9.46468041976648278e-11*V02*V03*V05*V08 - 
      5.58746055299940012e-11*V01*V04*V05*V08 - 7.76241046146929228e-12*V022*V06*V08 - 
      3.85115190357462705e-11*V01*V03*V06*V08 + 7.53554676494466446e-12*V062*V08 - 
      1.35209720282378325e-11*V01*V02*V07*V08 + 1.79154934532962937e-11*V05*V07*V08 - 
      9.82119292914208671e-13*V012*V082 + 3.92859226055028743e-12*V04*V082 - 
      1.63718061254146838e-11*V033*V09 - 4.77725776087079673e-11*V02*V03*V04*V09 - 
      1.44214439718825684e-11*V01*V042*V09 - 1.16174987340254129e-11*V022*V05*V09 - 
      2.86854167432348997e-11*V01*V03*V05*V09 - 1.02714371215997013e-11*V01*V02*V06*V09 + 1.35496295737393273e-11*V05*V06*V09 - 
      1.84187443018241419e-12*V012*V07*V09 + 9.10052682992914154e-12*V04*V07*V09 + 
      5.05222430881163618e-12*V03*V08*V09 + 6.46063149296892166e-13*V02*V092 - 
      1.04307530326792808e-11*V02*V032*V10 - 2.36513594902759535e-12*V022*V04*V10 - 
      1.21170650938357241e-11*V01*V03*V04*V10 - 6.25845181960756846e-12*V01*V02*V05*V10 + 
      4.29758799138050964e-12*V052*V10 - 1.19770545225693172e-12*V012*V06*V10 + 
      4.84506694116438835e-12*V04*V06*V10 + 4.12322028399698023e-12*V03*V07*V10 + 9.06863113883747762e-13*V02*V08*V10 + 
      3.51171525289348256e-13*V01*V09*V10 - 2.11227249709552962e-12*V022*V03*V11 - 
      2.44960790856780832e-12*V01*V032*V11 - 2.60577696047498003e-12*V01*V02*V04*V11 - 
      6.77191269711172409e-13*V012*V05*V11 + 3.52815936324254369e-12*V04*V05*V11 + 
      2.52016808708015893e-12*V03*V06*V11 + 8.52167490935571267e-13*V02*V07*V11 + 2.83833873160198232e-13*V01*V08*V11 - 
      3.51413879689133865e-15*V112 - 5.41772745293529826e-14*V023*V12 - 
      9.0682813881742576e-13*V01*V02*V03*V12 - 2.52291295718900679e-13*V012*V04*V12 + 
      5.289041628784641e-13*V042*V12 + 1.34433281283334658e-12*V03*V05*V12 + 3.79763754107156185e-13*V02*V06*V12 + 
      1.94742738674907059e-13*V01*V07*V12 - 5.94631364944065399e-15*V10*V12 - 8.12412498882896009e-14*V01*V022*V13 - 
      7.79957430929223155e-14*V012*V03*V13 + 4.66023701813509939e-13*V03*V04*V13 + 
      2.34608709303411746e-13*V02*V05*V13 + 1.0055768755904512e-13*V01*V06*V13 - 5.05191543929168149e-15*V09*V13 - 
      1.32927671937915412e-14*V012*V02*V14 + 7.5919621661387341e-14*V032*V14 + 
      5.98495128495237701e-14*V02*V04*V14 + 4.58452496751368932e-14*V01*V05*V14 - 3.0134525591120312e-15*V08*V14 - 
      5.17900020537332772e-16*V013*V15 + 2.31657501249873611e-14*V02*V03*V15 + 1.3901916265566404e-14*V01*V04*V15 - 
      1.83240640289184556e-15*V07*V15 + 1.26762195502947164e-15*V022*V16 + 3.87685158230803389e-15*V01*V03*V16 - 
      7.33048341698442132e-16*V06*V16 + 5.36396449842237514e-16*V01*V02*V17 - 3.09533723454688484e-16*V05*V17 + 
      3.69928586098094837e-17*V012*V18 - 7.45754584438333215e-17*V04*V18 - 2.03728786546776867e-17*V03*V19 - 
      2.23386827353922003e-18*V02*V20 - 3.35080241030883005e-19*V01*V21 + 6.7016048206176601e-22*V24) + 
   delta10*eps7*(-1.70557610707464509e-9*V042*V052 - 1.19217270167562565e-9*V03*V053 - 
      5.01323905320006685e-10*V043*V06 - 4.86215725920891613e-9*V03*V04*V05*V06 - 
      1.21733642787349358e-9*V02*V052*V06 - 8.59173938356269183e-10*V032*V062 - 
      5.31289659696870534e-10*V02*V04*V062 - 5.1550436301376151e-10*V01*V05*V062 - 
      1.6243581972139477e-9*V03*V042*V07 - 1.68494184567353601e-9*V032*V05*V07 - 
      1.61287383824424957e-9*V02*V04*V05*V07 - 5.00033949543139184e-10*V01*V052*V07 - 
      1.15936802654618436e-9*V02*V03*V06*V07 - 6.94593894172702304e-10*V01*V04*V06*V07 - 
      9.39246312560111764e-11*V022*V072 - 2.33856304153575109e-10*V01*V03*V072 + 
      4.44102205900675288e-11*V06*V072 - 8.89988989578240483e-10*V032*V04*V08 - 
      2.7239765423050433e-10*V02*V042*V08 - 8.9868083163720132e-10*V02*V03*V05*V08 - 
      5.3399339374694429e-10*V01*V04*V05*V08 - 9.55675284983031473e-11*V022*V06*V08 - 
      3.723987620360497e-10*V01*V03*V06*V08 + 3.1674494679726012e-11*V062*V08 - 
      1.28382975948171617e-10*V01*V02*V07*V08 + 6.94986314416835163e-11*V05*V07*V08 - 
      9.71432467093597043e-12*V012*V082 + 1.67162671835187365e-11*V04*V082 - 
      1.52649797958091841e-10*V033*V09 - 4.48020510623402657e-10*V02*V03*V04*V09 - 
      1.35363183101162308e-10*V01*V042*V09 - 1.09578736465346372e-10*V022*V05*V09 - 
      2.69805352535325616e-10*V01*V03*V05*V09 - 9.66140022121820299e-11*V01*V02*V06*V09 + 5.29256680159109844e-11*V05*V06*V09 - 
      1.79602794741199031e-11*V012*V07*V09 + 3.57673098659722354e-11*V04*V07*V09 + 2.0127259476718193e-11*V03*V08*V09 + 
      2.61853949669536431e-12*V02*V092 - 1.00756215900251097e-10*V02*V032*V10 - 
      2.97018917149718008e-11*V022*V04*V10 - 1.18149015058534227e-10*V01*V03*V04*V10 - 
      6.04537295401506583e-11*V01*V02*V05*V10 + 1.69961237638805225e-11*V052*V10 - 
      1.19030688053496982e-11*V012*V06*V10 + 2.08588297254544514e-11*V04*V06*V10 + 
      1.65213712420960515e-11*V03*V07*V10 + 3.99657392471796277e-12*V02*V08*V10 + 1.46042761310808322e-12*V01*V09*V10 - 
      1.99234066300629768e-11*V022*V03*V11 - 2.35260967386419907e-11*V01*V032*V11 - 
      2.44374823976401449e-11*V01*V02*V04*V11 - 6.69245203681785332e-12*V012*V05*V11 + 
      1.42250735474288297e-11*V04*V05*V11 + 1.02303454542559249e-11*V03*V06*V11 + 3.49571416005116678e-12*V02*V07*V11 + 
      1.18753241613923411e-12*V01*V08*V11 - 1.07722042660262976e-14*V112 - 7.15353102653051873e-13*V023*V12 - 
      9.02525129503932721e-12*V01*V02*V03*V12 - 2.54954781538806962e-12*V012*V04*V12 + 
      2.35514294482179882e-12*V042*V12 + 5.54943436053908996e-12*V03*V05*V12 + 1.71018478591264041e-12*V02*V06*V12 + 
      8.23411708842879362e-13*V01*V07*V12 - 1.88276916619772124e-14*V10*V12 - 7.6628487038703757e-13*V01*V022*V13 - 
      8.02123551808220998e-13*V012*V03*V13 + 1.96948746143338698e-12*V03*V04*V13 + 
      9.95921739493290921e-13*V02*V05*V13 + 4.32416922861785017e-13*V01*V06*V13 - 1.55700618665683636e-14*V09*V13 - 
      1.39833005545079848e-13*V012*V02*V14 + 3.29532384496182881e-13*V032*V14 + 
      2.80820188278785753e-13*V02*V04*V14 + 2.01241150837363591e-13*V01*V05*V14 - 9.65495738769839211e-15*V08*V14 - 
      6.21480024644799327e-15*V013*V15 + 1.03543011248856745e-13*V02*V03*V15 + 6.25179310505780275e-14*V01*V04*V15 - 
      5.74558068332762718e-15*V07*V15 + 6.30358310711153603e-15*V022*V16 + 1.7985927856089371e-14*V01*V03*V16 - 
      2.40764535427438304e-15*V06*V16 + 2.55250724407685438e-15*V01*V02*V17 - 1.00124656661956089e-15*V05*V17 + 
      1.84964293049047419e-16*V012*V18 - 2.54660983183471084e-16*V04*V18 - 6.9026529652361899e-17*V03*V19 - 
      8.04192578474119211e-18*V02*V20 - 1.20628886771117882e-18*V01*V21 + 2.01048144618529803e-21*V24) + 
   delta8*eps8*(1.12851894189429203e-8*V034*V04 + 
      3.22772161542391857e-8*V02*V032*V042 + 1.32727772394750297e-9*V022*V043 + 
      1.28988759163051102e-8*V01*V03*V043 + 2.32560932622207132e-8*V02*V033*V05 + 
      3.15213839859809359e-8*V022*V03*V04*V05 + 3.88793049954736852e-8*V01*V032*V04*V05 + 
      1.93663296925435114e-8*V01*V02*V042*V05 + 2.50509275733948937e-9*V023*V052 + 
      2.01676793537496152e-8*V01*V02*V03*V052 + 5.42296366876198809e-9*V012*V04*V052 - 
      7.79716800769014296e-9*V042*V052 - 5.26980793180764275e-9*V03*V053 + 
      1.12944672278822606e-8*V022*V032*V06 + 8.727044463213931e-9*V01*V033*V06 + 
      8.90219825015965694e-10*V023*V04*V06 + 2.72517925412416542e-8*V01*V02*V03*V04*V06 + 
      3.97332007927635067e-9*V012*V042*V06 - 2.82619430165753763e-9*V043*V06 + 
      6.77668033672935634e-9*V01*V022*V05*V06 + 7.21389005435262827e-9*V012*V03*V05*V06 - 
      2.24289006366088539e-8*V03*V04*V05*V06 - 5.65439409962507944e-9*V02*V052*V06 + 
      1.39900924433487459e-9*V012*V02*V062 - 4.00160730277563195e-9*V032*V062 - 
      3.03640156876773161e-9*V02*V04*V062 - 2.43622427282075352e-9*V01*V05*V062 + 
      2.38580262603760892e-9*V023*V03*V07 + 9.24041655785742309e-9*V01*V02*V032*V07 + 
      4.5030548551401337e-9*V01*V022*V04*V07 + 4.91510203033701322e-9*V012*V03*V04*V07 - 
      7.54012879201343963e-9*V03*V042*V07 + 2.57138691939695675e-9*V012*V02*V05*V07 - 
      7.59338696663967903e-9*V032*V05*V07 - 7.5484574628484751e-9*V02*V04*V05*V07 - 
      2.29457182461032637e-9*V01*V052*V07 + 2.82523339489181381e-10*V013*V06*V07 - 
      5.4663977239129376e-9*V02*V03*V06*V07 - 3.30056967893175719e-9*V01*V04*V06*V07 - 
      4.51109044388735651e-10*V022*V072 - 1.09454741335667439e-9*V01*V03*V072 + 
      1.26631398443508704e-10*V06*V072 + 3.65989257687912458e-11*V024*V08 + 
      2.43314756620078749e-9*V01*V022*V03*V08 + 1.21284391647629535e-9*V012*V032*V08 + 
      1.42878257665839365e-9*V012*V02*V04*V08 - 4.21187584438707663e-9*V032*V04*V08 - 
      1.57900113818356684e-9*V02*V042*V08 + 2.09303621061842869e-10*V013*V05*V08 - 
      4.27845468704313461e-9*V02*V03*V05*V08 - 2.56344641051699639e-9*V01*V04*V05*V08 - 
      5.6232564871173011e-10*V022*V06*V08 - 1.80530156382735475e-9*V01*V03*V06*V08 + 
      9.74318743872451483e-11*V062*V08 - 6.28867334096473348e-10*V01*V02*V07*V08 + 
      1.99076135566589245e-10*V05*V07*V08 - 4.90493244688611919e-11*V012*V082 + 
      5.22622857692870916e-11*V04*V082 + 1.98816885503134077e-10*V01*V023*V09 + 
      6.53734098066692215e-10*V012*V02*V03*V09 - 7.14665652030552913e-10*V033*V09 + 
      1.07959958566867997e-10*V013*V04*V09 - 2.16039515045621509e-9*V02*V03*V04*V09 - 
      6.56907690744922031e-10*V01*V042*V09 - 5.34141365181383528e-10*V022*V05*V09 - 
      1.28674492004969786e-9*V01*V03*V05*V09 - 4.75848265203103142e-10*V01*V02*V06*V09 + 1.53293911446729409e-10*V05*V06*V09 - 
      8.93781990681032949e-11*V012*V07*V09 + 1.04748497532374607e-10*V04*V07*V09 + 
      5.96375848728657949e-11*V03*V08*V09 + 8.00285623282956963e-12*V02*V092 + 
      7.68511840475348101e-11*V012*V022*V10 + 4.10332186271728755e-11*V013*V03*V10 - 
      4.99307533109571225e-10*V02*V032*V10 - 1.79761814709409732e-10*V022*V04*V10 - 
      5.90560875518700023e-10*V01*V03*V04*V10 - 3.03615680992265154e-10*V01*V02*V05*V10 + 
      4.95593811626264585e-11*V052*V10 - 6.1010472062228291e-11*V012*V06*V10 + 
      6.60909927939994441e-11*V04*V06*V10 + 4.90642617367695468e-11*V03*V07*V10 + 1.30867700317987669e-11*V02*V08*V10 + 
      4.56632279958408988e-12*V01*V09*V10 + 8.75768934728629718e-12*V013*V02*V11 - 
      1.01397055520901697e-10*V022*V03*V11 - 1.18628329061350954e-10*V01*V032*V11 - 
      1.24778071200457163e-10*V01*V02*V04*V11 - 3.4528579333517025e-11*V012*V05*V11 + 
      4.27939492219946726e-11*V04*V05*V11 + 3.09900829324836135e-11*V03*V06*V11 + 1.08063045332860666e-11*V02*V07*V11 + 
      3.74521866042146181e-12*V01*V08*V11 - 2.71163685054242072e-14*V112 + 2.9520301170627968e-13*V014*V12 - 
      4.5881009438459709e-12*V023*V12 - 4.77907041094267739e-11*V01*V02*V03*V12 - 
      1.3647553369765354e-11*V012*V04*V12 + 7.75800666716767563e-12*V042*V12 + 
      1.69422051777957712e-11*V03*V05*V12 + 5.72886205574953589e-12*V02*V06*V12 + 2.60664012717587559e-12*V01*V07*V12 - 
      4.85079215546758719e-14*V10*V12 - 4.17427416553090214e-12*V01*V022*V13 - 
      4.44746642636434518e-12*V012*V03*V13 + 6.23590467228488958e-12*V03*V04*V13 + 
      3.18383353458829799e-12*V02*V05*V13 + 1.40300965206493938e-12*V01*V06*V13 - 3.92968703471378353e-14*V09*V13 - 
      8.00155531730179133e-13*V012*V02*V14 + 1.06004577715517818e-12*V032*V14 + 
      9.83467477094655061e-13*V02*V04*V14 + 6.59268229714719714e-13*V01*V05*V14 - 2.50933103808588833e-14*V08*V14 - 
      3.88425015402999579e-14*V013*V15 + 3.49335894805300891e-13*V02*V03*V15 + 2.12560965571965293e-13*V01*V04*V15 - 
      1.46526903520153798e-14*V07*V15 + 2.35521199815787046e-14*V022*V16 + 6.23329667575289801e-14*V01*V03*V16 - 
      6.38931003597687713e-15*V06*V16 + 9.24821465245237093e-15*V01*V02*V17 - 2.61613898184861906e-15*V05*V17 + 
      6.9361609893392782e-16*V012*V18 - 7.01658024718669012e-16*V04*V18 - 1.8848263557987169e-16*V03*V19 - 
      2.34556168721618103e-17*V02*V20 - 3.51834253082427155e-18*V01*V21 + 5.02620361546324507e-21*V24) + 
   eps12*(4.38492191964414187e-7*V012*V025 + 1.56443190297356964e-6*V013*V023*V03 + 
      6.26423152464819131e-7*V014*V02*V032 - 6.15952990446624706e-7*V024*V032 - 
      2.13342389991695547e-6*V01*V022*V033 - 4.02632490461111493e-7*V012*V034 + 
      4.3106488418988419e-7*V014*V022*V04 - 1.43889032777921667e-7*V025*V04 + 
      9.17774355274355274e-8*V015*V03*V04 - 3.11017509368203813e-6*V01*V023*V03*V04 - 
      3.63782652349120603e-6*V012*V02*V032*V04 + 1.63667367473803243e-7*V034*V04 - 
      1.39086131227128251e-6*V012*V022*V042 - 6.47181474004390671e-7*V013*V03*V042 + 
      6.94893262950216634e-7*V02*V032*V042 + 1.51283642180000723e-7*V022*V043 + 
      2.90338231387046747e-7*V01*V03*V043 + 4.81771315104648438e-8*V015*V02*V05 - 
      4.63494115837865838e-7*V01*V024*V05 - 2.22791129909185465e-6*V012*V022*V03*V05 - 
      5.21445756440796123e-7*V013*V032*V05 + 3.96565639823316158e-7*V02*V033*V05 - 
      7.97474910818164786e-7*V013*V02*V04*V05 + 8.3079202034726953e-7*V022*V03*V04*V05 + 
      7.30771143336125926e-7*V01*V032*V04*V05 + 5.27975212689593233e-7*V01*V02*V042*V05 - 
      3.96192383729586111e-8*V014*V052 + 8.21761150132950242e-8*V023*V052 + 
      4.45765187284624921e-7*V01*V02*V03*V052 + 1.3232200882651688e-7*V012*V04*V052 - 
      2.37469976794500349e-8*V042*V052 - 1.36096627499663723e-8*V03*V053 + 
      1.80664243164243164e-9*V016*V06 - 3.92472994469522247e-7*V012*V023*V06 - 
      5.43036567342122898e-7*V013*V02*V03*V06 + 2.9825624725585578e-7*V022*V032*V06 + 
      1.71632696794454206e-7*V01*V033*V06 - 6.66349950204116871e-8*V014*V04*V06 + 
      1.29177689090543121e-7*V023*V04*V06 + 7.4981900942536933e-7*V01*V02*V03*V04*V06 + 
      1.1252040651039834e-7*V012*V042*V06 - 1.29392157703847877e-8*V043*V06 + 
      2.26994879836485229e-7*V01*V022*V05*V06 + 1.8517650554189128e-7*V012*V03*V05*V06 - 
      6.81809509230165907e-8*V03*V04*V05*V06 - 2.05992629199890677e-8*V02*V052*V06 + 
      4.8446145797846895e-8*V012*V02*V062 - 1.22055305562127859e-8*V032*V062 - 
      1.68156090978436291e-8*V02*V04*V062 - 9.37819813764003117e-9*V01*V05*V062 - 
      1.2330334595959596e-7*V013*V022*V07 - 3.92944728882228882e-8*V014*V03*V07 + 
      8.66334246474497019e-8*V023*V03*V07 + 2.31846393732372082e-7*V01*V02*V032*V07 + 
      1.6665107427975075e-7*V01*V022*V04*V07 + 1.36708868964792167e-7*V012*V03*V04*V07 - 
      2.50571343461910233e-8*V03*V042*V07 + 8.40820834182762287e-8*V012*V02*V05*V07 - 
      2.14821947819303148e-8*V032*V05*V07 - 3.02261663079119173e-8*V02*V04*V05*V07 - 
      8.22752243934466367e-9*V01*V052*V07 + 1.09705030084640262e-8*V013*V06*V07 - 
      2.17543301382968463e-8*V02*V03*V06*V07 - 1.38315040954813512e-8*V01*V04*V06*V07 - 
      2.39937340072932961e-9*V022*V072 - 4.31306178988452739e-9*V01*V03*V072 + 
      2.14767307517493529e-10*V06*V072 - 1.5356460668960669e-8*V014*V02*V08 + 
      7.81750055533643043e-9*V024*V08 + 9.19141145218555349e-8*V01*V022*V03*V08 + 
      3.68678479028521823e-8*V012*V032*V08 + 5.52415504398901925e-8*V012*V02*V04*V08 - 
      1.39583195853626023e-8*V032*V04*V08 - 9.5986425764438334e-9*V02*V042*V08 + 
      8.45095936083720086e-9*V013*V05*V08 - 1.6922158316131765e-8*V02*V03*V05*V08 - 
      1.07323878817334722e-8*V01*V04*V05*V08 - 4.15583968693321596e-9*V022*V06*V08 - 
      7.63161126818879759e-9*V01*V03*V06*V08 + 1.88392481149618117e-10*V062*V08 - 
      3.44611396259379405e-9*V01*V02*V07*V08 + 3.34163144371482397e-10*V05*V07*V08 - 
      2.87881903030246724e-10*V012*V082 + 1.07955611905981345e-10*V04*V082 - 
      6.32324851074851075e-10*V015*V09 + 1.08012321958230183e-8*V01*V023*V09 + 
      2.67003744013037314e-8*V012*V02*V03*V09 - 2.32715627508698703e-9*V033*V09 + 
      4.97490875478007831e-9*V013*V04*V09 - 9.88389262871376166e-9*V02*V03*V04*V09 - 
      3.15013205391853196e-9*V01*V042*V09 - 2.97133665297839776e-9*V022*V05*V09 - 
      5.32644539790241181e-9*V01*V03*V05*V09 - 2.74320110204596492e-9*V01*V02*V06*V09 + 2.65885815201741545e-10*V05*V06*V09 - 
      5.17205072695488891e-10*V012*V07*V09 + 1.95841700939319757e-10*V04*V07*V09 + 1.096083942566415e-10*V03*V08*V09 + 
      1.95715989957548972e-11*V02*V092 + 4.40590494971622423e-9*V012*V022*V10 + 
      2.16310006827776436e-9*V013*V03*V10 - 2.25902809958179182e-9*V02*V032*V10 - 
      1.54286144998219302e-9*V022*V04*V10 - 2.84471333483214826e-9*V01*V03*V04*V10 - 
      1.74167770044125429e-9*V01*V02*V05*V10 + 8.46077491142124186e-11*V052*V10 - 
      3.74968030744362659e-10*V012*V06*V10 + 1.40534807154727983e-10*V04*V06*V10 + 
      8.96631141416310435e-11*V03*V07*V10 + 3.53068698438173758e-11*V02*V08*V10 + 1.14933982587741202e-11*V01*V09*V10 + 
      6.56088693517206589e-10*V013*V02*V11 - 6.63592935339787407e-10*V022*V03*V11 - 
      5.86501686136304238e-10*V01*V032*V11 - 8.50965315512898983e-10*V01*V02*V04*V11 - 
      2.17109607466627468e-10*V012*V05*V11 + 8.25656605053924563e-11*V04*V05*V11 + 
      5.93973291009376551e-11*V03*V06*V11 + 2.66550932927223941e-11*V02*V07*V11 + 9.56771272405064299e-12*V01*V08*V11 - 
      4.07749009133190344e-14*V112 + 3.09963162291593664e-11*V014*V12 - 
      5.82036759080676063e-11*V023*V12 - 3.25941413725211455e-10*V01*V02*V03*V12 - 
      9.86366484114377131e-11*V012*V04*V12 + 1.84687031573766897e-11*V042*V12 + 
      3.1993273768693732e-11*V03*V05*V12 + 1.61905904420380971e-11*V02*V06*V12 + 6.62190665544894663e-12*V01*V07*V12 - 
      7.51070723847808455e-14*V10*V12 - 4.17471438054835888e-11*V01*V022*V13 - 
      3.44956371929249896e-11*V012*V03*V13 + 1.34089170629807992e-11*V03*V04*V13 + 
      8.16679779260448407e-12*V02*V05*V13 + 3.76684869312443917e-12*V01*V06*V13 - 5.91460018310722003e-14*V09*V13 - 
      8.42882283424509087e-12*V012*V02*V14 + 2.25096920533364482e-12*V032*V14 + 
      3.16777246847520571e-12*V02*V04*V14 + 1.75706830181942595e-12*V01*V05*V14 - 3.93062525938867e-14*V08*V14 - 
      4.8941551940777947e-13*V013*V15 + 1.01138475439219129e-12*V02*V03*V15 + 6.48114882843862155e-13*V01*V04*V15 - 
      2.21797318383885171e-14*V07*V15 + 1.05207689886298172e-13*V022*V16 + 1.90772171850787508e-13*V01*V03*V16 - 
      1.03716716845807155e-14*V06*V16 + 3.87037783205131723e-14*V01*V02*V17 - 4.05901125373965282e-15*V05*V17 + 
      3.12127244520267519e-15*V012*V18 - 1.25755614458890392e-15*V04*V18 - 3.20420480485781873e-16*V03*V19 - 
      5.52882397700956958e-17*V02*V20 - 8.29323596551435437e-18*V01*V21 + 7.53930542319486761e-21*V24) + 
   delta6*eps9*(7.65183075086203004e-8*V034*V04 + 
      2.36200532725392669e-7*V02*V032*V042 + 2.10474956623416007e-8*V022*V043 + 
      9.48188609885232979e-8*V01*V03*V043 + 1.57752553415679777e-7*V02*V033*V05 + 
      2.30720518966025502e-7*V022*V03*V04*V05 + 2.68114688535634692e-7*V01*V032*V04*V05 + 
      1.41720319635235602e-7*V01*V02*V042*V05 + 1.84747491222164425e-8*V023*V052 + 
      1.39170980163627222e-7*V01*V02*V03*V052 + 3.83673161377993311e-8*V012*V04*V052 - 
      2.2023741600738457e-8*V042*V052 - 1.42734771738816095e-8*V03*V053 + 
      8.35556661619725734e-8*V022*V032*V06 + 6.10311140773325647e-8*V01*V033*V06 + 
      1.45381579205108617e-8*V023*V04*V06 + 2.02131518633813996e-7*V01*V02*V03*V04*V06 + 
      2.94928838394835905e-8*V012*V042*V06 - 9.41028310842586455e-9*V043*V06 + 
      5.01333996971835441e-8*V01*V022*V05*V06 + 5.18720048632708141e-8*V012*V03*V05*V06 - 
      6.38881832797249232e-8*V03*V04*V05*V06 - 1.63995054407892911e-8*V02*V052*V06 + 
      1.04752648131110627e-8*V012*V02*V062 - 1.14954440383213866e-8*V032*V062 - 
      1.0373940513735223e-8*V02*V04*V062 - 7.1995374382365363e-9*V01*V05*V062 + 
      1.75949991640156595e-8*V023*V03*V07 + 6.49355534538774501e-8*V01*V02*V032*V07 + 
      3.29600741380036431e-8*V01*V022*V04*V07 + 3.5490127012847212e-8*V012*V03*V04*V07 - 
      2.19073568194984549e-8*V03*V042*V07 + 1.86392868465697597e-8*V012*V02*V05*V07 - 
      2.1179389152059458e-8*V032*V05*V07 - 2.23122299449632283e-8*V02*V04*V05*V07 - 
      6.59696094049781919e-9*V01*V052*V07 + 2.17904805955303932e-9*V013*V06*V07 - 
      1.62855136239927535e-8*V02*V03*V06*V07 - 9.93213689609712688e-9*V01*V04*V06*V07 - 
      1.39055312077097546e-9*V022*V072 - 3.23282820827403963e-9*V01*V03*V072 + 
      2.70691673066425051e-10*V06*V072 + 6.3274781919956039e-10*V024*V08 + 
      1.84578803786903694e-8*V01*V022*V03*V08 + 9.01661706319217472e-9*V012*V032*V08 + 
      1.08198370142036497e-8*V012*V02*V04*V08 - 1.23996749144077e-8*V032*V04*V08 - 
      5.5206283010412297e-9*V02*V042*V08 + 1.63325049124276223e-9*V013*V05*V08 - 
      1.28086576834036954e-8*V02*V03*V05*V08 - 7.75394468687961361e-9*V01*V04*V05*V08 - 
      2.01580544695901625e-9*V022*V06*V08 - 5.50766241918738492e-9*V01*V03*V06*V08 + 
      2.20755502650434519e-10*V062*V08 - 1.97947906813119159e-9*V01*V02*V07*V08 + 4.2591718923221259e-10*V05*V07*V08 - 
      1.583082256110483e-10*V012*V082 + 1.20675045280608754e-10*V04*V082 + 
      1.46624993033463829e-9*V01*V023*V09 + 4.95485603591345888e-9*V012*V02*V03*V09 - 
      2.10097487807609381e-9*V033*V09 + 8.58787732912382772e-10*V013*V04*V09 - 
      6.70950969054189387e-9*V02*V03*V04*V09 - 2.05870427299032854e-9*V01*V042*V09 - 
      1.68483925214565814e-9*V022*V05*V09 - 3.89132664126299495e-9*V01*V03*V05*V09 - 
      1.52386038876203899e-9*V01*V02*V06*V09 + 3.32066820728828843e-10*V05*V06*V09 - 
      2.85511375988624393e-10*V012*V07*V09 + 2.30855487854577695e-10*V04*V07*V09 + 
      1.32285455360861002e-10*V03*V08*V09 + 1.86224886360941026e-11*V02*V092 + 
      6.04575767974460785e-10*V012*V022*V10 + 3.40073869485634192e-10*V013*V03*V10 - 
      1.57213310981915158e-9*V02*V032*V10 - 6.71181261929988321e-10*V022*V04*V10 - 
      1.87883873030537691e-9*V01*V03*V04*V10 - 9.79242152784242622e-10*V01*V02*V05*V10 + 
      1.07336839085989354e-10*V052*V10 - 2.00661102814361779e-10*V012*V06*V10 + 
      1.54495629503149789e-10*V04*V06*V10 + 1.08715403184487502e-10*V03*V07*V10 + 3.19419553321709642e-11*V02*V08*V10 + 
      1.07962929205513937e-11*V01*V09*V10 + 7.75399910748494626e-11*V013*V02*V11 - 
      3.40440197433494265e-10*V022*V03*V11 - 3.83107217992122246e-10*V01*V032*V11 - 
      4.21791587392818139e-10*V01*V02*V04*V11 - 1.14751107550456822e-10*V012*V05*V11 + 
      9.62065320400714134e-11*V04*V05*V11 + 7.0053450335113439e-11*V03*V06*V11 + 2.5310464537020169e-11*V02*V07*V11 + 
      8.92101281804860605e-12*V01*V08*V11 - 5.43372820460500498e-14*V112 + 2.9520301170627968e-12*V014*V12 - 
      1.849485094293739e-11*V023*V12 - 1.63911361271335963e-10*V01*V02*V03*V12 - 
      4.73197850193238992e-11*V012*V04*V12 + 1.88537309952640217e-11*V042*V12 + 
      3.82877627980636899e-11*V03*V05*V12 + 1.42638050703933002e-11*V02*V06*V12 + 6.20117454352671344e-12*V01*V07*V12 - 
      9.861716111939824e-14*V10*V12 - 1.52801222059334661e-11*V01*V022*V13 - 
      1.59005664305371908e-11*V012*V03*V13 + 1.46902340825414441e-11*V03*V04*V13 + 
      7.63906846126070317e-12*V02*V05*V13 + 3.41839908555666496e-12*V01*V06*V13 - 7.88028307646789415e-14*V09*V13 - 
      3.00382011911653008e-12*V012*V02*V14 + 2.51465121876614934e-12*V032*V14 + 
      2.55827813001998466e-12*V02*V04*V14 + 1.60913386023879783e-12*V01*V05*V14 - 5.13051632836443249e-14*V08*V14 - 
      1.55370006161199832e-13*V013*V15 + 8.81293201614361267e-13*V02*V03*V15 + 5.4133499646664708e-13*V01*V04*V15 - 
      2.95144707744340306e-14*V07*V15 + 6.57733026082412621e-14*V022*V16 + 1.60419531361438826e-13*V01*V03*V16 - 
      1.32723943151368635e-14*V06*V16 + 2.52476260011949726e-14*V01*V02*V17 - 5.35350999490221159e-15*V05*V17 + 
      1.9421250770149979e-15*V012*V18 - 1.50866527721744764e-15*V04*V18 - 4.01091048513966957e-16*V03*V19 - 
      5.36128385649412808e-17*V02*V20 - 8.04192578474119211e-18*V01*V21 + 1.00524072309264901e-20*V24) + 
   delta2*eps11*(-5.19942132872027052e-7*V024*V032 - 
      2.12909656114021193e-6*V01*V022*V033 - 4.30973118225102352e-7*V012*V034 - 
      6.80612866459427306e-8*V025*V04 - 2.60643787429501715e-6*V01*V023*V03*V04 - 
      3.48396023619237905e-6*V012*V02*V032*V04 + 2.92634394072278254e-7*V034*V04 - 
      1.17616437060881505e-6*V012*V022*V042 - 5.9607155961322628e-7*V013*V03*V042 + 
      1.1082481523457393e-6*V02*V032*V042 + 1.95584655809718057e-7*V022*V043 + 
      4.54467079326658575e-7*V01*V03*V043 - 3.11965279723216231e-7*V01*V024*V05 - 
      1.86285023214586707e-6*V012*V022*V03*V05 - 4.72547688569513966e-7*V013*V032*V05 + 
      6.54479977676270082e-7*V02*V033*V05 - 6.53448229093070363e-7*V013*V02*V04*V05 + 
      1.19518228764965654e-6*V022*V03*V04*V05 + 1.16986246668154153e-6*V01*V032*V04*V05 + 
      7.49205341404634316e-7*V01*V02*V042*V05 - 3.07473335747145271e-8*V014*V052 + 
      1.0472435081384564e-7*V023*V052 + 6.53677756463315131e-7*V01*V02*V03*V052 + 
      1.8926780842484624e-7*V012*V04*V052 - 4.49111369355517819e-8*V042*V052 - 
      2.66308862018481758e-8*V03*V053 - 2.7752321899147296e-7*V012*V023*V06 - 
      4.30835469277929595e-7*V013*V02*V03*V06 + 4.35860386828621345e-7*V022*V032*V06 + 
      2.74950060854005765e-7*V01*V033*V06 - 5.11709961114723019e-8*V014*V04*V06 + 
      1.49373083789906074e-7*V023*V04*V06 + 1.07553785650458347e-6*V01*V02*V03*V04*V06 + 
      1.58959003141207273e-7*V012*V042*V06 - 2.34589188319894784e-8*V043*V06 + 
      2.91743367359030291e-7*V01*V022*V05*V06 + 2.64325940625106125e-7*V012*V03*V05*V06 - 
      1.30477649586021645e-7*V03*V04*V05*V06 - 3.63982154243717568e-8*V02*V052*V06 + 
      6.21909667103265376e-8*V012*V02*V062 - 2.35866641208131788e-8*V032*V062 - 
      2.83830922891645865e-8*V02*V04*V062 - 1.64809807039780169e-8*V01*V05*V062 - 
      8.3627470780248558e-8*V013*V022*V07 - 2.86653932487265821e-8*V014*V03*V07 + 
      1.09769440570337318e-7*V023*V03*V07 + 3.35492824806258513e-7*V01*V02*V032*V07 + 
      2.09044847038933562e-7*V01*V022*V04*V07 + 1.92355750008498608e-7*V012*V03*V04*V07 - 
      4.72618338936615608e-8*V03*V042*V07 + 1.07650164092011664e-7*V012*V02*V05*V07 - 
      4.18304532027872241e-8*V032*V05*V07 - 5.2495110872022949e-8*V02*V04*V05*V07 - 
      1.45549356985976133e-8*V01*V052*V07 + 1.36847681855268223e-8*V013*V06*V07 - 
      3.83220680268478737e-8*V02*V03*V06*V07 - 2.39667134245575088e-8*V01*V04*V06*V07 - 
      3.78370234356419949e-9*V022*V072 - 7.57514185448521646e-9*V01*V03*V072 + 
      4.26147160475657499e-10*V06*V072 - 9.63542630209296876e-9*V014*V02*V08 + 
      7.72535223236800164e-9*V024*V08 + 1.17120217666946775e-7*V01*V022*V03*V08 + 
      5.1466665825082803e-8*V012*V032*V08 + 6.95025549042676727e-8*V012*V02*V04*V08 - 
      2.66734083953653464e-8*V032*V04*V08 - 1.59763800882102491e-8*V02*V042*V08 + 
      1.04776967236360716e-8*V013*V05*V08 - 2.9909484601287233e-8*V02*V03*V05*V08 - 
      1.86295937434687129e-8*V01*V04*V05*V08 - 6.38461798617259437e-9*V022*V06*V08 - 
      1.33424917612395601e-8*V01*V03*V06*V08 + 3.69473760663051925e-10*V062*V08 - 
      5.46385122184290841e-9*V01*V02*V07*V08 + 6.65193360464561812e-10*V05*V07*V08 - 
      4.51929472006984006e-10*V012*V082 + 2.09622080250661849e-10*V04*V082 - 
      3.61328486328486328e-10*V015*V09 + 1.16554442820539537e-8*V01*V023*V09 + 
      3.32813562272012319e-8*V012*V02*V03*V09 - 4.49623559158400142e-9*V033*V09 + 
      6.05996959616532446e-9*V013*V04*V09 - 1.71008894358145883e-8*V02*V03*V04*V09 - 
      5.36744415768178965e-9*V01*V042*V09 - 4.68188403056017865e-9*V022*V05*V09 - 
      9.32814612085776875e-9*V01*V03*V05*V09 - 4.32938137442453789e-9*V01*V02*V06*V09 + 5.27480366322598665e-10*V05*V06*V09 - 
      8.11379645939557258e-10*V012*V07*V09 + 3.83426984261945439e-10*V04*V07*V09 + 2.1768055216367305e-10*V03*V08*V09 + 
      3.5427496549520743e-11*V02*V092 + 4.80738104563676459e-9*V012*V022*V10 + 
      2.57712229219582161e-9*V013*V03*V10 - 3.97089667710882205e-9*V02*V032*V10 - 
      2.32086891334837589e-9*V022*V04*V10 - 4.89421578838019756e-9*V01*V03*V04*V10 - 
      2.7556254125600797e-9*V01*V02*V05*V10 + 1.68525837843121799e-10*V052*V10 - 
      5.86367513038126459e-10*V012*V06*V10 + 2.72167713347360047e-10*V04*V06*V10 + 
      1.78212007585668558e-10*V03*V07*V10 + 6.34254219220624266e-11*V02*V08*V10 + 2.07887313037605561e-11*V01*V09*V10 + 
      6.93727077509757248e-10*V013*V02*V11 - 1.04023300630045484e-9*V022*V03*V11 - 
      1.01343227212338563e-9*V01*V032*V11 - 1.31535377883894447e-9*V01*V02*V04*V11 - 
      3.38479662243844452e-10*V012*V05*V11 + 1.61601702895817855e-10*V04*V05*V11 + 
      1.17549811516796611e-10*V03*V06*V11 + 4.82422574380474134e-11*V02*V07*V11 + 1.72881408123471871e-11*V01*V08*V11 - 
      8.15490478960957494e-14*V112 + 3.09963162291593664e-11*V014*V12 - 
      7.7737976854129163e-11*V023*V12 - 5.09456252588209318e-10*V01*V02*V03*V12 - 
      1.51223846568212385e-10*V012*V04*V12 + 3.5268177555702946e-11*V042*V12 + 
      6.35409685554323088e-11*V03*V05*V12 + 2.89625228485092606e-11*V02*V06*V12 + 1.19713052157937093e-11*V01*V07*V12 - 
      1.49876201115561999e-13*V10*V12 - 5.76407185857435255e-11*V01*V022*V13 - 
      5.26657709884619069e-11*V012*V03*V13 + 2.61749907254696341e-11*V03*V04*V13 + 
      1.47714796482632382e-11*V02*V05*V13 + 6.77909855989667958e-12*V01*V06*V13 - 1.18290495801059762e-13*V09*V13 - 
      1.15828339593174474e-11*V012*V02*V14 + 4.4488998996354753e-12*V032*V14 + 
      5.57193834952672406e-12*V02*V04*V14 + 3.16827187206643814e-12*V01*V05*V14 - 7.8365081937796196e-14*V08*V14 - 
      6.52554025877039293e-13*V013*V15 + 1.82291559014488683e-12*V02*V03*V15 + 1.14846179197084033e-12*V01*V04*V15 - 
      4.43579558156923953e-14*V07*V15 + 1.68539463826292008e-13*V022*V16 + 3.40815206372174774e-13*V01*V03*V16 - 
      2.06130641714486236e-14*V06*V16 + 6.27028953436270749e-14*V01*V02*V17 - 8.11651464639466667e-15*V05*V17 + 
      4.9940359123242803e-15*V012*V18 - 2.46806702333707186e-15*V04*V18 - 6.39333099886924773e-16*V03*V19 - 
      1.00524072309264901e-16*V02*V20 - 1.50786108463897352e-17*V01*V21 + 1.50786108463897352e-20*V24) + 
   delta4*eps10*(-1.17745291769762669e-7*V024*V032 - 
      5.79433243123719314e-7*V01*V022*V033 - 1.24555091072948216e-7*V012*V034 - 
      1.48202033122668043e-9*V025*V04 - 5.98870803897258924e-7*V01*V023*V03*V04 - 
      9.19068255377779187e-7*V012*V02*V032*V04 + 2.14311482438524922e-7*V034*V04 - 
      2.78216052025575835e-7*V012*V022*V042 - 1.52528798362131695e-7*V013*V03*V042 + 
      7.28419279216334149e-7*V02*V032*V042 + 9.77137892841674354e-8*V022*V043 + 
      2.94835574485628952e-7*V01*V03*V043 - 7.06471750618576015e-8*V01*V024*V05 - 
      4.70752516883469264e-7*V012*V022*V03*V05 - 1.22944598391026962e-7*V013*V032*V05 + 
      4.53829576895904121e-7*V02*V033*V05 - 1.57814517933565553e-7*V013*V02*V04*V05 + 
      7.3417265658745584e-7*V022*V03*V04*V05 + 7.89349551944867849e-7*V01*V032*V04*V05 + 
      4.54844988100998839e-7*V01*V02*V042*V05 - 7.17495137137994281e-9*V014*V052 + 
      6.06452340719542971e-8*V023*V052 + 4.1961331835354361e-7*V01*V02*V03*V052 + 
      1.18468274871461146e-7*V012*V04*V052 - 4.026399605523601e-8*V042*V052 - 
      2.49344252732416599e-8*V03*V053 - 6.40105840171977738e-8*V012*V023*V06 - 
      1.01929045381426334e-7*V013*V02*V03*V06 + 2.68121481016361191e-7*V022*V032*V06 + 
      1.83131423420507804e-7*V01*V033*V06 - 1.15108932073217788e-8*V014*V04*V06 + 
      6.94660406346006512e-8*V023*V04*V06 + 6.53241508264072845e-7*V01*V02*V03*V04*V06 + 
      9.57025503606288698e-8*V012*V042*V06 - 1.94107261144450045e-8*V043*V06 + 
      1.67111827140421912e-7*V01*V022*V05*V06 + 1.63286817054226796e-7*V012*V03*V05*V06 - 
      1.17292675685637981e-7*V03*V04*V05*V06 - 3.1097029829286499e-8*V02*V052*V06 + 
      3.52784186586804856e-8*V012*V02*V062 - 2.12175240295383638e-8*V032*V062 - 
      2.22496709765014992e-8*V02*V04*V062 - 1.3892605532982901e-8*V01*V05*V062 - 
      1.7584653001319668e-8*V013*V022*V07 - 6.08236285319618653e-9*V014*V03*V07 + 
      6.00239001444391008e-8*V023*V03*V07 + 2.05120027408751926e-7*V01*V02*V032*V07 + 
      1.13262007082035093e-7*V01*V022*V04*V07 + 1.1481891901160303e-7*V012*V03*V04*V07 - 
      4.13685034628376481e-8*V03*V042*V07 + 6.13554156716213205e-8*V012*V02*V05*V07 - 
      3.81989797524358541e-8*V032*V05*V07 - 4.35034561212444647e-8*V02*V04*V05*V07 - 
      1.24465574767207969e-8*V01*V052*V07 + 7.51825841670807435e-9*V013*V06*V07 - 
      3.18774024187369472e-8*V02*V03*V06*V07 - 1.9667871997796414e-8*V01*V04*V06*V07 - 
      2.88384332637313435e-9*V022*V072 - 6.2963852833022967e-9*V01*V03*V072 + 
      4.1939913591699306e-10*V06*V072 - 1.80664243164243164e-9*V014*V02*V08 + 
      3.19339934526286845e-9*V024*V08 + 6.40864146422619812e-8*V01*V022*V03*V08 + 
      3.00955337592388246e-8*V012*V032*V08 + 3.77117630268890773e-8*V012*V02*V04*V08 - 
      2.34923487086251406e-8*V032*V04*V08 - 1.21932300356941412e-8*V02*V042*V08 + 
      5.71217827651651181e-9*V013*V05*V08 - 2.5025281349342178e-8*V02*V03*V05*V08 - 
      1.53470257143579543e-8*V01*V04*V05*V08 - 4.61685998131022047e-9*V022*V06*V08 - 
      1.09728674070220722e-8*V01*V03*V06*V08 + 3.55652899273829005e-10*V062*V08 - 
      4.15881740242510684e-9*V01*V02*V07*V08 + 6.57949166107055085e-10*V05*V07*V08 - 
      3.39306748576642572e-10*V012*V082 + 1.98294607994327916e-10*V04*V082 - 
      6.02214143880810547e-11*V015*V09 + 5.56862526910962952e-9*V01*V023*V09 + 
      1.77171569817169724e-8*V012*V02*V03*V09 - 3.97927241519096207e-9*V033*V09 + 
      3.15622625744591197e-9*V013*V04*V09 - 1.37407137803524885e-8*V02*V03*V04*V09 - 
      4.2604639747773317e-9*V01*V042*V09 - 3.55753189027397834e-9*V022*V05*V09 - 
      7.70861279121372267e-9*V01*V03*V05*V09 - 3.26262256487220193e-9*V01*V02*V06*V09 + 5.18422609402698898e-10*V05*V06*V09 - 
      6.09370338393160972e-10*V012*V07*V09 + 3.68525742913893642e-10*V04*V07*V09 + 
      2.10984752273151009e-10*V03*V08*V09 + 3.17026393750257638e-11*V02*V092 + 
      2.31409640876552641e-9*V012*V022*V10 + 1.29948365753104315e-9*V013*V03*V10 - 
      3.22012106269394711e-9*V02*V032*V10 - 1.61126775629484608e-9*V022*V04*V10 - 
      3.90065748563062876e-9*V01*V03*V04*V10 - 2.08963724511459505e-9*V01*V02*V05*V10 + 
      1.66708646337348923e-10*V052*V10 - 4.36754705462371277e-10*V012*V06*V10 + 
      2.56156280440564972e-10*V04*V06*V10 + 1.72991833207666797e-10*V03*V07*V10 + 5.59156137952565482e-11*V02*V08*V10 + 
      1.85371567607405689e-11*V01*V09*V10 + 3.18819252642782055e-10*V013*V02*V11 - 
      7.60905183923706026e-10*V022*V03*V11 - 8.04406011184446243e-10*V01*V032*V11 - 
      9.51332212403664011e-10*V01*V02*V04*V11 - 2.51421963541570156e-10*V012*V05*V11 + 
      1.55046124435856297e-10*V04*V05*V11 + 1.13147716831517197e-10*V03*V06*V11 + 4.31537972541215944e-11*V02*V07*V11 + 
      1.53827773885756874e-11*V01*V08*V11 - 8.15425138313956472e-14*V112 + 1.32841355267825856e-11*V014*V12 - 
      4.86248930710779778e-11*V023*V12 - 3.70489767763205647e-10*V01*V02*V03*V12 - 
      1.0830510193769752e-10*V012*V04*V12 + 3.23502918471370033e-11*V042*V12 + 
      6.15313315114544086e-11*V03*V05*V12 + 2.53281964472471377e-11*V02*V06*V12 + 1.06661509229663684e-11*V01*V07*V12 - 
      1.4921036621479354e-13*V10*V12 - 3.77044162451691691e-11*V01*V022*V13 - 
      3.72150007257613897e-11*V012*V03*V13 + 2.45643216615985292e-11*V03*V04*V13 + 
      1.31821739602392982e-11*V02*V05*V13 + 5.98357638370737909e-12*V01*V06*V13 - 1.18277427671659557e-13*V09*V13 - 
      7.51602404804804186e-12*V012*V02*V14 + 4.20331355953960259e-12*V032*V14 + 
      4.72524580166540459e-12*V02*V04*V14 + 2.80845158458347374e-12*V01*V05*V14 - 7.78802878450727144e-14*V08*V14 - 
      4.07846266173149558e-13*V013*V15 + 1.58477406284423828e-12*V02*V03*V15 + 9.84657414046603933e-13*V01*V04*V15 - 
      4.43448876862921908e-14*V07*V15 + 1.31287655206213858e-13*V022*V16 + 2.92872461613861683e-13*V01*V03*V16 - 
      2.03625581832539355e-14*V06*V16 + 4.95241894638824463e-14*V01*V02*V17 - 8.10344651699446223e-15*V05*V17 + 
      3.88425015402999579e-15*V012*V18 - 2.3840288988865264e-15*V04*V18 - 6.26264970486720336e-16*V03*V19 - 
      9.04716650783384113e-17*V02*V20 - 1.35707497617507617e-17*V01*V21 + 1.50786108463897352e-20*V24) + 
   6.4469502843844734e-26*delta24*V24 + 3.86817017063068404e-25*delta22*eps*V24 + 
   delta22*eps2*(-1.85682880046129965e-20*V122 - 4.02312906766614924e-20*V11*V13 - 
      2.68208604511076616e-20*V10*V14 - 2.10735332115845913e-20*V09*V15 - 9.91695680545157236e-21*V08*V16 - 
      5.57828820306650945e-21*V07*V17 - 1.76156469570521351e-21*V06*V18 - 6.85052937218694143e-22*V05*V19 - 
      1.30486273755941742e-22*V04*V20 - 3.26215684389854354e-23*V03*V21 - 2.83665812512916829e-24*V02*V22 - 
      3.86817017063068404e-25*V01*V23 + 3.581639046880263e-27*V26) + 
   delta20*eps3*(-2.04251168050742961e-19*V122 - 4.42544197443276416e-19*V11*V13 - 
      2.95029464962184278e-19*V10*V14 - 2.31808865327430504e-19*V09*V15 - 1.09086524859967296e-19*V08*V16 - 
      6.1361170233731604e-20*V07*V17 - 1.93772116527573486e-20*V06*V18 - 7.53558230940563557e-21*V05*V19 - 
      1.43534901131535916e-21*V04*V20 - 3.58837252828839789e-22*V03*V21 - 3.12032393764208512e-23*V02*V22 - 
      4.25498718769375244e-24*V01*V23 + 1.96990147578414465e-26*V26) + 
   delta18*eps4*(3.30176453396809709e-15*V072*V08 + 1.9052198711412549e-15*V06*V082 + 
      4.99426568163241577e-15*V06*V07*V09 + 3.85205862296277994e-15*V05*V08*V09 + 9.77496079135291902e-16*V04*V092 + 
      1.16561970017120193e-15*V062*V10 + 3.11705043416568606e-15*V05*V07*V10 + 1.2063126956394299e-15*V04*V08*V10 + 
      8.65847342823801684e-16*V03*V09*V10 + 6.80933335986972465e-17*V02*V102 + 1.90690144207783147e-15*V05*V06*V11 + 
      1.27963123086801849e-15*V04*V07*V11 + 7.00374295084141807e-16*V03*V08*V11 + 1.78666912011260665e-16*V02*V09*V11 + 
      4.72280368812982737e-17*V01*V10*V11 + 4.95894387253631874e-16*V052*V12 + 4.97254203795415384e-16*V04*V06*V12 + 
      4.72280368812982737e-16*V03*V07*V12 + 9.17573287979509317e-17*V02*V08*V12 + 3.93566974010818947e-17*V01*V09*V12 - 
      1.4057404994796687e-18*V122 + 3.4451610061831267e-16*V04*V05*V13 + 2.4447454385613224e-16*V03*V06*V13 + 
      8.24616516975049223e-17*V02*V07*V13 + 2.6937472887851608e-17*V01*V08*V13 - 2.991109002482224e-18*V11*V13 + 
      3.79960143891801628e-17*V042*V14 + 1.07749891551406432e-16*V03*V05*V14 + 2.70991624009839705e-17*V02*V06*V14 + 
      1.53928416502009188e-17*V01*V07*V14 - 2.03780233210046255e-18*V10*V14 + 3.28110572017440638e-17*V03*V04*V15 + 
      1.64923303395009845e-17*V02*V05*V15 + 6.98498696731806401e-18*V01*V06*V15 - 1.57822438943280254e-18*V09*V15 + 
      4.36561685457379e-18*V032*V16 + 3.08401471364043177e-18*V02*V04*V16 + 2.619370112744274e-18*V01*V05*V16 - 
      7.61557606853427812e-19*V08*V16 + 1.21267134849271945e-18*V02*V03*V17 + 7.2377332062670729e-19*V01*V04*V17 - 
      4.23828636298205446e-19*V07*V17 + 4.72303577834006521e-20*V022*V18 + 1.60838515694823842e-19*V01*V03*V18 - 
      1.3767011045783136e-19*V06*V18 + 2.12749359384687622e-20*V01*V02*V19 - 5.31660649102334368e-20*V05*V19 + 
      1.06374679692343811e-21*V012*V20 - 1.04459935457881622e-20*V04*V20 - 2.60263382980601191e-21*V03*V21 - 
      2.34024295323156384e-22*V02*V22 - 3.19124039077031433e-23*V01*V23 + 9.84950737892072324e-26*V26) + 
   delta16*eps5*(3.91494937599074369e-14*V072*V08 + 2.38059997491145151e-14*V06*V082 + 
      5.90467869651332489e-14*V06*V07*V09 + 4.56744093865586764e-14*V05*V08*V09 + 1.15308333779477952e-14*V04*V092 + 
      1.45811602942764586e-14*V062*V10 + 3.71015586399999022e-14*V05*V07*V10 + 1.51019979579681752e-14*V04*V08*V10 + 
      1.03059885111110839e-14*V03*V09*V10 + 8.54602572137778286e-16*V02*V102 + 2.2545136841232695e-14*V05*V06*V11 + 
      1.50949091493134774e-14*V04*V07*V11 + 8.30443807028339571e-15*V03*V08*V11 + 2.10380288893259433e-15*V02*V09*V11 + 
      5.62144827878786397e-16*V01*V10*V11 + 5.93420283413512809e-15*V052*V12 + 6.24345874560816188e-15*V04*V06*V12 + 
      5.65162174679536008e-15*V03*V07*V12 + 1.15366349562739614e-15*V02*V08*V12 + 4.7096847889961334e-16*V01*V09*V12 - 
      7.4883685401212359e-18*V122 + 4.06401400173824391e-15*V04*V05*V13 + 2.8904021591323968e-15*V03*V06*V13 + 
      9.7098594873812046e-16*V02*V07*V13 + 3.19401464241669066e-16*V01*V08*V13 - 1.54868604273257256e-17*V11*V13 + 
      4.80337674442322357e-16*V042*V14 + 1.29973306683884008e-15*V03*V05*V14 + 3.42781767840608697e-16*V02*V06*V14 + 
      1.85676152405548583e-16*V01*V07*V14 - 1.09149240792333788e-17*V10*V14 + 3.8704895254649942e-16*V03*V04*V15 + 
      1.94197189747624092e-16*V02*V05*V15 + 8.25829188323541943e-17*V01*V06*V15 - 8.26678058267486846e-18*V09*V15 + 
      5.33575393336796556e-17*V032*V16 + 3.95203209992995727e-17*V02*V04*V16 + 3.20145236002077934e-17*V01*V05*V16 - 
      4.14491066914811507e-18*V08*V16 + 1.42792051285017715e-17*V02*V03*V17 + 8.53784454146689896e-18*V01*V04*V17 - 
      2.2701207643783708e-18*V07*V17 + 6.22930124278365357e-19*V022*V18 + 2.01718305100591569e-18*V01*V03*V18 - 
      7.68578335713122504e-19*V06*V18 + 2.50512370675469675e-19*V01*V02*V19 - 2.93865371384084395e-19*V05*V19 + 
      1.43605817584664145e-20*V012*V20 - 6.02825309816512377e-20*V04*V20 - 1.49509612307589226e-20*V03*V21 - 
      1.40414577193893831e-21*V02*V22 - 1.9147442344621886e-22*V01*V23 + 4.43227832051432546e-25*V26) + 
   delta14*eps6*(-1.54203318660389367e-12*V054 - 1.20222768349253792e-11*V04*V052*V06 - 
      2.20810148842809719e-12*V042*V062 - 8.49950385609556685e-12*V03*V05*V062 - 
      5.19154254600674884e-13*V02*V063 - 8.03458254146862924e-12*V042*V05*V07 - 
      8.72037364191043845e-12*V03*V052*V07 - 1.14497874618336945e-11*V03*V04*V06*V07 - 
      5.72782625570846122e-12*V02*V05*V06*V07 - 1.21421483658508098e-12*V01*V062*V07 - 
      2.04958885084975925e-12*V032*V072 - 1.89411468817236972e-12*V02*V04*V072 - 
      1.21671837233061723e-12*V01*V05*V072 - 7.53220636853102185e-13*V043*V08 - 
      8.7898649136415848e-12*V03*V04*V05*V08 - 2.21582514890753923e-12*V02*V052*V08 - 
      3.07934896700958681e-12*V032*V06*V08 - 1.58993354704801313e-12*V02*V04*V06*V08 - 
      1.84760938020575209e-12*V01*V05*V06*V08 - 2.11030966562622784e-12*V02*V03*V07*V08 - 
      1.25569498766308354e-12*V01*V04*V07*V08 + 2.52902464207594821e-13*V072*V08 - 
      7.05860041184046148e-14*V022*V082 - 3.2938676181467125e-13*V01*V03*V082 + 
      1.65322644154544154e-13*V06*V082 - 2.2318284837412859e-12*V03*V042*V09 - 
      2.36584127953175572e-12*V032*V05*V09 - 2.20980046953443135e-12*V02*V04*V05*V09 - 
      7.00410678164405918e-13*V01*V052*V09 - 1.5910628488079059e-12*V02*V03*V06*V09 - 
      9.54148955152807872e-13*V01*V04*V06*V09 - 2.55178500255161524e-13*V022*V07*V09 - 
      6.50858439786300493e-13*V01*V03*V07*V09 + 3.8183588904119501e-13*V06*V07*V09 - 1.75859138802185653e-13*V01*V02*V08*V09 + 
      2.96791441398816354e-13*V05*V08*V09 - 1.20920740210491967e-14*V012*V092 + 
      7.51242092489750279e-14*V04*V092 - 9.72977199189485451e-13*V032*V04*V10 - 
      2.45301962166125281e-13*V02*V042*V10 - 9.89880319917499004e-13*V02*V03*V05*V10 - 
      5.8378631951369127e-13*V01*V04*V05*V10 - 8.53406564866380643e-14*V022*V06*V10 - 
      4.02592159254841163e-13*V01*V03*V06*V10 + 1.01860733210772983e-13*V062*V10 - 
      1.41411474273928429e-13*V01*V02*V07*V10 + 2.42414016797913357e-13*V05*V07*V10 - 
      2.05587945175887093e-14*V012*V08*V10 + 1.06087349072260034e-13*V04*V08*V10 + 
      6.81155107853280148e-14*V03*V09*V10 + 6.10328012679467652e-15*V02*V102 - 
      1.38073789602302242e-13*V033*V11 - 4.0178190355171479e-13*V02*V03*V04*V11 - 
      1.21736099113161049e-13*V01*V042*V11 - 9.74317910065162182e-14*V022*V05*V11 - 
      2.4234761532458389e-13*V01*V03*V05*V11 - 8.67852462986130488e-14*V01*V02*V06*V11 + 1.47517807276666873e-13*V05*V06*V11 - 
      1.56321251096880647e-14*V012*V07*V11 + 9.89245613535953171e-14*V04*V07*V11 + 
      5.49103892488515527e-14*V03*V08*V11 + 1.39755139279545053e-14*V02*V09*V11 + 3.80029519523811889e-15*V01*V10*V11 - 
      7.36486711745073699e-14*V02*V032*V12 - 1.74606292638300763e-14*V022*V04*V12 - 
      8.55307773599781761e-14*V01*V03*V04*V12 - 4.4189202704704422e-14*V01*V02*V05*V12 + 
      3.94736305220268869e-14*V052*V12 - 8.45492335115312311e-15*V012*V06*V12 + 
      4.4391093491512922e-14*V04*V06*V12 + 3.7804669162617643e-14*V03*V07*V12 + 8.28983170499228742e-15*V02*V08*V12 + 
      3.20307292991376506e-15*V01*V09*V12 - 3.2885668253304498e-17*V122 - 1.2491255257245669e-14*V022*V03*V13 - 
      1.45258624807851906e-14*V01*V032*V13 - 1.5453150136604415e-14*V01*V02*V04*V13 - 
      4.02482301674727183e-15*V012*V05*V13 + 2.71021119581024799e-14*V04*V05*V13 + 
      1.93550835918877473e-14*V03*V06*V13 + 6.52510369708493555e-15*V02*V07*V13 + 2.17272708614309219e-15*V01*V08*V13 - 
      6.59474565261144479e-17*V11*V13 - 2.87957108924612235e-16*V023*V14 - 4.61600412862594148e-15*V01*V02*V03*V14 - 
      1.28347603729081856e-15*V012*V04*V14 + 3.49836247258676175e-15*V042*V14 + 
      8.9090194133122693e-15*V03*V05*V14 + 2.5090229770134993e-15*V02*V06*V14 + 1.28626433039491428e-15*V01*V07*V14 - 
      4.82088307689125368e-17*V10*V14 - 3.56893007349876257e-16*V01*V022*V15 - 
      3.43152802723375592e-16*V012*V03*V15 + 2.65553069586017059e-15*V03*V04*V15 + 
      1.33496733924397574e-15*V02*V05*V15 + 5.71968568230076054e-16*V01*V06*V15 - 3.56303053376302519e-17*V09*V15 - 
      5.10853761754511918e-17*V012*V02*V16 + 3.79444864943371915e-16*V032*V16 + 
      2.98429483390964099e-16*V02*V04*V16 + 2.28782576606636451e-16*V01*V05*V16 - 1.86185474371915526e-17*V08*V16 - 
      1.76156469570521351e-18*V013*V17 + 1.01462296984151374e-16*V02*V03*V17 + 6.08748251981782081e-17*V01*V04*V17 - 
      1.00166653385498626e-17*V07*V17 + 4.92472217103674908e-18*V022*V18 + 1.50805255906241974e-17*V01*V03*V18 - 
      3.54738281838028141e-18*V06*V18 + 1.85730190742832294e-18*V01*V02*V19 - 1.34095921220168608e-18*V05*V19 + 
      1.14884654067731316e-19*V012*V20 - 2.88488131325636416e-19*V04*V20 - 7.11646607141780096e-20*V03*V21 - 
      7.02072885969469153e-21*V02*V22 - 9.57372117231094299e-22*V01*V23 + 1.77291132820573018e-24*V26) + 
   delta12*eps7*(-1.66065112403496242e-11*V054 - 1.32286910338566607e-10*V04*V052*V06 - 
      2.9624444362982876e-11*V042*V062 - 9.40202849236138478e-11*V03*V05*V062 - 
      6.99935888436239844e-12*V02*V063 - 8.81082588939342752e-11*V042*V05*V07 - 
      9.41948082625692053e-11*V03*V052*V07 - 1.25987533655777721e-10*V03*V04*V06*V07 - 
      6.28954061798325235e-11*V02*V05*V06*V07 - 1.34314692748019783e-11*V01*V062*V07 - 
      2.22227074615757362e-11*V032*V072 - 2.07868960496107846e-11*V02*V04*V072 - 
      1.32336899509046145e-11*V01*V05*V072 - 1.0160231656237466e-11*V043*V08 - 
      9.74169938630722944e-11*V03*V04*V05*V08 - 2.44607475427185688e-11*V02*V052*V08 - 
      3.43735457862127048e-11*V032*V06*V08 - 2.15689127816977362e-11*V02*V04*V06*V08 - 
      2.06241274717276229e-11*V01*V05*V06*V08 - 2.32959500406843512e-11*V02*V03*V07*V08 - 
      1.39167134090103278e-11*V01*V04*V07*V08 + 1.14358065959054919e-12*V072*V08 - 
      9.72492181709934615e-13*V022*V082 - 3.72143225233535432e-12*V01*V03*V082 + 
      8.06832513790939047e-13*V06*V082 - 2.44745163594261876e-11*V03*V042*V09 - 
      2.57321749045367505e-11*V032*V05*V09 - 2.42513787245459154e-11*V02*V04*V05*V09 - 
      7.64803272769843236e-12*V01*V052*V09 - 1.74709461610645899e-11*V02*V03*V06*V09 - 
      1.04989611379814768e-11*V01*V04*V06*V09 - 2.81955869038106904e-12*V022*V07*V09 - 
      7.15964568449305329e-12*V01*V03*V07*V09 + 1.73526454756329624e-12*V06*V07*V09 - 1.94132917005702927e-12*V01*V02*V08*V09 + 
      1.35608337396241624e-12*V05*V08*V09 - 1.37908629566892789e-13*V012*V092 + 
      3.46474443578993563e-13*V04*V092 - 1.09131825067883835e-11*V032*V04*V10 - 
      3.37043773226947542e-12*V02*V042*V10 - 1.10387250589529224e-11*V02*V03*V05*V10 - 
      6.54790950407303009e-12*V01*V04*V05*V10 - 1.18352037247364295e-12*V022*V06*V10 - 
      4.56141900382685922e-12*V01*V03*V06*V10 + 5.0179374673263931e-13*V062*V10 - 
      1.57696072270756034e-12*V01*V02*V07*V10 + 1.11318188386107411e-12*V05*V07*V10 - 
      2.37735166353798372e-13*V012*V08*V10 + 5.27507721727871024e-13*V04*V08*V10 + 
      3.19132526809428339e-13*V03*V09*V10 + 3.11787899621623516e-14*V02*V102 - 
      1.51881168562532466e-12*V033*V11 - 4.40934158628107553e-12*V02*V03*V04*V11 - 
      1.33497361960506478e-12*V01*V042*V11 - 1.07655877269095363e-12*V022*V05*V11 - 
      2.68644112176895661e-12*V01*V03*V05*V11 - 9.52960699694432174e-13*V01*V02*V06*V11 + 6.84129584149527379e-13*V05*V06*V11 - 
      1.79020773765738028e-13*V012*V07*V11 + 4.60774808337594117e-13*V04*V07*V11 + 
      2.58509306778680506e-13*V03*V08*V11 + 6.66112563825561374e-14*V02*V09*V11 + 1.84889018457526946e-14*V01*V10*V11 - 
      8.35290526774251518e-13*V02*V032*V12 - 2.47605533628324811e-13*V022*V04*V12 - 
      9.78324647684366881e-13*V01*V03*V04*V12 - 5.01174316064550911e-13*V01*V02*V05*V12 + 
      1.85755303096988537e-13*V052*V12 - 9.84544380311962849e-14*V012*V06*V12 + 
      2.24702992214237174e-13*V04*V06*V12 + 1.79638835024222621e-13*V03*V07*V12 + 4.27110664190148531e-14*V02*V08*V12 + 
      1.56521585564102695e-14*V01*V09*V12 - 1.21283886108971637e-16*V122 - 
      1.38020355473199184e-13*V022*V03*V13 - 1.64470249379212965e-13*V01*V032*V13 - 
      1.69590061010810597e-13*V01*V02*V04*V13 - 4.6788567569687035e-14*V012*V05*V13 + 
      1.2987681548843124e-13*V04*V05*V13 + 9.32407235128521577e-14*V03*V06*V13 + 3.16695058366000516e-14*V02*V07*V13 + 
      1.07086075255241517e-14*V01*V08*V13 - 2.36726161901129699e-16*V11*V13 - 4.28788334463925038e-15*V023*V14 - 
      5.38763992793265321e-14*V01*V02*V03*V14 - 1.52040648886316978e-14*V012*V04*V14 + 
      1.83220005303319117e-14*V042*V14 + 4.36973912871109959e-14*V03*V05*V14 + 1.32520690923386879e-14*V02*V06*V14 + 
      6.42266317854633338e-15*V01*V07*V14 - 1.7866191433540021e-16*V10*V14 - 3.94343872780569097e-15*V01*V022*V15 - 
      4.14813254544663678e-15*V012*V03*V15 + 1.32933569350157555e-14*V03*V04*V15 + 
      6.70424078518043637e-15*V02*V05*V15 + 2.90109792042610258e-15*V01*V06*V15 - 1.29107459341060207e-16*V09*V15 - 
      6.28878596366761223e-16*V012*V02*V16 + 1.9498542612414436e-15*V032*V16 + 
      1.63958782899303425e-15*V02*V04*V16 + 1.18553176371345238e-15*V01*V05*V16 - 7.00374295084141807e-17*V08*V16 - 
      2.46619057398729892e-17*V013*V17 + 5.33805162644932019e-16*V02*V03*V17 + 3.2177532159368341e-16*V01*V04*V17 - 
      3.70192182554372465e-17*V07*V17 + 2.85220301165487614e-17*V022*V18 + 8.2215287939337454e-17*V01*V03*V18 - 
      1.36918254221765874e-17*V06*V18 + 1.03204714237511965e-17*V01*V02*V19 - 5.11287770447656681e-18*V05*V19 + 
      6.7016048206176601e-19*V012*V20 - 1.1553566710744846e-18*V04*V20 - 2.832544970847731e-19*V03*V21 - 
      2.94870612107177044e-20*V02*V22 - 4.02096289237059606e-21*V01*V23 + 6.20518964872005564e-24*V26) + 
   delta10*eps8*(1.03644223710013184e-9*V032*V043 + 7.69281785172546935e-11*V02*V044 + 
      2.23576403065925483e-9*V033*V04*V05 + 3.0758151273048265e-9*V02*V03*V042*V05 + 
      6.21865342260079102e-10*V01*V043*V05 + 1.72425317004195095e-9*V02*V032*V052 + 
      7.44933924140365489e-10*V022*V04*V052 + 1.95196621320524829e-9*V01*V03*V04*V052 + 
      3.37044154365490795e-10*V01*V02*V053 - 8.86044777363391133e-11*V054 + 
      3.8244802639047179e-10*V034*V06 + 2.19627954448125206e-9*V02*V032*V04*V06 + 
      1.57554740974366134e-10*V022*V042*V06 + 1.3106433671735816e-9*V01*V03*V042*V06 + 
      1.07889346598353593e-9*V022*V03*V05*V06 + 1.32380166356476179e-9*V01*V032*V05*V06 + 
      1.31776772668875124e-9*V01*V02*V04*V05*V06 + 1.85737232406228952e-10*V012*V052*V06 - 
      7.31437823120934984e-10*V04*V052*V06 + 1.78028801454292508e-11*V023*V062 + 
      4.63481031146693903e-10*V01*V02*V03*V062 + 1.3454676832729077e-10*V012*V04*V062 - 
      1.95663925615815219e-10*V042*V062 - 5.235117843415e-10*V03*V05*V062 - 
      4.66936333251060897e-11*V02*V063 + 5.34990721215064754e-10*V02*V033*V07 + 
      7.09460880133681418e-10*V022*V03*V04*V07 + 9.00830856579603447e-10*V01*V032*V04*V07 + 
      4.39402161043546643e-10*V01*V02*V042*V07 + 1.12101974959691146e-10*V023*V05*V07 + 
      9.34561339650519572e-10*V01*V02*V03*V05*V07 + 2.53549200883068641e-10*V012*V04*V05*V07 - 
      4.89345958036449584e-10*V042*V05*V07 - 5.0936164839679545e-10*V03*V052*V07 + 
      1.5412763799764799e-10*V01*V022*V06*V07 + 1.6931956922865567e-10*V012*V03*V06*V07 - 
      7.04068186757063522e-10*V03*V04*V06*V07 - 3.53228899935868542e-10*V02*V05*V06*V07 - 
      7.6362931160826196e-11*V01*V062*V07 + 3.02631670953244222e-11*V012*V02*V072 - 
      1.21809194119213621e-10*V032*V072 - 1.17419159346054373e-10*V02*V04*V072 - 
      7.34560746088200637e-11*V01*V05*V072 + 1.9730626157021439e-10*V022*V032*V08 + 
      1.52448556807254477e-10*V01*V033*V08 + 1.77815628638582902e-11*V023*V04*V08 + 
      4.7487650391059968e-10*V01*V02*V03*V04*V08 + 6.90528428335295722e-11*V012*V042*V08 - 
      6.78083241517972135e-11*V043*V08 + 1.18383756942128634e-10*V01*V022*V05*V08 + 
      1.26591387143792804e-10*V012*V03*V05*V08 - 5.48630925336919625e-10*V03*V04*V05*V08 - 
      1.38327168512975287e-10*V02*V052*V08 + 4.8745308936170531e-11*V012*V02*V06*V08 - 
      1.95031783256437153e-10*V032*V06*V08 - 1.4543219266699888e-10*V02*V04*V06*V08 - 
      1.18210669118258031e-10*V01*V05*V06*V08 + 5.01746472277715964e-12*V013*V07*V08 - 
      1.33112230181405307e-10*V02*V03*V07*V08 - 8.00030249249020578e-11*V01*V04*V07*V08 + 
      3.92990368802391292e-12*V072*V08 - 6.70541348750019e-12*V022*V082 - 
      2.17404810478333747e-11*V01*V03*V082 + 2.97203456063187927e-12*V06*V082 + 
      3.1139437488803096e-11*V023*V03*V09 + 1.22754882439275202e-10*V01*V02*V032*V09 + 
      5.91217400111401182e-11*V01*V022*V04*V09 + 6.56508562462427927e-11*V012*V03*V04*V09 - 
      1.38854417015004065e-10*V03*V042*V09 + 3.43776854632476121e-11*V012*V02*V05*V09 - 
      1.42941449688980166e-10*V032*V05*V09 - 1.38448103897304411e-10*V02*V04*V05*V09 - 
      4.30276258233606887e-11*V01*V052*V09 + 3.81396372267135777e-12*V013*V06*V09 - 
      1.00202658874331531e-10*V02*V03*V06*V09 - 6.05375329378461776e-11*V01*V04*V06*V09 - 
      1.64118652809714842e-11*V022*V07*V09 - 4.08646481491317894e-11*V01*V03*V07*V09 + 
      6.01397796505936062e-12*V06*V07*V09 - 1.14357032716647961e-11*V01*V02*V08*V09 + 4.72038477027008684e-12*V05*V08*V09 - 
      8.2482864742720661e-13*V012*V092 + 1.22588102727520073e-12*V04*V092 + 
      4.41628966719152241e-13*V024*V10 + 2.58472555773542445e-11*V01*V022*V03*V10 + 
      1.29549237470610211e-11*V012*V032*V10 + 1.51456161720281988e-11*V012*V02*V04*V10 - 
      6.3325802769482879e-11*V032*V04*V10 - 2.32112737609917358e-11*V02*V042*V10 + 
      2.24854925583291979e-12*V013*V05*V10 - 6.42691019807710967e-11*V02*V03*V05*V10 - 
      3.83706426821222986e-11*V01*V04*V05*V10 - 8.24636658227674083e-12*V022*V06*V10 - 
      2.69448662011830399e-11*V01*V03*V06*V10 + 1.86934827302314237e-12*V062*V10 - 
      9.3636809477959793e-12*V01*V02*V07*V10 + 3.88547034161994706e-12*V05*V07*V10 - 
      1.44871320788164355e-12*V012*V08*V10 + 1.99004986634628615e-12*V04*V08*V10 + 
      1.14387030318298649e-12*V03*V09*V10 + 1.21953854967834181e-13*V02*V102 + 
      1.69851477211653251e-12*V01*V023*V11 + 5.6508811098000575e-12*V012*V02*V03*V11 - 
      8.77872595288240884e-12*V033*V11 + 9.38064908627548888e-13*V013*V04*V11 - 
      2.59682468869140614e-11*V02*V03*V04*V11 - 7.89296648013855657e-12*V01*V042*V11 - 
      6.39681333144350255e-12*V022*V05*V11 - 1.57396968193959993e-11*V01*V03*V05*V11 - 
      5.69289266622793113e-12*V01*V02*V06*V11 + 2.42670699692985867e-12*V05*V06*V11 - 
      1.08447647752873986e-12*V012*V07*V11 + 1.64742693740948427e-12*V04*V07*V11 + 
      9.33604454491042186e-13*V03*V08*V11 + 2.46029316174515537e-13*V02*V09*V11 + 6.96299380888316339e-14*V01*V10*V11 + 
      5.48801388429393628e-13*V012*V022*V12 + 2.96756711767891678e-13*V013*V03*V12 - 
      5.06091900069081585e-12*V02*V032*V12 - 1.78082799284098192e-12*V022*V04*V12 - 
      5.96983353673383486e-12*V01*V03*V04*V12 - 3.06467337152966668e-12*V01*V02*V05*V12 + 
      6.64541833429161692e-13*V052*V12 - 6.12971667164543145e-13*V012*V06*V12 + 
      8.64904687778891982e-13*V04*V06*V12 + 6.515886536102613e-13*V03*V07*V12 + 1.6855302949908041e-13*V02*V08*V12 + 
      5.90505816400706376e-14*V01*V09*V12 - 3.74596196056266142e-16*V122 + 
      5.33437021153452755e-14*V013*V02*V13 - 8.53556778292250779e-13*V022*V03*V13 - 
      1.01555261646222982e-12*V01*V032*V13 - 1.04979567258204347e-12*V01*V02*V04*V13 - 
      2.945001473926933e-13*V012*V05*V13 + 4.78694801337721704e-13*V04*V05*V13 + 3.45583666266237063e-13*V03*V06*V13 + 
      1.1908242444271215e-13*V02*V07*V13 + 4.09234391918326829e-14*V01*V08*V13 - 7.16541842251606127e-16*V11*V13 + 
      1.55370006161199832e-15*V014*V14 - 3.25948187528654673e-14*V023*V14 - 
      3.46142178011987339e-13*V01*V02*V03*V14 - 9.8667352484083855e-14*V012*V04*V14 + 
      7.33058474524930906e-14*V042*V14 + 1.6352256203831978e-13*V03*V05*V14 + 5.36870923463537244e-14*V02*V06*V14 + 
      2.46884977078012e-14*V01*V07*V14 - 5.53761160863980495e-16*V10*V14 - 2.58210153096470196e-14*V01*V022*V15 - 
      2.7874118962491446e-14*V012*V03*V15 + 5.13986819450477708e-14*V03*V04*V15 + 2.60977111694806816e-14*V02*V05*V15 + 
      1.14235555772248634e-14*V01*V06*V15 - 3.92931397871210248e-16*V09*V15 - 4.3281644573477096e-15*V012*V02*V16 + 
      7.66455841729221167e-15*V032*V16 + 6.93053164128995936e-15*V02*V04*V16 + 4.72235285289644036e-15*V01*V05*V16 - 
      2.19634375428030821e-16*V08*V16 - 1.84964293049047419e-16*V013*V17 + 2.18324881846082131e-15*V02*V03*V17 + 
      1.32375459700696516e-15*V01*V04*V17 - 1.14226173525499769e-16*V07*V17 + 1.27732587880972601e-16*V022*V18 + 
      3.44998616165397142e-16*V01*V03*V18 - 4.39182970314357737e-17*V06*V18 + 4.49007522981383226e-17*V01*V02*V19 - 
      1.61950982095046374e-17*V05*V19 + 3.01572216927794704e-18*V012*V20 - 3.8427002041421663e-18*V04*V20 - 
      9.35544032958225349e-19*V03*V21 - 1.03204714237511965e-19*V02*V22 - 1.40733701232970862e-20*V01*V23 + 
      1.86155689461601669e-23*V26) + delta8*eps9*
    (9.45532553415107021e-9*V032*V043 + 1.26121885620031857e-9*V02*V044 + 
      1.9236691918831295e-8*V033*V04*V05 + 2.80143356086422153e-8*V02*V03*V042*V05 + 
      5.67319532049064213e-9*V01*V043*V05 + 1.48129746610753902e-8*V02*V032*V052 + 
      6.81024771582047124e-9*V022*V04*V052 + 1.69721695215116268e-8*V01*V03*V04*V052 + 
      2.92333949172506964e-9*V01*V02*V053 - 3.01794207563108192e-10*V054 + 
      3.32166487416964801e-9*V034*V06 + 2.01536861179702234e-8*V02*V032*V04*V06 + 
      2.63380560248332698e-9*V022*V042*V06 + 1.20713226448484733e-8*V01*V03*V042*V06 + 
      9.90150503351099135e-9*V022*V03*V05*V06 + 1.16365122459848362e-8*V01*V032*V05*V06 + 
      1.20922116707821341e-8*V01*V02*V04*V05*V06 + 1.66451337448793449e-9*V012*V052*V06 - 
      2.60533004952591578e-9*V04*V052*V06 + 3.04152605911516103e-10*V023*V062 + 
      4.29268672053267617e-9*V01*V02*V03*V062 + 1.24788195969702198e-9*V012*V04*V062 - 
      8.06569167406602239e-10*V042*V062 - 1.87772943073893864e-9*V03*V05*V062 - 
      1.96002792948003781e-10*V02*V063 + 4.64022141543661848e-9*V02*V033*V07 + 
      6.48595020554330594e-9*V022*V03*V04*V07 + 7.91967443622623238e-9*V01*V032*V04*V07 + 
      4.00204794409174504e-9*V01*V02*V042*V07 + 1.03563623669674131e-9*V023*V05*V07 + 
      8.20429847684633615e-9*V01*V02*V03*V05*V07 + 2.27371485633562394e-9*V012*V04*V05*V07 - 
      1.76603097599484093e-9*V042*V05*V07 - 1.7725841772712883e-9*V03*V052*V07 + 
      1.41450071907299876e-9*V01*V022*V06*V07 + 1.53932493269909523e-9*V012*V03*V06*V07 - 
      2.55804468490423388e-9*V03*V04*V06*V07 - 1.29848555321289188e-9*V02*V05*V06*V07 - 
      2.84730444412418445e-10*V01*V062*V07 + 2.75556597736724661e-10*V012*V02*V072 - 
      4.32782883923761649e-10*V032*V072 - 4.37045606733090645e-10*V02*V04*V072 - 
      2.66544802682082887e-10*V01*V05*V072 + 1.83748806362752038e-9*V022*V032*V08 + 
      1.36783610224156033e-9*V01*V033*V08 + 3.09244777418661657e-10*V023*V04*V08 + 
      4.4295562598826887e-9*V01*V02*V03*V04*V08 + 6.4469062655569227e-10*V012*V042*V08 - 
      2.84375948424868838e-10*V043*V08 + 1.10249283817651223e-9*V01*V022*V05*V08 + 
      1.16187002620730595e-9*V012*V03*V05*V08 - 2.00379019114445587e-9*V03*V04*V05*V08 - 
      5.11059549984255632e-10*V02*V052*V08 + 4.57908455110747334e-10*V012*V02*V06*V08 - 
      7.17308210461874218e-10*V032*V06*V08 - 6.20926322796909474e-10*V02*V04*V06*V08 - 
      4.43164997112489852e-10*V01*V05*V06*V08 + 4.87383378374813935e-11*V013*V07*V08 - 
      5.00958232930441006e-10*V02*V03*V07*V08 - 3.03361359199640337e-10*V01*V04*V07*V08 + 
      1.05185172877049743e-11*V072*V08 - 2.96368428745279302e-11*V022*V082 - 
      8.34852942360073705e-11*V01*V03*V082 + 8.42135875274038724e-12*V06*V082 + 
      2.87676732415761474e-10*V023*V03*V09 + 1.10333888951482431e-9*V01*V02*V032*V09 + 
      5.40495850461942162e-10*V01*V022*V04*V09 + 6.04535618391916272e-10*V012*V03*V04*V09 - 
      5.20240032580919634e-10*V03*V042*V09 + 3.16809430634511105e-10*V012*V02*V05*V09 - 
      5.17637658963436757e-10*V032*V05*V09 - 5.24562163091996322e-10*V02*V04*V05*V09 - 
      1.59044648426037593e-10*V01*V052*V09 + 3.71995253799096194e-11*V013*V06*V09 - 
      3.81897553570740288e-10*V02*V03*V06*V09 - 2.3236488317619325e-10*V01*V04*V06*V09 - 
      6.40105065788137506e-11*V022*V07*V09 - 1.53992753440856139e-10*V01*V03*V07*V09 + 
      1.62711915862272012e-11*V06*V07*V09 - 4.53052324091337561e-11*V01*V02*V08*V09 + 1.27970839761365963e-11*V05*V08*V09 - 
      3.29435978864654287e-12*V012*V092 + 3.40283698966436004e-12*V04*V092 + 
      8.1607890220289046e-12*V024*V10 + 2.46944717864024914e-10*V01*V022*V03*V10 + 
      1.23282523912579785e-10*V012*V032*V10 + 1.44532282360001167e-10*V012*V02*V04*V10 - 
      2.40824437360646892e-10*V032*V04*V10 - 1.02282749004364433e-10*V02*V042*V10 + 
      2.23117494323917926e-11*V013*V05*V10 - 2.46940637439620681e-10*V02*V03*V05*V10 - 
      1.48568020885695002e-10*V01*V04*V05*V10 - 3.69865033114333662e-11*V022*V06*V10 - 
      1.05079828554496227e-10*V01*V03*V06*V10 + 5.3573388311976452e-12*V062*V10 - 
      3.7225474562396066e-11*V01*V02*V07*V10 + 1.05331784243999658e-11*V05*V07*V10 - 
      5.88727892826532548e-12*V012*V08*V10 + 5.79164320309262717e-12*V04*V08*V10 + 
      3.19802563074875501e-12*V03*V09*V10 + 3.7107362635932425e-13*V02*V102 + 
      1.56914581317688077e-11*V01*V023*V11 + 5.45080893329476388e-11*V012*V02*V03*V11 - 
      3.35412399372212098e-11*V033*V11 + 9.46750831829132155e-12*V013*V04*V11 - 
      1.03379823418576005e-10*V02*V03*V04*V11 - 3.16140969679431848e-11*V01*V042*V11 - 
      2.57464068793074689e-11*V022*V05*V11 - 6.13166742838945541e-11*V01*V03*V05*V11 - 
      2.314427988088199e-11*V01*V02*V06*V11 + 6.70145101878702692e-12*V05*V06*V11 - 
      4.39712531127282944e-12*V012*V07*V11 + 4.60832450404364041e-12*V04*V07*V11 + 
      2.63025586772588469e-12*V03*V08*V11 + 7.18500274567017961e-13*V02*V09*V11 + 2.0643658012849413e-13*V01*V10*V11 + 
      5.43484281551877011e-12*V012*V022*V12 + 3.12397292388119128e-12*V013*V03*V12 - 
      2.04535364896567126e-11*V02*V032*V12 - 8.33434307335563745e-12*V022*V04*V12 - 
      2.43186859976911768e-11*V01*V03*V04*V12 - 1.25867461562704572e-11*V01*V02*V05*V12 + 
      1.83811761205944291e-12*V052*V12 - 2.55921528243809983e-12*V012*V06*V12 + 
      2.56527370540687419e-12*V04*V06*V12 + 1.83501369778612031e-12*V03*V07*V12 + 5.16770641723490209e-13*V02*V08*V12 + 
      1.7500680491185295e-13*V01*V09*V12 - 9.51467811463379367e-16*V122 + 
      5.92995523515246024e-13*V013*V02*V13 - 3.63570130250712084e-12*V022*V03*V13 - 
      4.20778969543138954e-12*V01*V032*V13 - 4.48928068754629983e-12*V01*V02*V04*V13 - 
      1.24654835657475017e-12*V012*V05*V13 + 1.37299761393899378e-12*V04*V05*V13 + 
      9.96161857994013652e-13*V03*V06*V13 + 3.52057919143315269e-13*V02*V07*V13 + 1.22784748364545112e-13*V01*V08*V13 - 
      1.79621550299223666e-15*V11*V13 + 1.9421250770149979e-14*V014*V14 - 1.63228933456972691e-13*V023*V14 - 
      1.50547987041411165e-12*V01*V02*V03*V14 - 4.33112388603649435e-13*V012*V04*V14 + 
      2.26134324491859549e-13*V042*V14 + 4.72403651941420687e-13*V03*V05*V14 + 1.68587357962076689e-13*V02*V06*V14 + 
      7.409507624095008e-14*V01*V07*V14 - 1.40971547280422602e-15*V10*V14 - 1.1822917611695111e-13*V01*V022*V15 - 
      1.26164144288755244e-13*V012*V03*V15 + 1.54348581062465391e-13*V03*V04*V15 + 
      7.93638556122369489e-14*V02*V05*V15 + 3.51664367400224497e-14*V01*V06*V15 - 9.87189392041246962e-16*V09*V15 - 
      2.0346072235395216e-14*V012*V02*V16 + 2.32222334842838003e-14*V032*V16 + 
      2.27093261593378277e-14*V02*V04*V16 + 1.45999822301012219e-14*V01*V05*V16 - 5.63749049917588494e-16*V08*V16 - 
      9.24821465245237093e-16*V013*V17 + 6.96548051042948046e-15*V02*V03*V17 + 4.25303946730858563e-15*V01*V04*V17 - 
      2.89206080632549967e-16*V07*V17 + 4.45522688474662043e-16*V022*V18 + 1.12194917104370556e-15*V01*V03*V18 - 
      1.14825296996462988e-16*V06*V18 + 1.53299210271628975e-16*V01*V02*V19 - 4.18163386794490446e-17*V05*V19 + 
      1.05550275924728147e-17*V012*V20 - 1.03975398791882996e-17*V04*V20 - 2.51142640652646812e-18*V03*V21 - 
      2.94870612107177044e-19*V02*V22 - 4.02096289237059606e-20*V01*V23 + 4.65389223654004173e-23*V26) + 
   eps13*(7.83069566138349207e-9*V027 + 3.89470526809316492e-7*V01*V025*V03 + 
      1.4560094596883618e-6*V012*V023*V032 + 6.43388385203861394e-7*V013*V02*V033 - 
      2.25963672458806971e-7*V022*V034 - 7.40421868182868416e-8*V01*V035 + 
      5.75913158068416005e-7*V012*V024*V04 + 1.47733453165000784e-6*V013*V022*V03*V04 + 
      2.2660888081274986e-7*V014*V032*V04 - 6.34316323392156272e-7*V023*V032*V04 - 
      1.09169531821405071e-6*V01*V02*V033*V04 + 1.68546834283441426e-7*V014*V02*V042 - 
      9.93094869534334209e-8*V024*V042 - 1.19255469126537345e-6*V01*V022*V03*V042 - 
      4.7194417974956753e-7*V012*V032*V042 - 2.36977895033304697e-7*V012*V02*V043 + 
      6.15396422160911125e-8*V032*V043 + 2.08755249185163841e-8*V02*V044 + 
      3.0365453335856775e-7*V013*V023*V05 + 2.72437377162079543e-7*V014*V02*V03*V05 - 
      1.87735168274331277e-7*V024*V03*V05 - 9.9695598435458963e-7*V01*V022*V032*V05 - 
      2.57829614588594222e-7*V012*V033*V05 + 2.32669736017950304e-8*V015*V04*V05 - 
      4.78481933545874632e-7*V01*V023*V04*V05 - 1.15909676568249893e-6*V012*V02*V03*V04*V05 + 
      1.04774569359265628e-7*V033*V04*V05 - 1.06365326721047134e-7*V013*V042*V05 + 
      2.22867743488102149e-7*V02*V03*V042*V05 + 4.68070079918040045e-8*V01*V043*V05 - 
      1.77712107617533329e-7*V012*V022*V052 - 8.62823368941701691e-8*V013*V03*V052 + 
      9.55102875060511121e-8*V02*V032*V052 + 6.68835757659441601e-8*V022*V04*V052 + 
      1.18262788679119731e-7*V01*V03*V04*V052 + 2.4114996135405519e-8*V01*V02*V053 - 
      5.87971432306545918e-10*V054 + 6.7598537650620984e-8*V014*V022*V06 - 
      1.67841748918624113e-8*V025*V06 + 1.55672356193189527e-8*V015*V03*V06 - 
      3.39250098452824682e-7*V01*V023*V03*V06 - 4.02710445142131358e-7*V012*V02*V032*V06 + 
      1.85997849341130047e-8*V034*V06 - 3.03600293319488289e-7*V012*V022*V04*V06 - 
      1.4652365639961199e-7*V013*V03*V04*V06 + 1.59493451267026331e-7*V02*V032*V04*V06 + 
      5.38775891387696344e-8*V022*V042*V06 + 9.95998783780060399e-8*V01*V03*V042*V06 - 
      9.0371657699760816e-8*V013*V02*V05*V06 + 9.61234477073195602e-8*V022*V03*V05*V06 + 
      8.35480469489877804e-8*V01*V032*V05*V06 + 1.21508776031097569e-7*V01*V02*V04*V05*V06 + 
      1.52399636306011813e-8*V012*V052*V06 - 5.89896157218003488e-9*V04*V052*V06 - 
      3.96868820344981643e-9*V014*V062 + 7.7188754804050435e-9*V023*V062 + 
      4.31138384904303964e-8*V01*V02*V03*V062 + 1.29330943052344899e-8*V012*V04*V062 - 
      2.43809977936439083e-9*V042*V062 - 4.2243022736965277e-9*V03*V05*V062 - 
      7.07716085533879318e-10*V02*V063 + 6.41358063233063233e-9*V015*V02*V07 - 
      3.72903536990352272e-8*V01*V024*V07 - 1.82159404246676656e-7*V012*V022*V03*V07 - 
      4.37857125942516349e-8*V013*V032*V07 + 3.33510664947870221e-8*V02*V033*V07 - 
      6.66512522719849401e-8*V013*V02*V04*V07 + 7.0436522298911306e-8*V022*V03*V04*V07 + 
      6.1629967050080088e-8*V01*V032*V04*V07 + 4.47039502924786497e-8*V01*V02*V042*V07 - 
      6.89687013435262735e-9*V014*V05*V07 + 1.40319220319051179e-8*V023*V05*V07 + 
      7.55002763583002605e-8*V01*V02*V03*V05*V07 + 2.25165618306410122e-8*V012*V04*V05*V07 - 
      4.3390872573251391e-9*V042*V05*V07 - 3.71581570466195363e-9*V03*V052*V07 + 
      1.93279029537411271e-8*V01*V022*V06*V07 + 1.57967461763094828e-8*V012*V03*V06*V07 - 
      6.22175490190489495e-9*V03*V04*V06*V07 - 3.78129113979179746e-9*V02*V05*V06*V07 - 
      8.58084901628134437e-10*V01*V062*V07 + 3.60138821890595882e-9*V012*V02*V072 - 
      9.78266741482981504e-10*V032*V072 - 1.38948128968561484e-9*V02*V04*V072 - 
      7.52394819580870262e-10*V01*V05*V072 + 2.10774950358283692e-10*V016*V08 - 
      2.45112683534232709e-8*V012*V023*V08 - 3.51761800156262108e-8*V013*V02*V03*V08 + 
      1.96330626303350956e-8*V022*V032*V08 + 1.1216843817911246e-8*V01*V033*V08 - 
      4.47633195393757952e-9*V014*V04*V08 + 8.78358434831316382e-9*V023*V04*V08 + 
      4.92151309619481556e-8*V01*V02*V03*V04*V08 + 7.3841526455329652e-9*V012*V042*V08 - 
      9.28787617588229207e-10*V043*V08 + 1.49915135042101125e-8*V01*V022*V05*V08 + 
      1.22042032643364276e-8*V012*V03*V05*V08 - 4.83269600788884407e-9*V03*V04*V05*V08 - 
      1.47011713658956168e-9*V02*V052*V08 + 6.3955703261807191e-9*V012*V02*V06*V08 - 
      1.72787802715219131e-9*V032*V06*V08 - 2.42668113764751516e-9*V02*V04*V06*V08 - 
      1.33087411285108721e-9*V01*V05*V06*V08 + 7.34425621745087177e-10*V013*V07*V08 - 
      1.55259713298449543e-9*V02*V03*V07*V08 - 9.82807179230375702e-10*V01*V04*V07*V08 + 
      1.66409833207679984e-11*V072*V08 - 1.50941041769118968e-10*V022*V082 - 
      2.70912027194210816e-10*V01*V03*V082 + 1.46477147933849181e-11*V06*V082 - 
      6.3675289625044527e-9*V013*V022*V09 - 2.10996352617063401e-9*V014*V03*V09 + 
      4.57593414678611544e-9*V023*V03*V09 + 1.21308679000675984e-8*V01*V02*V032*V09 + 
      8.77025813340971257e-9*V01*V022*V04*V09 + 7.1834582491458546e-9*V012*V03*V04*V09 - 
      1.4153130144278294e-9*V03*V042*V09 + 4.43374919694538825e-9*V012*V02*V05*V09 - 
      1.2085493846929004e-9*V032*V05*V09 - 1.71860988325774967e-9*V02*V04*V05*V09 - 
      4.64537966320880956e-10*V01*V052*V09 + 5.85119928881510634e-10*V013*V06*V09 - 
      1.23485121005822109e-9*V02*V03*V06*V09 - 7.82527221124742941e-10*V01*V04*V06*V09 - 
      2.74866492876620447e-10*V022*V07*V09 - 4.87679733209617839e-10*V01*V03*V07*V09 + 
      2.64872102510882816e-11*V06*V07*V09 - 1.96132737209951713e-10*V01*V02*V08*V09 + 2.05915231695656882e-11*V05*V08*V09 - 
      1.47194794595128582e-11*V012*V092 + 6.04604398570575428e-12*V04*V092 - 
      6.81918957041506061e-10*V014*V02*V10 + 3.48265568096190404e-10*V024*V10 + 
      3.9527475182641169e-9*V01*V022*V03*V10 + 1.58723639999545373e-9*V012*V032*V10 + 
      2.37547505225306883e-9*V012*V02*V04*V10 - 6.43522757525397723e-10*V032*V04*V10 - 
      4.50952228298101522e-10*V02*V042*V10 + 3.68274912836089829e-10*V013*V05*V10 - 
      7.85069953286181082e-10*V02*V03*V05*V10 - 4.96120765508822204e-10*V01*V04*V05*V10 - 
      1.96309128408017937e-10*V022*V06*V10 - 3.52688219460775253e-10*V01*V03*V06*V10 + 
      9.5316233966908681e-12*V062*V10 - 1.60333731470374093e-10*V01*V02*V07*V10 + 1.68369529618378081e-11*V05*V07*V10 - 
      2.67557676759354174e-11*V012*V08*V10 + 1.0935460066826233e-11*V04*V08*V10 + 5.52161429611184481e-12*V03*V09*V10 + 
      8.9919967036980298e-13*V02*V102 - 2.47970529833274931e-11*V015*V11 + 
      3.89954577624368677e-10*V01*V023*V11 + 9.61437921518691765e-10*V012*V02*V03*V11 - 
      8.91464542226039259e-11*V033*V11 + 1.80678947825540564e-10*V013*V04*V11 - 
      3.82417051477253683e-10*V02*V03*V04*V11 - 1.21402737967798751e-10*V01*V042*V11 - 
      1.1579794533571919e-10*V022*V05*V11 - 2.04845647122264229e-10*V01*V03*V05*V11 - 
      1.06250624924977204e-10*V01*V02*V06*V11 + 1.11490964617701429e-11*V05*V06*V11 - 
      2.0020992866254189e-11*V012*V07*V11 + 8.22649391242126872e-12*V04*V07*V11 + 4.59415296211132609e-12*V03*V08*V11 + 
      1.65438981434644094e-12*V02*V09*V11 + 4.82472259286606351e-13*V01*V10*V11 + 
      1.34548483210522039e-10*V012*V022*V12 + 6.68595979013183176e-11*V013*V03*V12 - 
      7.38062556142881292e-11*V02*V032*V12 - 5.13963980381249043e-11*V022*V04*V12 - 
      9.27015141760798796e-11*V01*V03*V04*V12 - 5.70547794500081007e-11*V01*V02*V05*V12 + 
      2.99860569026803575e-12*V052*V12 - 1.2273583111709115e-11*V012*V06*V12 + 
      5.01003651777715458e-12*V04*V06*V12 + 3.17860203949389117e-12*V03*V07*V12 + 1.2659976078683143e-12*V02*V08*V12 + 
      4.08194929348678229e-13*V01*V09*V12 - 1.4504663090396124e-15*V122 + 
      1.74558201922108011e-11*V013*V02*V13 - 1.87565584625415959e-11*V022*V03*V13 - 
      1.63891079936603135e-11*V01*V032*V13 - 2.39430034807101478e-11*V01*V02*V04*V13 - 
      6.09778721055783964e-12*V012*V05*V13 + 2.51300746588976029e-12*V04*V05*V13 + 
      1.80512891105252166e-12*V03*V06*V13 + 8.16578853091849905e-13*V02*V07*V13 + 2.91207984024564874e-13*V01*V08*V13 - 
      2.69675342393643147e-15*V11*V13 + 7.34123279111669205e-13*V014*V14 - 1.4520930099637216e-12*V023*V14 - 
      7.94578858294750353e-12*V01*V02*V03*V14 - 2.40313008101044368e-12*V012*V04*V14 + 
      4.89671735163281324e-13*V042*V14 + 8.42069244727671752e-13*V03*V05*V14 + 4.31272395984100651e-13*V02*V06*V14 + 
      1.74658263583684653e-13*V01*V07*V14 - 2.15457447914380396e-15*V10*V14 - 8.9781667846007617e-13*V01*V022*V15 - 
      7.37730082826125629e-13*V012*V03*V15 + 3.09546490011871761e-13*V03*V04*V15 + 
      1.89703701486212331e-13*V02*V05*V15 + 8.69839823895684655e-14*V01*V06*V15 - 1.48321425750994692e-15*V09*V15 - 
      1.5980914919437697e-13*V012*V02*V16 + 4.57771546685545971e-14*V032*V16 + 
      6.52843535205289976e-14*V02*V04*V16 + 3.57966221493292314e-14*V01*V05*V16 - 8.70649042677774238e-16*V08*V16 - 
      8.32339318720713384e-15*V013*V17 + 1.84343556902537708e-14*V02*V03*V17 + 1.17610148879670657e-14*V01*V04*V17 - 
      4.36239290396901429e-16*V07*V17 + 1.7370559695040975e-15*V022*V18 + 3.09639273730613213e-15*V01*V03*V18 - 
      1.8281307790162915e-16*V06*V18 + 5.69217559451212504e-16*V01*V02*V19 - 6.42876573435826361e-17*V05*V19 + 
      4.14661798275717718e-17*V012*V20 - 1.80792544048212925e-17*V04*V20 - 4.17426210264222503e-18*V03*V21 - 
      6.63458877241148349e-19*V02*V22 - 9.04716650783384113e-20*V01*V23 + 6.9808383548100626e-23*V26) + 
   delta6*eps10*(-2.74769340381696435e-8*V022*V034 - 1.07639452439872608e-8*V01*V035 - 
      4.89821079515290533e-8*V023*V032*V04 - 1.22930855987967722e-7*V01*V02*V033*V04 - 
      6.21784885258793341e-10*V024*V042 - 9.20991292139751524e-8*V01*V022*V03*V042 - 
      4.92875941492888272e-8*V012*V032*V042 - 1.87580428009933145e-8*V012*V02*V043 + 
      3.8824614260066828e-8*V032*V043 + 7.35917308458240036e-9*V02*V044 - 
      1.14557399132108646e-8*V024*V03*V05 - 9.39409530971155621e-8*V01*V022*V032*V05 - 
      2.85950056049067876e-8*V012*V033*V05 - 2.9389264770917432e-8*V01*V023*V04*V05 - 
      1.01809884577158153e-7*V012*V02*V03*V04*V05 + 7.44574559481591069e-8*V033*V04*V05 - 
      8.71032191546508384e-9*V013*V042*V05 + 1.17074384057691148e-7*V02*V03*V042*V05 + 
      2.38540431258448046e-8*V01*V043*V05 - 1.30756378568003218e-8*V012*V022*V052 - 
      7.29685615792836459e-9*V013*V03*V052 + 5.81283378552467414e-8*V02*V032*V052 + 
      2.89942622476878869e-8*V022*V04*V052 + 6.76905840804596579e-8*V01*V03*V04*V052 + 
      1.18056790875543742e-8*V01*V02*V053 - 7.06794045525907851e-10*V054 - 
      8.08275217575974916e-11*V025*V06 - 2.12515129940433395e-8*V01*V023*V03*V06 - 
      3.38762155989046745e-8*V012*V02*V032*V06 + 1.30392731897766477e-8*V034*V06 - 
      1.95949349048088544e-8*V012*V022*V04*V06 - 1.13983674421738536e-8*V013*V03*V04*V06 + 
      8.48076389399461026e-8*V02*V032*V04*V06 + 1.56786788592745625e-8*V022*V042*V06 + 
      5.10787322326783384e-8*V01*V03*V042*V06 - 5.92992564086557239e-9*V013*V02*V05*V06 + 
      4.24257291634024247e-8*V022*V03*V05*V06 + 4.70787089119660635e-8*V01*V032*V05*V06 + 
      5.20706209726761905e-8*V01*V02*V04*V05*V06 + 6.94713693255276068e-9*V012*V052*V06 - 
      6.40105790975212439e-9*V04*V052*V06 - 2.24298059751685646e-10*V014*V062 + 
      1.84866682635380758e-9*V023*V062 + 1.85948157653287073e-8*V01*V02*V03*V062 + 
      5.42265501444226541e-9*V012*V04*V062 - 2.22130745594143576e-9*V042*V062 - 
      4.63736991429361019e-9*V03*V05*V062 - 5.54580846146333209e-10*V02*V063 - 
      1.63653427331583779e-9*V01*V024*V07 - 1.17421299435771891e-8*V012*V022*V03*V07 - 
      3.20093405070451445e-9*V013*V032*V07 + 1.87592204069923935e-8*V02*V033*V07 - 
      4.00733871205393148e-9*V013*V02*V04*V07 + 2.82652039123999253e-8*V022*V03*V04*V07 + 
      3.2547018463495343e-8*V01*V032*V04*V07 + 1.75210095995387451e-8*V01*V02*V042*V07 - 
      3.83623342355446308e-10*V014*V05*V07 + 4.60317291956745984e-9*V023*V05*V07 + 
      3.41071335553664913e-8*V01*V02*V03*V05*V07 + 9.62912321222397202e-9*V012*V04*V05*V07 - 
      4.42951313977359782e-9*V042*V05*V07 - 4.25973443487603526e-9*V03*V052*V07 + 
      6.34079407561570895e-9*V01*V022*V06*V07 + 6.61773317046439941e-9*V012*V03*V06*V07 - 
      6.44617457894883118e-9*V03*V04*V06*V07 - 3.34149468111654351e-9*V02*V05*V06*V07 - 
      7.42741450773490953e-10*V01*V062*V07 + 1.21142067789604728e-9*V012*V02*V072 - 
      1.06680612584732195e-9*V032*V072 - 1.14702018027081605e-9*V02*V04*V072 - 
      6.77478100005880002e-10*V01*V05*V072 - 1.14891137851247821e-9*V012*V023*V08 - 
      1.92910950964172253e-9*V013*V02*V03*V08 + 8.11039841871320418e-9*V022*V032*V08 + 
      5.76365642877216439e-9*V01*V033*V08 - 2.22498727108904513e-10*V014*V04*V08 + 
      1.91415314893434211e-9*V023*V04*V08 + 1.96330381410626959e-8*V01*V02*V03*V04*V08 + 
      2.86591172869538992e-9*V012*V042*V08 - 8.01282368730101966e-10*V043*V08 + 
      4.97306318106403491e-9*V01*V022*V05*V08 + 5.05041475517903175e-9*V012*V03*V05*V08 - 
      5.05492119438749656e-9*V03*V04*V05*V08 - 1.31604917227658524e-9*V02*V052*V08 + 
      2.08191788365372175e-9*V012*V02*V06*V08 - 1.82019520578530927e-9*V032*V06*V08 - 
      1.79627438518836763e-9*V02*V04*V06*V08 - 1.15840113098896455e-9*V01*V05*V06*V08 + 
      2.25606373851185909e-10*V013*V07*V08 - 1.32165695838759844e-9*V02*V03*V07*V08 - 
      8.07434980281941008e-10*V01*V04*V07*V08 + 2.17051692867928172e-11*V072*V08 - 
      8.98487444929676867e-11*V022*V082 - 2.24134068354309549e-10*V01*V03*V082 + 
      1.81331803232160107e-11*V06*V082 - 2.52693778020575406e-10*V013*V022*V09 - 
      9.09225276055341415e-11*V014*V03*V09 + 1.3370593591798383e-9*V023*V03*V09 + 
      4.85068722880645286e-9*V01*V02*V032*V09 + 2.51833886420762107e-9*V01*V022*V04*V09 + 
      2.70947346742516175e-9*V012*V03*V04*V09 - 1.36161805484418992e-9*V03*V042*V09 + 
      1.43096367560202802e-9*V012*V02*V05*V09 - 1.29851267719888812e-9*V032*V05*V09 - 
      1.40116539159537664e-9*V02*V04*V05*V09 - 4.11291740294556219e-10*V01*V052*V09 + 
      1.74891630887711094e-10*V013*V06*V09 - 1.02452104590438096e-9*V02*V03*V06*V09 - 
      6.28379847623859237e-10*V01*V04*V06*V09 - 1.78484697920670409e-10*V022*V07*V09 - 
      4.08092701013585716e-10*V01*V03*V07*V09 + 3.3953132833433193e-11*V06*V07*V09 - 1.27888002532006643e-10*V01*V02*V08*V09 + 
      2.6678956657570525e-11*V05*V08*V09 - 9.36810066023675533e-12*V012*V092 + 
      7.3042193898542391e-12*V04*V092 - 2.1254616842852137e-11*V014*V02*V10 + 
      5.34565056721994546e-11*V024*V10 + 1.16830609307205209e-9*V01*V022*V03*V10 + 
      5.7084323796536825e-10*V012*V032*V10 + 6.85449851410095157e-10*V012*V02*V04*V10 - 
      6.33606321810949201e-10*V032*V04*V10 - 3.07470334617415872e-10*V02*V042*V10 + 
      1.06936736097720667e-10*V013*V05*V10 - 6.62203685910129601e-10*V02*V03*V05*V10 - 
      4.02223295614672744e-10*V01*V04*V05*V10 - 1.13976288763887216e-10*V022*V06*V10 - 
      2.86328062844170295e-10*V01*V03*V06*V10 + 1.16480856420793068e-11*V062*V10 - 
      1.04988399583446367e-10*V01*V02*V07*V10 + 2.19163995634344966e-11*V05*V07*V10 - 
      1.69271171359636885e-11*V012*V08*V10 + 1.28132665874286097e-11*V04*V08*V10 + 
      6.86706159496541213e-12*V03*V09*V10 + 8.64949181561006468e-13*V02*V102 - 
      5.9040602341255936e-13*V015*V11 + 7.9301443030414151e-11*V01*V023*V11 + 
      2.6594713548899463e-10*V012*V02*V03*V11 - 8.87299917031129082e-11*V033*V11 + 
      4.73697993641643616e-11*V013*V04*V11 - 2.90710931892431905e-10*V02*V03*V04*V11 - 
      8.95415287043420387e-11*V01*V042*V11 - 7.38304027027456823e-11*V022*V05*V11 - 
      1.6709053987121586e-10*V01*V03*V05*V11 - 6.70736015883760654e-11*V01*V02*V06*V11 + 1.41806766887971536e-11*V05*V06*V11 - 
      1.26383881868897513e-11*V012*V07*V11 + 9.92787536971747346e-12*V04*V07*V11 + 
      5.68022819682475523e-12*V03*V08*V11 + 1.63246143178152037e-12*V02*V09*V11 + 4.7344232554941086e-13*V01*V10*V11 + 
      2.78562884046415178e-11*V012*V022*V12 + 1.62444520441739797e-11*V013*V03*V12 - 
      5.77149632529734132e-11*V02*V032*V12 - 2.6944414439909714e-11*V022*V04*V12 - 
      6.92962743396114235e-11*V01*V03*V04*V12 - 3.64699830497891316e-11*V01*V02*V05*V12 + 
      3.87536377323733394e-12*V052*V12 - 7.53905826800908323e-12*V012*V06*V12 + 
      5.76198889094579598e-12*V04*V06*V12 + 3.95150326642972839e-12*V03*V07*V12 + 1.21099716344026668e-12*V02*V08*V12 + 
      4.00943552284233181e-13*V01*V09*V12 - 1.91905668480552483e-15*V122 + 
      3.26277012938519646e-12*V013*V02*V13 - 1.10242787871679341e-11*V022*V03*V13 - 
      1.21615132465506972e-11*V01*V032*V13 - 1.36914823893645027e-11*V01*V02*V04*V13 - 
      3.70892250064880374e-12*V012*V05*V13 + 3.00593384548658181e-12*V04*V05*V13 + 
      2.18822945116350435e-12*V03*V06*V13 + 8.0426113589143413e-13*V02*V07*V13 + 2.83733661829447263e-13*V01*V08*V13 - 
      3.5950044222355905e-15*V11*V13 + 1.16527504620899874e-13*V014*V14 - 5.70142157529630388e-13*V023*V14 - 
      4.61744861167641976e-12*V01*V02*V03*V14 - 1.3414535353382164e-12*V012*V04*V14 + 
      5.26901714422590449e-13*V042*V14 + 1.03479343769192604e-12*V03*V05*V14 + 4.02694965934368117e-13*V02*V06*V14 + 
      1.70833668881899522e-13*V01*V07*V14 - 2.84703099736483097e-15*V10*V14 - 3.89072390428671245e-13*V01*V022*V15 - 
      4.00077765865089566e-13*V012*V03*V15 + 3.51758725996098794e-13*V03*V04*V15 + 
      1.84741598720858294e-13*V02*V05*V15 + 8.28519403972961318e-14*V01*V06*V15 - 1.97695220033361111e-15*V09*V15 - 
      6.79743776955249263e-14*V012*V02*V16 + 5.30733593768815591e-14*V032*V16 + 
      5.64663818975602804e-14*V02*V04*V16 + 3.43795678100096272e-14*V01*V05*V16 - 1.14444869229479259e-15*V08*V16 - 
      3.23687512835832983e-15*V013*V17 + 1.69279186966391785e-14*V02*V03*V17 + 1.04222688009763788e-14*V01*V04*V17 - 
      5.80985577516217115e-16*V07*V17 + 1.18497776438161466e-15*V022*V18 + 2.76682456624020715e-15*V01*V03*V18 - 
      2.36325392394261166e-16*V06*V18 + 4.01091048513966957e-16*V01*V02*V19 - 8.50500667784587243e-17*V05*V19 + 
      2.81467402465941724e-17*V012*V20 - 2.20750862791145724e-17*V04*V20 - 5.28421540105702499e-18*V03*V21 - 
      6.63458877241148349e-19*V02*V22 - 9.04716650783384113e-20*V01*V23 + 9.30778447308008347e-23*V26) + 
   delta2*eps12*(2.67650730613693577e-11*V027 + 1.45976708476708477e-7*V01*V025*V03 + 
      7.0347310654023617e-7*V012*V023*V032 + 3.42178076553076553e-7*V013*V02*V033 - 
      3.084430776406004e-7*V022*V034 - 1.08118735615307161e-7*V01*V035 + 
      2.37633701175367842e-7*V012*V024*V04 + 6.93810915165081832e-7*V013*V022*V03*V04 + 
      1.13156037635204302e-7*V014*V032*V04 - 7.43688622196506832e-7*V023*V032*V04 - 
      1.44359805672247316e-6*V01*V02*V033*V04 + 7.64811962728629395e-8*V014*V02*V042 - 
      8.46192910475220622e-8*V024*V042 - 1.38524165905300651e-6*V01*V022*V03*V042 - 
      6.05303266276509741e-7*V012*V032*V042 - 2.74664734491634001e-7*V012*V02*V043 + 
      1.11694089518080728e-7*V032*V043 + 3.25142589196534057e-8*V02*V044 + 
      1.18629495076254336e-7*V013*V023*V05 + 1.16106886940220274e-7*V014*V02*V03*V05 - 
      1.89987803884635766e-7*V024*V03*V05 - 1.18823842681875478e-6*V01*V022*V032*V05 - 
      3.31736914716460702e-7*V012*V033*V05 + 9.63542630209296876e-9*V015*V04*V05 - 
      4.83504726572034514e-7*V01*V023*V04*V05 - 1.34919420843425862e-6*V012*V02*V03*V04*V05 + 
      1.95378476733736308e-7*V033*V04*V05 - 1.21287286511449093e-7*V013*V042*V05 + 
      3.72522518500135835e-7*V02*V03*V042*V05 + 7.73089389403570869e-8*V01*V043*V05 - 
      1.8487438634533931e-7*V012*V022*V052 - 9.78097825560769072e-8*V013*V03*V052 + 
      1.65316922135894928e-7*V02*V032*V052 + 1.01740062258203634e-7*V022*V04*V052 + 
      2.00321126014137137e-7*V01*V03*V04*V052 + 3.76852254599081583e-8*V01*V02*V053 - 
      1.16437164809287144e-9*V054 + 2.40283443408443408e-8*V014*V022*V06 - 
      1.2002167247946115e-8*V025*V06 + 5.90169861003194337e-9*V015*V03*V06 - 
      3.48537536633261034e-7*V01*V023*V03*V06 - 4.65194063466705857e-7*V012*V02*V032*V06 + 
      3.48391497335826987e-8*V034*V06 - 3.12553644628662136e-7*V012*V022*V04*V06 - 
      1.64529391194015377e-7*V013*V03*V04*V06 + 2.69770771364478109e-7*V02*V032*V04*V06 + 
      7.7090098636797543e-8*V022*V042*V06 + 1.65806390843634817e-7*V01*V03*V042*V06 - 
      9.2022791402022261e-8*V013*V02*V05*V06 + 1.48557661675356213e-7*V022*V03*V05*V06 + 
      1.41952602899461084e-7*V01*V032*V05*V06 + 1.85640328809827055e-7*V01*V02*V04*V05*V06 + 
      2.34643216241922976e-8*V012*V052*V06 - 1.14432768100795188e-8*V04*V052*V06 - 
      3.87938929240866683e-9*V014*V062 + 1.00510417097837275e-8*V023*V062 + 
      6.64465440764529479e-8*V01*V02*V03*V062 + 1.96674517835845123e-8*V012*V04*V062 - 
      4.58348028122747872e-9*V042*V062 - 8.278219783333639e-9*V03*V05*V062 - 
      1.24683518334632837e-9*V02*V063 + 2.04752808919475586e-9*V015*V02*V07 - 
      3.13823433674672781e-8*V01*V024*V07 - 1.84926089044246724e-7*V012*V022*V03*V07 - 
      4.810012569626832e-8*V013*V032*V07 + 5.73194526254322907e-8*V02*V033*V07 - 
      6.68356487246543269e-8*V013*V02*V04*V07 + 1.0676507036741326e-7*V022*V03*V04*V07 + 
      1.03432916432419505e-7*V01*V032*V04*V07 + 6.71412123632643145e-8*V01*V02*V042*V07 - 
      6.69646946126287863e-9*V014*V05*V07 + 1.90859584989206258e-8*V023*V05*V07 + 
      1.16939449769792707e-7*V01*V02*V03*V05*V07 + 3.4238071677382654e-8*V012*V04*V05*V07 - 
      8.30823257228058229e-9*V042*V05*V07 - 7.33675818986803955e-9*V03*V052*V07 + 
      2.65804099641751113e-8*V01*V022*V06*V07 + 2.40101095250355247e-8*V012*V03*V06*V07 - 
      1.20455061030964279e-8*V03*V04*V06*V07 - 6.79398788954425902e-9*V02*V05*V06*V07 - 
      1.53869034002724677e-9*V01*V062*V07 + 4.96562880025493872e-9*V012*V02*V072 - 
      1.92466642630860559e-9*V032*V072 - 2.45920200644826241e-9*V02*V04*V072 - 
      1.35724029323924052e-9*V01*V05*V072 + 6.02214143880810547e-11*V016*V08 - 
      2.13611851300781039e-8*V012*V023*V08 - 3.42695272229585955e-8*V013*V02*V03*V08 + 
      3.02792194681157412e-8*V022*V032*V08 + 1.88389345300225058e-8*V01*V033*V08 - 
      4.26361709807379742e-9*V014*V04*V08 + 1.12167139606465727e-8*V023*V04*V08 + 
      7.47344361790665714e-8*V01*V02*V03*V04*V08 + 1.10687472366313311e-8*V012*V042*V08 - 
      1.72772347997289948e-9*V043*V08 + 2.06640487907188666e-8*V01*V022*V05*V08 + 
      1.85082141198720689e-8*V012*V03*V05*V08 - 9.37950419429437389e-9*V03*V04*V05*V08 - 
      2.65050454855617483e-9*V02*V052*V08 + 8.80299398332571031e-9*V012*V02*V06*V08 - 
      3.38269656824215663e-9*V032*V06*V08 - 4.22589433929602085e-9*V02*V04*V06*V08 - 
      2.38981532068142626e-9*V01*V05*V06*V08 + 9.90515159221750045e-10*V013*V07*V08 - 
      2.79267731905870259e-9*V02*V03*V07*V08 - 1.74370892281823102e-9*V01*V04*V07*V08 + 
      3.31867925608791034e-11*V072*V08 - 2.41409229250683865e-10*V022*V082 - 
      4.84349766673563639e-10*V01*V03*V082 + 2.89712894379706975e-11*V06*V082 - 
      5.41549924975170073e-9*V013*V022*V09 - 1.93062769655906911e-9*V014*V03*V09 + 
      6.18950644102830038e-9*V023*V03*V09 + 1.85179574839370135e-8*V01*V02*V032*V09 + 
      1.17828203493836249e-8*V01*V022*V04*V09 + 1.07257156401284082e-8*V012*V03*V04*V09 - 
      2.70359820304872567e-9*V03*V042*V09 + 6.07914170003273737e-9*V012*V02*V05*V09 - 
      2.37460104972733882e-9*V032*V05*V09 - 3.04046225768207461e-9*V02*V04*V05*V09 - 
      8.36430987272470724e-10*V01*V052*V09 + 7.86772810235201405e-10*V013*V06*V09 - 
      2.21263297880806407e-9*V02*V03*V06*V09 - 1.38398602015655266e-9*V01*V04*V06*V09 - 
      4.4520846148331938e-10*V022*V07*V09 - 8.72931442629041828e-10*V01*V03*V07*V09 + 
      5.26721248135003586e-11*V06*V07*V09 - 3.19721355448360149e-10*V01*V02*V08*V09 + 4.10606581135547258e-11*V05*V08*V09 - 
      2.38199168900336927e-11*V012*V092 + 1.18839211140883258e-11*V04*V092 - 
      5.49077601773680205e-10*V014*V02*V10 + 3.86984390179204898e-10*V024*V10 + 
      5.38127123739438841e-9*V01*V022*V03*V10 + 2.35425271167935375e-9*V012*V032*V10 + 
      3.1997553842434887e-9*V012*V02*V04*V10 - 1.24450308167573351e-9*V032*V04*V10 - 
      7.73375929443341844e-10*V02*V042*V10 + 4.92008163903447967e-10*V013*V05*V10 - 
      1.41186771676983161e-9*V02*V03*V05*V10 - 8.79027095323632989e-10*V01*V04*V05*V10 - 
      3.12777136181320367e-10*V022*V06*V10 - 6.28829694329919415e-10*V01*V03*V06*V10 + 
      1.88137017465615999e-11*V062*V10 - 2.61467955813591311e-10*V01*V02*V07*V10 + 
      3.36011857984340028e-11*V05*V07*V10 - 4.32819850759256635e-11*V012*V08*V10 + 
      2.13961039994227219e-11*V04*V08*V10 + 1.09996421190625787e-11*V03*V09*V10 + 1.63674936427126164e-12*V02*V102 - 
      1.85977897374956198e-11*V015*V11 + 4.59321643964406406e-10*V01*V023*V11 + 
      1.28685984453044567e-9*V012*V02*V03*V11 - 1.73965530086105601e-10*V033*V11 + 
      2.37428674915237523e-10*V013*V04*V11 - 6.74434524894710797e-10*V02*V03*V04*V11 - 
      2.11500334074548793e-10*V01*V042*V11 - 1.87388333343387057e-10*V022*V05*V11 - 
      3.65495445156227141e-10*V01*V03*V05*V11 - 1.72407649831470694e-10*V01*V02*V06*V11 + 2.21675458077228265e-11*V05*V06*V11 - 
      3.23547309901701805e-11*V012*V07*V11 + 1.61689362500497414e-11*V04*V07*V11 + 
      9.14425764956572053e-12*V03*V08*V11 + 3.02273164582402388e-12*V02*V09*V11 + 8.81698213101695296e-13*V01*V10*V11 + 
      1.59805819837102087e-10*V012*V022*V12 + 8.63507651742408364e-11*V013*V03*V12 - 
      1.32009755806277339e-10*V02*V032*V12 - 8.03257382924611658e-11*V022*V04*V12 - 
      1.62859423095692768e-10*V01*V03*V04*V12 - 9.27706260841776561e-11*V01*V02*V05*V12 + 
      5.98372199130302705e-12*V052*V12 - 1.97702321500602692e-11*V012*V06*V12 + 
      9.77437966473708316e-12*V04*V06*V12 + 6.3322572941193529e-12*V03*V07*V12 + 2.30242322547588044e-12*V02*V08*V12 + 
      7.46025996387384221e-13*V01*V09*V12 - 2.89767620050883711e-15*V122 + 
      2.02563645532664281e-11*V013*V02*V13 - 3.02249688860715764e-11*V022*V03*V13 - 
      2.89074219856099494e-11*V01*V032*V13 - 3.81567556720352671e-11*V01*V02*V04*V13 - 
      9.79910305465500131e-12*V012*V05*V13 + 4.93805918318293845e-12*V04*V05*V13 + 
      3.58232318765102169e-12*V03*V06*V13 + 1.49168263991744812e-12*V02*V07*V13 + 5.31637941831333841e-13*V01*V08*V13 - 
      5.39349176926201655e-15*V11*V13 + 8.15692532346299116e-13*V014*V14 - 2.0394039642059269e-12*V023*V14 - 
      1.27822904068819101e-11*V01*V02*V03*V14 - 3.80462302587238088e-12*V012*V04*V14 + 
      9.43493087903362422e-13*V042*V14 + 1.6761637137509049e-12*V03*V05*V14 + 7.81357932304635833e-13*V02*V06*V14 + 
      3.18991229225688745e-13*V01*V07*V14 - 4.30350651164704879e-15*V10*V14 - 1.2922900262457796e-12*V01*V022*V15 - 
      1.16469240868589424e-12*V012*V03*V15 + 6.0699923045643279e-13*V03*V04*V15 + 3.46354183280487579e-13*V02*V05*V15 + 
      1.58266004160357444e-13*V01*V06*V15 - 2.96641343640904745e-15*V09*V15 - 2.29170759087769752e-13*V012*V02*V16 + 
      9.0756148202973631e-14*V032*V16 + 1.1655806393888189e-13*V02*V04*V16 + 6.52324830992174169e-14*V01*V05*V16 - 
      1.73765241233313247e-15*V08*V16 - 1.16527504620899874e-14*V013*V17 + 3.35629772626173653e-14*V02*V03*V17 + 
      2.11142771959826184e-14*V01*V04*V17 - 8.72463502182956469e-16*V07*V17 + 2.84623858336452642e-15*V022*V18 + 
      5.59838663504758089e-15*V01*V03*V18 - 3.6390719416676987e-16*V06*V18 + 9.40905316814719477e-16*V01*V02*V19 - 
      1.28560236076318882e-16*V05*V19 + 6.78537488087538085e-17*V012*V20 - 3.55955740047107016e-17*V04*V20 - 
      8.33344559443806033e-18*V03*V21 - 1.21634127494210531e-18*V02*V22 - 1.65864719310287087e-19*V01*V23 + 
      1.39616767096201252e-22*V26) + delta4*eps11*
    (-1.52806918959560572e-7*V022*V034 - 5.68856203558000944e-8*V01*V035 - 
      3.15876669022093859e-7*V023*V032*V04 - 6.958119979804348e-7*V01*V02*V033*V04 - 
      2.12135350797297057e-8*V024*V042 - 5.88091694777424625e-7*V01*V022*V03*V042 - 
      2.84453623063372519e-7*V012*V032*V042 - 1.17619271009793886e-7*V012*V02*V043 + 
      8.86966561558005104e-8*V032*V043 + 2.14460056215349951e-8*V02*V044 - 
      7.48091926548262786e-8*V024*V03*V05 - 5.39058962601990924e-7*V01*V022*V032*V05 - 
      1.58909001373938738e-7*V012*V033*V05 - 1.89526001413256315e-7*V01*V023*V04*V05 - 
      5.98055205770687797e-7*V012*V02*V03*V04*V05 + 1.61506258237866329e-7*V033*V04*V05 - 
      5.25955727480781947e-8*V013*V042*V05 + 2.7817888422773766e-7*V02*V03*V042*V05 + 
      5.71626170411310686e-8*V01*V043*V05 - 7.79750415933013972e-8*V012*V022*V052 - 
      4.30718512656148822e-8*V013*V03*V052 + 1.29951972063580657e-7*V02*V032*V052 + 
      7.14529200788832413e-8*V022*V04*V052 + 1.54251296369004045e-7*V01*V03*V04*V052 + 
      2.7666147109001462e-8*V01*V02*V053 - 1.13709972354473621e-9*V054 - 
      2.88534984820906597e-9*V025*V06 - 1.37982768361308666e-7*V01*V023*V03*V06 - 
      2.02380681221523114e-7*V012*V02*V032*V06 + 2.86427995168255253e-8*V034*V06 - 
      1.2455520353123839e-7*V012*V022*V04*V06 - 6.98371886039661483e-8*V013*V03*V04*V06 + 
      2.02138696129166647e-7*V02*V032*V04*V06 + 4.76440170839494897e-8*V022*V042*V06 + 
      1.22766511580894927e-7*V01*V03*V042*V06 - 3.73179340947003568e-8*V013*V02*V05*V06 + 
      1.04883064752468015e-7*V022*V03*V05*V06 + 1.08613935887695355e-7*V01*V032*V05*V06 + 
      1.29739082094093604e-7*V01*V02*V04*V05*V06 + 1.67949996998712611e-8*V012*V052*V06 - 
      1.07734910420858212e-8*V04*V052*V06 - 1.49676361306846834e-9*V014*V062 + 
      5.84866874828278493e-9*V023*V062 + 4.6490749479958687e-8*V01*V02*V03*V062 + 
      1.36335308620654137e-8*V012*V04*V062 - 4.07075243007609874e-9*V042*V062 - 
      7.81909983324219675e-9*V03*V05*V062 - 1.05468946841692334e-9*V02*V063 - 
      1.06870275221180398e-8*V01*V024*V07 - 7.26839521385117401e-8*V012*V022*V03*V07 - 
      1.97934519015381916e-8*V013*V032*V07 + 4.36427528289873252e-8*V02*V033*V07 - 
      2.5795429568918131e-8*V013*V02*V04*V07 + 7.24637097784827881e-8*V022*V03*V04*V07 + 
      7.71187361798493556e-8*V01*V032*V04*V07 + 4.5233620195199384e-8*V01*V02*V042*V07 - 
      2.55167860404399464e-9*V014*V05*V07 + 1.21804939863605216e-8*V023*V05*V07 + 
      8.29641982955464781e-8*V01*V02*V03*V05*V07 + 2.38538285080762939e-8*V012*V04*V05*V07 - 
      7.64283130640170456e-9*V042*V05*V07 - 7.0292409799740354e-9*V03*V052*V07 + 
      1.69392668103744883e-8*V01*V022*V06*V07 + 1.6595678076758996e-8*V012*V03*V06*V07 - 
      1.11310141599262844e-8*V03*V04*V06*V07 - 5.96678959169407956e-9*V02*V05*V06*V07 - 
      1.34126360695585486e-9*V01*V062*V07 + 3.18336816442698659e-9*V012*V02*V072 - 
      1.80743274343053554e-9*V032*V072 - 2.10266307800613464e-9*V02*V04*V072 - 
      1.19842672976589113e-9*V01*V05*V072 - 7.53560510796738621e-9*V012*V023*V08 - 
      1.27980626820787885e-8*V013*V02*V03*V08 + 2.07894937321814828e-8*V022*V032*V08 + 
      1.3921933471288758e-8*V01*V033*V08 - 1.54652640647038406e-9*V014*V04*V08 + 
      6.26249873969185865e-9*V023*V04*V08 + 5.07187641611914184e-8*V01*V02*V03*V04*V08 + 
      7.44622710619452884e-9*V012*V042*V08 - 1.50432993014089171e-9*V043*V08 + 
      1.32561219817359938e-8*V01*V022*V05*V08 + 1.27619496246252961e-8*V012*V03*V05*V08 - 
      8.70482219950651634e-9*V03*V04*V05*V08 - 2.34132189036775429e-9*V02*V052*V08 + 
      5.60267195480498943e-9*V012*V02*V06*V08 - 3.14457965704656587e-9*V032*V06*V08 - 
      3.49886763160363477e-9*V02*V04*V06*V08 - 2.08946769759537164e-9*V01*V05*V06*V08 + 
      6.17035147718537668e-10*V013*V07*V08 - 2.4147989327076599e-9*V02*V03*V07*V08 - 
      1.49030395092540559e-9*V01*V04*V07*V08 + 3.29892849746113782e-11*V072*V08 - 
      1.85769012528000428e-10*V022*V082 - 4.15060292854459985e-10*V01*V03*V082 + 
      2.8347059314050546e-11*V06*V082 - 1.82258339427457075e-9*V013*V022*V09 - 
      6.67749212479604636e-10*V014*V03*V09 + 3.77339507269355975e-9*V023*V03*V09 + 
      1.25618347953540254e-8*V01*V02*V032*V09 + 7.14196990737920524e-9*V01*V022*V04*V09 + 
      7.14037566314455689e-9*V012*V03*V04*V09 - 2.43543286477891104e-9*V03*V042*V09 + 
      3.85955520133643137e-9*V012*V02*V05*V09 - 2.22293375126654135e-9*V032*V05*V09 - 
      2.59506546555557269e-9*V02*V04*V05*V09 - 7.3581687943856921e-10*V01*V052*V09 + 
      4.8665825669129732e-10*V013*V06*V09 - 1.89847107157496911e-9*V02*V03*V06*V09 - 
      1.17490485564995988e-9*V01*V04*V06*V09 - 3.51426447562011315e-10*V022*V07*V09 - 
      7.50335709632982461e-10*V01*V03*V07*V09 + 5.20763182348270563e-11*V06*V07*V09 - 2.5303234703178275e-10*V01*V02*V08*V09 + 
      4.07778441576321774e-11*V05*V08*V09 - 1.8695582881471011e-11*V012*V092 + 
      1.15072965190096386e-11*V04*V092 - 1.71217746789642214e-10*V014*V02*V10 + 
      1.92113878170659558e-10*V024*V10 + 3.29879529180663194e-9*V01*V022*V03*V10 + 
      1.54202785290627957e-9*V012*V032*V10 + 1.94591185098659104e-9*V012*V02*V04*V10 - 
      1.13024061335515152e-9*V032*V04*V10 - 6.21893994910565973e-10*V02*V042*V10 + 
      3.01718378928932375e-10*V013*V05*V10 - 1.21968969858732122e-9*V02*V03*V05*V10 - 
      7.49404778180590171e-10*V01*V04*V05*V10 - 2.38893190799719848e-10*V022*V06*V10 - 
      5.35874668934533298e-10*V01*V03*V06*V10 + 1.83359842204111559e-11*V062*V10 - 
      2.0718693649376069e-10*V01*V02*V07*V10 + 3.34199798567538781e-11*V05*V07*V10 - 
      3.3924902962824983e-11*V012*V08*V10 + 2.05328632884404755e-11*V04*V08*V10 + 1.07581102072366036e-11*V03*V09*V10 + 
      1.47070404889579494e-12*V02*V102 - 5.31365421071303424e-12*V015*V11 + 
      2.48358769884384882e-10*V01*V023*V11 + 7.71874861251565881e-10*V012*V02*V03*V11 - 
      1.58559391707317819e-10*V033*V11 + 1.40032212088693673e-10*V013*V04*V11 - 
      5.61357991571373525e-10*V02*V03*V04*V11 - 1.7433030741664228e-10*V01*V042*V11 - 
      1.47512793895455299e-10*V022*V05*V11 - 3.12222269925821467e-10*V01*V03*V05*V11 - 
      1.35159910425839623e-10*V01*V02*V06*V11 + 2.18922952159847789e-11*V05*V06*V11 - 
      2.5333763872467914e-11*V012*V07*V11 + 1.56536001965007288e-11*V04*V07*V11 + 8.92813645643280211e-12*V03*V08*V11 + 
      2.73641576630246169e-12*V02*V09*V11 + 7.97100635634540666e-13*V01*V10*V11 + 
      8.70369827014528024e-11*V012*V022*V12 + 4.96329484681952862e-11*V013*V03*V12 - 
      1.1096220648949361e-10*V02*V032*V12 - 5.91343175830674534e-11*V022*V04*V12 - 
      1.34862071672957394e-10*V01*V03*V04*V12 - 7.31229327782623809e-11*V01*V02*V05*V12 + 
      5.9457389675347873e-12*V052*V12 - 1.53633191449469276e-11*V012*V06*V12 + 
      9.3275632375441689e-12*V04*V06*V12 + 6.19310925351062037e-12*V03*V07*V12 + 2.06544449972002528e-12*V02*V08*V12 + 
      6.74624177338058683e-13*V01*V09*V12 - 2.89121865360783184e-15*V122 + 
      1.06816879235824884e-11*V013*V02*V13 - 2.30842065612378769e-11*V022*V03*V13 - 
      2.38773642772143671e-11*V01*V032*V13 - 2.88804264470394409e-11*V01*V02*V04*V13 - 
      7.59812044951786155e-12*V012*V05*V13 + 4.77430004109124123e-12*V04*V05*V13 + 
      3.47710866212780649e-12*V03*V06*V13 + 1.34988740448089142e-12*V02*V07*V13 + 4.7964793038172923e-13*V01*V08*V13 - 
      5.39335103556078358e-15*V11*V13 + 4.07846266173149558e-13*V014*V14 - 1.36409933028385478e-12*V023*V14 - 
      9.72954723225390703e-12*V01*V02*V03*V14 - 2.85819773119901505e-12*V012*V04*V14 + 
      8.79942667404491114e-13*V042*V14 + 1.63558710494722192e-12*V03*V05*V14 + 6.95851218173700222e-13*V02*V06*V14 + 
      2.88122330608983782e-13*V01*V07*V14 - 4.29233219484547072e-15*V10*V14 - 8.92212260380690033e-13*V01*V022*V15 - 
      8.66576209364092061e-13*V012*V03*V15 + 5.76254546085077975e-13*V03*V04*V15 + 
      3.12876249383043852e-13*V02*V05*V15 + 1.418321277710942e-13*V01*V06*V15 - 2.96627270270781448e-15*V09*V15 - 
      1.5731213123821483e-13*V012*V02*V16 + 8.6747750819641693e-14*V032*V16 + 
      1.01055643603636294e-13*V02*V04*V16 + 5.86680601292778003e-14*V01*V05*V16 - 1.73047164276784065e-15*V08*V16 - 
      7.76850030805999158e-15*V013*V17 + 2.96757113864180916e-14*V02*V03*V17 + 1.84515955686548097e-14*V01*V04*V17 - 
      8.72322768481723498e-16*V07*V17 + 2.28069015255260208e-15*V022*V18 + 4.90597682498136425e-15*V01*V03*V18 - 
      3.60579847373333201e-16*V06*V18 + 7.61972468104227953e-16*V01*V02*V19 - 1.28419502375085912e-16*V05*V19 + 
      5.42829990470030468e-17*V012*V20 - 3.45802808743871261e-17*V04*V20 - 8.19271189320508947e-18*V03*V21 - 
      1.10576479540191392e-18*V02*V22 - 1.50786108463897352e-19*V01*V23 + 1.39616767096201252e-22*V26) + 
   9.18368986379554615e-29*delta26*V26 + 5.969398411467105e-28*delta24*eps*V26 + 
   delta24*eps2*(-1.19394855996739947e-22*V132 - 1.91031769594783915e-22*V12*V14 - 
      1.77386643195156492e-22*V11*V15 - 1.04345084232444995e-22*V10*V16 - 7.17372454098059343e-23*V09*V17 - 
      3.02051559620235513e-23*V08*V18 - 1.51025779810117756e-23*V07*V19 - 4.31502228028907875e-24*V06*V20 - 
      1.51025779810117756e-24*V05*V21 - 2.6265353010455262e-25*V04*V22 - 5.969398411467105e-26*V03*V23 - 
      4.775518729173684e-27*V02*V24 - 5.969398411467105e-28*V01*V25 + 5.1460331133337112e-30*V28) + 
   delta22*eps3*(-1.43273827196087936e-21*V132 - 2.29238123513740697e-21*V12*V14 - 
      2.1286397183418779e-21*V11*V15 - 1.25214101078933994e-21*V10*V16 - 8.60846944917671212e-22*V09*V17 - 
      3.62461871544282615e-22*V08*V18 - 1.81230935772141308e-22*V07*V19 - 5.17802673634689451e-23*V06*V20 - 
      1.81230935772141308e-23*V05*V21 - 3.15184236125463144e-24*V04*V22 - 7.163278093760526e-25*V03*V23 - 
      5.7306224750084208e-26*V02*V24 - 7.163278093760526e-27*V01*V25 + 3.08761986800022672e-29*V28) + 
   delta20*eps4*(1.10298597358411377e-17*V083 + 8.50874893907744908e-17*V07*V08*V09 + 
      3.21177283144453053e-17*V06*V092 + 3.45184474005755605e-17*V072*V10 + 
      4.05285146835004812e-17*V06*V08*V10 + 4.02715219673381539e-17*V05*V09*V10 + 6.42551185378679264e-18*V04*V102 + 
      4.20450261570920361e-17*V06*V07*V11 + 3.2487950494659351e-17*V05*V08*V11 + 1.64373559050359812e-17*V04*V09*V11 + 
      7.32209490315239162e-18*V03*V10*V11 + 7.50401030447294793e-19*V02*V112 + 
      8.37583361314851212e-18*V062*V12 + 2.20591261494802398e-17*V05*V07*V12 + 8.6735229906141829e-18*V04*V08*V12 + 
      6.12753504152228884e-18*V03*V09*V12 + 9.81159102388680945e-19*V02*V10*V12 + 3.34229184083033937e-19*V01*V11*V12 + 
      1.1319814734601702e-17*V05*V06*V13 + 7.58647195617045285e-18*V04*V07*V13 + 4.16512185828966039e-18*V03*V08*V13 + 
      1.05825786345131317e-18*V02*V09*V13 + 2.81619034736630447e-19*V01*V10*V13 - 1.06595727433889424e-20*V132 + 
      2.53457131262967402e-18*V052*V14 + 2.57722253056508207e-18*V04*V06*V14 + 2.41387744059968954e-18*V03*V07*V14 + 
      4.76053124119404531e-19*V02*V08*V14 + 2.01156453383307462e-19*V01*V09*V14 - 1.73647878561658578e-20*V12*V14 + 
      1.51729439123409057e-18*V04*V05*V15 + 1.07807759377159067e-18*V03*V06*V15 + 3.62831267469021658e-19*V02*V07*V15 + 
      1.19003481665418868e-19*V01*V08*V15 - 1.58849738981262639e-20*V11*V15 + 1.48754352081773585e-19*V042*V16 + 
      4.16512185828966039e-19*V03*V05*V16 + 1.06136400409832961e-19*V02*V06*V16 + 5.95017408327094341e-20*V01*V07*V16 - 
      9.54131450221477037e-21*V10*V16 + 1.11565764061330189e-19*V03*V04*V17 + 5.60254163003636384e-20*V02*V05*V17 + 
      2.37811233920203824e-20*V01*V06*V17 - 6.48217749523006422e-21*V09*V17 + 1.32117352177891013e-20*V032*V18 + 
      9.44607155668013042e-21*V02*V04*V18 + 7.9270411306734608e-21*V01*V05*V18 - 2.79458102960641896e-21*V08*V18 + 
      3.27634013452418938e-21*V02*V03*V19 + 1.95729410633912612e-21*V01*V04*V19 - 1.38505742663858994e-21*V07*V19 + 
      1.163029831302959e-22*V022*V20 + 3.91458821267825225e-22*V01*V03*V20 - 4.06216197466413874e-22*V06*V20 + 
      4.68048590646312769e-23*V01*V02*V21 - 1.4136012990227022e-22*V05*V21 + 2.12749359384687622e-24*V012*V22 - 
      2.52935349490684173e-23*V04*V22 - 5.73241329453186093e-24*V03*V23 - 4.72776354188194716e-25*V02*V24 - 
      5.90970442735243395e-26*V01*V25 + 1.6981909274001247e-28*V28) + 
   delta18*eps5*(1.52317110637806187e-16*V083 + 1.12120493832635136e-15*V07*V08*V09 + 
      4.22288650060299385e-16*V06*V092 + 4.56136626364748478e-16*V072*V10 + 
      5.60091452293578975e-16*V06*V08*V10 + 5.32159397425539891e-16*V05*V09*V10 + 8.89111523954218982e-17*V04*V102 + 
      5.52814232806210104e-16*V06*V07*V11 + 4.28096430997334157e-16*V05*V08*V11 + 2.15740296253597253e-16*V04*V09*V11 + 
      9.67562540773708892e-17*V03*V10*V11 + 9.8348013838925757e-18*V02*V112 + 
      1.15962448868508278e-16*V062*V12 + 2.92589798232689292e-16*V05*V07*V12 + 1.20147745912201742e-16*V04*V08*V12 + 
      8.12749439535248034e-17*V03*V09*V12 + 1.36140534804836448e-17*V02*V10*V12 + 4.43317876110135291e-18*V01*V11*V12 + 
      1.4883460114013349e-16*V05*V06*V13 + 9.95724444247371937e-17*V04*V07*V13 + 5.48841578201710458e-17*V03*V08*V13 + 
      1.38695916952331196e-17*V02*V09*V13 + 3.72139438759118805e-18*V01*V10*V13 - 6.13928349535236805e-20*V132 + 
      3.37942841683956536e-17*V052*V14 + 3.58270230657427606e-17*V04*V06*V14 + 3.21850325413291939e-17*V03*V07*V14 + 
      6.62404371072965862e-18*V02*V08*V14 + 2.68208604511076616e-18*V01*V09*V14 - 1.02870607926791138e-19*V12*V14 + 
      1.99144888849474387e-17*V04*V05*V15 + 1.41747239181079514e-17*V03*V06*V15 + 4.75528858122278385e-18*V02*V07*V15 + 
      1.56811879486202988e-18*V01*V08*V15 - 9.1930627835889852e-20*V11*V15 + 2.08256092914483019e-18*V042*V16 + 
      5.59688249707673115e-18*V03*V05*V16 + 1.48652232389268935e-18*V02*V06*V16 + 7.99554642439533021e-19*V01*V07*V16 - 
      5.70350230414544345e-20*V10*V16 + 1.46430065330495873e-18*V03*V04*V17 + 7.34272501512341624e-19*V02*V05*V17 + 
      3.12677733487675398e-19*V01*V06*V17 - 3.80494349653610676e-20*V09*V17 + 1.79826396019907213e-19*V032*V18 + 
      1.34032096412353202e-19*V02*V04*V18 + 1.07895837611944328e-19*V01*V05*V18 - 1.69994617754268547e-20*V08*V18 + 
      4.29399123691427851e-20*V02*V03*V19 + 2.56894851457010304e-20*V01*V04*V19 - 8.31623456524413426e-21*V07*V19 + 
      1.69726711153561903e-21*V022*V20 + 5.46411271353006043e-21*V01*V03*V20 - 2.53334958075771814e-21*V06*V20 + 
      6.13427319559182644e-22*V01*V02*V21 - 8.7443926510058181e-22*V05*V21 + 3.19124039077031433e-23*V012*V22 - 
      1.62713861899770348e-22*V04*V22 - 3.67386625233742977e-23*V03*V23 - 3.15184236125463144e-24*V02*V24 - 
      3.9398029515682893e-25*V01*V25 + 8.49095463700062349e-28*V28) + 
   delta16*eps6*(-1.9971583877377173e-13*V052*V062 - 5.15012279872686278e-14*V04*V063 - 
      1.38552891798664746e-13*V053*V07 - 5.35296957748947698e-13*V04*V05*V06*V07 - 
      1.90205560736925457e-13*V03*V062*V07 - 8.90955092929180725e-14*V042*V072 - 
      1.9633954345872527e-13*V03*V05*V072 - 6.35520307987724906e-14*V02*V06*V072 - 
      9.19777263033969904e-15*V01*V073 - 2.06722420226566058e-13*V04*V052*V08 - 
      7.93140422857561947e-14*V042*V06*V08 - 2.92044310053531097e-13*V03*V05*V06*V08 - 
      2.8054165341348957e-14*V02*V062*V08 - 1.96878495453872436e-13*V03*V04*V07*V08 - 
      9.88055510639503979e-14*V02*V05*V07*V08 - 4.17206157219330139e-14*V01*V06*V07*V08 - 
      2.64742324327273891e-14*V032*V082 - 1.43533312602985843e-14*V02*V04*V082 - 
      1.58845394596364335e-14*V01*V05*V082 + 1.1820275926538449e-15*V083 - 
      1.03944760841737751e-13*V042*V05*V09 - 1.13602057536292194e-13*V03*V052*V09 - 
      1.48693599374707694e-13*V03*V04*V06*V09 - 7.41440359319012391e-14*V02*V05*V06*V09 - 
      1.58504633947437881e-14*V01*V062*V09 - 5.34751684544834494e-14*V032*V07*V09 - 
      4.88875816832892394e-14*V02*V04*V07*V09 - 3.18195745542241038e-14*V01*V05*V07*V09 - 
      2.74459864066528883e-14*V02*V03*V08*V09 - 1.6406541287822703e-14*V01*V04*V08*V09 + 8.17560521363213863e-15*V07*V08*V09 - 
      1.643382958440418e-15*V022*V092 - 4.26733622425923663e-15*V01*V03*V092 + 
      3.08192679142743045e-15*V06*V092 - 8.23776276145120962e-15*V043*V10 - 
      9.24961930882277239e-14*V03*V04*V05*V10 - 2.33503285680618882e-14*V02*V052*V10 - 
      3.24037911030739563e-14*V032*V06*V10 - 1.74238643178067204e-14*V02*V04*V06*V10 - 
      1.94422746618443738e-14*V01*V05*V06*V10 - 2.22384081600589411e-14*V02*V03*V07*V10 - 
      1.32137418697468177e-14*V01*V04*V07*V10 + 3.34029474072375626e-15*V072*V10 - 
      1.55351438944380804e-15*V022*V08*V10 - 6.93994367294913794e-15*V01*V03*V08*V10 + 
      4.36673324974551584e-15*V06*V08*V10 - 1.85320068000491176e-15*V01*V02*V09*V10 + 3.91504901715321151e-15*V05*V09*V10 - 
      1.08465183908934031e-16*V012*V102 + 6.99478132891690773e-16*V04*V102 - 
      1.88990474257705002e-14*V03*V042*V11 - 2.0079848750027906e-14*V032*V05*V11 - 
      1.8666167551801346e-14*V02*V04*V05*V11 - 5.9528162369059927e-15*V01*V052*V11 - 
      1.34807338058002253e-14*V02*V03*V06*V11 - 8.11055996589314694e-15*V01*V04*V06*V11 - 
      2.15133769104927447e-15*V022*V07*V11 - 5.5380535084000978e-15*V01*V03*V07*V11 + 
      4.05344001817784992e-15*V06*V07*V11 - 1.49705380399924845e-15*V01*V02*V08*V11 + 3.15077698022744369e-15*V05*V08*V11 - 
      2.06810074200447004e-16*V012*V09*V11 + 1.59121692189397229e-15*V04*V09*V11 + 
      7.21666268378127112e-16*V03*V10*V11 + 7.36581415510666222e-17*V02*V112 - 
      6.9185418610290725e-15*V032*V04*V12 - 1.80834826436122564e-15*V02*V042*V12 - 
      7.0425748922771522e-15*V02*V03*V05*V12 - 4.1511251166174435e-15*V01*V04*V05*V12 - 
      6.30237871364720846e-16*V022*V06*V12 - 2.86359817679713366e-15*V01*V03*V06*V12 + 
      9.12710887385849357e-16*V062*V12 - 1.0060821274681646e-15*V01*V02*V07*V12 + 2.17298619641462655e-15*V05*V07*V12 - 
      1.46306960814815552e-16*V012*V08*V12 + 9.49799932113489445e-16*V04*V08*V12 + 
      6.09073484754213193e-16*V03*V09*V12 + 1.09033397228799142e-16*V02*V10*V12 + 3.38185036744886271e-17*V01*V11*V12 - 
      8.23403845626556504e-16*V033*V13 - 2.39309840407709564e-15*V02*V03*V04*V13 - 
      7.26886439452711547e-16*V01*V042*V13 - 5.79206301436343127e-16*V022*V05*V13 - 
      1.44677819056731709e-15*V01*V03*V05*V13 - 5.18489761761547126e-16*V01*V02*V06*V13 + 1.10659043311581401e-15*V05*V06*V13 - 
      9.35939746766680868e-17*V012*V07*V13 + 7.41243447021940299e-16*V04*V07*V13 + 
      4.11428398053562672e-16*V03*V08*V13 + 1.04354074922474458e-16*V02*V09*V13 + 2.83871112421247911e-17*V01*V10*V13 - 
      2.94467426655281363e-19*V132 - 3.77787547433765198e-16*V02*V032*V14 - 
      9.26777057356701142e-17*V022*V04*V14 - 4.38655479552699342e-16*V01*V03*V04*V14 - 
      2.26672528460259119e-16*V01*V02*V05*V14 + 2.55854974493514799e-16*V052*V14 - 
      4.33570429464430293e-17*V012*V06*V14 + 2.8735149788757784e-16*V04*V06*V14 + 2.44740351616357412e-16*V03*V07*V14 + 
      5.35741052876326988e-17*V02*V08*V14 + 2.06622661355679947e-17*V01*V09*V14 - 5.08721755295465973e-19*V12*V14 - 
      5.51625048986993454e-17*V022*V03*V15 - 6.42358395777375031e-17*V01*V032*V15 - 
      6.83742401164884467e-17*V01*V02*V04*V15 - 1.78262688228429759e-17*V012*V05*V15 + 
      1.50982944171200065e-16*V04*V05*V15 + 1.07814907755634392e-16*V03*V06*V15 + 3.6269383138285915e-17*V02*V07*V15 + 
      1.20757812882905002e-17*V01*V08*V15 - 4.43179318750542553e-19*V11*V15 - 1.15395252530254566e-18*V023*V16 - 
      1.78862641421894578e-17*V01*V02*V03*V16 - 4.9706760326638416e-18*V012*V04*V16 + 
      1.71110905763354099e-17*V042*V16 + 4.3613320824757824e-17*V03*V05*V16 + 1.22621922769833635e-17*V02*V06*V16 + 
      6.28244603275794854e-18*V01*V07*V16 - 2.8474503199052279e-19*V10*V16 - 1.21681996100072085e-18*V01*V022*V17 - 
      1.17086609937362833e-18*V012*V03*V17 + 1.14032592883395642e-17*V03*V04*V17 + 
      5.72673938731115986e-18*V02*V05*V17 + 2.45317031319295603e-18*V01*V06*V17 - 1.86187158637677321e-19*V09*V17 - 
      1.54775158952360245e-19*V012*V02*V18 + 1.45049853861487712e-18*V032*V18 + 
      1.1394855688643869e-18*V02*V04*V18 + 8.73649925579235103e-19*V01*V05*V18 - 8.64577938312806382e-20*V08*V18 - 
      4.7868605861554715e-21*V013*V19 + 3.45239022941501839e-19*V02*V03*V19 + 2.071115013609934e-19*V01*V04*V19 - 
      4.16838046931090252e-20*V07*V19 + 1.50626546444358836e-20*V022*V20 + 4.61453360505387452e-20*V01*V03*V20 - 
      1.32340232459151162e-20*V06*V20 + 5.1219408271863545e-21*V01*V02*V21 - 4.52579939307717773e-21*V05*V21 + 
      2.8721163516932829e-22*V012*V22 - 8.79364018790042171e-22*V04*V22 - 1.97679613094938916e-22*V03*V23 - 
      1.77291132820573018e-23*V02*V24 - 2.21613916025716273e-24*V01*V25 + 3.82092958665028057e-27*V28) + 
   delta14*eps7*(-2.51986024216111903e-12*V052*V062 - 
      7.66374204694040638e-13*V04*V063 - 1.71500114887796047e-12*V053*V07 - 
      6.73187355701465464e-12*V04*V05*V06*V07 - 2.39986689729630384e-12*V03*V062*V07 - 
      1.11856831327609723e-12*V042*V072 - 2.43566320925706709e-12*V03*V05*V072 - 
      7.98583082493023281e-13*V02*V06*V072 - 1.14618397393463942e-13*V01*V073 - 
      2.61143204268681004e-12*V04*V052*V08 - 1.18471866425539801e-12*V042*V06*V08 - 
      3.70632780010077628e-12*V03*V05*V06*V08 - 4.20522991215922173e-13*V02*V062*V08 - 
      2.48707813589220004e-12*V03*V04*V07*V08 - 1.24518743296266383e-12*V02*V05*V07*V08 - 
      5.29475400014396611e-13*V01*V06*V07*V08 - 3.38500229532863735e-13*V032*V082 - 
      2.1618555087787909e-13*V02*V04*V082 - 2.03100137719718241e-13*V01*V05*V082 + 
      6.55112010707955772e-15*V083 - 1.3049963654887801e-12*V042*V05*V09 - 
      1.41243945340161121e-12*V03*V052*V09 - 1.86996487694851518e-12*V03*V04*V06*V09 - 
      9.31680262908527161e-13*V02*V05*V06*V09 - 1.9998890810802532e-13*V01*V062*V09 - 
      6.67000771126056506e-13*V032*V07*V09 - 6.14853248028864449e-13*V02*V04*V07*V09 - 
      3.97810724009440211e-13*V01*V05*V07*V09 - 3.45885398045184397e-13*V02*V03*V08*V09 - 
      2.07256511324350003e-13*V01*V04*V08*V09 + 4.25003916946786307e-14*V07*V08*V09 - 
      2.082221806665971e-14*V022*V092 - 5.38830472713085848e-14*V01*V03*V092 + 
      1.60812251786407803e-14*V06*V092 - 1.24056419875980856e-13*V043*V10 - 
      1.17736463407971587e-12*V03*V04*V05*V10 - 2.96119791245740176e-13*V02*V052*V10 - 
      4.15039194364330216e-13*V032*V06*V10 - 2.63587490168626055e-13*V02*V04*V06*V10 - 
      2.49023516618598129e-13*V01*V05*V06*V10 - 2.82018848805466834e-13*V02*V03*V07*V10 - 
      1.68194947725673695e-13*V01*V04*V07*V10 + 1.74383716386006097e-14*V072*V10 - 
      2.38053768189902368e-14*V022*V08*V10 - 8.98202690897743747e-14*V01*V03*V08*V10 + 
      2.43846652416793024e-14*V06*V08*V10 - 2.35015707337889029e-14*V01*V02*V09*V10 + 2.06057236803017738e-14*V05*V09*V10 - 
      1.43370826246798331e-15*V012*V102 + 3.96428932547644154e-15*V04*V102 - 
      2.37272066452505473e-13*V03*V042*V11 - 2.51631536127520512e-13*V032*V05*V11 - 
      2.34762149247384608e-13*V02*V04*V05*V11 - 7.48492153453347417e-14*V01*V052*V11 - 
      1.69396411437914029e-13*V02*V03*V06*V11 - 1.01998084197191737e-13*V01*V04*V06*V11 - 
      2.72581763781727113e-14*V022*V07*V11 - 7.01033093976778396e-14*V01*V03*V07*V11 + 
      2.13218354709983197e-14*V06*V07*V11 - 1.8866476257010058e-14*V01*V02*V08*V11 + 1.66463961920891562e-14*V05*V08*V11 - 
      2.70549182705722968e-15*V012*V09*V11 + 8.46519127348510629e-15*V04*V09*V11 + 
      3.88883527020090202e-15*V03*V10*V11 + 4.02081764258068888e-16*V02*V112 - 
      8.9119744245507192e-14*V032*V04*V12 - 2.77615388249572503e-14*V02*V042*V12 - 
      9.02401843369926548e-14*V02*V03*V05*V12 - 5.34718465473043152e-14*V01*V04*V05*V12 - 
      9.75373498117561726e-15*V022*V06*V12 - 3.72237934749807608e-14*V01*V03*V06*V12 + 
      5.17221526231414158e-15*V062*V12 - 1.2891454905284665e-14*V01*V02*V07*V12 + 1.15738056510318501e-14*V05*V07*V12 - 
      1.9385984662704339e-15*V012*V08*V12 + 5.42172521751850093e-15*V04*V08*V12 + 3.29486197473159965e-15*V03*V09*V12 + 
      6.35760112757530432e-16*V02*V10*V12 + 1.88437848864205698e-16*V01*V11*V12 - 1.04411003105223144e-14*V033*V13 - 
      3.00977114419723856e-14*V02*V03*V04*V13 - 9.12584870971174895e-15*V01*V042*V13 - 
      7.33873979412342228e-15*V022*V05*V13 - 1.84758419748958044e-14*V01*V03*V05*V13 - 
      6.5152465937659242e-15*V01*V02*V06*V13 + 5.95861129736542136e-15*V05*V06*V13 - 
      1.23197707636072354e-15*V012*V07*V13 + 4.0041533527362525e-15*V04*V07*V13 + 2.2415825653105088e-15*V03*V08*V13 + 
      5.73795659728471751e-16*V02*V09*V13 + 1.58694949853917996e-16*V01*V10*V13 - 1.2092933945033283e-18*V132 - 
      4.9215054007228526e-15*V02*V032*V14 - 1.46814009844390231e-15*V022*V04*V14 - 
      5.7597988081150496e-15*V01*V03*V04*V14 - 2.95290324043371156e-15*V01*V02*V05*V14 + 
      1.39952415958247218e-15*V052*V14 - 5.79171836040122807e-16*V012*V06*V14 + 
      1.6750370091965098e-15*V04*V06*V14 + 1.34875401993507653e-15*V03*V07*V14 + 3.16627754139116627e-16*V02*V08*V14 + 
      1.16364635315865469e-16*V01*V09*V14 - 2.14611734546070503e-18*V12*V14 - 6.98927599440325931e-16*V022*V03*V15 - 
      8.37876759046778033e-16*V01*V032*V15 - 8.59934612627782446e-16*V01*V02*V04*V15 - 
      2.38362680259728934e-16*V012*V05*V15 + 8.3968746884450111e-16*V04*V05*V15 + 6.02108557224745365e-16*V03*V06*V15 + 
      2.03680279692837158e-16*V02*V07*V15 + 6.86493250381728478e-17*V01*V08*V15 - 1.82727523647880226e-18*V11*V15 - 
      1.9167866283122816e-17*V023*V16 - 2.3955748066203334e-16*V01*V02*V03*V16 - 
      6.75521765918260138e-17*V012*V04*V16 + 1.03124890677870831e-16*V042*V16 + 
      2.48128726852923635e-16*V03*V05*V16 + 7.43882390075747964e-17*V02*V06*V16 + 3.62386621307907661e-17*V01*V07*V16 - 
      1.21120144382787979e-18*V10*V16 - 1.54175205758895426e-17*V01*V022*V17 - 
      1.62676670159907543e-17*V012*V03*V17 + 6.60274019331159576e-17*V03*V04*V17 + 3.323932166218544e-17*V02*V05*V17 + 
      1.43510080372941035e-17*V01*V06*V17 - 7.77120222492417712e-19*V09*V17 - 2.182808427286895e-18*V012*V02*V18 + 
      8.61634905507984869e-18*V032*V18 + 7.17646139076428287e-18*V02*V04*V18 + 5.2234222716128505e-18*V01*V05*V18 - 
      3.7401337379828084e-19*V08*V18 - 7.65897693784875439e-20*V013*V19 + 2.09026245595455589e-18*V02*V03*V19 + 
      1.25862521011981197e-18*V01*V04*V19 - 1.77698902426060336e-19*V07*V19 + 9.95667001920338071e-20*V022*V20 + 
      2.89126379403790478e-19*V01*V03*V20 - 5.87492159558001676e-20*V06*V20 + 3.25506519858572062e-20*V01*V02*V21 - 
      1.98920651024682927e-20*V05*V21 + 1.9147442344621886e-21*V012*V22 - 4.04223782830906482e-21*V04*V22 - 
      9.04184777384922394e-22*V03*V23 - 8.50997437538750488e-23*V02*V24 - 1.06374679692343811e-23*V01*V25 + 
      1.52837183466011223e-26*V28) + delta12*eps8*
    (1.69722051530330397e-12*V045 + 9.90045300593593985e-11*V03*V043*V05 + 
      1.65145212109441825e-10*V032*V04*V052 + 7.29432517380202435e-11*V02*V042*V052 + 
      5.64335642606010761e-11*V02*V03*V053 + 3.24106070216067245e-11*V01*V04*V053 + 
      1.05663509164113951e-10*V032*V042*V06 + 1.17532365180228153e-11*V02*V043*V06 + 
      7.57945446961099518e-11*V033*V05*V06 + 2.10162034740904921e-10*V02*V03*V04*V05*V06 + 
      6.33981054984683709e-11*V01*V042*V05*V06 + 2.56238332842952961e-11*V022*V052*V06 + 
      6.63802309875038209e-11*V01*V03*V052*V06 + 3.74575065295956479e-11*V02*V032*V062 + 
      6.06698639197789842e-12*V022*V04*V062 + 4.45126951642857669e-11*V01*V03*V04*V062 + 
      2.24745039177573887e-11*V01*V02*V05*V062 - 1.63160233770679799e-11*V052*V062 + 
      1.52221561580565904e-12*V012*V063 - 5.78540684073728724e-12*V04*V063 + 
      5.14454079708043246e-11*V033*V04*V07 + 6.94697635600192795e-11*V02*V03*V042*V07 + 
      1.41435042941941998e-11*V01*V043*V07 + 7.92724339032897677e-11*V02*V032*V05*V07 + 
      3.34782410990087043e-11*V022*V04*V05*V07 + 9.03276914070541286e-11*V01*V03*V04*V05*V07 + 
      2.33776470874305423e-11*V01*V02*V052*V07 - 1.08185146013897752e-11*V053*V07 + 
      2.4403650746947901e-11*V022*V03*V06*V07 + 3.07358913088136596e-11*V01*V032*V06*V07 + 
      3.00231478201292744e-11*V01*V02*V04*V06*V07 + 8.68957492519746369e-12*V012*V05*V06*V07 - 
      4.37093686329841425e-11*V04*V05*V06*V07 - 1.566181267711276e-11*V03*V062*V07 + 
      1.25464861823383465e-12*V023*V072 + 1.08474889550181841e-11*V01*V02*V03*V072 + 
      2.96769747346639897e-12*V012*V04*V072 - 7.28858817233331817e-12*V042*V072 - 
      1.55159626435125332e-11*V03*V05*V072 - 5.24660148877228691e-12*V02*V06*V072 - 
      7.44212283487397049e-13*V01*V073 + 6.67609532142999851e-12*V034*V08 + 
      3.84582775897924735e-11*V02*V032*V04*V08 + 3.05603303904589489e-12*V022*V042*V08 + 
      2.28990069525048949e-11*V01*V03*V042*V08 + 1.89494560578382592e-11*V022*V03*V05*V08 + 
      2.31650689866383551e-11*V01*V032*V05*V08 + 2.30749665538754841e-11*V01*V02*V04*V05*V08 + 
      3.25981262240335248e-12*V012*V052*V08 - 1.70529257356118519e-11*V04*V052*V08 + 
      6.94763678262057234e-13*V023*V06*V08 + 1.62296042957806157e-11*V01*V02*V03*V06*V08 + 
      4.69918606764911534e-12*V012*V04*V06*V08 - 9.01512332233048342e-12*V042*V06*V08 - 
      2.43390798066278307e-11*V03*V05*V06*V08 - 3.22453879873185615e-12*V02*V062*V08 + 
      2.70706515111975132e-12*V01*V022*V07*V08 + 2.98045856840657767e-12*V012*V03*V07*V08 - 
      1.63678310962694555e-11*V03*V04*V07*V08 - 8.22054068494952146e-12*V02*V05*V07*V08 - 
      3.5306585954940383e-12*V01*V06*V07*V08 + 4.27227659317861358e-13*V012*V02*V082 - 
      2.25523495409310078e-12*V032*V082 - 1.67159794752105173e-12*V02*V04*V082 - 
      1.36330647299124867e-12*V01*V05*V082 + 2.80098426526990846e-14*V083 + 
      7.09060617403523279e-12*V02*V033*V09 + 9.29951141639130675e-12*V022*V03*V04*V09 + 
      1.19842625250196528e-11*V01*V032*V04*V09 + 5.78914696333493996e-12*V01*V02*V042*V09 + 
      1.46375672127280709e-12*V023*V05*V09 + 1.2430913178878777e-11*V01*V02*V03*V05*V09 + 
      3.3886904571058416e-12*V012*V04*V05*V09 - 8.57100355790489362e-12*V042*V05*V09 - 
      9.08705561862994056e-12*V03*V052*V09 + 2.03363756224565842e-12*V01*V022*V06*V09 + 
      2.26814706342825295e-12*V012*V03*V06*V09 - 1.23340808419557285e-11*V03*V04*V06*V09 - 
      6.1692665648056855e-12*V02*V05*V06*V09 - 1.33583675497378195e-12*V01*V062*V09 + 
      8.11760639874362548e-13*V012*V02*V07*V09 - 4.33464495272616129e-12*V032*V07*V09 - 
      4.09110037577523526e-12*V02*V04*V07*V09 - 2.60926157468941e-12*V01*V05*V07*V09 + 
      6.79697068800438898e-14*V013*V08*V09 - 2.31898587308895023e-12*V02*V03*V08*V09 - 
      1.39572328551556802e-12*V01*V04*V08*V09 + 1.71686331083175458e-13*V07*V08*V09 - 
      1.41825665686594023e-13*V022*V092 - 3.61035387268690237e-13*V01*V03*V092 + 
      6.53857258245341292e-14*V06*V092 + 2.10846776290424879e-12*V022*V032*V10 + 
      1.62762786071965243e-12*V01*V033*V10 + 2.0882306763634111e-13*V023*V04*V10 + 
      5.06712184364963239e-12*V01*V02*V03*V04*V10 + 7.35486409901654912e-13*V012*V042*V10 - 
      9.59305627506322286e-13*V043*V10 + 1.26508065774254928e-12*V01*V022*V05*V10 + 
      1.35509493219951251e-12*V012*V03*V05*V10 - 7.86276590867499058e-12*V03*V04*V05*V10 - 
      1.98258060474281681e-12*V02*V052*V10 + 5.19864378696037504e-13*V012*V02*V06*V10 - 
      2.78858403478309586e-12*V032*V06*V10 - 2.05469609340393125e-12*V02*V04*V06*V10 - 
      1.68557798488720377e-12*V01*V05*V06*V10 + 5.40740308239601506e-14*V013*V07*V10 - 
      1.90247352254040442e-12*V02*V03*V07*V10 - 1.14020824033674051e-12*V01*V04*V07*V10 + 
      7.06450656808127573e-14*V072*V10 - 1.88915965409151507e-13*V022*V08*V10 - 
      6.17169857042578985e-13*V01*V03*V08*V10 + 1.05241906443131414e-13*V06*V08*V10 - 1.62114839717559375e-13*V01*V02*V09*V10 + 
      8.43512198400368814e-14*V05*V09*V10 - 1.01879759579391264e-14*V012*V102 + 
      1.74429213223327529e-14*V04*V102 + 2.66137585685964925e-13*V023*V03*V11 + 
      1.05906854914023571e-12*V01*V02*V032*V11 + 5.07246077257707641e-13*V01*V022*V04*V11 + 
      5.68284293963893289e-13*V012*V03*V04*V11 - 1.59526465971872016e-12*V03*V042*V11 + 
      2.9770002966244182e-13*V012*V02*V05*V11 - 1.66744937872337325e-12*V032*V05*V11 - 
      1.58652933824338137e-12*V02*V04*V05*V11 - 5.007211389248975e-13*V01*V052*V11 + 
      3.32257525080438846e-14*V013*V06*V11 - 1.1479929179126796e-12*V02*V03*V06*V11 - 
      6.93777815562933079e-13*V01*V04*V06*V11 - 1.87092052579593526e-13*V022*V07*V11 - 
      4.74251271528799159e-13*V01*V03*V07*V11 + 8.74934122198606157e-14*V06*V07*V11 - 1.30363122113054841e-13*V01*V02*V08*V11 + 
      6.8574529490516731e-14*V05*V08*V11 - 1.90080765250655044e-14*V012*V09*V11 + 3.53027384466007188e-14*V04*V09*V11 + 
      1.64052489611799716e-14*V03*V10*V11 + 1.73546694453885326e-15*V02*V112 + 
      3.48280913281984102e-15*V024*V12 + 1.85950769278642338e-13*V01*V022*V03*V12 + 
      9.34645124364953167e-14*V012*V032*V12 + 1.08783666218579755e-13*V012*V02*V04*V12 - 
      6.13856704112766429e-13*V032*V04*V12 - 2.21778759541654563e-13*V02*V042*V12 + 
      1.6280968105939485e-14*V013*V05*V12 - 6.22704221012906932e-13*V02*V03*V05*V12 - 
      3.70956271646512361e-13*V01*V04*V05*V12 - 7.86666000003416018e-14*V022*V06*V12 - 
      2.60023262126741606e-13*V01*V03*V06*V12 + 2.27134927216431786e-14*V062*V12 - 
      9.02421222515664391e-14*V01*V02*V07*V12 + 4.79014585663032558e-14*V05*V07*V12 - 
      1.38882189976287973e-14*V012*V08*V12 + 2.40467287854516429e-14*V04*V08*V12 + 
      1.39260898601988465e-14*V03*V09*V12 + 2.9018707451200084e-15*V02*V10*V12 + 8.28596396924692205e-16*V01*V11*V12 + 
      1.02360609879217279e-14*V01*V023*V13 + 3.42738835019884867e-14*V012*V02*V03*V13 - 
      7.19332390498911321e-14*V033*V13 + 5.70923117878059699e-15*V013*V04*V13 - 
      2.09676282115613157e-13*V02*V03*V04*V13 - 6.37217418137510935e-14*V01*V042*V13 - 
      5.1525422695415292e-14*V022*V05*V13 - 1.28648176024020543e-13*V01*V03*V05*V13 - 
      4.58399896599754662e-14*V01*V02*V06*V13 + 2.51117911730858733e-14*V05*V06*V13 - 
      8.82037675447656105e-15*V012*V07*V13 + 1.69741932779255435e-14*V04*V07*V13 + 
      9.58338797132798474e-15*V03*V08*V13 + 2.49469101004387013e-15*V02*V09*V13 + 7.01380077351058344e-16*V01*V10*V13 - 
      4.27353345192435548e-18*V132 + 2.83817431889704983e-15*V012*V022*V14 + 
      1.54753458517703007e-15*V013*V03*V14 - 3.52847386806752976e-14*V02*V032*V14 - 
      1.22374878213716136e-14*V022*V04*V14 - 4.15516029503519116e-14*V01*V03*V04*V14 - 
      2.13136767458152763e-14*V01*V02*V05*V14 + 5.95542265348387808e-15*V052*V14 - 
      4.25021139007428497e-15*V012*V06*V14 + 7.60517821823443363e-15*V04*V06*V14 + 
      5.80084922444112894e-15*V03*V07*V14 + 1.46578502492623655e-15*V02*V08*V14 + 5.160537622557416e-16*V01*V09*V14 - 
      7.73886903353060472e-18*V12*V14 + 2.40453580963761644e-16*V013*V02*V15 - 
      5.09043477455507611e-15*V022*V03*V15 - 6.12709857802884349e-15*V01*V032*V15 - 
      6.25968312779994327e-15*V01*V02*V04*V15 - 1.77277552319798963e-15*V012*V05*V15 + 
      3.67333501324724325e-15*V04*V05*V15 + 2.64593878461763225e-15*V03*V06*V15 + 9.04658570208272093e-16*V02*V07*V15 + 
      3.08960363931146751e-16*V01*V08*V15 - 6.47264097833335275e-18*V11*V15 + 6.16547643496824729e-18*V014*V16 - 
      1.68403882914543334e-16*V023*V16 - 1.81046088097259627e-15*V01*V02*V03*V16 - 
      5.15451700909533787e-16*V012*V04*V16 + 4.86090927718546833e-16*V042*V16 + 
      1.10218688305046193e-15*V03*V05*V16 + 3.54020465499464205e-16*V02*V06*V16 + 1.64312925482935176e-16*V01*V07*V16 - 
      4.39498432485673238e-18*V10*V16 - 1.17948244842870818e-16*V01*V022*V17 - 
      1.28469764411240544e-16*V012*V03*V17 + 3.01963143875664068e-16*V03*V04*V17 + 
      1.52772017359073719e-16*V02*V05*V17 + 6.65625729466481393e-17*V01*V06*V17 - 2.77491205584608323e-18*V09*V17 - 
      1.75582046300182694e-17*V012*V02*V18 + 4.00700121566097593e-17*V032*V18 + 
      3.5554247441650226e-17*V02*V04*V18 + 2.45368091165547928e-17*V01*V05*V18 - 1.3760805856134416e-18*V08*V18 - 
      6.7016048206176601e-19*V013*V19 + 1.00524072309264901e-17*V02*V03*V19 + 6.08058944057375693e-18*V01*V04*V19 - 
      6.44825579181706125e-19*V07*V19 + 5.19746684976791861e-19*V022*V20 + 1.42520795851802238e-18*V01*V03*V20 - 
      2.21277062873357184e-19*V06*V20 + 1.65306252241902282e-19*V01*V02*V21 - 7.41520163022046649e-20*V05*V21 + 
      1.00524072309264901e-20*V012*V22 - 1.57611817077489413e-20*V04*V22 - 3.50593215152683144e-21*V03*V23 - 
      3.47490620328323116e-22*V02*V24 - 4.34363275410403895e-23*V01*V25 + 5.3493014213103928e-26*V28) + 
   delta10*eps9*(2.94346529368315861e-11*V045 + 1.07985655286172715e-9*V03*V043*V05 + 
      1.71897339904773307e-9*V032*V04*V052 + 7.96266008412303666e-10*V02*V042*V052 + 
      5.8607426055896506e-10*V02*V03*V053 + 3.39463604350525028e-10*V01*V04*V053 + 
      1.15932748685713087e-9*V032*V042*V06 + 2.06411599190622904e-10*V02*V043*V06 + 
      7.94747422420482385e-10*V033*V05*V06 + 2.30172081336221789e-9*V02*V03*V04*V05*V06 + 
      6.95596492114278522e-10*V01*V042*V05*V06 + 2.81347387631380162e-10*V022*V052*V06 + 
      7.01468961792346197e-10*V01*V03*V052*V06 + 4.12513514218773564e-10*V02*V032*V062 + 
      1.08095995688749874e-10*V022*V04*V062 + 4.91928317844827125e-10*V01*V03*V04*V062 + 
      2.47508108531264139e-10*V01*V02*V05*V062 - 6.99871235822987974e-11*V052*V062 + 
      1.69186310382554962e-11*V012*V063 - 2.82711509161556807e-11*V04*V063 + 
      5.38831118016706393e-10*V033*V04*V07 + 7.58348579440289206e-10*V02*V03*V042*V07 + 
      1.54265221837389593e-10*V01*V043*V07 + 8.28508293443252896e-10*V02*V032*V05*V07 + 
      3.67630249386954262e-10*V022*V04*V05*V07 + 9.535216764415262e-10*V01*V03*V04*V05*V07 + 
      2.45930292969252426e-10*V01*V02*V052*V07 - 4.50648873161857779e-11*V053*V07 + 
      2.67949892982266821e-10*V022*V03*V06*V07 + 3.27459639717265832e-10*V01*V032*V06*V07 + 
      3.28817259051745412e-10*V01*V02*V04*V06*V07 + 9.4048614407050179e-11*V012*V05*V06*V07 - 
      1.89215565149637133e-10*V04*V05*V06*V07 - 6.81763445170203853e-11*V03*V062*V07 + 
      1.39444848287510596e-11*V023*V072 + 1.15182666174941962e-10*V01*V02*V03*V072 + 
      3.21017537411587722e-11*V012*V04*V072 - 3.18406426463850054e-11*V042*V072 - 
      6.56634174168191508e-11*V03*V05*V072 - 2.32359443397106751e-11*V02*V06*V072 - 
      3.24855532859376506e-12*V01*V073 + 7.09335127901937342e-11*V034*V08 + 
      4.255771685715893e-10*V02*V032*V04*V08 + 5.51372149754177856e-11*V022*V042*V08 + 
      2.54174166457058009e-10*V01*V03*V042*V08 + 2.09757140803781025e-10*V022*V03*V05*V08 + 
      2.48540229250877708e-10*V01*V032*V05*V08 + 2.5534630114295358e-10*V01*V02*V04*V05*V08 + 
      3.55537576199033233e-11*V012*V052*V08 - 7.41718453423337579e-11*V04*V052*V08 + 
      1.27541569802581361e-11*V023*V06*V08 + 1.8086421825184335e-10*V01*V02*V03*V06*V08 + 
      5.24600512141898831e-11*V012*V04*V06*V08 - 4.4634629696567675e-11*V042*V06*V08 - 
      1.06465580947736599e-10*V03*V05*V06*V08 - 1.61793688506655506e-11*V02*V062*V08 + 
      2.9965305829111575e-11*V01*V022*V07*V08 + 3.28863762865051076e-11*V012*V03*V07*V08 - 
      7.22184165366019031e-11*V03*V04*V07*V08 - 3.65672326448746265e-11*V02*V05*V07*V08 - 
      1.58851445341324774e-11*V01*V06*V07*V08 + 4.81429545930922416e-12*V012*V02*V082 - 
      1.00567311914564964e-11*V032*V082 - 8.49608394495698954e-12*V02*V04*V082 - 
      6.1646152851312787e-12*V01*V05*V082 + 9.4887905784810694e-14*V083 + 
      7.50950919461509207e-11*V02*V033*V09 + 1.02119513718598406e-10*V022*V03*V04*V09 + 
      1.28440672102984811e-10*V01*V032*V04*V09 + 6.31957149533574338e-11*V01*V02*V042*V09 + 
      1.62685656335429029e-11*V023*V05*V09 + 1.32923002168697043e-10*V01*V02*V03*V05*V09 + 
      3.69364418100398072e-11*V012*V04*V05*V09 - 3.79694474739357151e-11*V042*V05*V09 - 
      3.9034308676048156e-11*V03*V052*V09 + 2.23291577485222351e-11*V01*V022*V06*V09 + 
      2.50290819078244188e-11*V012*V03*V06*V09 - 5.49219470293534729e-11*V03*V04*V06*V09 - 
      2.76958345878698167e-11*V02*V05*V06*V09 - 6.06184731941184335e-12*V01*V062*V09 + 
      8.94597365597926538e-12*V012*V02*V07*V09 - 1.89037760065707799e-11*V032*V07*V09 - 
      1.85289155193646286e-11*V02*V04*V07*V09 - 1.15536048336506895e-11*V01*V05*V07*V09 + 
      7.95055001224887219e-13*V013*V08*V09 - 1.05951063776393714e-11*V02*V03*V08*V09 - 
      6.41284233545450153e-12*V01*V04*V08*V09 + 5.55883324588347876e-13*V07*V08*V09 - 
      6.65118998787311756e-13*V022*V092 - 1.64515184248772008e-12*V01*V03*V092 + 
      2.13608060848841071e-13*V06*V092 + 2.37158096442747268e-11*V022*V032*V10 + 
      1.78646809595064318e-11*V01*V033*V10 + 3.93339699765279626e-12*V023*V04*V10 + 
      5.70557438613053632e-11*V01*V02*V03*V04*V10 + 8.29135109407503231e-12*V012*V042*V10 - 
      4.86945810336921357e-12*V043*V10 + 1.42294857865648361e-11*V01*V022*V05*V10 + 
      1.51736511538758572e-11*V012*V03*V05*V10 - 3.53050072330784785e-11*V03*V04*V05*V10 - 
      8.97064762190009636e-12*V02*V052*V10 + 5.88941853542087871e-12*V012*V02*V06*V10 - 
      1.25932366524160681e-11*V032*V06*V10 - 1.05676700348517258e-11*V02*V04*V06*V10 - 
      7.71623126310894452e-12*V01*V05*V06*V10 + 6.36406082595999729e-13*V013*V07*V10 - 
      8.72294959529437055e-12*V02*V03*V07*V10 - 5.25867723896048924e-12*V01*V04*V07*V10 + 
      2.28898431203407425e-13*V072*V10 - 9.97338905526024202e-13*V022*V08*V10 - 
      2.8782774654125242e-12*V01*V03*V08*V10 + 3.60135174475426985e-13*V06*V08*V10 - 7.71781383693338668e-13*V01*V02*V09*V10 + 
      2.76443023372544839e-13*V05*V09*V10 - 4.96460571321507087e-14*V012*V102 + 
      6.10495166679236661e-14*V04*V102 + 2.9579210242805278e-12*V023*V03*V11 + 
      1.16146626148653275e-11*V01*V02*V032*V11 + 5.57015529374173124e-12*V01*V022*V04*V11 + 
      6.37387447085132202e-12*V012*V03*V04*V11 - 7.35191647879915301e-12*V03*V042*V11 + 
      3.33627493944288791e-12*V012*V02*V05*V11 - 7.47447845867108231e-12*V032*V05*V11 - 
      7.3704400826648317e-12*V02*V04*V05*V11 - 2.27772842501028492e-12*V01*V052*V11 + 
      3.92839496530436844e-13*V013*V06*V11 - 5.35591512045307342e-12*V02*V03*V06*V11 - 
      3.2534226911779279e-12*V01*V04*V06*V11 - 8.87941756531218918e-13*V022*V07*V11 - 
      2.18868978399247471e-12*V01*V03*V07*V11 + 2.88103562668946431e-13*V06*V07*V11 - 6.25646721041756942e-13*V01*V02*V08*V11 + 
      2.26356906084163136e-13*V05*V08*V11 - 9.17518543701169467e-14*V012*V09*V11 + 
      1.18720485286494369e-13*V04*V09*V11 + 5.55963333795981137e-14*V03*V10*V11 + 6.08766127182957582e-15*V02*V112 + 
      6.97126310184236409e-14*V024*V12 + 2.14508023030128266e-12*V01*V022*V03*V12 + 
      1.08549131494993563e-12*V012*V032*V12 + 1.25421574306927669e-12*V012*V02*V04*V12 - 
      2.87395694078467199e-12*V032*V04*V12 - 1.18073000878447294e-12*V02*V042*V12 + 
      1.96419748265218422e-13*V013*V05*V12 - 2.93488217411979218e-12*V02*V03*V05*V12 - 
      1.75892385028531593e-12*V01*V04*V05*V12 - 4.24427157495073098e-13*V022*V06*V12 - 
      1.24049252083159444e-12*V01*V03*V06*V12 + 7.90915954466652055e-14*V062*V12 - 
      4.35830349941432114e-13*V01*V02*V07*V12 + 1.58221233806604946e-13*V05*V07*V12 - 
      6.83918592447986524e-14*V012*V08*V12 + 8.47838077594851237e-14*V04*V08*V12 + 
      4.71921138034589144e-14*V03*V09*V12 + 1.06064692652075795e-14*V02*V10*V12 + 2.94712436112520976e-15*V01*V11*V12 + 
      1.13766193241558761e-13*V01*V023*V13 + 4.018188964103246e-13*V012*V02*V03*V13 - 
      3.39446113184688056e-13*V033*V13 + 6.98943070573740386e-14*V013*V04*V13 - 
      1.02076494598224435e-12*V02*V03*V04*V13 - 3.115083629311985e-13*V01*V042*V13 - 
      2.52986278945218013e-13*V022*V05*V13 - 6.15808787097615085e-13*V01*V03*V05*V13 - 
      2.26529352821879131e-13*V01*V02*V06*V13 + 8.4727092316375805e-14*V05*V06*V13 - 
      4.35519694409946241e-14*V012*V07*V13 + 5.78301316721366918e-14*V04*V07*V13 + 
      3.28743702409754702e-14*V03*V08*V13 + 8.79555959489167708e-15*V02*V09*V13 + 2.50710033784371886e-15*V01*V10*V13 - 
      1.28605817626567052e-17*V132 + 3.39150527734733347e-14*V012*V022*V14 + 
      1.97689836410821881e-14*V013*V03*V14 - 1.74504919696047553e-13*V02*V032*V14 - 
      6.88531028421720269e-14*V022*V04*V14 - 2.06827059977782492e-13*V01*V03*V04*V14 - 
      1.06625347370051632e-13*V01*V02*V05*V14 + 2.01573940483405383e-14*V052*V14 - 
      2.15718046925592802e-14*V012*V06*V14 + 2.74241246925085559e-14*V04*V06*V14 + 1.9914991776080897e-14*V03*V07*V14 + 
      5.42456758466606654e-15*V02*V08*V14 + 1.84487798792354805e-15*V01*V09*V14 - 2.36008514869398616e-17*V12*V14 + 
      3.21837869905342508e-15*V013*V02*V15 - 2.63042546300521179e-14*V022*V03*V15 - 
      3.10484279082444893e-14*V01*V032*V15 - 3.24148583247491478e-14*V01*V02*V04*V15 - 
      9.13844236549065366e-15*V012*V05*V15 + 1.28653803882824346e-14*V04*V05*V15 + 
      9.30702659603714739e-15*V03*V06*V15 + 3.24213499459520527e-15*V02*V07*V15 + 1.12131899680374015e-15*V01*V08*V15 - 
      1.94978857487673357e-17*V11*V15 + 9.24821465245237093e-17*V014*V16 - 1.00713504338861027e-15*V023*V16 - 
      9.5489022575438441e-15*V01*V02*V03*V16 - 2.74127804866401263e-15*V012*V04*V16 + 
      1.82135143557975467e-15*V042*V16 + 3.8926459245492656e-15*V03*V05*V16 + 1.34458139769482602e-15*V02*V06*V16 + 
      5.97447399597582336e-16*V01*V07*V16 - 1.34599721373616975e-17*V10*V16 - 6.48500895281529732e-16*V01*V022*V17 - 
      7.04231440969786193e-16*V012*V03*V17 + 1.10490698998487486e-15*V03*V04*V17 + 
      5.64120095437823358e-16*V02*V05*V17 + 2.48213369185554833e-16*V01*V06*V17 - 8.39360579453806537e-18*V09*V17 - 
      9.91837513451413694e-17*V012*V02*V18 + 1.48092063326009053e-16*V032*V18 + 
      1.40635411028935136e-16*V02*V04*V18 + 9.20552542974503644e-17*V01*V05*V18 - 4.25846563971969208e-18*V08*V18 - 
      4.02096289237059606e-18*V013*V19 + 3.88268644623851834e-17*V02*V03*V19 + 2.36131045854463253e-17*V01*V04*V19 - 
      1.97123450811280778e-18*V07*V19 + 2.17400060380836893e-18*V022*V20 + 5.6072327534107962e-18*V01*V03*V20 - 
      6.98636983815406448e-19*V06*V20 + 6.77532247364445436e-19*V01*V02*V21 - 2.31689371103909438e-19*V05*V21 + 
      4.22201103698912586e-20*V012*V22 - 5.14534325671867014e-20*V04*V22 - 1.1374112626103862e-20*V03*V23 - 
      1.19139641255425068e-21*V02*V24 - 1.48924551569281335e-22*V01*V25 + 1.60479042639311784e-25*V28) + 
   delta8*eps10*(-3.48353822487445235e-10*V036 - 5.63618331860497148e-9*V02*V034*V04 - 
      7.52142487857241595e-9*V022*V032*V042 - 6.31557116084406533e-9*V01*V033*V042 - 
      1.18235613578975095e-10*V023*V043 - 6.20497920477853972e-9*V01*V02*V03*V043 - 
      4.68244180888229736e-10*V012*V044 + 2.04522364126337295e-10*V045 - 
      5.69957259001663313e-9*V022*V033*V05 - 2.91870821835366133e-9*V01*V034*V05 - 
      4.75996246502304676e-9*V023*V03*V04*V05 - 1.94477609941236912e-8*V01*V02*V032*V04*V05 - 
      4.51285492714344957e-9*V01*V022*V042*V05 - 5.29793573792971798e-9*V012*V03*V042*V05 + 
      5.59571374853810928e-9*V03*V043*V05 - 2.76558300226923378e-10*V024*V052 - 
      4.94975404004256773e-9*V01*V022*V03*V052 - 2.375237797497436e-9*V012*V032*V052 - 
      2.73842679842908882e-9*V012*V02*V04*V052 + 8.44899434558817426e-9*V032*V04*V052 + 
      4.17434942425085623e-9*V02*V042*V052 - 1.38131989351095415e-10*V013*V053 + 
      2.90352382085443044e-9*V02*V03*V053 + 1.70184735404769042e-9*V01*V04*V053 - 
      1.73954584163477662e-9*V023*V032*V06 - 4.40434437955229898e-9*V01*V02*V033*V06 - 
      5.87254203673968461e-11*V024*V04*V06 - 6.49781876600089265e-9*V01*V022*V03*V04*V06 - 
      3.5490267205211955e-9*V012*V032*V04*V06 - 1.97199129312179211e-9*V012*V02*V042*V06 + 
      6.04178321890165732e-9*V032*V042*V06 + 1.45494291493694489e-9*V02*V043*V06 - 
      1.04372750498086597e-9*V01*V023*V05*V06 - 3.67813736079536552e-9*V012*V02*V03*V05*V06 + 
      3.94832555048672289e-9*V033*V05*V06 - 6.34555710698009723e-10*V013*V04*V05*V06 + 
      1.21278448455036406e-8*V02*V03*V04*V05*V06 + 3.68117797660595973e-9*V01*V042*V05*V06 + 
      1.50086149642047213e-9*V022*V052*V06 + 3.55613591527038345e-9*V01*V03*V052*V06 - 
      3.44719728612722945e-10*V012*V022*V062 - 2.08773784678927438e-10*V013*V03*V062 + 
      2.18499743603896193e-9*V02*V032*V062 + 7.73560057249388023e-10*V022*V04*V062 + 
      2.61697161424435874e-9*V01*V03*V04*V062 + 1.33089573649811817e-9*V01*V02*V05*V062 - 
      2.15515965268820468e-10*V052*V062 + 9.16959769356950817e-11*V012*V063 - 
      9.67413716629006364e-11*V04*V063 - 2.63388857358974646e-10*V024*V03*V07 - 
      2.27137749955722174e-9*V01*V022*V032*V07 - 7.11282704434497315e-10*V012*V033*V07 - 
      6.79994637860435252e-10*V01*V023*V04*V07 - 2.48766852904853134e-9*V012*V02*V03*V04*V07 + 
      2.70257970473577217e-9*V033*V04*V07 - 2.15513291631896969e-10*V013*V042*V07 + 
      4.03779812962716808e-9*V02*V03*V042*V07 + 8.24512636044631884e-10*V01*V043*V07 - 
      6.39821675829280626e-10*V012*V022*V05*V07 - 3.68508356270347032e-10*V013*V03*V05*V07 + 
      4.1867374435375795e-9*V02*V032*V05*V07 + 1.98341983515254212e-9*V022*V04*V05*V07 + 
      4.87810293002306012e-9*V01*V03*V04*V05*V07 + 1.26645435615914452e-9*V01*V02*V052*V07 - 
      1.34822783062642816e-10*V053*V07 - 1.47932961866283733e-10*V013*V02*V06*V07 + 
      1.45131577655238092e-9*V022*V03*V06*V07 + 1.69420034313961507e-9*V01*V032*V06*V07 + 
      1.78593788867828818e-9*V01*V02*V04*V06*V07 + 4.97484348880810243e-10*V012*V05*V06*V07 - 
      5.91527317494421009e-10*V04*V05*V06*V07 - 2.14111837640765805e-10*V03*V062*V07 - 
      4.98460273337877888e-12*V014*V072 + 7.75456826903812862e-11*V023*V072 + 
      6.04883423727214372e-10*V01*V02*V03*V072 + 1.71199337557789747e-10*V012*V04*V072 - 
      1.01035142618061238e-10*V042*V072 - 2.00437065382737022e-10*V03*V05*V072 - 
      7.51436497578171893e-11*V02*V06*V072 - 1.034089196038987e-11*V01*V073 - 
      1.90317570721649182e-12*V025*V08 - 3.82821435828408598e-10*V01*V023*V03*V08 - 
      6.21948995444348751e-10*V012*V02*V032*V08 + 3.62822522193854791e-10*V034*V08 - 
      3.51341006389575525e-10*V012*V022*V04*V08 - 2.10733814299509583e-10*V013*V03*V04*V08 + 
      2.29129168331781158e-9*V02*V032*V04*V08 + 4.00038718360123285e-10*V022*V042*V08 + 
      1.37391448269021764e-9*V01*V03*V042*V08 - 1.09914167977695533e-10*V013*V02*V05*V08 + 
      1.14273217810063096e-9*V022*V03*V05*V08 + 1.29747898633794244e-9*V01*V032*V05*V08 + 
      1.39521690195051682e-9*V01*V02*V04*V05*V08 + 1.89817244764465933e-10*V012*V052*V08 - 
      2.32345054050319718e-10*V04*V052*V08 - 8.4691450501297832e-12*V014*V06*V08 + 
      9.40480899945783424e-11*V023*V06*V08 + 9.92961990520016034e-10*V01*V02*V03*V06*V08 + 
      2.88801564071787016e-10*V012*V04*V06*V08 - 1.55454334755832098e-10*V042*V06*V08 - 
      3.35167087204343158e-10*V03*V05*V06*V08 - 5.74591434619374414e-11*V02*V062*V08 + 
      1.68078190530655331e-10*V01*V022*V07*V08 + 1.7922784297330001e-10*V012*V03*V07*V08 - 
      2.30627741795751109e-10*V03*V04*V07*V08 - 1.1847375577040188e-10*V02*V05*V07*V08 - 
      5.20635310606352351e-11*V01*V06*V07*V08 + 2.73302791010986286e-11*V012*V02*V082 - 
      3.23689884485910393e-11*V032*V082 - 3.0687952430678249e-11*V02*V04*V082 - 
      2.02660877457561619e-11*V01*V05*V082 + 2.5478272581313858e-13*V083 - 
      2.19490714465812205e-11*V01*V024*V09 - 1.63453537653180961e-10*V012*V022*V03*V09 - 
      4.5621590851981985e-11*V013*V032*V09 + 3.9451350045098616e-10*V02*V033*V09 - 
      5.63016510897856419e-11*V013*V02*V04*V09 + 5.67847963196590586e-10*V022*V03*V04*V09 + 
      6.83497674924997587e-10*V01*V032*V04*V09 + 3.52039989815995021e-10*V01*V02*V042*V09 - 
      5.54652425566178494e-12*V014*V05*V09 + 9.18275435053114489e-11*V023*V05*V09 + 
      7.11472707603287305e-10*V01*V02*V03*V05*V09 + 2.00808560272265483e-10*V012*V04*V05*V09 - 
      1.22379251573796394e-10*V042*V05*V09 - 1.2104186629599732e-10*V03*V052*V09 + 
      1.26423950179252656e-10*V01*V022*V06*V09 + 1.3777207229766087e-10*V012*V03*V06*V09 - 
      1.77770794499627443e-10*V03*V04*V06*V09 - 9.09454281396483529e-11*V02*V05*V06*V09 - 
      2.01178788126795057e-11*V01*V062*V09 + 4.98127842058461555e-11*V012*V02*V07*V09 - 
      5.97734920434934253e-11*V032*V07*V09 - 6.17065865165672288e-11*V02*V04*V07*V09 - 
      3.73422990754700221e-11*V01*V05*V07*V09 + 4.6326605235350596e-12*V013*V08*V09 - 
      3.54902394595375172e-11*V02*V03*V08*V09 - 2.16182468692036307e-11*V01*V04*V08*V09 + 1.44416410754209022e-12*V07*V08*V09 - 
      2.31982052822957649e-12*V022*V092 - 5.50043602650990372e-12*V01*V03*V092 + 
      5.60756891947137004e-13*V06*V092 - 1.25177421440102926e-11*V012*V023*V10 - 
      2.16603545160845274e-11*V013*V02*V03*V10 + 1.33909625510296353e-10*V022*V032*V10 + 
      9.76607742790705792e-11*V01*V033*V10 - 2.52831391454603897e-12*V014*V04*V10 + 
      2.97886436303311412e-11*V023*V04*V10 + 3.23010487473487697e-10*V01*V02*V03*V04*V10 + 
      4.70550540341506635e-11*V012*V042*V10 - 1.75022677593823745e-11*V043*V10 + 
      8.14695838240757881e-11*V01*V022*V05*V10 + 8.48788142856757976e-11*V012*V03*V05*V10 - 
      1.14552171393243433e-10*V03*V04*V05*V10 - 2.95108352868355473e-11*V02*V052*V10 + 
      3.39326742656223317e-11*V012*V02*V06*V10 - 4.10807357303802357e-11*V032*V06*V10 - 
      3.87061693537785587e-11*V02*V04*V06*V10 - 2.57011365522157467e-11*V01*V05*V06*V10 + 
      3.73548841761136647e-12*V013*V07*V10 - 2.92217665576245852e-11*V02*V03*V07*V10 - 
      1.77384521140662386e-11*V01*V04*V07*V10 + 5.93962491830135727e-13*V072*V10 - 
      3.78246057178661458e-12*V022*V08*V10 - 9.79616287622452431e-12*V01*V03*V08*V10 + 
      9.76297712086681666e-13*V06*V08*V10 - 2.72121658140061301e-12*V01*V02*V09*V10 + 7.25084909932484695e-13*V05*V09*V10 - 
      1.78323033133655411e-13*V012*V102 + 1.69575297984627578e-13*V04*V102 - 
      2.29222549089823485e-12*V013*V022*V11 - 8.44435983486121085e-13*V014*V03*V11 + 
      1.74364153827111444e-11*V023*V03*V11 + 6.5728760123736834e-11*V01*V02*V032*V11 + 
      3.281694442754688e-11*V01*V022*V04*V11 + 3.66814218986499327e-11*V012*V03*V04*V11 - 
      2.47814438354677427e-11*V03*V042*V11 + 1.92631247960223483e-11*V012*V02*V05*V11 - 
      2.4270321576788209e-11*V032*V05*V11 - 2.51925693621858727e-11*V02*V04*V05*V11 - 
      7.5569455661131593e-12*V01*V052*V11 + 2.35164218730202385e-12*V013*V06*V11 - 
      1.83757610573746442e-11*V02*V03*V06*V11 - 1.12271506506756399e-11*V01*V04*V06*V11 - 
      3.13110455057833352e-12*V022*V07*V11 - 7.39832471867915497e-12*V01*V03*V07*V11 + 
      7.60245426486413122e-13*V06*V07*V11 - 2.22886744666734419e-12*V01*V02*V08*V11 + 5.97517127561872589e-13*V05*V08*V11 - 
      3.27626045988909981e-13*V012*V09*V11 + 3.21185006823789825e-13*V04*V09*V11 + 
      1.50808308443720851e-13*V03*V10*V11 + 1.72946818913936683e-14*V02*V112 - 
      1.63138506469259823e-13*V014*V02*V12 + 5.58419531667944093e-13*V024*V12 + 
      1.28764372320438753e-11*V01*V022*V03*V12 + 6.45396832557506403e-12*V012*V032*V12 + 
      7.54254792767127526e-12*V012*V02*V04*V12 - 9.75145473881211404e-12*V032*V04*V12 - 
      4.50376637938931664e-12*V02*V042*V12 + 1.20158353693452675e-12*V013*V05*V12 - 
      1.00839260572710666e-11*V02*V03*V05*V12 - 6.08782612914198772e-12*V01*V04*V05*V12 - 
      1.6484320757807942e-12*V022*V06*V12 - 4.31836552247896612e-12*V01*V03*V06*V12 + 
      2.17717556668614242e-13*V062*V12 - 1.55274369081896802e-12*V01*V02*V07*V12 + 
      4.16717345659387109e-13*V05*V07*V12 - 2.47998588843422056e-13*V012*V08*V12 + 
      2.36849734453498605e-13*V04*V08*V12 + 1.27868089741642656e-13*V03*V09*V12 + 3.09373294846011127e-14*V02*V10*V12 + 
      8.44356355298828722e-15*V01*V11*V12 - 3.88425015402999579e-15*V015*V13 + 
      7.1809920585718673e-13*V01*V023*V13 + 2.48945291657643411e-12*V012*V02*V03*V13 - 
      1.16160373954814387e-12*V033*V13 + 4.43525878302310805e-13*V013*V04*V13 - 
      3.66707114608416697e-12*V02*V03*V04*V13 - 1.12477065389886273e-12*V01*V042*V13 - 
      9.21441289700999496e-13*V022*V05*V13 - 2.15189828220726337e-12*V01*V03*V05*V13 - 
      8.31430815663206351e-13*V01*V02*V06*V13 + 2.27749640225126443e-13*V05*V06*V13 - 
      1.58376245559656605e-13*V012*V07*V13 + 1.57655305342467814e-13*V04*V07*V13 + 
      8.99693016116435438e-14*V03*V08*V13 + 2.50465583102290494e-14*V02*V09*V13 + 7.20849329211898222e-15*V01*V10*V13 - 
      3.21803883195180805e-17*V132 + 2.18045156860869549e-13*V012*V022*V14 + 
      1.30270351594444097e-13*V013*V03*V14 - 6.30326478088255669e-13*V02*V032*V14 - 
      2.80122041894993088e-13*V022*V04*V14 - 7.52745557853500325e-13*V01*V03*V04*V14 - 
      3.92273981607649023e-13*V01*V02*V05*V14 + 5.40803287586297931e-14*V052*V14 - 
      8.04948184417643853e-14*V012*V06*V14 + 7.80891139128618399e-14*V04*V06*V14 + 
      5.43740781719425874e-14*V03*V07*V14 + 1.597202818528769e-14*V02*V08*V14 + 5.29724316851910525e-15*V01*V09*V14 - 
      5.95245198917411751e-17*V12*V14 + 2.21957151658856902e-14*V013*V02*V15 - 
      1.00947915306144865e-13*V022*V03*V15 - 1.14771751173946253e-13*V01*V032*V15 - 
      1.24857632920951728e-13*V01*V02*V04*V15 - 3.4513834462590702e-14*V012*V05*V15 + 
      3.58028429140039697e-14*V04*V05*V15 + 2.59899778457856372e-14*V03*V06*V15 + 9.32107114925971582e-15*V02*V07*V15 + 
      3.25854476754579703e-15*V01*V08*V15 - 4.88025821976709744e-17*V11*V15 + 6.9361609893392782e-16*V014*V16 - 
      4.38463664730278108e-15*V023*V16 - 3.70702621454876177e-14*V01*V02*V03*V16 - 
      1.07299394782909356e-14*V012*V04*V16 + 5.38104465524185602e-15*V042*V16 + 
      1.08618951941430341e-14*V03*V05*V16 + 4.04737615083692379e-15*V02*V06*V16 + 1.73388722735808211e-15*V01*V07*V16 - 
      3.40357899883500811e-17*V10*V16 - 2.66841149944943681e-15*V01*V022*V17 - 
      2.82321857080570476e-15*V012*V03*V17 + 3.20146552388739126e-15*V03*V04*V17 + 
      1.65932740599216357e-15*V02*V05*V17 + 7.37439568257151854e-16*V01*V06*V17 - 2.10418823120977985e-17*V09*V17 - 
      4.14661798275717718e-16*V012*V02*V18 + 4.31147746134437162e-16*V032*V18 + 
      4.40295436714580268e-16*V02*V04*V18 + 2.73892913617438614e-16*V01*V05*V18 - 1.08451911250036055e-17*V08*V18 - 
      1.75917126541213578e-17*V013*V19 + 1.19137779698530452e-16*V02*V03*V19 + 7.29134604483201418e-17*V01*V04*V19 - 
      4.96989816781859134e-18*V07*V19 + 7.22432999662583758e-18*V022*V20 + 1.74509789528883869e-17*V01*V03*V20 - 
      1.80799724339092158e-18*V06*V20 + 2.21655579441929108e-18*V01*V02*V21 - 5.93510876925951522e-19*V05*V21 + 
      1.40733701232970862e-19*V012*V22 - 1.37382898822662032e-19*V04*V22 - 3.01572216927794704e-20*V03*V23 - 
      3.35080241030883005e-21*V02*V24 - 4.18850301288603756e-22*V01*V25 + 4.0119760659827946e-25*V28) + 
   eps14*(-4.44285396439000936e-8*V012*V026 - 2.38124362318310731e-7*V013*V024*V03 - 
      1.91046128236108395e-7*V014*V022*V032 + 8.47814123243652694e-8*V025*V032 - 
      1.35979953688287022e-8*V015*V033 + 4.85554468215240858e-7*V01*V023*V033 + 
      2.73534843558599589e-7*V012*V02*V034 - 5.66691941869923714e-9*V036 - 
      8.77483361362329616e-8*V014*V023*V04 + 1.66609565924847593e-8*V026*V04 - 
      5.61693735056830295e-8*V015*V02*V03*V04 + 5.31943375712827938e-7*V01*V024*V03*V04 + 
      1.23637235775819508e-6*V012*V022*V032*V04 + 
      1.92166939849085624e-7*V013*V033*V04 - 1.23357570532137392e-7*V02*V034*V04 - 
      1.71415954526073574e-9*V016*V042 + 3.15099921017591905e-7*V012*V023*V042 + 
      4.38158827637666048e-7*V013*V02*V03*V042 - 2.6288958283670669e-7*V022*V032*V042 - 
      1.49320092000854684e-7*V01*V033*V042 + 1.81036536333863598e-8*V014*V043 - 
      3.84541066603365207e-8*V023*V043 - 2.18275281392033712e-7*V01*V02*V03*V043 - 
      1.62557222292894705e-8*V012*V044 + 1.23616495716322489e-9*V045 - 
      1.47743203298758854e-8*V015*V022*V05 + 6.3486237399161944e-8*V01*V025*V05 - 
      2.61963152588152588e-9*V016*V03*V05 + 5.04749092373161098e-7*V012*V023*V03*V05 + 
      3.52991140766754484e-7*V013*V02*V032*V05 - 1.49577749258686372e-7*V022*V033*V05 - 
      6.20592452742179181e-8*V01*V034*V05 + 2.69761723133219301e-7*V013*V022*V04*V05 + 
      8.77107272725415816e-8*V014*V03*V04*V05 - 2.09818162328113677e-7*V023*V03*V04*V05 - 
      5.48198735129195742e-7*V01*V02*V032*V04*V05 - 1.98662769889577042e-7*V01*V022*V042*V05 - 
      1.6042882424496805e-7*V012*V03*V042*V05 + 2.15636899144237912e-8*V03*V043*V05 + 
      2.67278282813924154e-8*V014*V02*V052 - 1.55886771333317162e-8*V024*V052 - 
      1.67299596589608388e-7*V01*V022*V03*V052 - 
      6.60736192207424135e-8*V012*V032*V052 - 
      9.87358270157971727e-8*V012*V02*V04*V052 + 2.75385910139636236e-8*V032*V04*V052 + 
      1.95974610187973338e-8*V02*V042*V052 - 5.0322316333669934e-9*V013*V053 + 
      1.11939649437148335e-8*V02*V03*V053 + 6.96824490892339008e-9*V01*V04*V053 - 
      1.11409616617949951e-9*V016*V02*V06 + 6.65795095057685511e-8*V012*V024*V06 + 
      1.83568097555524123e-7*V013*V022*V03*V06 + 2.97925711255105513e-8*V014*V032*V06 - 
      7.51309637948993831e-8*V023*V032*V06 - 1.2851692907095802e-7*V01*V02*V033*V06 + 
      4.49398509403761505e-8*V014*V02*V04*V06 - 2.45969778812155529e-8*V024*V04*V06 - 
      2.81476680443194741e-7*V01*V022*V03*V04*V06 - 1.11990144232753333e-7*V012*V032*V04*V06 - 
      8.39195240244391173e-8*V012*V02*V042*V06 + 2.30850772817083477e-8*V032*V042*V06 + 
      1.07019465801876516e-8*V02*V043*V06 + 3.34093899905641269e-9*V015*V05*V06 - 
      5.68612789544256521e-8*V01*V023*V05*V06 - 1.37946216092929594e-7*V012*V02*V03*V05*V06 + 
      1.30513790433038994e-8*V033*V05*V06 - 2.5648829174374078e-8*V013*V04*V05*V06 + 
      5.61239769146853626e-8*V02*V03*V04*V05*V06 + 1.76001840353159858e-8*V01*V042*V05*V06 + 
      8.48834586634070483e-9*V022*V052*V06 + 1.47938814807311634e-8*V01*V03*V052*V06 - 
      1.80369720913617452e-8*V012*V022*V062 - 8.88476205467893865e-9*V013*V03*V062 + 
      1.00226471812315941e-8*V02*V032*V062 + 6.94477230572795859e-9*V022*V04*V062 + 
      1.24772222583550127e-8*V01*V03*V04*V062 + 7.65341039943219654e-9*V01*V02*V05*V062 - 
      4.00421842173653072e-10*V052*V062 + 5.42508390784734171e-10*V012*V063 - 
      2.22402533455576898e-10*V04*V063 - 3.01107071940405274e-11*V017*V07 + 
      2.77283134599238124e-8*V013*V023*V07 + 2.64719083561724785e-8*V014*V02*V03*V07 - 
      1.63832980432584913e-8*V024*V03*V07 - 8.67821980500707419e-8*V01*V022*V032*V07 - 
      2.26562275544794585e-8*V012*V033*V07 + 2.42602052206102159e-9*V015*V04*V07 - 
      4.17244583788554264e-8*V01*V023*V04*V07 - 1.01754981256123818e-7*V012*V02*V03*V04*V07 + 
      9.61933163483392822e-9*V033*V04*V07 - 9.46603145239704213e-9*V013*V042*V07 + 
      2.06181050369082218e-8*V02*V03*V042*V07 + 4.32428629621820677e-9*V01*V043*V07 - 
      3.12950296226941361e-8*V012*V022*V05*V07 - 1.54385614355878046e-8*V013*V03*V05*V07 + 
      1.76198113679567036e-8*V02*V032*V05*V07 + 1.24514430520378678e-8*V022*V04*V05*V07 + 
      2.18382321119836989e-8*V01*V03*V04*V05*V07 + 6.7076755062824439e-9*V01*V02*V052*V07 - 
      2.34661747410824179e-10*V053*V07 - 8.10809190164792969e-9*V013*V02*V06*V07 + 
      8.93730376339007827e-9*V022*V03*V06*V07 + 7.72142743457785924e-9*V01*V032*V06*V07 + 
      1.12813037607382006e-8*V01*V02*V04*V06*V07 + 2.83745875649115152e-9*V012*V05*V06*V07 - 
      1.18025293159619893e-9*V04*V05*V06*V07 - 4.22181735978734033e-10*V03*V062*V07 - 
      3.18691793748441956e-10*V014*V072 + 6.57786841443475241e-10*V023*V072 + 
      3.50638547974525262e-9*V01*V02*V03*V072 + 1.04890139026294974e-9*V012*V04*V072 - 
      2.17336706555266237e-10*V042*V072 - 3.70918013728160585e-10*V03*V05*V072 - 
      1.90194226432363861e-10*V02*V06*V072 - 2.51314251998090779e-11*V01*V073 + 
      5.16310067474283161e-9*V014*V022*V08 - 1.18730700632077167e-9*V025*V08 + 
      1.25136556662291956e-9*V015*V03*V08 - 2.29279375669576944e-8*V01*V023*V03*V08 - 
      2.73729662872491818e-8*V012*V02*V032*V08 + 1.32330997386533185e-9*V034*V08 - 
      2.05293337471624539e-8*V012*V022*V04*V08 - 1.00946782145188957e-8*V013*V03*V04*V08 + 
      1.14433490804597708e-8*V02*V032*V04*V08 + 3.9580363656136679e-9*V022*V042*V08 + 
      7.12851884157794588e-9*V01*V03*V042*V08 - 6.24094168156796559e-9*V013*V02*V05*V08 + 
      6.94356978258042249e-9*V022*V03*V05*V08 + 5.97551640081225015e-9*V01*V032*V05*V08 + 
      8.74380863198565107e-9*V01*V02*V04*V05*V08 + 1.09674986486655438e-9*V012*V052*V08 - 
      4.581985947432085e-10*V04*V052*V08 - 5.64122782334582771e-10*V014*V06*V08 + 
      1.14077085538480067e-9*V023*V06*V08 + 6.2033225723360664e-9*V01*V02*V03*V06*V08 + 
      1.86052874460750999e-9*V012*V04*V06*V08 - 3.81590377099588795e-10*V042*V06*V08 - 
      6.55281918259906118e-10*V03*V05*V06*V08 - 1.66926781546952041e-10*V02*V062*V08 + 
      1.4005434568201366e-9*V01*V022*V07*V08 + 1.13979684147809739e-9*V012*V03*V07*V08 - 
      4.83322804309876299e-10*V03*V04*V07*V08 - 2.95582748451497857e-10*V02*V05*V07*V08 - 
      1.33409947208532761e-10*V01*V06*V07*V08 + 2.31526965969625083e-10*V012*V02*V082 - 
      6.69929031241200044e-11*V032*V082 - 9.55031661992683771e-11*V02*V04*V082 - 
      5.17126889322778945e-11*V01*V05*V082 + 4.13107977656135402e-13*V083 + 
      4.2464953233948332e-10*V015*V02*V09 - 2.02019027419996013e-9*V01*V024*V09 - 
      9.89520180800151304e-9*V012*V022*V03*V09 - 2.41562895063108654e-9*V013*V032*V09 + 
      1.90018113274307923e-9*V02*V033*V09 - 3.66727316596148449e-9*V013*V02*V04*V09 + 
      4.05192218156296103e-9*V022*V03*V04*V09 + 3.51340513992207514e-9*V01*V032*V04*V09 + 
      2.56351206321914891e-9*V01*V02*V042*V09 - 3.89765451634726026e-10*V014*V05*V09 + 
      8.1311449232293595e-10*V023*V05*V09 + 4.32302295795212964e-9*V01*V02*V03*V05*V09 + 
      1.29182440988578419e-9*V012*V04*V05*V09 - 2.68529095864056996e-10*V042*V05*V09 - 
      2.29028113383650342e-10*V03*V052*V09 + 1.1142292397210049e-9*V01*V022*V06*V09 + 
      9.07931717762568069e-10*V012*V03*V06*V09 - 3.84555435601096485e-10*V03*V04*V06*V09 - 
      2.35077579863707066e-10*V02*V05*V06*V09 - 5.31194531671469679e-11*V01*V062*V09 + 
      4.15842572147764832e-10*V012*V02*V07*V09 - 1.20677033057322425e-10*V032*V07*V09 - 
      1.7307782150521251e-10*V02*V04*V07*V09 - 9.30875921523964184e-11*V01*V05*V07*V09 + 
      4.27915270305025167e-11*V013*V08*V09 - 9.64922137274363018e-11*V02*V03*V08*V09 - 
      6.0897977955022888e-11*V01*V04*V08*V09 + 2.23672006049290896e-12*V07*V08*V09 - 
      8.61435126001093185e-12*V022*V092 - 1.5101570440934915e-11*V01*V03*V092 + 
      8.90312494831359498e-13*V06*V092 + 1.23985264916637466e-11*V016*V10 - 
      1.08597003336772874e-9*V012*V023*V10 - 1.59037792603074527e-9*V013*V02*V03*V10 + 
      9.21839305565832322e-10*V022*V032*V10 + 5.2290045243083601e-10*V01*V033*V10 - 
      2.07045792763975322e-10*V014*V04*V10 + 4.223102586584077e-10*V023*V04*V10 + 
      2.30531604195516552e-9*V01*V02*V03*V04*V10 + 3.45866196153316002e-10*V012*V042*V10 - 
      4.730140076757285e-11*V043*V10 + 7.06111048292429286e-10*V01*V022*V05*V10 + 
      5.72957043956577621e-10*V012*V03*V05*V10 - 2.43995573875325085e-10*V03*V04*V05*V10 - 
      7.46676721210225473e-11*V02*V052*V10 + 3.01169854286320233e-10*V012*V02*V06*V10 - 
      8.71561659032362657e-11*V032*V06*V10 - 1.24184781432973377e-10*V02*V04*V06*V10 - 
      6.72932958419904147e-11*V01*V05*V06*V10 + 3.49217470015431594e-11*V013*V07*V10 - 
      7.88821815003766501e-11*V02*V03*V07*V10 - 4.97562731181520737e-11*V01*V04*V07*V10 + 
      9.14063254057000579e-13*V072*V10 - 1.55453703275504475e-11*V022*V08*V10 - 
      2.74200591514209273e-11*V01*V03*V08*V10 + 1.61275026622152242e-12*V06*V08*V10 - 9.98822615803830342e-12*V01*V02*V09*V10 + 
      1.13079968870586721e-12*V05*V09*V10 - 6.80460290457835636e-13*V012*V102 + 
      3.01293286387371767e-13*V04*V102 - 2.40416310658712261e-10*V013*V022*V11 - 
      8.17459866166382764e-11*V014*V03*V11 + 1.80452585440968922e-10*V023*V03*V11 + 
      4.7330571674483787e-10*V01*V02*V032*V11 + 3.44422568062248563e-10*V01*V022*V04*V11 + 
      2.81012315314083125e-10*V012*V03*V04*V11 - 5.95582892105503442e-11*V03*V042*V11 + 
      1.74071537746559336e-10*V012*V02*V05*V11 - 5.06728075205236914e-11*V032*V05*V11 - 
      7.27687542032896293e-11*V02*V04*V05*V11 - 1.95355626099852823e-11*V01*V052*V11 + 
      2.31618530300907583e-11*V013*V06*V11 - 5.2207755670901011e-11*V02*V03*V06*V11 - 
      3.297199918412495e-11*V01*V04*V06*V11 - 1.1719434646825447e-11*V022*V07*V11 - 
      2.05337843265451811e-11*V01*V03*V07*V11 + 1.2105816634917136e-12*V06*V07*V11 - 8.31119230639439751e-12*V01*V02*V08*V11 + 
      9.40616387175285778e-13*V05*V08*V11 - 1.24684884587326264e-12*V012*V09*V11 + 
      5.53411506155556774e-13*V04*V09*V11 + 2.5217127119503702e-13*V03*V10*V11 + 3.80558411977371771e-14*V02*V112 - 
      2.25674933949142755e-11*V014*V02*V12 + 1.18826980712085631e-11*V024*V12 + 
      1.31282476206008484e-10*V01*V022*V03*V12 + 5.26689431260876981e-11*V012*V032*V12 + 
      7.88924869784827072e-11*V012*V02*V04*V12 - 2.28704609621203231e-11*V032*V04*V12 - 
      1.62613938571251225e-11*V02*V042*V12 + 1.2343499614481655e-11*V013*V05*V12 - 
      2.8057126377794321e-11*V02*V03*V05*V12 - 1.76754020392417743e-11*V01*V04*V05*V12 - 
      7.11446422836924071e-12*V022*V06*V12 - 1.25639885755102269e-11*V01*V03*V06*V12 + 
      3.69165227756859453e-13*V062*V12 - 5.7461886803326097e-12*V01*V02*V07*V12 + 6.50304802067189682e-13*V05*V07*V12 - 
      9.58157148441811182e-13*V012*V08*V12 + 4.23974042778759694e-13*V04*V08*V12 + 
      2.13299545045710937e-13*V03*V09*V12 + 7.01010201669626122e-14*V02*V10*V12 + 1.86645558392741721e-14*V01*V11*V12 - 
      7.34123279111669205e-13*V015*V13 + 1.11917223375579105e-11*V01*V023*V13 + 
      2.74773798021158917e-11*V012*V02*V03*V13 - 2.71184870502481249e-12*V033*V13 + 
      5.19683538733058212e-12*V013*V04*V13 - 1.17379576815014896e-11*V02*V03*V04*V13 - 
      3.7125710821677119e-12*V01*V042*V13 - 3.57769544470418032e-12*V022*V05*V13 - 
      6.25241942029032562e-12*V01*V03*V05*V13 - 3.26429884921483961e-12*V01*V02*V06*V13 + 3.69055431492914755e-13*V05*V06*V13 - 
      6.14606188580291793e-13*V012*V07*V13 + 2.72738495171039016e-13*V04*V07*V13 + 
      1.52048984007312621e-13*V03*V08*V13 + 5.51653449031946066e-14*V02*V09*V13 + 1.59933365724365125e-14*V01*V10*V13 - 
      4.82840505109887935e-17*V132 + 3.34634624519940854e-12*V012*V022*V14 + 
      1.67527709143313718e-12*V013*V03*V14 - 1.96009308477979693e-12*V02*V032*V14 - 
      1.38589788154165138e-12*V022*V04*V14 - 2.45614126959940437e-12*V01*V03*V04*V14 - 
      1.5188247425853835e-12*V01*V02*V05*V14 + 8.59482153995903017e-14*V052*V14 - 
      3.26537068713583715e-13*V012*V06*V14 + 1.44221830492316582e-13*V04*V06*V14 + 
      9.11392462040902418e-14*V03*V07*V14 + 3.66389488900220047e-14*V02*V08*V14 + 1.17260332723494438e-14*V01*V09*V14 - 
      9.00758329931411365e-17*V12*V14 + 3.84540765248969583e-13*V013*V02*V15 - 
      4.39666189529948373e-13*V022*V03*V15 - 3.80178623655181342e-13*V01*V032*V15 - 
      5.58897255567581823e-13*V01*V02*V04*V15 - 1.42081226422276558e-13*V012*V05*V15 + 
      6.31543037165354444e-14*V04*V05*V15 + 4.53093106098236628e-14*V03*V06*V15 + 2.06422463096400032e-14*V02*V07*V15 + 
      7.32019980438718352e-15*V01*V08*V15 - 7.32308093599298073e-17*V11*V15 + 1.45659380776124842e-14*V014*V16 - 
      3.04692484132274287e-14*V023*V16 - 1.63637306916058396e-13*V01*V02*V03*V16 - 
      4.94650813093645986e-14*V012*V04*V16 + 1.08989807582861954e-14*V042*V16 + 
      1.86396459507237516e-14*V03*V05*V16 + 9.64001727668496181e-15*V02*V06*V16 + 3.8737051788447539e-15*V01*V07*V16 - 
      5.16507406747715027e-17*V10*V16 - 1.6556767067661321e-14*V01*V022*V17 - 
      1.35313945874416845e-14*V012*V03*V17 + 6.10374627756433287e-15*V03*V04*V17 + 
      3.76127654327226431e-15*V02*V05*V17 + 1.71578004959984158e-15*V01*V06*V17 - 3.15897595315700434e-17*V09*V17 - 
      2.63498724540660623e-15*V012*V02*V18 + 8.06592590700502911e-16*V032*V18 + 
      1.16286246847357638e-15*V02*V04*V18 + 6.31725940714921152e-16*V01*V05*V18 - 1.66021090089434833e-17*V08*V18 - 
      1.24398539482715316e-16*V013*V19 + 2.94460138811914213e-16*V02*V03*V19 + 1.87125560603696614e-16*V01*V04*V19 - 
      7.48178331515123269e-18*V07*V19 + 2.53588726412172258e-17*V022*V20 + 4.45623212546971308e-17*V01*V03*V20 - 
      2.83988482374650272e-18*V06*V20 + 7.49155648884796678e-18*V01*V02*V21 - 9.06880710673375232e-19*V05*V21 + 
      4.97594157930861262e-19*V012*V22 - 2.33439234584848493e-19*V04*V22 - 4.9284718784959042e-20*V03*V23 - 
      7.2600718890024651e-21*V02*V24 - 9.07508986125308138e-22*V01*V25 + 6.0179640989741919e-25*V28) + 
   delta6*eps11*(-2.49661808097621507e-9*V036 - 4.26038561333340795e-8*V02*V034*V04 - 
      6.35525387519264992e-8*V022*V032*V042 - 4.83292346032964941e-8*V01*V033*V042 - 
      3.48009271425128996e-9*V023*V043 - 5.21007542194428255e-8*V01*V02*V03*V043 - 
      3.88562403920447723e-9*V012*V044 + 7.74456172615070677e-10*V045 - 
      4.33178344404360152e-8*V022*V033*V05 - 2.14585667164907926e-8*V01*V034*V05 - 
      4.05750607908712866e-8*V023*V03*V04*V05 - 1.49701349905328914e-7*V01*V02*V032*V04*V05 - 
      3.81315232511558995e-8*V01*V022*V042*V05 - 4.14542305333481087e-8*V012*V03*V042*V05 + 
      1.74757770810771918e-8*V03*V043*V05 - 2.39083324048852658e-9*V024*V052 - 
      3.83066196167295525e-8*V01*V022*V03*V052 - 
      1.80376103167323091e-8*V012*V032*V052 - 
      2.15672748820465144e-8*V012*V02*V04*V052 + 2.50208225944889591e-8*V032*V04*V052 + 
      1.33552205247362602e-8*V02*V042*V052 - 1.0931822218562792e-9*V013*V053 + 
      8.75985166357305396e-9*V02*V03*V053 + 5.20810599820024563e-9*V01*V04*V053 - 
      1.48779795339320709e-8*V023*V032*V06 - 3.43121584273838304e-8*V01*V02*V033*V06 - 
      1.78831917683038053e-9*V024*V04*V06 - 5.51184596961167823e-8*V01*V022*V03*V04*V06 - 
      2.80922928946639527e-8*V012*V032*V04*V06 - 1.64962882079455804e-8*V012*V02*V042*V06 + 
      1.8942406412571866e-8*V032*V042*V06 + 5.66450426445252467e-9*V02*V043*V06 - 
      8.92678772035924254e-9*V01*V023*V05*V06 - 2.93794851767513907e-8*V012*V02*V03*V05*V06 + 
      1.18176763577933914e-8*V033*V05*V06 - 5.18481639171417276e-9*V013*V04*V05*V06 + 
      3.89480165738484644e-8*V02*V03*V04*V05*V06 + 1.18938744327780421e-8*V01*V042*V05*V06 + 
      4.93394369258030515e-9*V022*V052*V06 + 1.09980585927146159e-8*V01*V03*V052*V06 - 
      2.90935693102773385e-9*V012*V022*V062 - 1.72637399528795707e-9*V013*V03*V062 + 
      7.0439280037250256e-9*V02*V032*V062 + 3.09503195995822463e-9*V022*V04*V062 + 
      8.48663599829213159e-9*V01*V03*V04*V062 + 4.41494802311360294e-9*V01*V02*V05*V062 - 
      4.84192342238050314e-10*V052*V062 + 3.06606269118169895e-10*V012*V063 - 
      2.3609905663751539e-10*V04*V063 - 2.2769840385605015e-9*V024*V03*V07 - 
      1.79177086843174721e-8*V01*V022*V032*V07 - 5.54028518810008891e-9*V012*V033*V07 - 
      5.79643725583875523e-9*V01*V023*V04*V07 - 2.00156143389004272e-8*V012*V02*V03*V04*V07 + 
      8.24612384933782233e-9*V033*V04*V07 - 1.77952711019574461e-9*V013*V042*V07 + 
      1.32850691831887295e-8*V02*V03*V042*V07 + 2.72810098339074092e-9*V01*V043*V07 - 
      5.17986347072184624e-9*V012*V022*V05*V07 - 3.00001458976562176e-9*V013*V03*V05*V07 + 
      1.30002531630843894e-8*V02*V032*V05*V07 + 6.67320638621514296e-9*V022*V04*V05*V07 + 
      1.5359262313915318e-8*V01*V03*V04*V05*V07 + 4.05369906224963899e-9*V01*V02*V052*V07 - 
      2.95320892275880125e-10*V053*V07 - 1.25602716004587036e-9*V013*V02*V06*V07 + 
      4.89987598832738015e-9*V022*V03*V06*V07 + 5.39008937563491906e-9*V01*V032*V06*V07 + 
      6.05928022089994357e-9*V01*V02*V04*V06*V07 + 1.63292218138416486e-9*V012*V05*V06*V07 - 
      1.35522339946117897e-9*V04*V05*V06*V07 - 4.9177054136235004e-10*V03*V062*V07 - 
      4.42819314702863444e-11*V014*V072 + 2.73300107347243502e-10*V023*V072 + 
      1.98787540226761154e-9*V01*V02*V03*V072 + 5.70839279729497001e-10*V012*V04*V072 - 
      2.36194080412229453e-10*V042*V072 - 4.48932968279637233e-10*V03*V05*V072 - 
      1.80111790128789343e-10*V02*V06*V072 - 2.44145584190784027e-11*V01*V073 - 
      6.1591651792682389e-11*V025*V08 - 3.3205120028876497e-9*V01*V023*V03*V08 - 
      5.12971004917428142e-9*V012*V02*V032*V08 + 1.12654005149410709e-9*V034*V08 - 
      2.99579217556008662e-9*V012*V022*V04*V08 - 1.77931999951134116e-9*V013*V03*V04*V08 + 
      7.57072442063727112e-9*V02*V032*V04*V08 + 1.63909310102557311e-9*V022*V042*V08 + 
      4.56593896082372445e-9*V01*V03*V042*V08 - 9.42611166537989541e-10*V013*V02*V05*V08 + 
      3.86025914024896609e-9*V022*V03*V05*V08 + 4.15757927376058933e-9*V01*V032*V05*V08 + 
      4.73780983192891003e-9*V01*V02*V04*V05*V08 + 6.27676099485222348e-10*V012*V052*V08 - 
      5.31670146918461443e-10*V04*V052*V08 - 7.66171425620634154e-11*V014*V06*V08 + 
      3.95636370021983198e-10*V023*V06*V08 + 3.38492848473740677e-9*V01*V02*V03*V06*V08 + 
      9.88657452675484232e-10*V012*V04*V06*V08 - 3.87119861701422049e-10*V042*V06*V08 - 
      7.695276814491008e-10*V03*V05*V06*V08 - 1.46948279806190887e-10*V02*V062*V08 + 
      5.9700727167391108e-10*V01*V022*V07*V08 + 6.08501502443267155e-10*V012*V03*V07*V08 - 
      5.39598172457962928e-10*V03*V04*V07*V08 - 2.83515124264387506e-10*V02*V05*V07*V08 - 
      1.25932010249151538e-10*V01*V06*V07*V08 + 9.79822849116433203e-11*V012*V02*V082 - 
      7.60321202835209672e-11*V032*V082 - 8.00438662894526186e-11*V02*V04*V082 - 
      4.90581509132273981e-11*V01*V05*V082 + 5.30370390189967646e-13*V083 - 
      1.89748669880041792e-10*V01*V024*V09 - 1.38492783871933339e-9*V012*V022*V03*V09 - 
      3.92619956245540495e-10*V013*V032*V09 + 1.28926976485616982e-9*V02*V033*V09 - 
      4.94435450321130617e-10*V013*V02*V04*V09 + 2.00577754615659779e-9*V022*V03*V04*V09 + 
      2.26381328315603608e-9*V01*V032*V04*V09 + 1.24854198374475265e-9*V01*V02*V042*V09 - 
      5.06266999599834683e-11*V014*V05*V09 + 3.30997431172136471e-10*V023*V05*V09 + 
      2.39176482559352055e-9*V01*V02*V03*V05*V09 + 6.84796104831609499e-10*V012*V04*V05*V09 - 
      2.8964693312899592e-10*V042*V05*V09 - 2.7452581036405451e-10*V03*V052*V09 + 
      4.58543497875720728e-10*V01*V022*V06*V09 + 4.74776799562345758e-10*V012*V03*V06*V09 - 
      4.21594857816365011e-10*V03*V04*V06*V09 - 2.20749527071950243e-10*V02*V05*V06*V09 - 
      4.92822244041278936e-11*V01*V062*V09 + 1.76500396127192128e-10*V012*V02*V07*V09 - 
      1.38689184975927788e-10*V032*V07*V09 - 1.52857352811459595e-10*V02*V04*V07*V09 - 
      8.93272283859778263e-11*V01*V05*V07*V09 + 1.70090809796901564e-11*V013*V08*V09 - 
      8.79396612859014719e-11*V02*V03*V08*V09 - 5.39460898133261518e-11*V01*V04*V08*V09 + 2.94106739734106171e-12*V07*V08*V09 - 
      6.08730636079525797e-12*V022*V092 - 1.3637441496554828e-11*V01*V03*V092 + 
      1.15356416762231491e-12*V06*V092 - 1.10290212716417116e-10*V012*V023*V10 - 
      1.96961668981946391e-10*V013*V02*V03*V10 + 4.73736502833791189e-10*V022*V032*V10 + 
      3.30526268265465486e-10*V01*V033*V10 - 2.40308568958011191e-11*V014*V04*V10 + 
      1.306858449197228e-10*V023*V04*V10 + 1.14855445011369218e-9*V01*V02*V03*V04*V10 + 
      1.68032962650687216e-10*V012*V042*V10 - 4.50591365188107947e-11*V043*V10 + 
      2.95281792295839512e-10*V01*V022*V05*V10 + 2.96087417912995843e-10*V012*V03*V05*V10 - 
      2.70958150839110306e-10*V03*V04*V05*V10 - 7.13538949593980984e-11*V02*V052*V10 + 
      1.23973004586497602e-10*V012*V02*V06*V10 - 9.75850911950480834e-11*V032*V06*V10 - 
      1.02290832413024991e-10*V02*V04*V06*V10 - 6.29210003101351228e-11*V01*V05*V06*V10 + 
      1.37901305728218524e-11*V013*V07*V10 - 7.22394463607154801e-11*V02*V03*V07*V10 - 
      4.42014311579501796e-11*V01*V04*V07*V10 + 1.20693083515099705e-12*V072*V10 - 
      1.04548365252086475e-11*V022*V08*V10 - 2.45525098402197856e-11*V01*V03*V08*V10 + 
      2.04868873712807041e-12*V06*V08*V10 - 7.16738347520472014e-12*V01*V02*V09*V10 + 1.48553413763209583e-12*V05*V09*V10 - 
      4.76362356925007745e-13*V012*V102 + 3.64596047658544612e-13*V04*V102 - 
      2.2225852014699815e-11*V013*V022*V11 - 8.46041473549786817e-12*V014*V03*V11 + 
      6.68071543587624776e-11*V023*V03*V11 + 2.35400430463378888e-10*V01*V02*V032*V11 + 
      1.25999768576681367e-10*V01*V022*V04*V11 + 1.33242160559910272e-10*V012*V03*V04*V11 - 
      6.1093208918199871e-11*V03*V042*V11 + 7.08712637913533671e-11*V012*V02*V05*V11 - 
      5.73967385086297412e-11*V032*V05*V11 - 6.35821678907591332e-11*V02*V04*V05*V11 - 
      1.84336694398277715e-11*V01*V052*V11 + 8.89175146688824675e-12*V013*V06*V11 - 
      4.64625183219576854e-11*V02*V03*V06*V11 - 2.85686697464344414e-11*V01*V04*V06*V11 - 
      8.26546389412233474e-12*V022*V07*V11 - 1.84599259550681866e-11*V01*V03*V07*V11 + 
      1.56758121391240015e-12*V06*V07*V11 - 5.91926806409766088e-12*V01*V02*V08*V11 + 1.22978944900088456e-12*V05*V08*V11 - 
      8.73047668890433673e-13*V012*V09*V11 + 6.79875661187316609e-13*V04*V09*V11 + 
      3.18472665746274171e-13*V03*V10*V11 + 3.86507060780704276e-14*V02*V112 - 
      1.76086006982693143e-12*V014*V02*V12 + 2.65284831789715095e-12*V024*V12 + 
      4.94243888968296153e-11*V01*V022*V03*V12 + 2.4059427713600762e-11*V012*V032*V12 + 
      2.90634455322732559e-11*V012*V02*V04*V12 - 2.40332415562754902e-11*V032*V04*V12 - 
      1.24004736709692699e-11*V02*V042*V12 + 4.62159797731715339e-12*V013*V05*V12 - 
      2.53817340430362582e-11*V02*V03*V05*V12 - 1.54582452810502205e-11*V01*V04*V05*V12 - 
      4.65443001013582812e-12*V022*V06*V12 - 1.10195143774801306e-11*V01*V03*V06*V12 + 
      4.62275445114552831e-13*V062*V12 - 4.11091841812275455e-12*V01*V02*V07*V12 + 
      8.54827264660022273e-13*V05*V07*V12 - 6.6677690271151634e-13*V012*V08*V12 + 5.11140088822477658e-13*V04*V08*V12 + 
      2.69716890703278048e-13*V03*V09*V12 + 7.01887047142654836e-14*V02*V10*V12 + 1.89467326589422553e-14*V01*V11*V12 - 
      4.66110018483599495e-14*V015*V13 + 2.99423691357777777e-12*V01*V023*V13 + 
      9.82167794662163755e-12*V012*V02*V03*V13 - 2.87880905295321031e-12*V033*V13 + 
      1.77930100984392145e-12*V013*V04*V13 - 9.67816167205109803e-12*V02*V03*V04*V13 - 
      2.98580071451049345e-12*V01*V042*V13 - 2.48794034649747452e-12*V022*V05*V13 - 
      5.49948735789160165e-12*V01*V03*V05*V13 - 2.26100990709481797e-12*V01*V02*V06*V13 + 4.7500858695694337e-13*V05*V06*V13 - 
      4.26483138776411711e-13*V012*V07*V13 + 3.34748910337749257e-13*V04*V07*V13 + 
      1.91031803190879603e-13*V03*V08*V13 + 5.60095614202921938e-14*V02*V09*V13 + 1.62074470333207622e-14*V01*V10*V13 - 
      6.43752435954743197e-17*V132 + 9.10425077769586236e-13*V012*V022*V14 + 
      5.39910771410169415e-13*V013*V03*V14 - 1.66140669058117387e-12*V02*V032*V14 - 
      8.28263992410037937e-13*V022*V04*V14 - 2.00219641298408411e-12*V01*V03*V04*V14 - 
      1.06363153783049786e-12*V01*V02*V05*V14 + 1.12234590097211278e-13*V052*V14 - 
      2.21355079481772612e-13*V012*V06*V14 + 1.70954099969788965e-13*V04*V06*V14 + 
      1.15073071065298605e-13*V03*V07*V14 + 3.64577550958467795e-14*V02*V08*V14 + 1.18950180456313298e-14*V01*V09*V14 - 
      1.19600364870750189e-16*V12*V14 + 9.71062538507498948e-14*V013*V02*V15 - 
      2.85947268917745482e-13*V022*V03*V15 - 3.0871699887519981e-13*V01*V032*V15 - 
      3.55411636751721068e-13*V01*V02*V04*V15 - 9.56295552285267934e-14*V012*V05*V15 + 
      7.69887767065883574e-14*V04*V05*V15 + 5.59914492163303378e-14*V03*V06*V15 + 2.09270410588993816e-14*V02*V07*V15 + 
      7.37375232850873924e-15*V01*V08*V15 - 9.76340983082182663e-17*V11*V15 + 3.23687512835832983e-15*V014*V16 - 
      1.39609618717725926e-14*V023*V16 - 1.05698917519649446e-13*V01*V02*V03*V16 - 
      3.08646430976438706e-14*V012*V04*V16 + 1.21795591493021946e-14*V042*V16 + 
      2.33127207864400535e-14*V03*V05*V16 + 9.39590908722569e-15*V02*V06*V16 + 3.91432583953079108e-15*V01*V07*V16 - 
      6.8486373534522317e-17*V10*V16 - 8.15973999748765058e-15*V01*V022*V17 - 
      8.26669761042470843e-15*V012*V03*V17 + 7.12626876408814967e-15*V03*V04*V17 + 
      3.78036522690319113e-15*V02*V05*V17 + 1.69613932127181637e-15*V01*V06*V17 - 4.21126985370719144e-17*V09*V17 - 
      1.28067668122003484e-15*V012*V02*V18 + 9.60189184686046794e-16*V032*V18 + 
      1.05979178633247677e-15*V02*V04*V18 + 6.29005926858352959e-16*V01*V05*V18 - 2.19183431885879037e-17*V08*V18 - 
      5.62934804931883448e-17*V013*V19 + 2.81701958634663342e-16*V02*V03*V19 + 1.73672088926306661e-16*V01*V04*V19 - 
      9.96873024851350019e-18*V07*V19 + 1.85321711972813694e-17*V022*V20 + 4.17241916131655518e-17*V01*V03*V20 - 
      3.6971583673871015e-18*V06*V20 + 5.61594483967759916e-18*V01*V02*V21 - 1.20219344254302358e-18*V05*V21 + 
      3.61886660313353645e-19*V012*V22 - 2.88913630044405791e-19*V04*V22 - 6.29206230380213642e-20*V03*V23 - 
      7.44622757846406677e-21*V02*V24 - 9.30778447308008347e-22*V01*V25 + 8.02395213196558919e-25*V28) + 
   delta2*eps13*(6.26037729789820904e-8*V025*V032 + 
      4.32286855970912927e-7*V01*V023*V033 + 2.65611018375665901e-7*V012*V02*V034 - 
      1.0056479547259229e-8*V036 + 6.86627585651083939e-9*V026*V04 + 
      3.95802566746899341e-7*V01*V024*V03*V04 + 1.07162878384648343e-6*V012*V022*V032*V04 + 
      1.78563679745402434e-7*V013*V033*V04 - 2.00100852048114414e-7*V02*V034*V04 + 
      2.40940930801944652e-7*V012*V023*V042 + 
      3.71028688605719418e-7*V013*V02*V03*V042 - 3.786789464730803e-7*V022*V032*V042 - 
      2.36280973326511114e-7*V01*V033*V042 + 1.49288633236900044e-8*V014*V043 - 
      4.47785160224899766e-8*V023*V043 - 3.11478549885343524e-7*V01*V02*V03*V043 - 
      2.30545145737442503e-8*V012*V044 + 2.19249275444418889e-9*V045 + 
      3.75622637873892542e-8*V01*V025*V05 + 3.80256762866230264e-7*V012*V023*V03*V05 + 
      2.93511920167790849e-7*V013*V02*V032*V05 - 2.22910418782730152e-7*V022*V033*V05 - 
      9.93600987223710436e-8*V01*V034*V05 + 2.03066187598021165e-7*V013*V022*V04*V05 + 
      7.068880712087995e-8*V014*V03*V04*V05 - 2.71181513017230613e-7*V023*V03*V04*V05 - 
      7.99658959096722232e-7*V01*V02*V032*V04*V05 - 2.55860711226782637e-7*V01*V022*V042*V05 - 
      2.29459772380387721e-7*V012*V03*V042*V05 + 4.01679166923128863e-8*V03*V043*V05 + 
      1.93668779267081088e-8*V014*V02*V052 - 1.77379742813162922e-8*V024*V052 - 
      2.22534401542033469e-7*V01*V022*V03*V052 - 9.521874323339043e-8*V012*V032*V052 - 
      1.29568314594432361e-7*V012*V02*V04*V052 + 5.27035762312654575e-8*V032*V04*V052 + 
      3.38001761885005644e-8*V02*V042*V052 - 6.53865642029561654e-9*V013*V053 + 
      1.99735057415167033e-8*V02*V03*V053 + 1.22479913352590455e-8*V01*V04*V053 + 
      4.23093812467791226e-8*V012*V024*V06 + 1.33534491939312201e-7*V013*V022*V03*V06 + 
      2.31786657294360376e-8*V014*V032*V06 - 9.86821340376802218e-8*V023*V032*V06 - 
      1.87628983514970859e-7*V01*V02*V033*V06 + 3.22085884826606115e-8*V014*V02*V04*V06 - 
      2.54812550973248439e-8*V024*V04*V06 - 3.66514117038712385e-7*V01*V022*V03*V04*V06 - 
      1.5958495148039661e-7*V012*V032*V04*V06 - 1.08852043899466103e-7*V012*V02*V042*V06 + 
      4.34041600832955616e-8*V032*V042*V06 + 1.77200747105181666e-8*V02*V043*V06 + 
      2.28056978100745608e-9*V015*V05*V06 - 6.60077636103449389e-8*V01*V023*V05*V06 - 
      1.80647912983891509e-7*V012*V02*V03*V05*V06 + 2.51194422978490909e-8*V033*V05*V06 - 
      3.3036760746107917e-8*V013*V04*V05*V06 + 9.79806517215620028e-8*V02*V03*V04*V05*V06 + 
      3.04115383559460582e-8*V01*V042*V05*V06 + 1.36283104170069822e-8*V022*V052*V06 + 
      2.61204247533627771e-8*V01*V03*V052*V06 - 2.11807889001744888e-8*V012*V022*V062 - 
      1.1333556656753781e-8*V013*V03*V062 + 1.76746991456447859e-8*V02*V032*V062 + 
      1.06677036842741399e-8*V022*V04*V062 + 2.1702681959296302e-8*V01*V03*V04*V062 + 
      1.23289861151022954e-8*V01*V02*V05*V062 - 7.90901730498100935e-10*V052*V062 + 
      8.69955863714949038e-10*V012*V063 - 4.28930339326720835e-10*V04*V063 + 
      1.7269235611954644e-8*V013*V023*V07 + 1.80196135531394635e-8*V014*V02*V03*V07 - 
      1.8548270418758121e-8*V024*V03*V07 - 1.13948565609417724e-7*V01*V022*V032*V07 - 
      3.20680607512308394e-8*V012*V033*V07 + 1.61914634735012886e-9*V015*V04*V07 - 
      4.7288839506620564e-8*V01*V023*V04*V07 - 1.31384056746108091e-7*V012*V02*V03*V04*V07 + 
      1.83196164302877053e-8*V033*V04*V07 - 1.2047569175203672e-8*V013*V042*V07 + 
      3.54792234131722972e-8*V02*V03*V042*V07 + 7.37777134042991446e-9*V01*V043*V07 - 
      3.66318637990656579e-8*V012*V022*V05*V07 - 1.96262914574951561e-8*V013*V03*V05*V07 + 
      3.1297380532310738e-8*V02*V032*V05*V07 + 1.96511394126519307e-8*V022*V04*V05*V07 + 
      3.81400923195861699e-8*V01*V03*V04*V05*V07 + 1.08726304366174659e-8*V01*V02*V052*V07 - 
      4.66805721270364971e-10*V053*V07 - 9.37224948779954554e-9*V013*V02*V06*V07 + 
      1.43114854589958633e-8*V022*V03*V06*V07 + 1.35332733566607584e-8*V01*V032*V06*V07 + 
      1.79211033285429649e-8*V01*V02*V04*V06*V07 + 4.55414833979787922e-9*V012*V05*V06*V07 - 
      2.30576331233322882e-9*V04*V05*V06*V07 - 8.32632663866097855e-10*V03*V062*V07 - 
      3.56422123491067297e-10*V014*V072 + 9.38987455031989622e-10*V023*V072 + 
      5.64466615821918792e-9*V01*V02*V03*V072 + 1.66530240177509072e-9*V012*V04*V072 - 
      4.19734176015411067e-10*V042*V072 - 7.36328011081932439e-10*V03*V05*V072 - 
      3.45983715856640743e-10*V02*V06*V072 - 4.59703508778850503e-11*V01*V073 + 
      3.03321094528202371e-9*V014*V022*V08 - 1.04471088085659645e-9*V025*V08 + 
      7.83763996080172551e-10*V015*V03*V08 - 2.63937953457177631e-8*V01*V023*V03*V08 - 
      3.50566928973522331e-8*V012*V02*V032*V08 + 2.53313431522826346e-9*V034*V08 - 
      2.36319893513054495e-8*V012*V022*V04*V08 - 1.26474364551414176e-8*V013*V03*V04*V08 + 
      1.9953363374100479e-8*V02*V032*V04*V08 + 5.99519201575933914e-9*V022*V042*V08 + 
      1.22625520447323922e-8*V01*V03*V042*V08 - 7.16912037204157159e-9*V013*V02*V05*V08 + 
      1.11541958989999938e-8*V022*V03*V05*V08 + 1.04698608963253418e-8*V01*V032*V05*V08 + 
      1.39123975502834464e-8*V01*V02*V04*V05*V08 + 1.75830385152653858e-9*V012*V052*V08 - 
      8.97418632544638092e-10*V04*V052*V08 - 6.29395016672954164e-10*V014*V06*V08 + 
      1.5886748524893385e-9*V023*V06*V08 + 9.94336310560763942e-9*V01*V02*V03*V06*V08 + 
      2.94820165189933703e-9*V012*V04*V06*V08 - 7.29384657133766073e-10*V042*V06*V08 - 
      1.29495456392085736e-9*V03*V05*V06*V08 - 3.00324904831965124e-10*V02*V062*V08 + 
      2.02862826846065116e-9*V01*V022*V07*V08 + 1.80786199791238447e-9*V012*V03*V07*V08 - 
      9.45167289704024987e-10*V03*V04*V07*V08 - 5.39343867628521465e-10*V02*V05*V07*V08 - 
      2.43084042759038705e-10*V01*V06*V07*V08 + 3.35452430689708632e-10*V012*V02*V082 - 
      1.32292084412831336e-10*V032*V082 - 1.70110732268529292e-10*V02*V04*V082 - 
      9.43311982681580721e-11*V01*V05*V082 + 8.21637941907666639e-13*V083 + 
      2.3114395816601699e-10*V015*V02*V09 - 1.95942959641549458e-9*V01*V024*V09 - 
      1.1279391898141591e-8*V012*V022*V03*V09 - 2.96983274530447457e-9*V013*V032*V09 + 
      3.3499775104416207e-9*V02*V033*V09 - 4.14151236512458962e-9*V013*V02*V04*V09 + 
      6.37297699327406587e-9*V022*V03*V04*V09 + 6.07421868620520999e-9*V01*V032*V04*V09 + 
      4.0048526338949564e-9*V01*V02*V042*V09 - 4.30909278909142232e-10*V014*V05*V09 + 
      1.1596879253737509e-9*V023*V05*V09 + 6.93903765995887209e-9*V01*V02*V03*V05*V09 + 
      2.04341393515044019e-9*V012*V04*V05*V09 - 5.1850245911125742e-10*V042*V05*V09 - 
      4.54321365784394465e-10*V03*V052*V09 + 1.6067111920432139e-9*V01*V022*V06*V09 + 
      1.43643437206426077e-9*V012*V03*V06*V09 - 7.49981534908386298e-10*V03*V04*V06*V09 - 
      4.27517072375866469e-10*V02*V05*V06*V09 - 9.65503667363073166e-11*V01*V062*V09 + 
      6.02020936065519019e-10*V012*V02*V07*V09 - 2.38718295375480113e-10*V032*V07*V09 - 
      3.10667159008854608e-10*V02*V04*V07*V09 - 1.70043575180262805e-10*V01*V05*V07*V09 + 
      6.09077193529588257e-11*V013*V08*V09 - 1.75696170557529793e-10*V02*V03*V08*V09 - 
      1.09663819995065411e-10*V01*V04*V08*V09 + 4.46497234172275058e-12*V07*V08*V09 - 
      1.42528415799870108e-11*V022*V092 - 2.74113180136972269e-11*V01*V03*V092 + 
      1.77303866649813176e-12*V06*V092 + 6.19926324583187328e-12*V016*V10 - 
      1.08013598211852221e-9*V012*V023*V10 - 1.75570881426551545e-9*V013*V02*V03*V10 + 
      1.47307460970132083e-9*V022*V032*V10 + 9.04896052257042606e-10*V01*V033*V10 - 
      2.24642833193929071e-10*V014*V04*V10 + 5.75877358442485548e-10*V023*V04*V10 + 
      3.63624248841115733e-9*V01*V02*V03*V04*V10 + 5.39568743006184196e-10*V012*V042*V10 - 
      8.93783511579785148e-11*V043*V10 + 1.02043843621241647e-9*V01*V022*V05*V10 + 
      9.04205048358374603e-10*V012*V03*V05*V10 - 4.77151607123061347e-10*V03*V04*V05*V10 - 
      1.36304962154936436e-10*V02*V052*V10 + 4.34684552305441662e-10*V012*V02*V06*V10 - 
      1.71766859580324334e-10*V032*V06*V10 - 2.20617707752033349e-10*V02*V04*V06*V10 - 
      1.22486998470881226e-10*V01*V05*V06*V10 + 4.96346324840088191e-11*V013*V07*V10 - 
      1.4373321721592951e-10*V02*V03*V07*V10 - 8.96259820389039816e-11*V01*V04*V07*V10 + 
      1.82594934724659227e-12*V072*V10 - 2.55378844470172402e-11*V022*V08*V10 - 
      4.97209607691980023e-11*V01*V03*V08*V10 + 3.20226136731066484e-12*V06*V08*V10 - 1.66424128279075483e-11*V01*V02*V09*V10 + 
      2.25874092088892671e-12*V05*V09*V10 - 1.12653412881304331e-12*V012*V102 + 
      5.92609032826688976e-13*V04*V102 - 2.35307874331137145e-10*V013*V022*V11 - 
      8.59390346579136569e-11*V014*V03*V11 + 2.56122800222029521e-10*V023*V03*V11 + 
      7.49755212651196611e-10*V01*V02*V032*V11 + 4.86471165308878208e-10*V01*V022*V04*V11 + 
      4.3713910750440046e-10*V012*V03*V04*V11 - 1.14780689171311559e-10*V03*V042*V11 + 
      2.50421907850127219e-10*V012*V02*V05*V11 - 1.00095716619238854e-10*V032*V05*V11 - 
      1.30555855138937328e-10*V02*V04*V05*V11 - 3.56124023162364183e-11*V01*V052*V11 + 
      3.28078102742084746e-11*V013*V06*V11 - 9.47291834291967603e-11*V02*V03*V06*V11 - 
      5.91897930748147892e-11*V01*V04*V06*V11 - 1.93856434348288081e-11*V022*V07*V11 - 
      3.72456668581856948e-11*V01*V03*V07*V11 + 2.41080199563574167e-12*V06*V07*V11 - 1.38343978742014259e-11*V01*V02*V08*V11 + 
      1.87750330278607734e-12*V05*V08*V11 - 2.06379980709586934e-12*V012*V09*V11 + 
      1.09092874076500041e-12*V04*V09*V11 + 5.0298800777905358e-13*V03*V10*V11 + 7.0070765338504517e-14*V02*V112 - 
      2.1208005841003777e-11*V014*V02*V12 + 1.43260393895278697e-11*V024*V12 + 
      1.87465703907169474e-10*V01*V022*V03*V12 + 8.15053018303082035e-11*V012*V032*V12 + 
      1.11649857489976707e-10*V012*V02*V04*V12 - 4.4564767919231618e-11*V032*V04*V12 - 
      2.84835600049112391e-11*V02*V042*V12 + 1.73871521984163422e-11*V013*V05*V12 - 
      5.10750075917268583e-11*V02*V03*V05*V12 - 3.17784325607582635e-11*V01*V04*V05*V12 - 
      1.16381576566694122e-11*V022*V06*V12 - 2.27141689369831666e-11*V01*V03*V06*V12 + 
      7.31381556139377256e-13*V062*V12 - 9.56832624987960252e-12*V01*V02*V07*V12 + 
      1.29918256119366774e-12*V05*V07*V12 - 1.58491086696809916e-12*V012*V08*V12 + 
      8.33446556463244752e-13*V04*V08*V12 + 4.25530730443919345e-13*V03*V09*V12 + 1.28805732732071082e-13*V02*V10*V12 + 
      3.43922679955297765e-14*V01*V11*V12 - 6.52554025877039293e-13*V015*V13 + 
      1.40670431381859411e-11*V01*V023*V13 + 3.87184829818105716e-11*V012*V02*V03*V13 - 
      5.32620413852048442e-12*V033*V13 + 7.21263636637434183e-12*V013*V04*V13 - 
      2.10052472792949051e-11*V02*V03*V04*V13 - 6.57704165621252631e-12*V01*V042*V13 - 
      5.91280120430917342e-12*V022*V05*V13 - 1.13084914015245695e-11*V01*V03*V05*V13 - 
      5.41157832841609232e-12*V01*V02*V06*V13 + 7.34867886046282007e-13*V05*V06*V13 - 
      1.01573925615648402e-12*V012*V07*V13 + 5.37612816248197697e-13*V04*V07*V13 + 
      3.03057183654965243e-13*V03*V08*V13 + 1.01567905899118282e-13*V02*V09*V13 + 2.94634403383630342e-14*V01*V10*V13 - 
      9.6568031213594039e-17*V132 + 4.23286160535418791e-12*V012*V022*V14 + 
      2.29364971595471251e-12*V013*V03*V14 - 3.55109930502696861e-12*V02*V032*V14 - 
      2.22905375128135736e-12*V022*V04*V14 - 4.3827866246146841e-12*V01*V03*V04*V14 - 
      2.52199778603470324e-12*V01*V02*V05*V14 + 1.71668370770168171e-13*V052*V14 - 
      5.38067360972162115e-13*V012*V06*V14 + 2.8277801582513226e-13*V04*V06*V14 + 1.81793451574552243e-13*V03*V07*V14 + 
      6.72568307750133747e-14*V02*V08*V14 + 2.16039025365449634e-14*V01*V09*V14 - 1.8004300704052234e-16*V12*V14 + 
      4.77762768945689482e-13*V013*V02*V15 - 7.24117615574366523e-13*V022*V03*V15 - 
      6.80930463628860136e-13*V01*V032*V15 - 9.12230925712573974e-13*V01*V02*V04*V15 - 
      2.33698865924940589e-13*V012*V05*V15 + 1.24464156570915188e-13*V04*V05*V15 + 
      9.00859793439058392e-14*V03*V06*V15 + 3.79980993329021327e-14*V02*V07*V15 + 1.3473894818080785e-14*V01*V08*V15 - 
      1.46461479103092518e-16*V11*V15 + 1.74791256931349811e-14*V014*V16 - 4.44825721573317806e-14*V023*V16 - 
      2.69225580940119444e-13*V01*V02*V03*V16 - 8.02978247680623291e-14*V012*V04*V16 + 
      2.11371564748402071e-14*V042*V16 + 3.71537976495766168e-14*V03*V05*V16 + 1.76383558236728567e-14*V02*V06*V16 + 
      7.13233371645080865e-15*V01*V07*V16 - 1.03218422065554138e-16*V10*V16 - 2.46324186786622714e-14*V01*V022*V17 - 
      2.1924300170650675e-14*V012*V03*V17 + 1.20094852636974912e-14*V03*V04*V17 + 6.92055462711326482e-15*V02*V05*V17 + 
      3.1493186613769601e-15*V01*V06*V17 - 6.31793794463729905e-17*V09*V17 - 3.90837593138421937e-15*V012*V02*V18 + 
      1.60247936770006911e-15*V032*V18 + 2.10075206311901791e-15*V02*V04*V18 + 1.16097764211777766e-15*V01*V05*V18 - 
      3.31561898500058733e-17*V08*V18 - 1.80943330156676823e-16*V013*V19 + 5.40568198843072007e-16*V02*V03*V19 + 
      3.39494923206464888e-16*V01*V04*V19 - 1.49634270135353692e-17*V07*V19 + 4.23206344422005235e-17*V022*V20 + 
      8.13491055162726215e-17*V01*V03*V20 - 5.65926592798230618e-18*V06*V20 + 1.25906400567354289e-17*V01*V02*V21 - 
      1.81362180457965426e-18*V05*V21 + 8.29323596551435437e-19*V012*V22 - 4.60735331417464132e-19*V04*V22 - 
      9.84298208028218827e-20*V03*V23 - 1.34032096412353202e-20*V02*V24 - 1.67540120515441502e-21*V01*V25 + 
      1.20359281979483838e-24*V28) + delta4*eps12*
    (1.20882353260258126e-8*V025*V032 + 1.04426097371018395e-7*V01*V023*V033 + 
      6.9719079284711093e-8*V012*V02*V034 - 7.23344550992912055e-9*V036 + 
      5.52620037914155561e-11*V026*V04 + 7.90326424631072416e-8*V01*V024*V03*V04 + 
      2.54323416726398753e-7*V012*V022*V032*V04 + 
      4.51281960847592656e-8*V013*V033*V04 - 1.324883216725678e-7*V02*V034*V04 + 
      5.06434542722669084e-8*V012*V023*V042 + 
      8.66226005370204717e-8*V013*V02*V03*V042 - 
      2.22409766088872341e-7*V022*V032*V042 - 1.53016681070112025e-7*V01*V033*V042 + 
      3.41313722134800566e-9*V014*V043 - 1.96395897468419557e-8*V023*V043 - 
      1.82156807683404165e-7*V01*V02*V03*V043 - 1.34927607259456209e-8*V012*V044 + 
      1.73105497543500998e-9*V045 + 7.25294119561548755e-9*V01*V025*V05 + 
      8.59807307885671175e-8*V012*V023*V03*V05 + 6.99591777342322005e-8*V013*V02*V032*V05 - 
      1.39049724059185477e-7*V022*V033*V05 - 6.57865723958235981e-8*V01*V034*V05 + 
      4.46305625278255997e-8*V013*V022*V04*V05 + 1.61950340242143074e-8*V014*V03*V04*V05 - 
      1.47756732055728671e-7*V023*V03*V04*V05 - 4.89030123593119722e-7*V01*V02*V032*V04*V05 - 
      1.38963331863418844e-7*V01*V022*V042*V05 - 1.37800085223021031e-7*V012*V03*V042*V05 + 
      3.44050669150184239e-8*V03*V043*V05 + 4.18302667587798307e-9*V014*V02*V052 - 
      9.04196340258141116e-9*V024*V052 - 1.28790956572407237e-7*V01*V022*V03*V052 - 
      5.83555802365083814e-8*V012*V032*V052 - 
      7.37360574267513578e-8*V012*V02*V04*V052 + 4.69398212292297161e-8*V032*V04*V052 + 
      2.73458931028917595e-8*V02*V042*V052 - 3.72952775189787807e-9*V013*V053 + 
      1.6958793336841598e-8*V02*V03*V053 + 1.02386762080878323e-8*V01*V04*V053 + 
      8.71170327812938561e-9*V012*V024*V06 + 2.89591202453743303e-8*V013*V022*V03*V06 + 
      5.14017324083364388e-9*V014*V032*V06 - 5.41574870492825955e-8*V023*V032*V06 - 
      1.13699493062326463e-7*V01*V02*V033*V06 + 6.72413420064563855e-9*V014*V02*V04*V06 - 
      1.03756170676674664e-8*V024*V04*V06 - 2.00346967720785699e-7*V01*V022*V03*V04*V06 - 
      9.4732859862585303e-8*V012*V032*V04*V06 - 5.95676145783665186e-8*V012*V02*V042*V06 + 
      3.73178531516166455e-8*V032*V042*V06 + 1.32159742949447015e-8*V02*V043*V06 + 
      4.60713500269600487e-10*V015*V05*V06 - 3.37780054041672907e-8*V01*V023*V05*V06 - 
      1.01912862830765567e-7*V012*V02*V03*V05*V06 + 2.23348100714193579e-8*V033*V05*V06 - 
      1.83126783282942847e-8*V013*V04*V05*V06 + 7.97301498466301465e-8*V02*V03*V04*V05*V06 + 
      2.45304974411087697e-8*V01*V042*V05*V06 + 1.04873740107954018e-8*V022*V052*V06 + 
      2.17844261436320787e-8*V01*V03*V052*V06 - 1.0911096004189193e-8*V012*V022*V062 - 
      6.19369308313955983e-9*V013*V03*V062 + 1.44345788288939075e-8*V02*V032*V062 + 
      7.52095144554799776e-9*V022*V04*V062 + 1.75328066449056264e-8*V01*V03*V04*V062 + 
      9.45427784090595249e-9*V01*V02*V05*V062 - 7.70529739619229361e-10*V052*V062 + 
      6.62001241850818438e-10*V012*V063 - 3.99981412133341695e-10*V04*V063 + 
      3.33215319513658294e-9*V013*V023*V07 + 3.57136603562257157e-9*V014*V02*V03*V07 - 
      8.94594528544603356e-9*V024*V03*V07 - 6.29789259431921199e-8*V01*V022*V032*V07 - 
      1.87936322738569965e-8*V012*V033*V07 + 3.09963162291593664e-10*V015*V04*V07 - 
      2.27966376917771864e-8*V01*V023*V04*V07 - 7.15304904904188209e-8*V012*V02*V03*V04*V07 + 
      1.59574377651104258e-8*V033*V04*V07 - 6.47274061062662212e-9*V013*V042*V07 + 
      2.80661408894938849e-8*V02*V03*V042*V07 + 5.79788133003006763e-9*V01*V043*V07 - 
      1.89350223704757276e-8*V012*V022*V05*V07 - 1.07012255785477306e-8*V013*V03*V05*V07 + 
      2.59524523300590123e-8*V02*V032*V05*V07 + 1.46388001108568292e-8*V022*V04*V05*V07 + 
      3.1127191581057809e-8*V01*V03*V04*V05*V07 + 8.45935591506244628e-9*V01*V02*V052*V07 - 
      4.60775985578051114e-10*V053*V07 - 4.74234229789098545e-9*V013*V02*V06*V07 + 
      1.07393279794729315e-8*V022*V03*V06*V07 + 1.10090898685328405e-8*V01*V032*V06*V07 + 
      1.33582456330230875e-8*V01*V02*V04*V06*V07 + 3.48362573500462324e-9*V012*V05*V06*V07 - 
      2.2032984342683328e-9*V04*V05*V06*V07 - 7.99139107397828057e-10*V03*V062*V07 - 
      1.73530910238513601e-10*V014*V072 + 6.40666703698504504e-10*V023*V072 + 
      4.27646404882137475e-9*V01*V02*V03*V072 + 1.2450965718386082e-9*V012*V04*V072 - 
      3.92905777070812353e-10*V042*V072 - 7.15578374379870009e-10*V03*V05*V072 - 
      3.09694258732338897e-10*V02*V06*V072 - 4.14768341729476862e-11*V01*V073 + 
      5.32251030106422263e-10*V014*V022*V08 - 3.7599196224330001e-10*V025*V08 + 
      1.39926227548776568e-10*V015*V03*V08 - 1.29607199114575347e-8*V01*V023*V03*V08 - 
      1.87787565822432913e-8*V012*V02*V032*V08 + 2.20249261839429827e-9*V034*V08 - 
      1.16240437448587649e-8*V012*V022*V04*V08 - 6.6443470413816776e-9*V013*V03*V04*V08 + 
      1.59373880158148374e-8*V02*V032*V04*V08 + 4.10863213632520728e-9*V022*V042*V08 + 
      9.69019621454820376e-9*V01*V03*V042*V08 - 3.59849807784135024e-9*V013*V02*V05*V08 + 
      8.42325230947116132e-9*V022*V03*V05*V08 + 8.51769281088870386e-9*V01*V032*V05*V08 + 
      1.04141439935135217e-8*V01*V02*V04*V05*V08 + 1.34401063281953465e-9*V012*V052*V08 - 
      8.61241971193464998e-10*V04*V052*V08 - 3.05016292273996891e-10*V014*V06*V08 + 
      1.02953600221241218e-9*V023*V06*V08 + 7.45566703073174797e-9*V01*V02*V03*V06*V08 + 
      2.19130998543030349e-9*V012*V04*V06*V08 - 6.6905946103917063e-10*V042*V06*V08 - 
      1.24720512530691495e-9*V03*V05*V06*V08 - 2.63072992129871742e-10*V02*V062*V08 + 
      1.39859646064307274e-9*V01*V022*V07*V08 + 1.34354140443118404e-9*V012*V03*V07*V08 - 
      8.93225254027936508e-10*V03*V04*V07*V08 - 4.85337063910672764e-10*V02*V05*V07*V08 - 
      2.17489322951947217e-10*V01*V06*V07*V08 + 2.30893271575664754e-10*V012*V02*V082 - 
      1.25747164684605609e-10*V032*V082 - 1.46299824985844711e-10*V02*V04*V082 - 
      8.46083818310006371e-11*V01*V05*V082 + 8.12672495620012848e-13*V083 + 
      3.66051734515786803e-11*V015*V02*V09 - 8.29133332629294245e-10*V01*V024*V09 - 
      5.47087570944765504e-9*V012*V022*V03*V09 - 1.51631914791537193e-9*V013*V032*V09 + 
      2.69669756136912825e-9*V02*V033*V09 - 1.98663118520845969e-9*V013*V02*V04*V09 + 
      4.61220388749224967e-9*V022*V03*V04*V09 + 4.80632079808038063e-9*V01*V032*V04*V09 + 
      2.88370634770292973e-9*V01*V02*V042*V09 - 2.05719876229253226e-10*V014*V05*V09 + 
      7.89190574074530246e-10*V023*V05*V09 + 5.22812950672100975e-9*V01*V02*V03*V05*V09 + 
      1.51791882925948914e-9*V012*V04*V05*V09 - 4.84854684995298139e-10*V042*V05*V09 - 
      4.40672046256432976e-10*V03*V052*V09 + 1.09662515229161045e-9*V01*V022*V06*V09 + 
      1.0613831516673568e-9*V012*V03*V06*V09 - 7.04914834356448994e-10*V03*V04*V06*V09 - 
      3.82230795717939654e-10*V02*V05*V06*V09 - 8.5942197180477207e-11*V01*V062*V09 + 
      4.14350377197574503e-10*V012*V02*V07*V09 - 2.27728148229236456e-10*V032*V07*V09 - 
      2.71296133326879144e-10*V02*V04*V07*V09 - 1.53009091405004201e-10*V01*V05*V07*V09 + 
      4.10498544838390642e-11*V013*V08*V09 - 1.55152746080081988e-10*V02*V03*V08*V09 - 
      9.59423029015289857e-11*V01*V04*V08*V09 + 4.44773535618112588e-12*V07*V08*V09 - 
      1.15555001237355942e-11*V022*V092 - 2.41257779299523541e-11*V01*V03*V092 + 
      1.75819821034290929e-12*V06*V092 + 8.8560903511883904e-13*V016*V10 - 
      4.7028558739918174e-10*V012*V023*V10 - 8.1843740245514698e-10*V013*V02*V03*V10 + 
      1.08025794505111839e-9*V022*V032*V10 + 7.1154440620899848e-10*V01*V033*V10 - 
      1.02649078820550699e-10*V014*V04*V10 + 3.57535624229162578e-10*V023*V04*V10 + 
      2.63925751474864757e-9*V01*V02*V03*V04*V10 + 3.88468872118375081e-10*V012*V042*V10 - 
      8.02194685956035236e-11*V043*V10 + 7.01148303994630507e-10*V01*V022*V05*V10 + 
      6.66210883791491801e-10*V012*V03*V05*V10 - 4.50711553031096479e-10*V03*V04*V05*V10 - 
      1.22690085869169305e-10*V02*V052*V10 + 2.96824185621000256e-10*V012*V02*V06*V10 - 
      1.62614166065059905e-10*V032*V06*V10 - 1.88755241645819331e-10*V02*V04*V06*V10 - 
      1.09389510016645682e-10*V01*V05*V06*V10 + 3.33774532149794918e-11*V013*V07*V10 - 
      1.27115440921079826e-10*V02*V03*V07*V10 - 7.84755984592965309e-11*V01*V04*V07*V10 + 
      1.82130306750850787e-12*V072*V10 - 2.04109508615751688e-11*V022*V08*V10 - 
      4.3660858041144564e-11*V01*V03*V08*V10 + 3.15711796440761009e-12*V06*V08*V10 - 1.35716438685426404e-11*V01*V02*V09*V10 + 
      2.25146259575764275e-12*V05*V09*V10 - 9.11392969230539979e-13*V012*V102 + 
      5.74360148619121813e-13*V04*V102 - 9.9642669201331482e-11*V013*V022*V11 - 
      3.77898697485578291e-11*V014*V03*V11 + 1.68168394627053444e-10*V023*V03*V11 + 
      5.43769172804245806e-10*V01*V02*V032*V11 + 3.18163757684645535e-10*V01*V022*V04*V11 + 
      3.12142097152999357e-10*V012*V03*V04*V11 - 1.05468421638837286e-10*V03*V042*V11 + 
      1.70517703181524832e-10*V012*V02*V05*V11 - 9.51761282987384297e-11*V032*V05*V11 - 
      1.13828360332427639e-10*V02*V04*V05*V11 - 3.19184559893581372e-11*V01*V052*V11 + 
      2.1895471877193824e-11*V013*V06*V11 - 8.30677175300375597e-11*V02*V03*V06*V11 - 
      5.1450365942944162e-11*V01*V04*V06*V11 - 1.57105521096675428e-11*V022*V07*V11 - 
      3.27396475996945943e-11*V01*V03*V07*V11 + 2.39040097981453856e-12*V06*V07*V11 - 1.12578722185719423e-11*V01*V02*V08*V11 + 
      1.8688161409045364e-12*V05*V08*V11 - 1.66948591790450449e-12*V012*V09*V11 + 1.06199280278071825e-12*V04*V09*V11 + 
      4.9427418823354929e-13*V03*V10*V11 + 6.40281712049283203e-14*V02*V112 - 
      8.50650783732569078e-12*V014*V02*V12 + 7.98040773312985024e-12*V024*V12 + 
      1.23857732036580147e-10*V01*V022*V03*V12 + 5.74712727968812932e-11*V012*V032*V12 + 
      7.32396637436056347e-11*V012*V02*V04*V12 - 4.12875645130824172e-11*V032*V04*V12 - 
      2.37244082451593395e-11*V02*V042*V12 + 1.15172641174315601e-11*V013*V05*V12 - 
      4.50673354173006439e-11*V02*V03*V05*V12 - 2.77261980520601875e-11*V01*V04*V05*V12 - 
      9.22551319763251332e-12*V022*V06*V12 - 1.98248863022593421e-11*V01*V03*V06*V12 + 
      7.17967666041412286e-13*V062*V12 - 7.79601827328047531e-12*V01*V02*V07*V12 + 
      1.29534634912714369e-12*V05*V07*V12 - 1.28004691923030537e-12*V012*V08*V12 + 
      8.06898150216084409e-13*V04*V08*V12 + 4.18311280199754674e-13*V03*V09*V12 + 1.17212660295230542e-13*V02*V10*V12 + 
      3.14292422906541054e-14*V01*V11*V12 - 2.44707759703889735e-13*V015*V13 + 
      8.29470830809344407e-12*V01*V023*V13 + 2.51527855599340736e-11*V012*V02*V03*V13 - 
      4.95163469108411185e-12*V033*V13 + 4.62128662075718749e-12*V013*V04*V13 - 
      1.79399282081407719e-11*V02*V03*V04*V13 - 5.57203912826001651e-12*V01*V042*V13 - 
      4.78132194911426031e-12*V022*V05*V13 - 9.8862445917739025e-12*V01*V03*V05*V13 - 
      4.36794692598014939e-12*V01*V02*V06*V13 + 7.28040642889289817e-13*V05*V06*V13 - 
      8.19479307658213228e-13*V012*V07*V13 + 5.23260039465917009e-13*V04*V07*V13 + 
      2.97359507159829527e-13*V03*V08*V13 + 9.28014863712321666e-14*V02*V09*V13 + 2.69121310061478652e-14*V01*V10*V13 - 
      9.65673331297585579e-17*V132 + 2.51116772458039228e-12*V012*V022*V14 + 
      1.44008574460662094e-12*V013*V03*V14 - 3.06151557533819164e-12*V02*V032*V14 - 
      1.7112000522365447e-12*V022*V04*V14 - 3.72993907514810658e-12*V01*V03*V04*V14 - 
      2.0446358065653108e-12*V01*V02*V05*V14 + 1.70985078442690671e-13*V052*V14 - 
      4.31254469191205498e-13*V012*V06*V14 + 2.72387093882243787e-13*V04*V06*V14 + 1.7864407249719243e-13*V03*V07*V14 + 
      6.10919899771084163e-14*V02*V08*V14 + 1.97384141183837402e-14*V01*V09*V14 - 1.79826806083139243e-16*V12*V14 + 
      2.767528234746372e-13*V013*V02*V15 - 5.713527912711336e-13*V022*V03*V15 - 
      5.7875508238377094e-13*V01*V032*V15 - 7.14478161232486493e-13*V01*V02*V04*V15 - 
      1.87009153727962485e-13*V012*V05*V15 + 1.21020252115635927e-13*V04*V05*V15 + 
      8.79582868294079383e-14*V03*V06*V15 + 3.47072260237016761e-14*V02*V07*V15 + 1.22859180855419439e-14*V01*V08*V15 - 
      1.46460082935421556e-16*V11*V15 + 9.71062538507498948e-15*V014*V16 - 3.12672755152665796e-14*V023*V16 - 
      2.11989988841248669e-13*V01*V02*V03*V16 - 6.25139100876856569e-14*V012*V04*V16 + 
      1.99525674035381883e-14*V042*V16 + 3.64406463725905885e-14*V03*V05*V16 + 1.59224099093537048e-14*V02*V06*V16 + 
      6.50930227029003634e-15*V01*V07*V16 - 1.03053420431713173e-16*V10*V16 - 1.77282243443173395e-14*V01*V022*V17 - 
      1.69492633079928458e-14*V012*V03*V17 + 1.14998784791256728e-14*V03*V04*V17 + 
      6.31266880784708842e-15*V02*V05*V17 + 2.85571297717967464e-15*V01*V06*V17 - 6.31779832787020285e-17*V09*V17 - 
      2.80060065453612015e-15*V012*V02*V18 + 1.54455237103185521e-15*V032*V18 + 
      1.85252462056333978e-15*V02*V04*V18 + 1.05585459350036389e-15*V01*V05*V18 - 3.30612504483804565e-17*V08*V18 - 
      1.26660331109673776e-16*V013*V19 + 4.84358488410141383e-16*V02*V03*V19 + 3.01170120638557645e-16*V01*V04*V19 - 
      1.49620308458644072e-17*V07*V19 + 3.4680804946696391e-17*V022*V20 + 7.2377332062670729e-17*V01*V03*V20 - 
      5.61937542309767725e-18*V06*V20 + 1.04042414840089173e-17*V01*V02*V21 - 1.81222563690869225e-18*V05*V21 + 
      6.78537488087538085e-19*V012*V22 - 4.49565990049768031e-19*V04*V22 - 9.70336531318598701e-20*V03*V23 - 
      1.22862755044657102e-20*V02*V24 - 1.53578443805821377e-21*V01*V25 + 1.20359281979483838e-24*V28) + 
   1.13099628864477169e-31*delta28*V28 + 7.91697402051340185e-31*delta26*eps*V28 + 
   delta26*eps2*(-4.94047679986510124e-25*V142 - 1.05867359997109312e-24*V13*V15 - 
      7.47299011744301028e-25*V12*V16 - 6.07180447042244585e-25*V11*V17 - 3.19568656338023466e-25*V10*V18 - 
      1.9529195665101434e-25*V09*V19 - 7.4396935867053082e-26*V08*V20 - 3.34786211401738869e-26*V07*V21 - 
      8.73355334091492701e-27*V06*V22 - 2.77885788120020405e-27*V05*V23 - 4.44617260992032648e-28*V04*V24 - 
      9.26285960400068017e-29*V03*V25 - 6.86137748444494827e-30*V02*V26 - 7.91697402051340185e-31*V01*V27 + 
      6.38465646815596924e-33*V30) + delta24*eps3*
    (-6.42261983982463161e-24*V142 - 1.37627567996242106e-23*V13*V15 - 9.71488715267591336e-24*V12*V16 - 
      7.8933458115491796e-24*V11*V17 - 4.15439253239430505e-24*V10*V18 - 2.53879543646318642e-24*V09*V19 - 
      9.67160166271690066e-25*V08*V20 - 4.3522207482226053e-25*V07*V21 - 1.13536193431894051e-25*V06*V22 - 
      3.61251524556026527e-26*V05*V23 - 5.78002439289642442e-27*V04*V24 - 1.20417174852008842e-27*V03*V25 - 
      8.91979072977843275e-29*V02*V26 - 1.02920662266674224e-29*V01*V27 + 4.15002670430138e-32*V30) + 
   delta22*eps4*(5.50715506077594399e-19*V08*V092 + 3.5340032475567555e-19*V082*V10 + 
      8.9528082271437806e-19*V07*V09*V10 + 2.16553315883834953e-19*V06*V102 + 7.20936662501578122e-19*V07*V08*V11 + 
      5.43563356648015251e-19*V06*V09*V11 + 3.41834495945489805e-19*V05*V10*V11 + 6.94815768932680364e-20*V04*V112 + 
      2.45857887468486898e-19*V072*V12 + 2.92599934817490315e-19*V06*V08*V12 + 2.86834202046568048e-19*V05*V09*V12 + 
      9.28707543611102179e-20*V04*V10*V12 + 5.21516730993760087e-20*V03*V11*V12 + 3.55319091446298081e-21*V02*V122 + 
      2.50875395376007039e-19*V06*V07*V13 + 1.94098332211963341e-19*V05*V08*V13 + 9.79868392084549231e-20*V04*V09*V13 + 
      4.3824935377626898e-20*V03*V10*V13 + 8.9402868170358872e-21*V02*V11*V13 + 2.0058335807452311e-21*V01*V12*V13 + 
      4.36137225807519929e-20*V062*V14 + 1.13472871139301645e-19*V05*V07*V14 + 4.51814177991727375e-20*V04*V08*V14 + 
      3.15202419831393459e-20*V03*V09*V14 + 5.11740399255674086e-21*V02*V10*V14 + 1.71928592635305523e-21*V01*V11*V14 - 
      5.30277843185520866e-23*V142 + 5.01750790752014078e-20*V05*V06*V15 + 3.35954877286131165e-20*V04*V07*V15 + 
      1.84855554487584134e-20*V03*V08*V15 + 4.68300738035213139e-21*V02*V09*V15 + 1.25214101078933994e-21*V01*V10*V15 - 
      1.11925325596943901e-22*V13*V15 + 9.86061045996605206e-21*V052*V16 + 1.01400090053859715e-20*V04*V06*V16 + 
      9.39105758092004958e-21*V03*V07*V16 + 1.87425738667625411e-21*V02*V08*V16 + 7.82588131743337465e-22*V01*V09*V16 - 
      8.04107575507455763e-23*V12*V16 + 5.18753854632996652e-21*V04*V05*V17 + 3.68934404964716234e-21*V03*V06*V17 + 
      1.23961960068144654e-21*V02*V07*V17 + 4.07769605487317942e-22*V01*V08*V17 - 6.45185445394148042e-23*V11*V17 + 
      4.57805102972235216e-22*V042*V18 + 1.26861655040498915e-21*V03*V05*V18 + 3.26733487063489043e-22*V02*V06*V18 + 
      1.81230935772141308e-22*V01*V07*V18 - 3.46436095222738772e-23*V10*V18 + 3.03364827270758276e-22*V03*V04*V19 + 
      1.52233986048598698e-22*V02*V05*V19 + 6.47253342043361813e-23*V01*V06*V19 - 2.09613366805422058e-23*V09*V19 + 
      3.23626671021680907e-23*V032*V20 + 2.33686597927307674e-23*V02*V04*V20 + 1.94176002613008544e-23*V01*V05*V20 - 
      8.16506371140907575e-24*V08*V20 + 7.24923743088565231e-24*V02*V03*V21 + 4.33378324672511823e-24*V01*V04*V21 - 
      3.64730978088227734e-24*V07*V21 + 2.36388177094097358e-25*V022*V22 + 7.8796059031365786e-25*V01*V03*V22 - 
      9.74923324796947779e-25*V06*V22 + 8.59593371251263119e-26*V01*V02*V23 - 3.08710526468889335e-25*V05*V23 + 
      3.581639046880263e-27*V012*V24 - 5.07069518855450567e-26*V04*V24 - 1.05390758161074405e-26*V03*V25 - 
      8.02781165680058948e-28*V02*V26 - 9.26285960400068017e-29*V01*V27 + 2.490016022580828e-31*V30) + 
   delta20*eps5*(7.98537483812511878e-18*V08*V092 + 5.34812491463588999e-18*V082*V10 + 
      1.30095494550683062e-17*V07*V09*V10 + 3.27882067539551445e-18*V06*V102 + 1.04535816062728828e-17*V07*V08*V11 + 
      7.86807958748002075e-18*V06*V09*V11 + 4.96728251920789872e-18*V05*V10*V11 + 1.00432461145723798e-18*V04*V112 + 
      3.58250064596938051e-18*V072*V12 + 4.43336435533937491e-18*V06*V08*V12 + 4.17958408696427727e-18*V05*V09*V12 + 
      1.40838098847909328e-18*V04*V10*V12 + 7.59924379448050412e-19*V03*V11*V12 + 5.39855780874859342e-20*V02*V122 + 
      3.63142134806770189e-18*V06*V07*V13 + 2.81442581707346844e-18*V05*V08*V13 + 1.41635522128584843e-18*V04*V09*V13 + 
      6.36831092206140862e-19*V03*V10*V13 + 1.29075390920955621e-19*V02*V11*V13 + 2.92278607480019389e-20*V01*V12*V13 + 
      6.62311043792658582e-19*V062*V14 + 1.65954074041228656e-18*V05*V07*V14 + 6.86376711010421088e-19*V04*V08*V14 + 
      4.60983539003412934e-19*V03*V09*V14 + 7.78330852306653709e-20*V02*V10*V14 + 2.51445566729134328e-20*V01*V11*V14 - 
      3.45092304470577321e-22*V142 + 7.26284269613540377e-19*V05*V06*V15 + 4.8560750444086232e-19*V04*V07*V15 + 
      2.68040554006996994e-19*V03*V08*V15 + 6.7610919053833897e-20*V02*V09*V15 + 1.81951740630325961e-20*V01*V10*V15 - 
      7.11340436380576987e-22*V13*V15 + 1.44950973761500965e-19*V052*V16 + 1.54647969833178317e-19*V04*V06*V16 + 
      1.38048546439524729e-19*V03*V07*V16 + 2.86041728591055321e-20*V02*V08*V16 + 1.15040455366270607e-20*V01*V09*V16 - 
      5.25299309491539157e-22*V12*V16 + 7.49835117151331524e-20*V04*V05*V17 + 5.34032551186426748e-20*V03*V06*V17 + 
      1.78970079848383845e-20*V02*V07*V17 + 5.91265927956611016e-21*V01*V08*V17 - 4.13354955447536952e-22*V11*V17 + 
      7.0325482685493964e-21*V042*V18 + 1.87913826528739018e-20*V03*V05*V18 + 5.02061472356194891e-21*V02*V06*V18 + 
      2.68448323612484312e-21*V01*V07*V18 - 2.28882173194988807e-22*V10*V18 + 4.38500068509550599e-21*V03*V04*V19 + 
      2.19787817357664371e-21*V02*V05*V19 + 9.36899212607766225e-22*V01*V06*V19 - 1.36411431720733517e-22*V09*V19 + 
      4.8544000653252136e-22*V032*V20 + 3.63767634808230963e-22*V02*V04*V20 + 2.91264003919512816e-22*V01*V05*V20 - 
      5.49328375208353194e-23*V08*V20 + 1.04660865408411605e-22*V02*V03*V21 + 6.26428669299357998e-23*V01*V04*V21 - 
      2.42747902117210825e-23*V07*V21 + 3.78221083350555773e-24*V022*V22 + 1.21148940760724896e-23*V01*V03*V22 - 
      6.71949890101837912e-24*V06*V22 + 1.24103792974401113e-24*V01*V02*V23 - 2.11339860914945519e-24*V05*V23 + 
      5.90970442735243395e-26*V012*V24 - 3.59812693697538421e-25*V04*V24 - 7.45505817128654742e-26*V03*V25 - 
      5.88706188165376562e-27*V02*V26 - 6.79276370960049879e-28*V01*V27 + 1.3695088124194554e-30*V30) + 
   delta18*eps6*(-4.48616519584018787e-16*V064 - 8.94203167249278406e-15*V05*V062*V07 - 
      4.68756430676455096e-15*V052*V072 - 5.97195093749807253e-15*V04*V06*V072 - 
      1.47936203145323831e-15*V03*V073 - 6.90101777365995919e-15*V052*V06*V08 - 
      2.77113458677757312e-15*V04*V062*V08 - 9.26081661527549284e-15*V04*V05*V07*V08 - 
      6.57239787967615161e-15*V03*V06*V07*V08 - 1.10332073076130262e-15*V02*V072*V08 - 
      7.12558774566068427e-16*V042*V082 - 2.52308041457366025e-15*V03*V05*V082 - 
      5.05380902678429376e-16*V02*V06*V082 - 3.60440059224808607e-16*V01*V07*V082 - 
      1.81221848853021693e-15*V053*V09 - 6.96727609374775129e-15*V04*V05*V06*V09 - 
      2.48389768680355113e-15*V03*V062*V09 - 2.31331611781168147e-15*V042*V07*V09 - 
      5.14232352504223456e-15*V03*V05*V07*V09 - 1.65069972803369648e-15*V02*V06*V07*V09 - 
      3.62588733199323114e-16*V01*V072*V09 - 2.57244905979874801e-15*V03*V04*V08*V09 - 
      1.28720751922151973e-15*V02*V05*V08*V09 - 5.47699823306345967e-16*V01*V06*V08*V09 - 
      3.50880726819000322e-16*V032*V092 - 3.16781136756807561e-16*V02*V04*V092 - 
      2.0925186629108305e-16*V01*V05*V092 + 6.47900595385405175e-17*V08*V092 - 
      2.18878336926376849e-15*V04*V052*V10 - 8.67705487992327205e-16*V042*V06*V10 - 
      3.09080814108455986e-15*V03*V05*V06*V10 - 3.07417181543249318e-16*V02*V062*V10 - 
      2.08455558977501761e-15*V03*V04*V07*V10 - 1.04794169938382275e-15*V02*V05*V07*V10 - 
      4.41544020154937123e-16*V01*V06*V07*V10 - 5.60676683231374374e-16*V032*V08*V10 - 
      3.15013122383262073e-16*V02*V04*V08*V10 - 3.36406009938824624e-16*V01*V05*V08*V10 + 
      4.59978794695492182e-17*V082*V10 - 2.91094916495506318e-16*V02*V03*V09*V10 - 
      1.73712965814584801e-16*V01*V04*V09*V10 + 1.05912840428139317e-16*V07*V09*V10 - 
      8.56483107862193025e-18*V022*V102 - 3.67972626510464579e-17*V01*V03*V102 + 
      2.83060212558496971e-17*V06*V102 - 8.83266154073551106e-16*V042*V05*V11 - 
      9.69100796005463596e-16*V03*V052*V11 - 1.26677747159050023e-15*V03*V04*V06*V11 - 
      6.30267168885593203e-16*V02*V05*V06*V11 - 1.35485328371102789e-16*V01*V062*V11 - 
      4.56549526453272109e-16*V032*V07*V11 - 4.14695306299820807e-16*V02*V04*V07*V11 - 
      2.71996429415012383e-16*V01*V05*V07*V11 - 2.34037730767549042e-16*V02*V03*V08*V11 - 
      1.40315403261749892e-16*V01*V04*V08*V11 + 8.51383790375393081e-17*V07*V08*V11 - 
      2.78422604550881203e-17*V022*V09*V11 - 7.30794763610125791e-17*V01*V03*V09*V11 + 
      6.41281743874469234e-17*V06*V09*V11 - 1.58779045361185265e-17*V01*V02*V10*V11 + 4.07445354511027254e-17*V05*V10*V11 - 
      8.90066848916775158e-19*V012*V112 + 8.2559002258536699e-18*V04*V112 - 
      6.07146609342992803e-17*V043*V12 - 6.61813833733044596e-16*V03*V04*V05*V12 - 
      1.67205415189365619e-16*V02*V052*V12 - 2.31855790198954275e-16*V032*V06*V12 - 
      1.28577657496500636e-16*V02*V04*V06*V12 - 1.39113474119372565e-16*V01*V05*V06*V12 - 
      1.59243252561300589e-16*V02*V03*V07*V12 - 9.45448333904349422e-17*V01*V04*V07*V12 + 
      2.93874473238087814e-17*V072*V12 - 1.14938253020557183e-17*V022*V08*V12 - 
      4.96896749165462919e-17*V01*V03*V08*V12 + 3.84223034757161606e-17*V06*V08*V12 - 1.32702710467750491e-17*V01*V02*V09*V12 + 
      3.44130121911419594e-17*V05*V09*V12 - 1.5544213563282003e-18*V012*V10*V12 + 1.22950122296540487e-17*V04*V10*V12 + 
      6.32654238749765499e-18*V03*V11*V12 + 4.78129678540683892e-19*V02*V122 - 
      1.13239250522250142e-16*V03*V042*V13 - 1.2043230636304643e-16*V032*V05*V13 - 
      1.11648736311490217e-16*V02*V04*V05*V13 - 3.5731738429929615e-17*V01*V052*V13 - 
      8.0803483190460667e-17*V02*V03*V06*V13 - 4.87222104457884705e-17*V01*V04*V06*V13 - 
      1.28502740561945171e-17*V022*V07*V13 - 3.32668823746511836e-17*V01*V03*V07*V13 + 
      2.98222184467548409e-17*V06*V07*V13 - 9.00145118336727083e-18*V01*V02*V08*V13 + 2.31821913954806098e-17*V05*V08*V13 - 
      1.24629541770092667e-18*V012*V09*V13 + 1.16868394101382844e-17*V04*V09*V13 + 
      5.30188590081608009e-18*V03*V10*V13 + 1.07830062601667895e-18*V02*V11*V13 + 2.47792084135634085e-19*V01*V12*V13 - 
      3.5709051611878866e-17*V032*V04*V14 - 9.59963275489394107e-18*V02*V042*V14 - 
      3.63607867100278612e-17*V02*V03*V05*V14 - 2.14254309671273196e-17*V01*V04*V05*V14 - 
      3.34953107171274943e-18*V022*V06*V14 - 1.47827306418680236e-17*V01*V03*V06*V14 + 
      5.80715783574750585e-18*V062*V14 - 5.1943981014325516e-18*V01*V02*V07*V14 + 1.38256377767680936e-17*V05*V07*V14 - 
      7.55408505672181901e-19*V012*V08*V14 + 6.03944361528490781e-18*V04*V08*V14 + 
      3.86839333429437427e-18*V03*V09*V14 + 6.92096131220533651e-19*V02*V10*V14 + 2.14051097830955376e-19*V01*V11*V14 - 
      1.89356124546829668e-21*V142 - 3.66013997885416585e-18*V033*V15 - 
      1.06332129820466874e-17*V02*V03*V04*V15 - 3.23540715777857548e-18*V01*V042*V15 - 
      2.57005481123890341e-18*V022*V05*V15 - 6.43558302164304669e-18*V01*V03*V05*V15 - 
      2.3086709482988762e-18*V01*V02*V06*V15 + 6.05428348883193408e-18*V05*V06*V15 - 
      4.17158943881495489e-19*V012*V07*V15 + 4.05207394035795021e-18*V04*V07*V15 + 
      2.24914840530658248e-18*V03*V08*V15 + 5.69023573403384661e-19*V02*V09*V15 + 1.54835061865419317e-19*V01*V10*V15 - 
      3.80383188925613711e-21*V13*V15 - 1.47350206309834647e-18*V02*V032*V16 - 
      3.71375281741910713e-19*V022*V04*V16 - 1.71067504894039623e-18*V01*V03*V04*V16 - 
      8.84101237859007882e-19*V01*V02*V05*V16 + 1.2315902464497599e-18*V052*V16 - 
      1.69050640967072785e-19*V012*V06*V16 + 1.38238068358027677e-18*V04*V06*V16 + 
      1.17707515719251901e-18*V03*V07*V16 + 2.57422856685301392e-19*V02*V08*V16 + 9.91226127666111233e-20*V01*V09*V16 - 
      2.89406903444333095e-21*V12*V16 - 1.8897461847344878e-19*V022*V03*V17 - 
      2.20195586963151689e-19*V01*V032*V17 - 2.34556168721618103e-19*V01*V02*V04*V17 - 
      6.11760782910669257e-20*V012*V05*V17 + 6.37309321605777932e-19*V04*V05*V17 + 
      4.55076705003925214e-19*V03*V06*V17 + 1.52847117882936513e-19*V02*V07*V17 + 5.08896467648172792e-20*V01*V08*V17 - 
      2.22924951841677783e-21*V11*V17 - 3.61673910953968958e-21*V023*V18 - 5.45702106821723751e-20*V01*V02*V03*V18 - 
      1.51583918561589931e-20*V012*V04*V18 + 6.43738193567073277e-20*V042*V18 + 
      1.64120470048554016e-19*V03*V05*V18 + 4.61046435143389756e-20*V02*V06*V18 + 2.36030639976242536e-20*V01*V07*V18 - 
      1.27617896511908607e-21*V10*V18 - 3.31534418374471544e-21*V01*V022*V19 - 
      3.19124039077031433e-21*V012*V03*V19 + 3.82210133839018665e-20*V03*V04*V19 + 1.9180241204193692e-20*V02*V05*V19 + 
      8.21558667055639149e-21*V01*V06*V19 - 7.47995534847316065e-22*V09*V19 - 3.79403024236026259e-22*V012*V02*V20 + 
      4.37963973893640771e-21*V032*V20 + 3.43894143062534349e-21*V02*V04*V20 + 2.63593923547159098e-21*V01*V05*V20 - 
      3.12286346087466005e-22*V08*V20 - 1.06374679692343811e-23*V013*V21 + 9.39347518727669376e-22*V02*V03*V21 + 
      5.63490317148054577e-22*V01*V04*V21 - 1.36341126616339151e-22*V07*V21 + 3.72311378923203339e-23*V022*V22 + 
      1.14057295447901975e-22*V01*V03*V22 - 3.92087540068889534e-23*V06*V22 + 1.15239236333372462e-23*V01*V02*V23 - 
      1.22373336419380386e-23*V05*V23 + 5.90970442735243395e-25*V012*V24 - 2.16757089973351916e-24*V04*V24 - 
      4.47473309369932858e-25*V03*V25 - 3.67941367603360351e-26*V02*V26 - 4.24547731850031174e-27*V01*V27 + 
      6.84754406209727701e-30*V30) + delta16*eps7*
    (-7.34206382378028133e-15*V064 - 1.26850963458063282e-13*V05*V062*V07 - 
      6.55247959665185957e-14*V052*V072 - 8.45494331555300777e-14*V04*V06*V072 - 
      2.07110684403453363e-14*V03*V073 - 9.82765845876355675e-14*V052*V06*V08 - 
      4.54709966735524697e-14*V04*V062*V08 - 1.31480939504825697e-13*V04*V05*V07*V08 - 
      9.35967472263195881e-14*V03*V06*V07*V08 - 1.56430238338706235e-14*V02*V072*V08 - 
      1.17259622953321769e-14*V042*V082 - 3.61090033102099245e-14*V03*V05*V082 - 
      8.33714019981313481e-15*V02*V06*V082 - 5.15842904431570351e-15*V01*V07*V082 - 
      2.5371058839423037e-14*V053*V09 - 9.8641005348118424e-14*V04*V05*V06*V09 - 
      3.52363787383509116e-14*V03*V062*V09 - 3.27320935750135619e-14*V042*V07*V09 - 
      7.21224891624196487e-14*V03*V05*V07*V09 - 2.33708877377919834e-14*V02*V06*V07*V09 - 
      5.10283210522514063e-15*V01*V072*V09 - 3.6522483195784916e-14*V03*V04*V08*V09 - 
      1.82501944728490607e-14*V02*V05*V08*V09 - 7.79972893552663234e-15*V01*V06*V08*V09 - 
      4.94418043201276432e-15*V032*V092 - 4.49312020502002561e-15*V02*V04*V092 - 
      2.95331703793771478e-15*V01*V05*V092 + 3.79750736470270608e-16*V08*V092 - 
      3.12313497958389332e-14*V04*V052*V10 - 1.43212533605983009e-14*V042*V06*V10 - 
      4.42842469492141436e-14*V03*V05*V06*V10 - 5.08775746460910372e-15*V02*V062*V10 - 
      2.97441426627037459e-14*V03*V04*V07*V10 - 1.49166848148849441e-14*V02*V05*V07*V10 - 
      6.32632099274487766e-15*V01*V06*V07*V10 - 8.08521985387725728e-15*V032*V08*V10 - 
      5.23418054551202919e-15*V02*V04*V08*V10 - 4.85113191232635437e-15*V01*V05*V08*V10 + 
      2.86640883007379905e-16*V082*V10 - 4.14352355969026224e-15*V02*V03*V09*V10 - 
      2.47867855522531216e-15*V01*V04*V09*V10 + 6.23018090819736941e-16*V07*V09*V10 - 
      1.44378242369284632e-16*V022*V102 - 5.36268736401798886e-16*V01*V03*V102 + 
      1.77476156057167523e-16*V06*V102 - 1.24977084559142691e-14*V042*V05*V11 - 
      1.36384785357835577e-14*V03*V052*V11 - 1.79347282451124407e-14*V03*V04*V06*V11 - 
      8.92342986352057548e-15*V02*V05*V06*V11 - 1.92198429481914063e-15*V01*V062*V11 - 
      6.44360081004592315e-15*V032*V07*V11 - 5.88190281384439716e-15*V02*V04*V07*V11 - 
      3.84618319263906144e-15*V01*V05*V07*V11 - 3.3182171768816474e-15*V02*V03*V08*V11 - 
      1.9921354470428136e-15*V01*V04*V08*V11 + 5.02325342009665761e-16*V07*V08*V11 - 
      3.97980546505083131e-16*V022*V09*V11 - 1.04280831740192632e-15*V01*V03*V09*V11 + 
      3.79448276278040429e-16*V06*V09*V11 - 2.26010375983105213e-16*V01*V02*V10*V11 + 2.42826407126078001e-16*V05*V10*V11 - 
      1.31199082797811721e-17*V012*V112 + 4.96118762076116878e-17*V04*V112 - 
      1.01180421757528827e-15*V043*V12 - 9.51670270746231298e-15*V03*V04*V05*V12 - 
      2.39601757314829602e-15*V02*V052*V12 - 3.3527522090915847e-15*V032*V06*V12 - 
      2.15097048744028581e-15*V02*V04*V06*V12 - 2.01165132545495082e-15*V01*V05*V06*V12 - 
      2.2819214982364724e-15*V02*V03*V07*V12 - 1.35952895820890185e-15*V01*V04*V07*V12 + 
      1.74604354164330062e-16*V072*V12 - 1.94446677797083224e-16*V022*V08*V12 - 
      7.25320499429494088e-16*V01*V03*V08*V12 + 2.42360576913313143e-16*V06*V08*V12 - 1.90160124853039367e-16*V01*V02*V09*V12 + 
      2.0579014386556974e-16*V05*V09*V12 - 2.31440927460396376e-17*V012*V10*V12 + 7.84854587587295795e-17*V04*V10*V12 + 
      3.85536974340224988e-17*V03*V11*V12 + 3.12336320357788239e-18*V02*V122 - 
      1.60227031486080373e-15*V03*V042*V13 - 1.70913857306692002e-15*V032*V05*V13 - 
      1.58358921911195308e-15*V02*V04*V05*V13 - 5.08629385970571426e-16*V01*V052*V13 - 
      1.14402946968212506e-15*V02*V03*V06*V13 - 6.89797240196632336e-16*V01*V04*V06*V13 - 
      1.83683329156192214e-16*V022*V07*V13 - 4.76521043771045156e-16*V01*V03*V07*V13 + 
      1.78736043395954438e-16*V06*V07*V13 - 1.27623737572371054e-16*V01*V02*V08*V13 + 1.39439100106179099e-16*V05*V08*V13 - 
      1.84101884509505308e-17*V012*V09*V13 + 7.06679175536846871e-17*V04*V09*V13 + 
      3.23999938493564539e-17*V03*V10*V13 + 6.6556548271607382e-18*V02*V11*V13 + 1.55573885260872085e-18*V01*V12*V13 - 
      5.19573506998252725e-16*V032*V04*V14 - 1.63128039200778097e-16*V02*V042*V14 - 
      5.2646913923462922e-16*V02*V03*V05*V14 - 3.11744104198951635e-16*V01*V04*V05*V14 - 
      5.73340801598107289e-17*V022*V06*V14 - 2.16913204746820974e-16*V01*V03*V06*V14 + 
      3.72838824329503798e-17*V062*V14 - 7.520987703351846e-17*V01*V02*V07*V14 + 8.39982928608680429e-17*V05*V07*V14 - 
      1.1289970254467218e-17*V012*V08*V14 + 3.90013947631343566e-17*V04*V08*V14 + 2.37938426670223137e-17*V03*V09*V14 + 
      4.54630205875946513e-18*V02*V10*V14 + 1.34813507700158943e-18*V01*V11*V14 - 8.97659932151489569e-21*V142 - 
      5.25729196962689277e-17*V033*V15 - 1.50818020867805055e-16*V02*V03*V04*V15 - 
      4.57791518531658209e-17*V01*V042*V15 - 3.67366658312384429e-17*V022*V05*V15 - 
      9.30536764035747341e-17*V01*V03*V05*V15 - 3.26865562766321446e-17*V01*V02*V06*V15 + 3.71896365708575066e-17*V05*V06*V15 - 
      6.20726040915139994e-18*V012*V07*V15 + 2.49515214428033644e-17*V04*V07*V15 + 
      1.39462098311928584e-17*V03*V08*V15 + 3.55329547765984752e-18*V02*V09*V15 + 9.80074246788768674e-19*V01*V10*V15 - 
      1.76222043419988291e-20*V13*V15 - 2.16829892097685931e-17*V02*V032*V16 - 
      6.50910920024639473e-18*V022*V04*V16 - 2.53626170299423963e-17*V01*V03*V04*V16 - 
      1.30097935258611558e-17*V01*V02*V05*V16 + 7.6893040366815274e-18*V052*V16 - 
      2.54869477555668077e-18*V012*V06*V16 + 9.12964400060918768e-18*V04*V06*V16 + 
      7.39235879597283543e-18*V03*V07*V16 + 1.71889491055298644e-18*V02*V08*V16 + 6.33332923257248144e-19*V01*V09*V16 - 
      1.37678571153793654e-20*V12*V16 - 2.70122542876753257e-18*V022*V03*V17 - 
      3.25155483415587327e-18*V01*V032*V17 - 3.32686810737805269e-18*V01*V02*V04*V17 - 
      9.25012939668683312e-19*V012*V05*V17 + 4.03875139818214825e-18*V04*V05*V17 + 
      2.89362341237922317e-18*V03*V06*V17 + 9.76048851618077564e-19*V02*V07*V17 + 3.28213755456742212e-19*V01*V08*V17 - 
      1.03994426280195746e-20*V11*V17 - 6.63778001280225381e-20*V023*V18 - 8.24935641014126255e-19*V01*V02*V03*V18 - 
      2.32481862467617399e-19*V012*V04*V18 + 4.39027805114913171e-19*V042*V18 + 
      1.063340800229279e-18*V03*V05*V18 + 3.16082736330017946e-19*V02*V06*V18 + 1.54605845920516598e-19*V01*V07*V18 - 
      6.13607824904285805e-21*V10*V18 - 4.73899198029391678e-20*V01*V022*V19 - 
      5.0102474135093935e-20*V012*V03*V19 + 2.51407690896213569e-19*V03*V04*V19 + 1.26399713144427533e-19*V02*V05*V19 + 
      5.44867572132232625e-20*V01*V06*V19 - 3.5391823902471404e-21*V09*V19 - 6.03144433855589409e-21*V012*V02*V20 + 
      2.95370826374777947e-20*V032*V20 + 2.44281853722060966e-20*V02*V04*V20 + 1.78690466404621113e-20*V01*V05*V20 - 
      1.5288112779523826e-21*V08*V20 - 1.9147442344621886e-22*V013*V21 + 6.43389521005859484e-21*V02*V03*V21 + 
      3.87115188513721186e-21*V01*V04*V21 - 6.59309551492957433e-22*V07*V21 + 2.76574167200093909e-22*V022*V22 + 
      8.07561109997710099e-22*V01*V03*V22 - 1.96911642637827796e-22*V06*V22 + 8.24403767615664536e-23*V01*V02*V23 - 
      6.09519782235234957e-23*V05*V23 + 4.43227832051432546e-24*V012*V24 - 1.12498356176548661e-23*V04*V24 - 
      2.31293604311896984e-24*V03*V25 - 1.9868833850581459e-25*V02*V26 - 2.29255775199016834e-26*V01*V27 + 
      3.08139482794377465e-29*V30) + delta14*eps8*
    (2.35507378426005005e-12*V043*V052 + 5.39330385626284643e-12*V03*V04*V053 + 
      6.88466707637125585e-13*V02*V054 + 3.1637336346366468e-13*V044*V06 + 
      1.0128598222905747e-11*V03*V042*V05*V06 + 5.60203400580988479e-12*V032*V052*V06 + 
      5.00458911220634749e-12*V02*V04*V052*V06 + 1.1016481335927049e-12*V01*V053*V06 + 
      3.59755664865051297e-12*V032*V04*V062 + 6.61421923585583323e-13*V02*V042*V062 + 
      3.5956297266427196e-12*V02*V03*V05*V062 + 2.15853398919030778e-12*V01*V04*V05*V062 + 
      7.63853768139394869e-14*V022*V063 + 5.04755377957519226e-13*V01*V03*V063 - 
      6.2256926751198383e-14*V064 + 2.24292741358100004e-12*V03*V043*V07 + 
      7.59694726657796423e-12*V032*V04*V05*V07 + 3.29027994910963913e-12*V02*V042*V05*V07 + 
      3.88847318858481207e-12*V02*V03*V052*V07 + 2.24675242154841578e-12*V01*V04*V052*V07 + 
      1.74864783109953159e-12*V033*V06*V07 + 4.76627534495842619e-12*V02*V03*V04*V06*V07 + 
      1.44694260327224958e-12*V01*V042*V06*V07 + 1.15692431047412348e-12*V022*V05*V06*V07 + 
      3.07762258254794945e-12*V01*V03*V05*V06*V07 + 5.13661389520388515e-13*V01*V02*V062*V07 - 
      9.42006032871439169e-13*V05*V062*V07 + 9.13017171480372307e-13*V02*V032*V072 + 
      3.76241252751854662e-13*V022*V04*V072 + 1.04684224853117798e-12*V01*V03*V04*V072 + 
      5.41292833798604223e-13*V01*V02*V05*V072 - 4.75911104879919518e-13*V052*V072 + 
      1.01723480862693579e-13*V012*V06*V072 - 6.29308193489189785e-13*V04*V06*V072 - 
      1.51545961948382109e-13*V03*V073 + 1.85358347412499737e-12*V032*V042*V08 + 
      2.23657512618854329e-13*V02*V043*V08 + 1.32637060567983116e-12*V033*V05*V08 + 
      3.69646701706884502e-12*V02*V03*V04*V05*V08 + 1.11215008447499842e-12*V01*V042*V05*V08 + 
      4.52270181011196878e-13*V022*V052*V08 + 1.16357203439198338e-12*V01*V03*V052*V08 + 
      1.31660051684880815e-12*V02*V032*V06*V08 + 2.31925124161845252e-13*V022*V04*V06*V08 + 
      1.56122149013202281e-12*V01*V03*V04*V06*V08 + 7.8996031010928489e-13*V01*V02*V05*V06*V08 - 
      7.3328091220647616e-13*V052*V06*V08 + 8.00286287486456962e-14*V012*V062*V08 - 
      3.87975902269054153e-13*V04*V062*V08 + 4.30733505724949408e-13*V022*V03*V07*V08 + 
      5.39719296986723196e-13*V01*V032*V07*V08 + 5.28066716724120717e-13*V01*V02*V04*V07*V08 + 
      1.5292828601852896e-13*V012*V05*V07*V08 - 9.82752412489036078e-13*V04*V05*V07*V08 - 
      7.02569620265405834e-13*V03*V06*V07*V08 - 1.17931399348594738e-13*V02*V072*V08 + 
      6.69504784238175546e-15*V023*V082 + 1.42768095707150999e-13*V01*V02*V03*V082 + 
      4.12321448947806462e-14*V012*V04*V082 - 1.00684561450507463e-13*V042*V082 - 
      2.7244245951980103e-13*V03*V05*V082 - 7.20150591440760036e-14*V02*V06*V082 - 
      3.93805813103512825e-14*V01*V07*V082 + 6.83463167630692065e-13*V033*V04*V09 + 
      9.13966652530455315e-13*V02*V03*V042*V09 + 1.8691061779841667e-13*V01*V043*V09 + 
      1.05251384349728599e-12*V02*V032*V05*V09 + 4.38948128210497106e-13*V022*V04*V05*V09 + 
      1.20335386860583348e-12*V01*V03*V04*V05*V09 + 3.11270730685248432e-13*V01*V02*V052*V09 - 
      1.85663164695406226e-13*V053*V09 + 3.21367864020589857e-13*V022*V03*V06*V09 + 
      4.10289288341899865e-13*V01*V032*V06*V09 + 3.97189612079868849e-13*V01*V02*V04*V06*V09 + 
      1.1644421962918155e-13*V012*V05*V06*V09 - 7.3867914771912083e-13*V04*V05*V06*V09 - 
      2.64857061775150264e-13*V03*V062*V09 + 3.28144186416223419e-14*V023*V07*V09 + 
      2.89513621919572316e-13*V01*V02*V03*V07*V09 + 7.95621864156627378e-14*V012*V04*V07*V09 - 
      2.45860160648114288e-13*V042*V07*V09 - 5.31756052052083213e-13*V03*V05*V07*V09 - 
      1.76653134013751701e-13*V02*V06*V07*V09 - 3.81738632799045893e-14*V01*V072*V09 + 
      3.58944588104124506e-14*V01*V022*V08*V09 + 4.00863087575386264e-14*V012*V03*V08*V09 - 
      2.76287578102280811e-13*V03*V04*V08*V09 - 1.38414799522561442e-13*V02*V05*V08*V09 - 
      5.95991800393076211e-14*V01*V06*V08*V09 + 5.46573122039895515e-15*V012*V02*V092 - 
      3.70205749417367073e-14*V032*V092 - 3.43136211819166243e-14*V02*V04*V092 - 
      2.22694838787587368e-14*V01*V05*V092 + 1.75815601364974319e-15*V08*V092 + 
      7.13960256425088574e-14*V034*V10 + 4.12382840676584542e-13*V02*V032*V04*V10 + 
      3.52902630852678872e-14*V022*V042*V10 + 2.45227411077153522e-13*V01*V03*V042*V10 + 
      2.03543540650939398e-13*V022*V03*V05*V10 + 2.48086925858791731e-13*V01*V032*V05*V10 + 
      2.47429704405950725e-13*V01*V02*V04*V05*V10 + 3.49710714692579749e-14*V012*V052*V10 - 
      2.36083996391657882e-13*V04*V052*V10 + 8.052229042807684e-15*V023*V06*V10 + 
      1.74006404430094811e-13*V01*V02*V03*V06*V10 + 5.02953956410009868e-14*V012*V04*V06*V10 - 
      1.23751897475290984e-13*V042*V06*V10 - 3.36313607147811151e-13*V03*V05*V06*V10 - 
      4.42315251698325436e-14*V02*V062*V10 + 2.90776486644199139e-14*V01*V022*V07*V10 + 
      3.20288157153542396e-14*V012*V03*V07*V10 - 2.26174512961892422e-13*V03*V04*V07*V10 - 
      1.13658394798520683e-13*V02*V05*V07*V10 - 4.86081734818727821e-14*V01*V06*V07*V10 + 
      9.16444207788403927e-15*V012*V02*V08*V10 - 6.21136505345846184e-14*V032*V08*V10 - 
      4.58131085651719322e-14*V02*V04*V08*V10 - 3.74819600969795208e-14*V01*V05*V08*V10 + 
      1.40272626093548825e-15*V082*V10 + 7.35595415710697318e-16*V013*V09*V10 - 
      3.19446931879264903e-14*V02*V03*V09*V10 - 1.91810289892836924e-14*V01*V04*V09*V10 + 2.89231312706572991e-15*V07*V09*V10 - 
      1.29087015069869918e-15*V022*V102 - 4.22201059214955624e-15*V01*V03*V102 + 
      8.7531860031276066e-16*V06*V102 + 6.12091820913871831e-14*V02*V033*V11 + 
      7.98087505837267465e-14*V022*V03*V04*V11 + 1.03686350858970266e-13*V01*V032*V04*V11 + 
      4.9852726501661199e-14*V01*V02*V042*V11 + 1.25291416631648942e-14*V023*V05*V11 + 
      1.0752873588460693e-13*V01*V02*V03*V05*V11 + 2.93985391034053639e-14*V012*V04*V05*V11 - 
      9.50165954753263758e-14*V042*V05*V11 - 1.0207624806039861e-13*V03*V052*V11 + 
      1.75291562193049013e-14*V01*V022*V06*V11 + 1.97058943271430255e-14*V012*V03*V06*V11 - 
      1.36752347938967104e-13*V03*V04*V06*V11 - 6.82645199531197787e-14*V02*V05*V06*V11 - 
      1.4794609112556735e-14*V01*V062*V11 + 7.0563895204977358e-15*V012*V02*V07*V11 - 
      4.86066102769434268e-14*V032*V07*V11 - 4.51897795363406399e-14*V02*V04*V07*V11 - 
      2.92199066434005037e-14*V01*V05*V07*V11 + 5.94536014549359353e-16*V013*V08*V11 - 
      2.56180546127571243e-14*V02*V03*V08*V11 - 1.54303184625236455e-14*V01*V04*V08*V11 + 2.34408338056338325e-15*V07*V08*V11 - 
      3.11648381170519151e-15*V022*V09*V11 - 8.05853468833981609e-15*V01*V03*V09*V11 + 
      1.77963751824100912e-15*V06*V09*V11 - 1.78311964897825348e-15*V01*V02*V10*V11 + 1.1459049713302062e-15*V05*V10*V11 - 
      1.05459850752079744e-16*V012*V112 + 2.37547917906263567e-16*V04*V112 + 
      1.52525141068358642e-14*V022*V032*V12 + 1.17596105971387453e-14*V01*V033*V12 + 
      1.62032944752791867e-15*V023*V04*V12 + 3.66192626889360174e-14*V01*V02*V03*V04*V12 + 
      5.30808529895446134e-15*V012*V042*V12 - 8.91213407167000147e-15*V043*V12 + 
      9.15150846410151852e-15*V01*V022*V05*V12 + 9.80679950661887164e-15*V012*V03*V05*V12 - 
      7.36852272780232135e-14*V03*V04*V05*V12 - 1.85802239602777975e-14*V02*V052*V12 + 
      3.75473724082799042e-15*V012*V02*V06*V12 - 2.60928654740262308e-14*V032*V06*V12 - 
      1.90697685334469798e-14*V02*V04*V06*V12 - 1.57439574873784056e-14*V01*V05*V06*V12 + 
      3.93004735476517777e-16*V013*V07*V12 - 1.77969527992233029e-14*V02*V03*V07*V12 - 
      1.0646790530117513e-14*V01*V04*V07*V12 + 8.18619305942503411e-16*V072*V12 - 
      1.7496502802931511e-15*V022*V08*V12 - 5.74719224038411533e-15*V01*V03*V08*V12 + 
      1.20375159168186655e-15*V06*V08*V12 - 1.50845475205591107e-15*V01*V02*V09*V12 + 9.73061545993915613e-16*V05*V09*V12 - 
      1.88581051499437961e-16*V012*V10*V12 + 3.9600806983082428e-16*V04*V10*V12 + 1.86845920911636295e-16*V03*V11*V12 + 
      1.62416456368852207e-17*V02*V122 + 1.60630021322626848e-15*V023*V03*V13 + 
      6.4254987020082125e-15*V01*V02*V032*V13 + 3.0695673301433364e-15*V01*V022*V04*V13 + 
      3.45546360666068958e-15*V012*V03*V04*V13 - 1.24746188955898646e-14*V03*V042*V13 + 
      1.81050555833806705e-15*V012*V02*V05*V13 - 1.3182339638802919e-14*V032*V05*V13 - 
      1.23846610202144402e-14*V02*V04*V05*V13 - 3.95227360913456059e-15*V01*V052*V13 + 
      2.02879916602831963e-16*V013*V06*V13 - 8.96087217642702106e-15*V02*V03*V06*V13 - 
      5.41656776391363267e-15*V01*V04*V06*V13 - 1.45533965028767569e-15*V022*V07*V13 - 
      3.73673003834541619e-15*V01*V03*V07*V13 + 8.50569575782453662e-16*V06*V07*V13 - 1.01426667913404723e-15*V01*V02*V08*V13 + 
      6.65816973411454945e-16*V05*V08*V13 - 1.49055682538065716e-16*V012*V09*V13 + 
      3.40638052108108738e-16*V04*V09*V13 + 1.57745758916597785e-16*V03*V10*V13 + 3.29867430439438251e-17*V02*V11*V13 + 
      7.83601936716412597e-18*V01*V12*V13 + 1.94336611494474191e-17*V024*V14 + 
      9.68033413128579765e-16*V01*V022*V03*V14 + 4.87276452248782066e-16*V012*V032*V14 + 
      5.65577151975441268e-16*V012*V02*V04*V14 - 4.14782248581965959e-15*V032*V04*V14 - 
      1.48441281213257568e-15*V02*V042*V14 + 8.50891062859058144e-17*V013*V05*V14 - 
      4.20642581189548862e-15*V02*V03*V05*V14 - 2.50222130134117737e-15*V01*V04*V05*V14 - 
      5.25947800152932185e-16*V022*V06*V14 - 1.75182054295518458e-15*V01*V03*V06*V14 + 
      1.89031595263368786e-16*V062*V14 - 6.07493346661976358e-16*V01*V02*V07*V14 + 
      4.03522144097446741e-16*V05*V07*V14 - 9.31577804673769177e-17*V012*V08*V14 + 
      1.99320373596417201e-16*V04*V08*V14 + 1.16245219695545947e-16*V03*V09*V14 + 2.3778878613523285e-17*V02*V10*V14 + 
      6.8008036727040445e-18*V01*V11*V14 - 3.69652918266080612e-20*V142 + 
      4.58942918064648138e-17*V01*V023*V15 + 1.54226265605147751e-16*V012*V02*V03*V15 - 
      4.20893758885493681e-16*V033*V15 + 2.57533099535164367e-17*V013*V04*V15 - 
      1.21412357561987932e-15*V02*V03*V04*V15 - 3.6897500091946079e-16*V01*V042*V15 - 
      2.97852932627031595e-16*V022*V05*V15 - 7.51525836310361637e-16*V01*V03*V05*V15 - 
      2.64982518354019204e-16*V01*V02*V06*V15 + 1.81997009349986521e-16*V05*V06*V15 - 
      5.13606738464949776e-17*V012*V07*V15 + 1.22654111747908539e-16*V04*V07*V15 + 
      6.90465812794839058e-17*V03*V08*V15 + 1.78208791724052304e-17*V02*V09*V15 + 4.98398737326352444e-18*V01*V10*V15 - 
      7.12953494384185117e-20*V13*V15 + 1.1137428963788397e-17*V012*V022*V16 + 
      6.10803410793438163e-18*V013*V03*V16 - 1.79641304077242534e-16*V02*V032*V16 - 
      6.17156106664664935e-17*V022*V04*V16 - 2.11308620722934517e-16*V01*V03*V04*V16 - 
      1.08337292532667554e-16*V01*V02*V05*V16 + 3.80219780308867073e-17*V052*V16 - 
      2.15593818319660896e-17*V012*V06*V16 + 4.78338732852947527e-17*V04*V06*V16 + 
      3.68625447919736493e-17*V03*V07*V16 + 9.14643664831279325e-18*V02*V08*V16 + 3.2361788577276163e-18*V01*V09*V16 - 
      5.6845179760082636e-20*V12*V16 + 8.36104982381822355e-19*V013*V02*V17 - 
      2.26492968000938442e-17*V022*V03*V17 - 2.74893447260954876e-17*V01*V032*V17 - 
      2.78516568851276107e-17*V01*V02*V04*V17 - 7.94172083647100424e-18*V012*V05*V17 + 
      2.04835189590256935e-17*V04*V05*V17 + 1.4730218574014496e-17*V03*V06*V17 + 5.00934322873200858e-18*V02*V07*V17 + 
      1.7028990598548859e-18*V01*V08*V17 - 4.22620822393289065e-20*V11*V17 + 1.9147442344621886e-20*V014*V18 - 
      6.61650507686378505e-19*V023*V18 - 7.1707171580608963e-18*V01*V02*V03*V18 - 
      2.03984085778038492e-18*V012*V04*V18 + 2.38412250860465566e-18*V042*V18 + 
      5.47547707514385916e-18*V03*V05*V18 + 1.72956111350063122e-18*V02*V06*V18 + 8.09085813739967027e-19*V01*V07*V18 - 
      2.55481496550053068e-20*V10*V18 - 4.14861250800140863e-19*V01*V022*V19 - 
      4.54751755684769792e-19*V012*V03*V19 + 1.3286197493573742e-18*V03*V04*V19 + 6.70532793440689213e-19*V02*V05*V19 + 
      2.91185489274977991e-19*V01*V06*V19 - 1.45291153206743851e-20*V09*V19 - 5.55275827994034694e-20*V012*V02*V20 + 
      1.58730017579493456e-19*V032*V20 + 1.38834153381321865e-19*V02*V04*V20 + 9.67857621372196761e-20*V01*V05*V20 - 
      6.46373776182450114e-21*V08*V20 - 1.9147442344621886e-21*V013*V21 + 3.55823303570890048e-20*V02*V03*V21 + 
      2.14876852978534498e-20*V01*V04*V21 - 2.75476796222807948e-21*V07*V21 + 1.64880753523132907e-21*V022*V22 + 
      4.57411122677078387e-21*V01*V03*V22 - 8.52473408053365111e-22*V06*V22 + 4.7868605861554715e-22*V01*V02*V23 - 
      2.6161140693877141e-22*V05*V23 + 2.65936699230859528e-23*V012*V24 - 5.03323412590268159e-23*V04*V24 - 
      1.03012261656091564e-23*V03*V25 - 9.27212246360468085e-25*V02*V26 - 1.06986028426207856e-25*V01*V27 + 
      1.23255793117750986e-28*V30) + delta12*eps9*
    (2.99274705639916675e-11*V043*V052 + 6.58249687646379103e-11*V03*V04*V053 + 
      8.38355745128408355e-12*V02*V054 + 5.91350753111858379e-12*V044*V06 + 
      1.29112358279710881e-10*V03*V042*V05*V06 + 6.87725617938263416e-11*V032*V052*V06 + 
      6.37949307878690797e-11*V02*V04*V052*V06 + 1.35878554204104533e-11*V01*V053*V06 + 
      4.60783274315401983e-11*V032*V04*V062 + 1.24775010640780169e-11*V02*V042*V062 + 
      4.5956102350150425e-11*V02*V03*V05*V062 + 2.7646996458924119e-11*V01*V04*V05*V062 + 
      1.45662197747842583e-12*V022*V063 + 6.5030447635881829e-12*V01*V03*V063 - 
      3.50616975686924707e-13*V064 + 2.85023529180873024e-11*V03*V043*V07 + 
      9.31233517847333218e-11*V032*V04*V05*V07 + 4.19179686773922271e-11*V02*V042*V05*V07 + 
      4.7546133452372778e-11*V02*V03*V052*V07 + 2.76633101717094601e-11*V01*V04*V052*V07 + 
      2.15680244768419894e-11*V033*V06*V07 + 6.0757076940827695e-11*V02*V03*V04*V06*V07 + 
      1.84446226113872687e-11*V01*V042*V06*V07 + 1.48093880265108019e-11*V022*V05*V06*V07 + 
      3.81885381911825697e-11*V01*V03*V05*V06*V07 + 6.56515747859291785e-12*V01*V02*V062*V07 - 
      4.7504363079003252e-12*V05*V062*V07 + 1.12180398817314233e-11*V02*V032*V072 + 
      4.82828651882513257e-12*V022*V04*V072 + 1.29708627581858364e-11*V01*V03*V04*V072 + 
      6.67940833955408062e-12*V01*V02*V05*V072 - 2.33622696927972026e-12*V052*V072 + 
      1.28726504296064179e-12*V012*V06*V072 - 3.19493265130704942e-12*V04*V06*V072 - 
      7.53032381752962175e-13*V03*V073 + 2.38132382141785785e-11*V032*V042*V08 + 
      4.25662720272345912e-12*V02*V043*V08 + 1.64457007008087424e-11*V033*V05*V08 + 
      4.74111459426845681e-11*V02*V03*V04*V05*V08 + 1.42879429285071471e-11*V01*V042*V05*V08 + 
      5.81308164503694043e-12*V022*V052*V08 + 1.45202422111765354e-11*V01*V03*V052*V08 + 
      1.69597472347494122e-11*V02*V032*V06*V08 + 4.46521874484051658e-12*V022*V04*V06*V08 + 
      2.01747533438157336e-11*V01*V03*V04*V06*V08 + 1.01758483408496473e-11*V01*V02*V05*V06*V08 - 
      3.71345497569127969e-12*V052*V06*V08 + 1.03943458475259342e-12*V012*V062*V08 - 
      2.20757693571267634e-12*V04*V062*V08 + 5.53626823336851469e-12*V022*V03*V07*V08 + 
      6.78064466267866795e-12*V01*V032*V07*V08 + 6.7730208489549383e-12*V01*V02*V04*V07*V08 + 
      1.94795764325240098e-12*V012*V05*V07*V08 - 5.0094286982996104e-12*V04*V05*V07*V08 - 
      3.59771978939794215e-12*V03*V06*V07*V08 - 6.11503626802998923e-13*V02*V072*V08 + 
      1.32049579085802776e-13*V023*V082 + 1.85627442163221303e-12*V01*V02*V03*V082 + 
      5.37293571340890865e-13*V012*V04*V082 - 5.78765396274511515e-13*V042*V082 - 
      1.40113686956856952e-12*V03*V05*V082 - 4.18231179472413647e-13*V02*V06*V082 - 
      2.06931258449005453e-13*V01*V07*V082 + 8.45358481728361841e-12*V033*V04*V09 + 
      1.16438801881645075e-11*V02*V03*V042*V09 + 2.3751960765072752e-12*V01*V043*V09 + 
      1.29877384380218234e-11*V02*V032*V05*V09 + 5.63300093862932133e-12*V022*V04*V05*V09 + 
      1.49806202380442889e-11*V01*V03*V04*V05*V09 + 3.8604577023148137e-12*V01*V02*V052*V09 - 
      9.2230203265481826e-13*V053*V09 + 4.11371889625300052e-12*V022*V03*V06*V09 + 
      5.14978745042163907e-12*V01*V032*V06*V09 + 5.06308974506897458e-12*V01*V02*V04*V06*V09 + 
      1.48196910507850886e-12*V012*V05*V06*V09 - 3.79139809589677287e-12*V04*V05*V06*V09 - 
      1.3653837904260381e-12*V03*V062*V09 + 4.2657375191981404e-13*V023*V07*V09 + 
      3.61884510384372809e-12*V01*V02*V03*V07*V09 + 1.01146544171423152e-12*V012*V04*V07*V09 - 
      1.27036881179183744e-12*V042*V07*V09 - 2.67329456629419149e-12*V03*V05*V07*V09 - 
      9.22306872596369582e-13*V02*V06*V07*V09 - 1.96466069544989172e-13*V01*V072*V09 + 
      4.61355686114042891e-13*V01*V022*V08*V09 + 5.18806613637465929e-13*V012*V03*V08*V09 - 
      1.43902158379398903e-12*V03*V04*V08*V09 - 7.25267774033968481e-13*V02*V05*V08*V09 - 
      3.15083983206152218e-13*V01*V06*V08*V09 + 7.0485888718273877e-14*V012*V02*V092 - 
      1.90459173684033928e-13*V032*V092 - 1.8224445417882732e-13*V02*V04*V092 - 
      1.1590010335608468e-13*V01*V05*V092 + 6.66293197487206057e-15*V08*V092 + 
      8.98486392168483228e-13*V034*V10 + 5.3505977617576787e-12*V02*V032*V04*V10 + 
      6.92130118710875523e-13*V022*V042*V10 + 3.19014976317693238e-12*V01*V03*V042*V10 + 
      2.64221084431906982e-12*V022*V03*V05*V10 + 3.1487892345961313e-12*V01*V032*V05*V10 + 
      3.21035865705460722e-12*V01*V02*V04*V05*V10 + 4.50486713382125994e-13*V012*V052*V10 - 
      1.22086069399478844e-12*V04*V052*V10 + 1.60245330251889559e-13*V023*V06*V10 + 
      2.2707190824963045e-12*V01*V02*V03*V06*V10 + 6.57692559761716392e-13*V012*V04*V06*V10 - 
      7.18267362471191286e-13*V042*V06*V10 - 1.74734351445411948e-12*V03*V05*V06*V10 - 
      2.59351340588797288e-13*V02*V062*V10 + 3.77458692045581402e-13*V01*V022*V07*V10 + 
      4.1678328266720452e-13*V012*V03*V07*V10 - 1.18216262517081052e-12*V03*V04*V07*V10 - 
      5.97523377217129259e-13*V02*V05*V07*V10 - 2.57927361435616765e-13*V01*V06*V07*V10 + 
      1.20749385687371266e-13*V012*V02*V08*V10 - 3.27626770755060952e-13*V032*V08*V10 - 
      2.71341121964510637e-13*V02*V04*V08*V10 - 1.99780448697639718e-13*V01*V05*V08*V10 + 
      5.5606575809184384e-15*V082*V10 + 1.0081873984243812e-14*V013*V09*V10 - 
      1.7137744656538277e-13*V02*V03*V09*V10 - 1.03373090772463402e-13*V01*V04*V09*V10 + 1.09739905445472126e-14*V07*V09*V10 - 
      7.87879228963516412e-15*V022*V102 - 2.30636426462300249e-14*V01*V03*V102 + 
      3.50048518125410756e-15*V06*V102 + 7.66586150711844289e-13*V02*V033*V11 + 
      1.02418198884169479e-12*V022*V03*V04*V11 + 1.31278925866360826e-12*V01*V032*V04*V11 + 
      6.35120737536245865e-13*V01*V02*V042*V11 + 1.62873614369383543e-13*V023*V05*V11 + 
      1.35779312827081092e-12*V01*V02*V03*V05*V11 + 3.77902097026932749e-13*V012*V04*V05*V11 - 
      5.01242840122766278e-13*V042*V05*V11 - 5.24745050938145996e-13*V03*V052*V11 + 
      2.24384667068345483e-13*V01*V022*V06*V11 + 2.56237000807609342e-13*V012*V03*V06*V11 - 
      7.24241473456803361e-13*V03*V04*V06*V11 - 3.6371964082039179e-13*V02*V05*V06*V11 - 
      7.94738230424327435e-14*V01*V062*V11 + 9.14934120571831756e-14*V012*V02*V07*V11 - 
      2.52748391469663746e-13*V032*V07*V11 - 2.4238944525262867e-13*V02*V04*V07*V11 - 
      1.5367966920862549e-13*V01*V05*V07*V11 + 8.15645688805532779e-15*V013*V08*V11 - 
      1.38328800422795945e-13*V02*V03*V08*V11 - 8.3675389520846374e-14*V01*V04*V08*V11 + 8.95086340497616003e-15*V07*V08*V11 - 
      1.71730482603146296e-14*V022*V09*V11 - 4.33420930802019802e-14*V01*V03*V09*V11 + 
      6.84543656472515582e-15*V06*V09*V11 - 9.93681315866477881e-15*V01*V02*V10*V11 + 4.4240463229207593e-15*V05*V10*V11 - 
      5.94163351315726398e-16*V012*V112 + 9.3665674474549308e-16*V04*V112 + 
      2.01270218202110796e-13*V022*V032*V12 + 1.52799514246731647e-13*V01*V033*V12 + 
      3.32065678848475826e-14*V023*V04*V12 + 4.83607299216812802e-13*V01*V02*V03*V04*V12 + 
      7.02057716553328008e-14*V012*V042*V12 - 5.32089848910127126e-14*V043*V12 + 
      1.20762130921266477e-13*V01*V022*V05*V12 + 1.29790110531419956e-13*V012*V03*V05*V12 - 
      3.94246334572618666e-13*V03*V04*V05*V12 - 9.99410226990819012e-14*V02*V052*V12 + 
      4.98706797625107438e-14*V012*V02*V06*V12 - 1.40282084301902682e-13*V032*V06*V12 - 
      1.15008179472858505e-13*V02*V04*V06*V12 - 8.55001637105705976e-14*V01*V05*V06*V12 + 
      5.44434314048299544e-15*V013*V07*V12 - 9.66769172545415174e-14*V02*V03*V07*V12 - 
      5.81098215819723718e-14*V01*V04*V07*V12 + 3.1305300129232274e-15*V072*V12 - 
      1.07705648115281712e-14*V022*V08*V12 - 3.16775769328511526e-14*V01*V03*V08*V12 + 
      4.8471969496679166e-15*V06*V08*V12 - 8.43015748982767218e-15*V01*V02*V09*V12 + 3.75792799881330772e-15*V05*V09*V12 - 
      1.07661086695732196e-15*V012*V10*V12 + 1.62508303589957569e-15*V04*V10*V12 + 
      7.42606428117459797e-16*V03*V11*V12 + 6.91148457300207282e-17*V02*V122 + 
      2.08812326114594285e-14*V023*V03*V13 + 8.32526963655690678e-14*V01*V02*V032*V13 + 
      3.93916149554497995e-14*V01*V022*V04*V13 + 4.57365013933917663e-14*V012*V03*V04*V13 - 
      6.84139359557092387e-14*V03*V042*V13 + 2.39215124392911501e-14*V012*V02*V05*V13 - 
      7.06946037695791054e-14*V032*V05*V13 - 6.83399517277351354e-14*V02*V04*V05*V13 - 
      2.14304816562599629e-14*V01*V052*V13 + 2.82215301563922655e-15*V013*V06*V13 - 
      4.95963918095970232e-14*V02*V03*V06*V13 - 3.00923877683344605e-14*V01*V04*V06*V13 - 
      8.16551007923820238e-15*V022*V07*V13 - 2.04912253403889833e-14*V01*V03*V07*V13 + 
      3.31414088223259229e-15*V06*V07*V13 - 5.7345649147626554e-15*V01*V02*V08*V13 + 2.60071064651362746e-15*V05*V08*V13 - 
      8.47393424709072174e-16*V012*V09*V13 + 1.35032310931830388e-15*V04*V09*V13 + 
      6.30052494144506083e-16*V03*V10*V13 + 1.35429493274973811e-16*V02*V11*V13 + 3.25870090660667398e-17*V01*V12*V13 + 
      4.22720155402648721e-16*V024*V14 + 1.30944372200882539e-14*V01*V022*V03*V14 + 
      6.68593617069795287e-15*V012*V032*V14 + 7.65069503078662727e-15*V012*V02*V04*V14 - 
      2.31183957278804889e-14*V032*V04*V14 - 9.2720456855547129e-15*V02*V042*V14 + 
      1.20986603543987295e-15*V013*V05*V14 - 2.35498271527213396e-14*V02*V03*V05*V14 - 
      1.40780188347643777e-14*V01*V04*V05*V14 - 3.31993282381864712e-15*V022*V06*V14 - 
      9.90907097838467691e-15*V01*V03*V06*V14 + 7.77103483977842813e-16*V062*V14 - 
      3.4636178802245616e-15*V01*V02*V07*V14 + 1.57864644075648917e-15*V05*V07*V14 - 
      5.40570669636768498e-16*V012*V08*V14 + 8.27767841122725696e-16*V04*V08*V14 + 4.6449732961539699e-16*V03*V09*V14 + 
      1.01702824367818314e-16*V02*V10*V14 + 2.82857341081140983e-17*V01*V11*V14 - 1.31462543389314789e-19*V142 + 
      5.96606646041697958e-16*V01*V023*V15 + 2.12968065726135081e-15*V012*V02*V03*V15 - 
      2.36877902480583199e-15*V033*V15 + 3.70840004353698839e-16*V013*V04*V15 - 
      6.99765491517326585e-15*V02*V03*V04*V15 - 2.13262817198601003e-15*V01*V042*V15 - 
      1.72889713794637442e-15*V022*V05*V15 - 4.27665294420541087e-15*V01*V03*V05*V15 - 
      1.5441398500240083e-15*V01*V02*V06*V15 + 7.27963100135749636e-16*V05*V06*V15 - 
      2.99764272871743629e-16*V012*V07*V15 + 4.94288703046505278e-16*V04*V07*V15 + 
      2.79989233213771876e-16*V03*V08*V15 + 7.38235073570117765e-17*V02*V09*V15 + 2.09010108073024989e-17*V01*V10*V15 - 
      2.50523536821150808e-19*V13*V15 + 1.55959747385414186e-16*V012*V022*V16 + 
      9.17851796231794727e-17*V013*V03*V16 - 1.05216684929212956e-15*V02*V032*V16 - 
      4.05666904285484695e-16*V022*V04*V16 - 1.24447282488443941e-15*V01*V03*V04*V16 - 
      6.39992835650376689e-16*V01*V02*V05*V16 + 1.52749966371494767e-16*V052*V16 - 
      1.29046102425813663e-16*V012*V06*V16 + 2.03527003449825917e-16*V04*V06*V16 + 
      1.49780046963446622e-16*V03*V07*V16 + 3.97317255248549377e-17*V02*V08*V16 + 1.35841698946364935e-17*V01*V09*V16 - 
      2.02519366355126002e-19*V12*V16 + 1.30904680829398294e-17*V013*V02*V17 - 
      1.37690428021652598e-16*V022*V03*V17 - 1.64877349533382752e-16*V01*V032*V17 - 
      1.69464225721716617e-16*V01*V02*V04*V17 - 4.83275062297474862e-17*V012*V05*V17 + 
      8.49423943276741339e-17*V04*V05*V17 + 6.13083950957692399e-17*V03*V06*V17 + 2.11481798701473653e-17*V02*V07*V17 + 
      7.26677349382308276e-18*V01*V08*V17 - 1.48835991452750896e-19*V11*V17 + 3.35080241030883005e-19*V014*V18 - 
      4.59879015245940764e-18*V023*V18 - 4.44785511944394101e-17*V01*V02*V03*V18 - 
      1.27509201053618679e-17*V012*V04*V18 + 1.05246469839526813e-17*V042*V18 + 
      2.29119491810892027e-17*V03*V05*V18 + 7.7165894643701278e-18*V02*V06*V18 + 3.46361275812256066e-18*V01*V07*V18 - 
      9.15650428368490872e-20*V10*V18 - 2.66277098205875028e-18*V01*V022*V19 - 
      2.92860130660991746e-18*V012*V03*V19 + 5.74150685221944949e-18*V03*V04*V19 + 
      2.91758088979379064e-18*V02*V05*V19 + 1.27718759172612597e-18*V01*V06*V19 - 5.14786812698952865e-20*V09*V19 - 
      3.66354396860432085e-19*V012*V02*V20 + 6.9325708438996616e-19*V032*V20 + 
      6.43737011626187807e-19*V02*V04*V20 + 4.2762621236322212e-19*V01*V05*V20 - 2.34489837383993854e-20*V08*V20 - 
      1.34032096412353202e-20*V013*V21 + 1.61452829470047128e-19*V02*V03*V21 + 9.79178926568024781e-20*V01*V04*V21 - 
      9.88618151018885634e-21*V07*V21 + 8.04192578474119211e-21*V022*V22 + 2.11286707538917895e-20*V01*V03*V22 - 
      3.15801358708480349e-21*V06*V22 + 2.28971498037770053e-21*V01*V02*V23 - 9.60681042253133442e-22*V05*V23 + 
      1.30308982623121169e-22*V012*V24 - 1.92553453961488899e-22*V04*V24 - 3.92103794182051792e-23*V03*V25 - 
      3.70884898544187234e-24*V02*V26 - 4.27944113704831424e-25*V01*V27 + 4.31395275912128451e-28*V30) + 
   delta10*eps10*(-2.83147397803971713e-10*V034*V042 - 
      5.06254614839170405e-10*V02*V032*V043 - 1.14623038722347948e-11*V022*V044 - 
      1.54810757003022798e-10*V01*V03*V044 - 1.09529688867210913e-10*V035*V05 - 
      1.1541005125191192e-9*V02*V033*V04*V05 - 7.30524805740573423e-10*V022*V03*V042*V05 - 
      9.83508372811947777e-10*V01*V032*V042*V05 - 3.03752768903502243e-10*V01*V02*V043*V05 - 
      4.36594739373776737e-10*V022*V032*V052 - 3.10252614595279692e-10*V01*V033*V052 - 
      1.14908473825788093e-10*V023*V04*V052 - 1.00816232934700338e-9*V01*V02*V03*V04*V052 - 
      1.39639358019218935e-10*V012*V042*V052 + 1.86642603593877716e-10*V043*V052 - 
      8.53257609945033718e-11*V01*V022*V053 - 8.5597727110223257e-11*V012*V03*V053 + 
      3.91377601529063344e-10*V03*V04*V053 + 5.00934710005086973e-11*V02*V054 - 
      1.99096974289751206e-10*V02*V034*V06 - 5.31131576240508968e-10*V022*V032*V04*V06 - 
      4.46808032689607542e-10*V01*V033*V04*V06 - 1.5429439176868032e-11*V023*V042*V06 - 
      6.53366437479125617e-10*V01*V02*V03*V042*V06 - 6.5359057922723474e-11*V012*V043*V06 + 
      4.79079742525889495e-11*V044*V06 - 1.69233958038536371e-10*V023*V03*V05*V06 - 
      6.90041724024096878e-10*V01*V02*V032*V05*V06 - 3.18678945744305381e-10*V01*V022*V04*V05*V06 - 
      3.76942641940912647e-10*V012*V03*V04*V05*V06 + 8.08647268213460881e-10*V03*V042*V05*V06 - 
      9.76725501388835622e-11*V012*V02*V052*V06 + 4.12341529647321837e-10*V032*V052*V06 + 
      4.02719371915161521e-10*V02*V04*V052*V06 + 8.26330431252899527e-11*V01*V053*V06 - 
      1.29070701481524603e-12*V024*V062 - 1.14464374269921289e-10*V01*V022*V03*V062 - 
      6.33206080539851901e-11*V012*V032*V062 - 6.90498148639599e-11*V012*V02*V04*V062 + 
      2.89910887081657422e-10*V032*V04*V062 + 1.02209999015727333e-10*V02*V042*V062 - 
      1.142007595082246e-11*V013*V05*V062 + 2.91231750057451425e-10*V02*V03*V05*V062 + 
      1.7583202327727012e-10*V01*V04*V05*V062 + 1.20738847348225361e-11*V022*V063 + 
      4.15428266827867303e-11*V01*V03*V063 - 1.42760703378761961e-12*V064 - 
      1.35437715864291066e-10*V022*V033*V07 - 7.08526174689070824e-11*V01*V034*V07 - 
      1.09436641738845803e-10*V023*V03*V04*V07 - 4.65540094012761655e-10*V01*V02*V032*V04*V07 - 
      1.04360686534367632e-10*V01*V022*V042*V07 - 1.27872399168444168e-10*V012*V03*V042*V07 + 
      1.79727254021590893e-10*V03*V043*V07 - 1.26606282934859687e-11*V024*V05*V07 - 
      2.36897739508122665e-10*V01*V022*V03*V05*V07 - 1.16393161739913878e-10*V012*V032*V05*V07 - 
      1.32254650451981218e-10*V012*V02*V04*V05*V07 + 5.61661612493264455e-10*V032*V04*V05*V07 + 
      2.666416824335273e-10*V02*V042*V05*V07 - 1.02689340983093492e-11*V013*V052*V07 + 
      2.88100796208181595e-10*V02*V03*V052*V07 + 1.69178248851878072e-10*V01*V04*V052*V07 - 
      2.41762797197909101e-11*V01*V023*V06*V07 - 8.92061358343166122e-11*V012*V02*V03*V06*V07 + 
      1.31194537764959105e-10*V033*V06*V07 - 1.55511174753068746e-11*V013*V04*V06*V07 + 
      3.87738650698101693e-10*V02*V03*V04*V06*V07 + 1.18054076106699637e-10*V01*V042*V06*V07 + 
      9.54200122661066923e-11*V022*V05*V06*V07 + 2.35682116756852721e-10*V01*V03*V05*V06*V07 + 
      4.25042085868382114e-11*V01*V02*V062*V07 - 1.77540839305428114e-11*V05*V062*V07 - 
      7.77259687480252758e-12*V012*V022*V072 - 4.59651872487241882e-12*V013*V03*V072 + 
      6.89322026462861178e-11*V02*V032*V072 + 3.13805915832851226e-11*V022*V04*V072 + 
      8.04890627969764801e-11*V01*V03*V04*V072 + 4.15936567180707272e-11*V01*V02*V05*V072 - 
      8.48599897372070743e-12*V052*V072 + 8.2002675722444813e-12*V012*V06*V072 - 
      1.20762474939533595e-11*V04*V06*V072 - 2.77896531802062462e-12*V03*V073 - 
      3.1406770411793385e-11*V023*V032*V08 - 7.98266942205689067e-11*V01*V02*V033*V08 - 
      1.28161804561128541e-12*V024*V04*V08 - 1.16873026333121435e-10*V01*V022*V03*V04*V08 - 
      6.44993064794030546e-11*V012*V032*V04*V08 - 3.53283964846833836e-11*V012*V02*V042*V08 + 
      1.51602595389973449e-10*V032*V042*V08 + 3.52405353526509445e-11*V02*V043*V08 - 
      1.8844062247076031e-11*V01*V023*V05*V08 - 6.69581899549187723e-11*V012*V02*V03*V05*V08 + 
      1.00764892659486774e-10*V033*V05*V08 - 1.16017842317448639e-11*V013*V04*V05*V08 + 
      3.04080770992841975e-10*V02*V03*V04*V05*V08 + 9.19333218147416301e-11*V01*V042*V05*V08 + 
      3.76182883364071839e-11*V022*V052*V08 + 9.02789308548414284e-11*V01*V03*V052*V08 - 
      1.23777258930322607e-11*V012*V022*V06*V08 - 7.6577477249667976e-12*V013*V03*V06*V08 + 
      1.09212690827840409e-10*V02*V032*V06*V08 + 3.74163458071209689e-11*V022*V04*V06*V08 + 
      1.30371084812711088e-10*V01*V03*V04*V06*V08 + 6.62179747756822236e-11*V01*V02*V05*V06*V08 - 
      1.39138776739401995e-11*V052*V06*V08 + 6.81113143208472836e-12*V012*V062*V08 - 
      9.11527037083692531e-12*V04*V062*V08 - 2.72316763179677546e-12*V013*V02*V07*V08 + 
      3.62077053204156496e-11*V022*V03*V07*V08 + 4.27859951220466131e-11*V01*V032*V07*V08 + 
      4.43658895932414209e-11*V01*V02*V04*V07*V08 + 1.25063243117776522e-11*V012*V05*V07*V08 - 
      1.89791484872501004e-11*V04*V05*V07*V08 - 1.36874210104183073e-11*V03*V06*V07*V08 - 
      2.37702872190506103e-12*V02*V072*V08 - 7.92151622321874899e-14*V014*V082 + 
      1.13353984756073838e-12*V023*V082 + 1.22688215292282076e-11*V01*V02*V03*V082 + 
      3.56058950679644889e-12*V012*V04*V082 - 2.42287900363913201e-12*V042*V082 - 
      5.34578088957031999e-12*V03*V05*V082 - 1.77694022465065124e-12*V02*V06*V082 - 
      8.14192771338936449e-13*V01*V07*V082 - 3.51684119263499131e-12*V024*V03*V09 - 
      3.11545515003692533e-11*V01*V022*V032*V09 - 9.91132733697322221e-12*V012*V033*V09 - 
      9.11972014490381693e-12*V01*V023*V04*V09 - 3.43145352906135209e-11*V012*V02*V03*V04*V09 + 
      5.24478092747042114e-11*V033*V04*V09 - 2.99256308014199351e-12*V013*V042*V09 + 
      7.56891251299102765e-11*V02*V03*V042*V09 + 1.54703695324641749e-11*V01*V043*V09 - 
      8.83074553485866602e-12*V012*V022*V05*V09 - 5.17758147319585576e-12*V013*V03*V05*V09 + 
      8.09178799563830596e-11*V02*V032*V05*V09 + 3.70058109033106848e-11*V022*V04*V05*V09 + 
      9.42675261719759545e-11*V01*V03*V04*V05*V09 + 2.43743465493817395e-11*V01*V02*V052*V09 - 
      3.39585461230969546e-12*V053*V09 - 2.06330471385501017e-12*V013*V02*V06*V09 + 
      2.70776609945128878e-11*V022*V03*V06*V09 + 3.27086838033074454e-11*V01*V032*V06*V09 + 
      3.33606521576621069e-11*V01*V02*V04*V06*V09 + 9.57451088234425317e-12*V012*V05*V06*V09 - 
      1.45206027634999439e-11*V04*V05*V06*V09 - 5.24961158700746602e-12*V03*V062*V09 - 
      1.42335628479819232e-13*V014*V07*V09 + 2.86858561012979369e-12*V023*V07*V09 + 
      2.3176605664144501e-11*V01*V02*V03*V07*V09 + 6.56563869675572709e-12*V012*V04*V07*V09 - 
      4.91902242363934911e-12*V042*V07*V09 - 9.99781704581917746e-12*V03*V05*V07*V09 - 
      3.62306438031649679e-12*V02*V06*V07*V09 - 7.58651502437713266e-13*V01*V072*V09 + 
      3.11249978861302989e-12*V01*V022*V08*V09 + 3.43074524903875492e-12*V012*V03*V08*V09 - 
      5.60577627792254974e-12*V03*V04*V08*V09 - 2.855180461060563e-12*V02*V05*V08*V09 - 
      1.2517058538252239e-12*V01*V06*V08*V09 + 4.71724460539165804e-13*V012*V02*V092 - 
      7.32769969810313421e-13*V032*V092 - 7.32583790015828685e-13*V02*V04*V092 - 
      4.53301268054394796e-13*V01*V05*V092 + 2.08431369621129702e-14*V08*V092 - 
      2.50109090726160402e-14*V025*V10 - 4.18886355110222943e-12*V01*V023*V03*V10 - 
      6.87689618785493251e-12*V012*V02*V032*V10 + 5.69751173864715897e-12*V034*V10 - 
      3.83208484261073027e-12*V012*V022*V04*V10 - 2.33988305434653777e-12*V013*V03*V04*V10 + 
      3.52631050361651277e-11*V02*V032*V04*V10 + 5.9222970446754979e-12*V022*V042*V10 + 
      2.10885965835992367e-11*V01*V03*V042*V10 - 1.22205123720504815e-12*V013*V02*V05*V10 + 
      1.75606500821715209e-11*V022*V03*V05*V10 + 2.0270218289170958e-11*V01*V032*V05*V10 + 
      2.13742921698198171e-11*V01*V02*V04*V05*V10 + 2.95140459100951693e-12*V012*V052*V10 - 
      4.69130966557547262e-12*V04*V052*V10 - 9.51994401387715332e-14*V014*V06*V10 + 
      1.38948133380905834e-12*V023*V06*V10 + 1.51773425231397669e-11*V01*V02*V03*V06*V10 + 
      4.40720670726728527e-12*V012*V04*V06*V10 - 3.0427377813810252e-12*V042*V06*V10 - 
      6.74419985568290098e-12*V03*V05*V06*V10 - 1.11483113055115267e-12*V02*V062*V10 + 
      2.55983962018950329e-12*V01*V022*V07*V10 + 2.7732047011699478e-12*V012*V03*V07*V10 - 
      4.61001271959722056e-12*V03*V04*V07*V10 - 2.35421510610348157e-12*V02*V05*V07*V10 - 
      1.02615652192418426e-12*V01*V06*V07*V10 + 8.27290853592509651e-13*V012*V02*V08*V10 - 
      1.28739533983589227e-12*V032*V08*V10 - 1.18185338357454263e-12*V02*V04*V08*V10 - 
      7.97433834392765342e-13*V01*V05*V08*V10 + 1.79838061478275356e-14*V082*V10 + 
      7.07667942690225346e-14*V013*V09*V10 - 6.93266595037648323e-13*V02*V03*V09*V10 - 
      4.20343673537467043e-13*V01*V04*V09*V10 + 3.43127327957938456e-14*V07*V09*V10 - 
      3.56620081849067188e-14*V022*V102 - 9.47289723171371046e-14*V01*V03*V102 + 
      1.14227646427996491e-14*V06*V102 - 1.91827701416454072e-13*V01*V024*V11 - 
      1.45805132639047492e-12*V012*V022*V03*V11 - 4.12892092087527572e-13*V013*V032*V11 + 
      4.97504660232350187e-12*V02*V033*V11 - 5.05026505741119072e-13*V013*V02*V04*V11 + 
      6.94384964940814728e-12*V022*V03*V04*V11 + 8.61220411311333573e-12*V01*V032*V04*V11 + 
      4.30544222024206645e-12*V01*V02*V042*V11 - 5.06432234368291832e-14*V014*V05*V11 + 
      1.11830112714242857e-12*V023*V05*V11 + 8.93255102955499645e-12*V01*V02*V03*V05*V11 + 
      2.52069915148951116e-12*V012*V04*V05*V11 - 1.98640000143620835e-12*V042*V05*V11 - 
      2.00955788888641668e-12*V03*V052*V11 + 1.53937445770493643e-12*V01*V022*V06*V11 + 
      1.7276704271902925e-12*V012*V03*V06*V11 - 2.88037708353703038e-12*V03*V04*V06*V11 - 
      1.46165874516332932e-12*V02*V05*V06*V11 - 3.22050403429014343e-13*V01*V062*V11 + 
      6.20392232335052706e-13*V012*V02*V07*V11 - 9.82589150691560702e-13*V032*V07*V11 - 
      9.84312166513688056e-13*V02*V04*V07*V11 - 6.07256462944098659e-13*V01*V05*V07*V11 + 
      5.7643268997213004e-14*V013*V08*V11 - 5.64729490641266178e-13*V02*V03*V08*V11 - 
      3.43243938216667035e-13*V01*V04*V08*V11 + 2.81675723048505771e-14*V07*V08*V11 - 
      7.22873015865764146e-14*V022*V09*V11 - 1.75988706085494922e-13*V01*V03*V09*V11 + 
      2.17404411903046408e-14*V06*V09*V11 - 4.22232998182778095e-14*V01*V02*V10*V11 + 1.40581481641081888e-14*V05*V10*V11 - 
      2.5456729818479927e-15*V012*V112 + 3.05713520165617753e-15*V04*V112 - 
      9.18623106269282349e-14*V012*V023*V12 - 1.61969532137189844e-13*V013*V02*V03*V12 + 
      1.3878422469854658e-12*V022*V032*V12 + 1.0302241901089193e-12*V01*V033*V12 - 
      1.90513221840518841e-14*V014*V04*V12 + 2.96922204744444057e-13*V023*V04*V12 + 
      3.34057350116526412e-12*V01*V02*V03*V04*V12 + 4.86041584682261339e-13*V012*V042*V12 - 
      2.33307524072229123e-13*V043*V12 + 8.40732798509608141e-13*V01*V022*V05*V12 + 
      8.91481723719246785e-13*V012*V03*V05*V12 - 1.57370827229456183e-12*V03*V04*V05*V12 - 
      4.02799456284057844e-13*V02*V052*V12 + 3.49059614851123976e-13*V012*V02*V06*V12 - 
      5.62604433823534657e-13*V032*V06*V12 - 5.1145449319346481e-13*V02*V04*V06*V12 - 
      3.48171946516168537e-13*V01*V05*V06*V12 + 3.89147976407890454e-14*V013*V07*V12 - 
      3.95056942445859434e-13*V02*V03*V07*V12 - 2.38775055165300741e-13*V01*V04*V07*V12 + 
      9.83816916868575191e-15*V072*V12 - 4.92019150679978326e-14*V022*V08*V12 - 
      1.31271558584103721e-13*V01*V03*V08*V12 + 1.59101406322255024e-14*V06*V08*V12 - 3.58303645343328356e-14*V01*V02*V09*V12 + 
      1.19308055858564106e-14*V05*V09*V12 - 4.65810520796089365e-15*V012*V10*V12 + 
      5.44895773954939066e-15*V04*V10*V12 + 2.43100075755068269e-15*V03*V11*V12 + 2.41628575888465093e-16*V02*V122 - 
      1.43976205709378511e-14*V013*V022*V13 - 5.38616021358826083e-15*V014*V03*V13 + 
      1.49275268888226993e-13*V023*V03*V13 + 5.77482000854680938e-13*V01*V02*V032*V13 + 
      2.80886550250361437e-13*V01*V022*V04*V13 + 3.22151830262168042e-13*V012*V03*V04*V13 - 
      2.8328680477699054e-13*V03*V042*V13 + 1.68640684865502617e-13*V012*V02*V05*V13 - 
      2.83422711088884393e-13*V032*V05*V13 - 2.85869921228774187e-13*V02*V04*V05*V13 - 
      8.72941443715518424e-14*V01*V052*V13 + 2.05783856003702008e-14*V013*V06*V13 - 
      2.08090712199965333e-13*V02*V03*V06*V13 - 1.2680389091150609e-13*V01*V04*V06*V13 - 
      3.49718824504750984e-14*V022*V07*V13 - 8.46870590547369439e-14*V01*V03*V07*V13 + 
      1.06219391275561935e-14*V06*V07*V13 - 2.47578183972894002e-14*V01*V02*V08*V13 + 8.34401027553271522e-15*V05*V08*V13 - 
      3.65805829890077738e-15*V012*V09*V13 + 4.42115660397718329e-15*V04*V09*V13 + 
      2.07093407511499004e-15*V03*V10*V13 + 4.62363159206493138e-16*V02*V11*V13 + 1.12206352754376923e-16*V01*V12*V13 - 
      8.87828606635427609e-16*V014*V02*V14 + 3.99211739812803882e-15*V024*V14 + 
      9.53601265889606092e-14*V01*V022*V03*V14 + 4.86331950191297589e-14*V012*V032*V14 + 
      5.58051747595388596e-14*V012*V02*V04*V14 - 9.64521471645753854e-14*V032*V04*V14 - 
      4.29266509808032957e-14*V02*V042*V14 + 9.02435424502445861e-15*V013*V05*V14 - 
      9.91053011406376153e-14*V02*V03*V05*V14 - 5.95908660361035031e-14*V01*V04*V05*V14 - 
      1.55838885364026884e-14*V022*V06*V14 - 4.21589680955393128e-14*V01*V03*V06*V14 + 
      2.598712458397398e-15*V062*V14 - 1.49747351593544257e-14*V01*V02*V07*V14 + 5.05576992588472146e-15*V05*V07*V14 - 
      2.37489897771310463e-15*V012*V08*V14 + 2.80249121973150038e-15*V04*V08*V14 + 
      1.52464088464662998e-15*V03*V09*V14 + 3.56902535545661175e-16*V02*V10*V14 + 9.73421414696800047e-17*V01*V11*V14 - 
      3.97796467101277375e-19*V142 - 1.84964293049047419e-17*V015*V15 + 
      4.51800751870616667e-15*V01*V023*V15 + 1.60147178141528924e-14*V012*V02*V03*V15 - 
      9.98391124498909381e-15*V033*V15 + 2.85418668668177896e-15*V013*V04*V15 - 
      3.06748893910163551e-14*V02*V03*V04*V15 - 9.38258741377643886e-15*V01*V042*V15 - 
      7.65815838468852181e-15*V022*V05*V15 - 1.8308165588415677e-14*V01*V03*V05*V15 - 
      6.87680710931134112e-15*V01*V02*V06*V15 + 2.38355627618465332e-15*V05*V06*V15 - 
      1.32382608079171842e-15*V012*V07*V15 + 1.63649620317106183e-15*V04*V07*V15 + 
      9.31012724243195772e-16*V03*V08*V15 + 2.53305692642547847e-16*V02*V09*V15 + 7.23939531063726578e-17*V01*V10*V15 - 
      7.52489723265375153e-19*V13*V15 + 1.20665075437149217e-15*V012*V022*V16 + 
      7.3296792244059472e-16*V013*V03*V16 - 4.64329625469588737e-15*V02*V032*V16 - 
      1.99012465138218982e-15*V022*V04*V16 - 5.52581294596366606e-15*V01*V03*V04*V16 - 
      2.86243971301836961e-15*V01*V02*V05*V16 + 4.99966872963872092e-16*V052*V16 - 
      5.84427968525741054e-16*V012*V06*V16 + 7.04003833968776113e-16*V04*V06*V16 + 
      4.97326189233487643e-16*V03*V07*V16 + 1.41170457293979315e-16*V02*V08*V16 + 4.69976522923450451e-17*V01*V09*V16 - 
      6.13465562735739467e-19*V12*V16 + 1.08565998094006094e-16*V013*V02*V17 - 
      6.4005687320755148e-16*V022*V03*V17 - 7.44038973604255094e-16*V01*V032*V17 - 
      7.89546221138659315e-16*V01*V02*V04*V17 - 2.21803014747982696e-16*V012*V05*V17 + 
      2.87834373819183209e-16*V04*V05*V17 + 2.08417237257381959e-16*V03*V06*V17 + 7.35056908400392968e-17*V02*V07*V17 + 
      2.55024385682970053e-17*V01*V08*V17 - 4.47427087160175417e-19*V11*V17 + 3.01572216927794704e-18*V014*V18 - 
      2.39694065750758309e-17*V023*V18 - 2.09157086451477172e-16*V01*V02*V03*V18 - 
      6.03982134458166616e-17*V012*V04*V18 + 3.77410183257556608e-17*V042*V18 + 
      7.79570696207480467e-17*V03*V05*V18 + 2.80752670993088866e-17*V02*V06*V18 + 1.21528151719567033e-17*V01*V07*V18 - 
      2.78446831189661083e-19*V10*V18 - 1.31518994604621579e-17*V01*V022*V19 - 
      1.42074022197094394e-17*V012*V03*V19 + 2.02337272768051394e-17*V03*V04*V19 + 
      1.03973164923609457e-17*V02*V05*V19 + 4.58941588381151984e-18*V01*V06*V19 - 1.55209193627826197e-19*V09*V19 - 
      1.8395905232595477e-18*V012*V02*V20 + 2.45776038062168067e-18*V032*V20 + 
      2.43226768863341047e-18*V02*V04*V20 + 1.54116965621763868e-18*V01*V05*V20 - 7.19439622289528542e-20*V08*V20 - 
      7.0366850616485431e-20*V013*V21 + 5.99104855394272652e-19*V02*V03*V21 + 3.65144384878931674e-19*V01*V04*V21 - 
      3.00494103435625461e-20*V07*V21 + 3.20560097252878075e-20*V022*V22 + 7.94884794001039128e-20*V01*V03*V22 - 
      9.86103979350869749e-21*V06*V22 + 8.99131980099536063e-21*V01*V02*V23 - 2.97373015312066046e-21*V05*V23 + 
      5.21235930492484674e-22*V012*V24 - 6.20005431935559767e-22*V04*V24 - 1.25548104358154919e-22*V03*V25 - 
      1.25173653258663191e-23*V02*V26 - 1.44431138375380606e-24*V01*V27 + 1.29418582773638535e-27*V30) + 
   delta8*eps11*(-2.70769233078483378e-9*V034*V042 - 
      5.2849037735279136e-9*V02*V032*V043 - 3.15709843216944468e-10*V022*V044 - 
      1.61037939893695159e-9*V01*V03*V044 - 1.00986373135568462e-9*V035*V05 - 
      1.1057785719031284e-8*V02*V033*V04*V05 - 7.66974404297867338e-9*V022*V03*V042*V05 - 
      9.51540934945386793e-9*V01*V032*V042*V05 - 3.17094226411674816e-9*V01*V02*V043*V05 - 
      4.19369923254413275e-9*V022*V032*V052 - 2.90983540450796314e-9*V01*V033*V052 - 
      1.21852959418989951e-9*V023*V04*V052 - 9.77152738667720209e-9*V01*V02*V03*V04*V052 - 
      1.37159931983338818e-9*V012*V042*V052 + 7.34782729020672138e-10*V043*V052 - 
      8.28491729834760568e-10*V01*V022*V053 - 8.21336321588804959e-10*V012*V03*V053 + 
      1.46453395338214103e-9*V03*V04*V053 + 1.89782847320951886e-10*V02*V054 - 
      1.92357192532689145e-9*V02*V034*V06 - 5.58835387896902411e-9*V022*V032*V04*V06 - 
      4.36051478170372235e-9*V01*V033*V04*V06 - 4.3569327826351269e-10*V023*V042*V06 - 
      6.83968891953341714e-9*V01*V02*V03*V042*V06 - 6.77992580765286073e-10*V012*V043*V06 + 
      2.26257954018371214e-10*V044*V06 - 1.79365774695378641e-9*V023*V03*V05*V06 - 
      6.75297478382221273e-9*V01*V02*V032*V05*V06 - 3.35301232738141446e-9*V01*V022*V04*V05*V06 - 
      3.74016205972046605e-9*V012*V03*V04*V05*V06 + 3.19520179769643088e-9*V03*V042*V05*V06 - 
      9.72039096167003577e-10*V012*V02*V052*V06 + 1.55664001306521241e-9*V032*V052*V06 + 
      1.6175969284219239e-9*V02*V04*V052*V06 + 3.19314200223651209e-10*V01*V053*V06 - 
      3.74309240912914694e-11*V024*V062 - 1.20684284142954094e-9*V01*V022*V03*V062 - 
      6.3413946401022949e-10*V012*V032*V062 - 
      7.20202163712626555e-10*V012*V02*V04*V062 + 1.1497464459863449e-9*V032*V04*V062 + 
      4.92267262977367602e-10*V02*V042*V062 - 1.17205990640662389e-10*V013*V05*V062 + 
      1.17381796268426579e-9*V02*V03*V05*V062 + 7.12011064353481034e-10*V01*V04*V05*V062 + 
      5.93013262597060489e-11*V022*V063 + 1.68814100807082011e-10*V01*V03*V063 - 
      4.32974712630363354e-12*V064 - 1.31506623783295328e-9*V022*V033*V07 - 
      6.7454712747304742e-10*V01*V034*V07 - 1.16050437541895192e-9*V023*V03*V04*V07 - 
      4.56716553629821362e-9*V01*V02*V032*V04*V07 - 1.09567772042552477e-9*V01*V022*V042*V07 - 
      1.27310177488348393e-9*V012*V03*V042*V07 + 7.22286779408660039e-10*V03*V043*V07 - 
      1.36344455668646115e-10*V024*V05*V07 - 2.32927025459899152e-9*V01*V022*V03*V05*V07 - 
      1.13596860395683898e-9*V012*V032*V05*V07 - 1.31967414597038001e-9*V012*V02*V04*V05*V07 + 
      2.14846013369944086e-9*V032*V04*V05*V07 + 1.08891690401549956e-9*V02*V042*V05*V07 - 
      1.03574214004454016e-10*V013*V052*V07 + 1.11508967056077928e-9*V02*V03*V052*V07 + 
      6.61937463231797974e-10*V01*V04*V052*V07 - 2.56236820993398059e-10*V01*V023*V06*V07 - 
      9.01196641965537243e-10*V012*V02*V03*V06*V07 + 5.06221494252538875e-10*V033*V06*V07 - 
      1.60550455814033235e-10*V013*V04*V06*V07 + 1.58863211987852681e-9*V02*V03*V04*V06*V07 + 
      4.85765929649484683e-10*V01*V042*V06*V07 + 3.97280172036646943e-10*V022*V05*V06*V07 + 
      9.302970874451516e-10*V01*V03*V05*V06*V07 + 1.78140977416299296e-10*V01*V02*V062*V07 - 
      5.05575733027045824e-11*V05*V062*V07 - 7.8930631473357521e-11*V012*V022*V072 - 
      4.73259067769259649e-11*V013*V03*V072 + 2.72368016632682124e-10*V02*V032*V072 + 
      1.32717469230699681e-10*V022*V04*V072 + 3.21496242822697314e-10*V01*V03*V04*V072 + 
      1.67889888642869614e-10*V01*V02*V05*V072 - 2.35208557414920747e-11*V052*V072 + 
      3.38045756691589119e-11*V012*V06*V072 - 3.4929126803506077e-11*V04*V06*V072 - 
      7.8456365347813506e-12*V03*V073 - 3.3606077243994217e-10*V023*V032*V08 - 
      7.97558643198112695e-10*V01*V02*V033*V08 - 3.79125297581047968e-11*V024*V04*V08 - 
      1.24138886084073368e-9*V01*V022*V03*V04*V08 - 6.53786770772800742e-10*V012*V032*V04*V08 - 
      3.70952627427921929e-10*V012*V02*V042*V08 + 6.12638869143912934e-10*V032*V042*V08 + 
      1.72768087835016637e-10*V02*V043*V08 - 2.01636463463965302e-10*V01*V023*V05*V08 - 
      6.82315412603310794e-10*V012*V02*V03*V05*V08 + 3.91350565437022265e-10*V033*V05*V08 - 
      1.20697537152166511e-10*V013*V04*V05*V08 + 1.24824322132544079e-9*V02*V03*V04*V05*V08 + 
      3.79063693721972457e-10*V01*V042*V05*V08 + 1.56899850601904995e-10*V022*V052*V08 + 
      3.5870249760142936e-10*V01*V03*V052*V08 - 1.30822250667700514e-10*V012*V022*V06*V08 - 
      8.05230798728697216e-11*V013*V03*V06*V08 + 4.49879017717270193e-10*V02*V032*V06*V08 + 
      1.87017356849217665e-10*V022*V04*V06*V08 + 5.39452386670568975e-10*V01*V03*V04*V06*V08 + 
      2.78119084952677826e-10*V01*V02*V05*V06*V08 - 3.96354560188055355e-11*V052*V06*V08 + 
      2.88090219036862163e-11*V012*V062*V08 - 2.81085044764062211e-11*V04*V062*V08 - 
      2.91114609549204539e-11*V013*V02*V07*V08 + 1.53836256560521283e-10*V022*V03*V07*V08 + 
      1.7353844815332962e-10*V01*V032*V07*V08 + 1.89133487527127768e-10*V01*V02*V04*V07*V08 + 
      5.19059393198766873e-11*V012*V05*V07*V08 - 5.48898304568036419e-11*V04*V05*V07*V08 - 
      3.97070283494940312e-11*V03*V06*V07*V08 - 7.11612428347958144e-12*V02*V072*V08 - 
      8.96751732530399836e-13*V014*V082 + 5.87597767868451872e-12*V023*V082 + 
      5.26019657389852216e-11*V01*V02*V03*V082 + 1.53193584740453577e-11*V012*V04*V082 - 
      7.59515759376866709e-12*V042*V082 - 1.55236972611883851e-11*V03*V05*V082 - 
      5.68265534731106992e-12*V02*V06*V082 - 2.46116741375142167e-12*V01*V07*V082 - 
      3.78734599079572541e-11*V024*V03*V09 - 3.14186242742249013e-10*V01*V022*V032*V09 - 
      9.99691694792499952e-11*V012*V033*V09 - 9.67086979515793265e-11*V01*V023*V04*V09 - 
      3.52252361146458457e-10*V012*V02*V03*V04*V09 + 2.08892379826975924e-10*V033*V04*V09 - 
      3.14944508532419064e-11*V013*V042*V09 + 3.20821332750362179e-10*V02*V03*V042*V09 + 
      6.58139909884409326e-11*V01*V043*V09 - 9.08657228291473481e-11*V012*V022*V05*V09 - 
      5.41728749948350846e-11*V013*V03*V05*V09 + 3.25758686854994221e-10*V02*V032*V05*V09 + 
      1.59282849594574961e-10*V022*V04*V05*V09 + 3.83582639290067379e-10*V01*V03*V04*V05*V09 + 
      1.0018185639911531e-10*V01*V02*V052*V09 - 9.53000374697754342e-12*V053*V09 - 
      2.21867621467716394e-11*V013*V02*V06*V09 + 1.16860626687187126e-10*V022*V03*V06*V09 + 
      1.34252881626236139e-10*V01*V032*V06*V09 + 1.44401914144765153e-10*V01*V02*V04*V06*V09 + 
      4.01855462494203005e-11*V012*V05*V06*V09 - 4.25198473038538317e-11*V04*V05*V06*V09 - 
      1.54117389351079318e-11*V03*V062*V09 - 1.60096404346460718e-12*V014*V07*V09 + 
      1.27580139152221315e-11*V023*V07*V09 + 9.70894929477466002e-11*V01*V02*V03*V07*V09 + 
      2.78385224692644464e-11*V012*V04*V07*V09 - 1.46329303132615509e-11*V042*V07*V09 - 
      2.85819369795551925e-11*V03*V05*V07*V09 - 1.09841618384869999e-11*V02*V06*V07*V09 - 
      2.2592770034367596e-12*V01*V072*V09 + 1.39216449006725716e-11*V01*V022*V08*V09 + 
      1.47802408512010082e-11*V012*V03*V08*V09 - 1.6713873136280412e-11*V03*V04*V08*V09 - 
      8.65385818649188504e-12*V02*V05*V08*V09 - 3.82596696541192332e-12*V01*V06*V08*V09 + 
      2.08973196445988763e-12*V012*V02*V092 - 2.16106844250979952e-12*V032*V092 - 
      2.28384166378228319e-12*V02*V04*V092 - 1.36716828894291613e-12*V01*V05*V092 + 
      5.32252711422059609e-14*V08*V092 - 7.90314933119651833e-13*V025*V10 - 
      4.55865268533332244e-11*V01*V023*V03*V10 - 7.26771740633275153e-11*V012*V02*V032*V10 + 
      2.31335411714399361e-11*V034*V10 - 4.11072267643068035e-11*V012*V022*V04*V10 - 
      2.52936187739062626e-11*V013*V03*V04*V10 + 1.50234688757787613e-10*V02*V032*V04*V10 + 
      3.05757962507838267e-11*V022*V042*V10 + 9.0229736448768765e-11*V01*V03*V042*V10 - 
      1.33466964293355892e-11*V013*V02*V05*V10 + 7.59248434520164238e-11*V022*V03*V05*V10 + 
      8.41214926683626087e-11*V01*V032*V05*V10 + 9.27395871431695045e-11*V01*V02*V04*V05*V10 + 
      1.25303992223556671e-11*V012*V052*V10 - 1.37210528476302462e-11*V04*V052*V10 - 
      1.09379027043054598e-12*V014*V06*V10 + 7.31106688615551354e-12*V023*V06*V10 + 
      6.60849329722809952e-11*V01*V02*V03*V06*V10 + 1.92572466566963193e-11*V012*V04*V06*V10 - 
      9.65377752972800324e-12*V042*V06*V10 - 1.97981237688494499e-11*V03*V05*V06*V10 - 
      3.60790224457745026e-12*V02*V062*V10 + 1.14546291076524415e-11*V01*V022*V07*V10 + 
      1.20054634519351767e-11*V012*V03*V07*V10 - 1.37301661786255464e-11*V03*V04*V07*V10 - 
      7.12459506348421325e-12*V02*V05*V07*V10 - 3.13550385611748061e-12*V01*V06*V07*V10 + 
      3.73553117385012201e-12*V012*V02*V08*V10 - 3.85483594627473664e-12*V032*V08*V10 - 
      3.88619480703953173e-12*V02*V04*V08*V10 - 2.44102095064815417e-12*V01*V05*V08*V10 + 
      4.69649607688543926e-14*V082*V10 + 3.25472637589004965e-13*V013*V09*V10 - 
      2.16213993830881259e-12*V02*V03*V09*V10 - 1.31851796934635121e-12*V01*V04*V09*V10 + 8.74729103498187793e-14*V07*V09*V10 - 
      1.22842961118007378e-13*V022*V102 - 2.99027520708754681e-13*V01*V03*V102 + 
      3.00797036495938604e-14*V06*V102 - 2.0658250858885775e-12*V01*V024*V11 - 
      1.57257505117001011e-11*V012*V022*V03*V11 - 4.5708191133987549e-12*V013*V032*V11 + 
      2.11112938649033068e-11*V02*V033*V11 - 5.63430214366642788e-12*V013*V02*V04*V11 + 
      3.13855011037910835e-11*V022*V03*V04*V11 + 3.69339070498637689e-11*V01*V032*V04*V11 + 
      1.95005543283774608e-11*V01*V02*V042*V11 - 5.90375196030384519e-13*V014*V05*V11 + 
      5.12988824279130284e-12*V023*V05*V11 + 3.86494704849125462e-11*V01*V02*V03*V05*V11 + 
      1.10382124643695347e-11*V012*V04*V05*V11 - 6.02574402553772853e-12*V042*V05*V11 - 
      5.86065950487755921e-12*V03*V052*V11 + 7.08385491133828903e-12*V01*V022*V06*V11 + 
      7.63429429891017533e-12*V012*V03*V06*V11 - 8.75762270419255321e-12*V03*V04*V06*V11 - 
      4.51908922194792723e-12*V02*V05*V06*V11 - 1.00319318895153867e-12*V01*V062*V11 + 
      2.78856534194745054e-12*V012*V02*V07*V11 - 2.91931345055065142e-12*V032*V07*V11 - 
      3.09097195181517997e-12*V02*V04*V07*V11 - 1.84530720111911496e-12*V01*V05*V07*V11 + 
      2.67537093328460769e-13*V013*V08*V11 - 1.77672651862831385e-12*V02*V03*V08*V11 - 
      1.08549916667667726e-12*V01*V04*V08*V11 + 7.21969685808930552e-14*V07*V08*V11 - 
      2.37718869184732011e-13*V022*V09*V11 - 5.51568550731522464e-13*V01*V03*V09*V11 + 
      5.62759032607874966e-14*V06*V09*V11 - 1.39485595689417132e-13*V01*V02*V10*V11 + 3.63036838344687864e-14*V05*V10*V11 - 
      8.4762325330435429e-15*V012*V112 + 8.13619376933364333e-15*V04*V112 - 
      1.01814211656491648e-12*V012*V023*V12 - 1.87567973747534509e-12*V013*V02*V03*V12 + 
      6.29198029883627969e-12*V022*V032*V12 + 4.5179317601098536e-12*V01*V033*V12 - 
      2.30243551987454227e-13*V014*V04*V12 + 1.63183234523232524e-12*V023*V04*V12 + 
      1.51983607990053672e-11*V01*V02*V03*V04*V12 + 2.21899508353305481e-12*V012*V042*V12 - 
      7.67622409575923744e-13*V043*V12 + 3.87421497906201032e-12*V01*V022*V05*V12 + 
      3.9974675075661919e-12*V012*V03*V05*V12 - 4.77688649044064251e-12*V03*V04*V05*V12 - 
      1.24167226614877991e-12*V02*V052*V12 + 1.61928091951465818e-12*V012*V02*V06*V12 - 
      1.71501986259447189e-12*V032*V06*V12 - 1.71570347365917145e-12*V02*V04*V06*V12 - 
      1.08491507130179143e-12*V01*V05*V06*V12 + 1.822452783408343e-13*V013*V07*V12 - 
      1.23955218846814539e-12*V02*V03*V07*V12 - 7.53992943398918739e-13*V01*V04*V07*V12 + 
      2.514108289774699e-14*V072*V12 - 1.70860271545318255e-13*V022*V08*V12 - 
      4.17272476972729539e-13*V01*V03*V08*V12 + 4.20775619553044381e-14*V06*V08*V12 - 1.18222543305119371e-13*V01*V02*V09*V12 + 
      3.07695292892914839e-14*V05*V09*V12 - 1.55943732580682249e-14*V012*V10*V12 + 
      1.47395049716510006e-14*V04*V10*V12 + 6.46014360006089842e-15*V03*V11*V12 + 6.84806977386757954e-16*V02*V122 - 
      1.75611265297200587e-13*V013*V022*V13 - 6.84922777160622591e-14*V014*V03*V13 + 
      7.23997612170711996e-13*V023*V03*V13 + 2.65331298483672984e-12*V01*V02*V032*V13 + 
      1.36258228576674328e-12*V01*V022*V04*V13 + 1.49844947815938967e-12*V012*V03*V04*V13 - 
      8.95974776441620578e-13*V03*V042*V13 + 7.9019326108408995e-13*V012*V02*V05*V13 - 
      8.6310803951469148e-13*V032*V05*V13 - 9.19356878384301417e-13*V02*V04*V05*V13 - 
      2.7192294469240702e-13*V01*V052*V13 + 9.8852323478737723e-14*V013*V06*V13 - 
      6.70585221398290731e-13*V02*V03*V06*V13 - 4.1056167171177864e-13*V01*V04*V06*V13 - 
      1.16335394741710843e-13*V022*V07*V13 - 2.68634844375280028e-13*V01*V03*V07*V13 + 
      2.76345042190096508e-14*V06*V07*V13 - 8.28360300089827386e-14*V01*V02*V08*V13 + 2.16940773074746741e-14*V05*V08*V13 - 
      1.22343703058866892e-14*V012*V09*V13 + 1.17814293524730856e-14*V04*V09*V13 + 
      5.51810263502300414e-15*V03*V10*V13 + 1.29201754511031737e-15*V02*V11*V13 + 3.14988372293160695e-16*V01*V12*V13 - 
      1.20226790481880822e-14*V014*V02*V14 + 2.35311275767894987e-14*V024*V14 + 
      4.63845526109898326e-13*V01*V022*V03*V14 + 2.32187093336954648e-13*V012*V032*V14 + 
      2.72272029967499923e-13*V012*V02*V04*V14 - 3.05483133968956297e-13*V032*V04*V14 - 
      1.50047739995673031e-13*V02*V042*V14 + 4.4166334595188201e-14*V013*V05*V14 - 
      3.18481901590034896e-13*V02*V03*V05*V14 - 1.92823333578249204e-13*V01*V04*V05*V14 - 
      5.55022048180016092e-14*V022*V06*V14 - 1.37060588895774704e-13*V01*V03*V06*V14 + 
      6.97791424950739716e-15*V062*V14 - 4.99776947621698893e-14*V01*V02*V07*V14 + 
      1.31000250534010513e-14*V05*V07*V14 - 8.04238829701328171e-15*V012*V08*V14 + 
      7.63265362252156149e-15*V04*V08*V14 + 4.05508994062944655e-15*V03*V09*V14 + 1.01396710076047469e-15*V02*V10*V14 + 
      2.73107322985628684e-16*V01*V11*V14 - 9.99010714395400467e-19*V142 - 2.77446439573571128e-16*V015*V15 + 
      2.35279160188349072e-14*V01*V023*V15 + 8.00606549734606702e-14*V012*V02*V03*V15 - 
      3.18661002063482126e-14*V033*V15 + 1.44958727992129266e-14*V013*V04*V15 - 
      1.03115616401421854e-13*V02*V03*V04*V15 - 3.16736787025350229e-14*V01*V042*V15 - 
      2.61676664298677674e-14*V022*V05*V15 - 5.97501107375548902e-14*V01*V03*V05*V15 - 
      2.36292459591238514e-14*V01*V02*V06*V15 + 6.29646953310172236e-15*V05*V06*V15 - 
      4.49715324143854128e-15*V012*V07*V15 + 4.38688044831203657e-15*V04*V07*V15 + 
      2.49993389888186668e-15*V03*V08*V15 + 7.09232706371279065e-16*V02*V09*V15 + 2.03937042180346142e-16*V01*V10*V15 - 
      1.88185619821475976e-18*V13*V15 + 6.30972847873204242e-15*V012*V022*V16 + 
      3.84303528438319718e-15*V013*V03*V16 - 1.56196704962529859e-14*V02*V032*V16 - 
      7.41008061130717081e-15*V022*V04*V16 - 1.87214323359545695e-14*V01*V03*V04*V16 - 
      9.82547302075418786e-15*V01*V02*V05*V16 + 1.31609881312271195e-15*V052*V16 - 
      2.03093139329541282e-15*V012*V06*V16 + 1.95087014910293091e-15*V04*V06*V16 + 
      1.33140296669692414e-15*V03*V07*V16 + 4.04612857892306656e-16*V02*V08*V16 + 1.3218544889613861e-16*V01*V09*V16 - 
      1.54156523737838203e-18*V12*V16 + 5.94767427829817333e-16*V013*V02*V17 - 
      2.29051638062083273e-15*V022*V03*V17 - 2.55243185102262243e-15*V01*V032*V17 - 
      2.83479280079797984e-15*V01*V02*V04*V17 - 7.77877051744758815e-16*V012*V05*V17 + 
      7.84540541187959212e-16*V04*V05*V17 + 5.69382765977192195e-16*V03*V06*V17 + 2.07275949967380283e-16*V02*V07*V17 + 
      7.24776167919506862e-17*V01*V08*V17 - 1.11919960795176042e-18*V11*V17 + 1.75917126541213578e-17*V014*V18 - 
      9.52521431837123422e-17*V023*V18 - 7.53578708066404334e-16*V01*V02*V03*V18 - 
      2.19226247694455206e-16*V012*V04*V18 + 1.08173395744931576e-16*V042*V18 + 
      2.1251235659833308e-16*V03*V05*V18 + 8.20474286947829355e-17*V02*V06*V18 + 3.44742319671513401e-17*V01*V07*V18 - 
      7.01323707274126518e-19*V10*V18 - 5.02787901666839949e-17*V01*V022*V19 - 
      5.2523827781590911e-17*V012*V03*V19 + 5.71416523532977674e-17*V03*V04*V19 + 2.9865562266315506e-17*V02*V05*V19 + 
      1.32911372677619552e-17*V01*V06*V19 - 3.88654874120887369e-19*V09*V19 - 7.10705191226502853e-18*V012*V02*V20 + 
      6.95676443511218904e-18*V032*V20 + 7.36713800411280915e-18*V02*V04*V20 + 4.46314913901670774e-18*V01*V05*V20 - 
      1.82286287562215143e-19*V08*V20 - 2.81467402465941724e-19*V013*V21 + 1.78625691822879882e-18*V02*V03*V21 + 
      1.09487468756841022e-18*V01*V04*V21 - 7.55642739076560618e-20*V07*V21 + 1.02757940582804121e-19*V022*V22 + 
      2.39582372337081348e-19*V01*V03*V22 - 2.53337718849022358e-20*V06*V22 + 2.84818204876250554e-20*V01*V02*V23 - 
      7.57589464491663069e-21*V05*V23 + 1.67540120515441502e-21*V012*V24 - 1.63881198343265194e-21*V04*V24 - 
      3.29784432623785716e-22*V03*V25 - 3.47704592385175532e-23*V02*V26 - 4.0119760659827946e-24*V01*V27 + 
      3.23546456934096338e-27*V30) + eps15*(-6.94206524686864971e-10*V028 - 
      4.54639386231988551e-8*V01*V026*V03 - 2.53851546801452458e-7*V012*V024*V032 - 
      2.2386601636791296e-7*V013*V022*V033 - 1.7497802026109877e-8*V014*V034 + 
      5.82321609376665683e-8*V023*V034 + 5.68952526355953279e-8*V01*V02*V035 - 
      8.02033267037497897e-8*V012*V025*V04 - 3.42381597943718625e-7*V013*V023*V03*V04 - 
      1.57460316491376832e-7*V014*V02*V032*V04 + 1.23015905721350914e-7*V024*V032*V04 + 
      4.20140204066269924e-7*V01*V022*V033*V04 + 8.03264375297130437e-8*V012*V034*V04 - 
      5.8539769345966825e-8*V014*V022*V042 + 1.55258266251201437e-8*V025*V042 - 
      1.38203085397588199e-8*V015*V03*V042 + 3.06655008449177551e-7*V01*V023*V03*V042 + 
      3.61660918326332802e-7*V012*V02*V032*V042 - 1.80890848399191371e-8*V034*V042 + 
      9.08700312449270914e-8*V012*V022*V043 + 4.3865201265538045e-8*V013*V03*V043 - 
      5.19912794462820501e-8*V02*V032*V043 - 8.87063997906019346e-9*V022*V044 - 
      1.60972767434028839e-8*V01*V03*V044 - 5.27147785356624448e-8*V013*V024*V05 - 
      9.4583154597524929e-8*V014*V022*V03*V05 + 2.91617791598488678e-8*V025*V03*V05 - 
      1.10898943522270631e-8*V015*V032*V05 + 2.55904363772325924e-7*V01*V023*V032*V05 + 
      1.97413677627478624e-7*V012*V02*V033*V05 - 6.07572300720626769e-9*V035*V05 - 
      1.61646843431536475e-8*V015*V02*V04*V05 + 9.23641668053448817e-8*V01*V024*V04*V05 + 
      4.44160770415495624e-7*V012*V022*V03*V04*V05 + 1.06946035281486025e-7*V013*V032*V04*V05 - 
      8.82916460558425759e-8*V02*V033*V04*V05 + 8.11535252964248265e-8*V013*V02*V042*V05 - 
      9.42461290386927715e-8*V022*V03*V042*V05 - 8.08199662875465147e-8*V01*V032*V042*V05 - 
      3.9343271570668984e-8*V01*V02*V043*V05 - 4.4215788239092005e-10*V016*V052 + 
      4.54036675918749289e-8*V012*V023*V052 + 
      6.58069309998302386e-8*V013*V02*V03*V052 - 
      4.02737285295749096e-8*V022*V032*V052 - 2.245245242685755e-8*V01*V033*V052 + 
      8.48207471303910781e-9*V014*V04*V052 - 1.88785363563949947e-8*V023*V04*V052 - 
      9.91840918028478183e-8*V01*V02*V03*V04*V052 - 1.46710678526782349e-8*V012*V042*V052 + 
      2.06176703909365558e-9*V043*V052 - 1.01178869715510899e-8*V01*V022*V053 - 
      8.0857279035660943e-9*V012*V03*V053 + 3.50820802817152802e-9*V03*V04*V053 + 
      5.36491683617947045e-10*V02*V054 - 1.56362709521994069e-8*V014*V023*V06 + 
      2.18414198041136536e-9*V026*V06 - 1.08113464132955263e-8*V015*V02*V03*V06 + 
      6.53452271788922513e-8*V01*V024*V03*V06 + 1.54115501019122208e-7*V012*V022*V032*V06 + 
      2.45674819171181349e-8*V013*V033*V06 - 1.56446306688506395e-8*V02*V034*V06 - 
      7.37965357406884018e-10*V016*V04*V06 + 7.75054431271121163e-8*V012*V023*V04*V06 + 
      1.11688681151582586e-7*V013*V02*V03*V04*V06 - 6.72961703587403294e-8*V022*V032*V04*V06 - 
      3.79433180973422844e-8*V01*V033*V04*V06 + 7.17244087745385852e-9*V014*V042*V06 - 
      1.52458893817500879e-8*V023*V042*V06 - 8.35490099178811725e-8*V01*V02*V03*V042*V06 - 
      8.29670664585292318e-9*V012*V043*V06 + 8.54108890191812222e-10*V044*V06 + 
      3.44275149917664599e-8*V013*V022*V05*V06 + 1.16192374107110268e-8*V014*V03*V05*V06 - 
      2.70668530957032087e-8*V023*V03*V05*V06 - 6.99456808524552684e-8*V01*V02*V032*V05*V06 - 
      5.10000496945692542e-8*V01*V022*V04*V05*V06 - 4.11083020764441806e-8*V012*V03*V04*V05*V06 + 
      8.83086349348011714e-9*V03*V042*V05*V06 - 1.26930442310423802e-8*V012*V02*V052*V06 + 
      3.74332101481123714e-9*V032*V052*V06 + 5.38614315013184056e-9*V02*V04*V052*V06 + 
      9.49993437743467316e-10*V01*V053*V06 + 3.0114948425280142e-9*V014*V02*V062 - 
      1.63620013152507348e-9*V024*V062 - 1.80584740578789607e-8*V01*V022*V03*V062 - 
      7.1929056405474561e-9*V012*V032*V062 - 1.07684886489502604e-8*V012*V02*V04*V062 + 
      3.14672738103771724e-9*V032*V04*V062 + 2.22930859597044076e-9*V02*V042*V062 - 
      1.66798448619505426e-9*V013*V05*V062 + 3.84844365382511371e-9*V02*V03*V05*V062 + 
      2.40407175189785005e-9*V01*V04*V05*V062 + 3.23109770393266229e-10*V022*V063 + 
      5.67857461620184775e-10*V01*V03*V063 - 8.24720775442092173e-12*V064 - 
      2.22730672332388019e-9*V015*V022*V07 + 5.74832684711426961e-9*V01*V025*V07 - 
      4.18007464576092027e-10*V016*V03*V07 + 4.6434845998860201e-8*V012*V023*V03*V07 + 
      3.33343996582832413e-8*V013*V02*V032*V07 - 1.40280482779142205e-8*V022*V033*V07 - 
      5.82303383547719375e-9*V01*V034*V07 + 2.53665641824400394e-8*V013*V022*V04*V07 + 
      8.530772859016492e-9*V014*V03*V04*V07 - 1.98269640247326998e-8*V023*V03*V04*V07 - 
      5.15631486875711777e-8*V01*V02*V032*V04*V07 - 1.87539200523709339e-8*V01*V022*V042*V07 - 
      1.51747452738871774e-8*V012*V03*V042*V07 + 2.16718128580535291e-9*V03*V043*V07 + 
      5.23129368023274051e-9*V014*V02*V05*V07 - 2.96604718038281032e-9*V024*V05*V07 - 
      3.15981234782751671e-8*V01*V022*V03*V05*V07 - 1.25314642189172153e-8*V012*V032*V05*V07 - 
      1.87396397034696155e-8*V012*V02*V04*V05*V07 + 5.5211014707465104e-9*V032*V04*V05*V07 + 
      3.96041468981929047e-9*V02*V042*V05*V07 - 1.45062232163661665e-9*V013*V052*V07 + 
      3.38170717130058158e-9*V02*V03*V052*V07 + 2.10457748122992872e-9*V01*V04*V052*V07 + 
      3.43631842626725668e-10*V015*V06*V07 - 5.39783543705181403e-9*V01*V023*V06*V07 - 
      1.31260650334553307e-8*V012*V02*V03*V06*V07 + 1.30836224655562808e-9*V033*V06*V07 - 
      2.46435173785586098e-9*V013*V04*V06*V07 + 5.66570096524915792e-9*V02*V03*V04*V06*V07 + 
      1.77427655588753536e-9*V01*V042*V06*V07 + 1.72322372090584275e-9*V022*V05*V06*V07 + 
      2.98020226518573325e-9*V01*V03*V05*V06*V07 + 7.74976901766769758e-10*V01*V02*V062*V07 - 
      8.71776361934645449e-11*V05*V062*V07 - 1.49511564735614854e-9*V012*V022*V072 - 
      7.45256511956404467e-10*V013*V03*V072 + 8.87980713987765631e-10*V02*V032*V072 + 
      6.32997636546799913e-10*V022*V04*V072 + 1.10078412033046672e-9*V01*V03*V04*V072 + 
      6.78931013741368324e-10*V01*V02*V05*V072 - 3.82721782951213454e-11*V052*V072 + 
      1.43978074925781938e-10*V012*V06*V072 - 6.43123832372462254e-11*V04*V06*V072 - 
      1.34477087404639948e-11*V03*V073 - 1.46715896818021001e-10*V016*V02*V08 + 
      4.67786220396497877e-9*V012*V024*V08 + 1.33664331694032427e-8*V013*V022*V03*V08 + 
      2.23978478446155502e-9*V014*V032*V08 - 5.50717848709859038e-9*V023*V032*V08 - 
      9.35981329925486542e-9*V01*V02*V033*V08 + 3.39152044441936349e-9*V014*V02*V04*V08 - 
      1.85912736904691369e-9*V024*V04*V08 - 2.05812179693864974e-8*V01*V022*V03*V04*V08 - 
      8.19813509983616513e-9*V012*V032*V04*V08 - 6.1382480463705707e-9*V012*V02*V042*V08 + 
      1.79774164950644287e-9*V032*V042*V08 + 8.48045452956239672e-10*V02*V043*V08 + 
      2.63371396729710816e-10*V015*V05*V08 - 4.18223509668411617e-9*V01*V023*V05*V08 - 
      1.01322501728694028e-8*V012*V02*V03*V05*V08 + 1.01345303804956742e-9*V033*V05*V08 - 
      1.8997957778747097e-9*V013*V04*V05*V08 + 4.39621114644282016e-9*V02*V03*V04*V05*V08 + 
      1.37430016250060562e-9*V01*V042*V05*V08 + 6.69231294397409884e-10*V022*V052*V08 + 
      1.15333970536551651e-9*V01*V03*V052*V08 - 2.65391812960214649e-9*V012*V022*V06*V08 - 
      1.3211813507329157e-9*V013*V03*V06*V08 + 1.56837918999985064e-9*V02*V032*V06*V08 + 
      1.10629910626498957e-9*V022*V04*V06*V08 + 1.94821463148274307e-9*V01*V03*V04*V06*V08 + 
      1.20080021374790508e-9*V01*V02*V05*V06*V08 - 6.76310012259065884e-11*V052*V06*V08 + 
      1.27634421168221221e-10*V012*V062*V08 - 5.66401102840554386e-11*V04*V062*V08 - 
      6.05110657245563602e-10*V013*V02*V07*V08 + 7.04806175345157051e-10*V022*V03*V07*V08 + 
      6.02854330585281706e-10*V01*V032*V07*V08 + 8.86224786502716822e-10*V01*V02*V04*V07*V08 + 
      2.22670865768818283e-10*V012*V05*V07*V08 - 9.98173085443164546e-11*V04*V05*V07*V08 - 
      7.13165068345512982e-11*V03*V06*V07*V08 - 1.61779418183039124e-11*V02*V072*V08 - 
      2.1515879747530703e-11*V014*V082 + 4.57369966971094349e-11*V023*V082 + 
      2.43542008755544192e-10*V01*V02*V03*V082 + 7.30330831775538141e-11*V012*V04*V082 - 
      1.62117180060434137e-11*V042*V082 - 2.76589309412361286e-11*V03*V05*V082 - 
      1.42437756285810815e-11*V02*V06*V082 - 5.64273854878146676e-12*V01*V07*V082 - 
      3.54243614047535616e-12*V017*V09 + 1.6090617241645087e-9*V013*V023*V09 + 
      1.59583030346124509e-9*V014*V02*V03*V09 - 9.62818371692481156e-10*V024*V03*V09 - 
      5.05625715084009515e-9*V01*V022*V032*V09 - 1.32487387979222179e-9*V012*V033*V09 + 
      1.52457040502828994e-10*V015*V04*V09 - 2.4440274769942435e-9*V01*V023*V04*V09 - 
      5.95530002485853638e-9*V012*V02*V03*V04*V09 + 5.95146924057484682e-10*V033*V04*V09 - 
      5.58696871612924697e-10*V013*V042*V09 + 1.286303864806352e-9*V02*V03*V042*V09 + 
      2.69059187025538313e-10*V01*V043*V09 - 1.83782961588857547e-9*V012*V022*V05*V09 - 
      9.14650866732722728e-10*V013*V03*V05*V09 + 1.09535713420573542e-9*V02*V032*V05*V09 + 
      7.81703691827714168e-10*V022*V04*V05*V09 + 1.35682439590345054e-9*V01*V03*V04*V05*V09 + 
      4.18551100180693069e-10*V01*V02*V052*V09 - 1.57475509151900846e-11*V053*V09 - 
      4.81760810253798968e-10*V013*V02*V06*V09 + 5.60297060359912343e-10*V022*V03*V06*V09 + 
      4.80021826540252563e-10*V01*V032*V06*V09 + 7.05251608405353447e-10*V01*V02*V04*V06*V09 + 
      1.77360964063524029e-10*V012*V05*V06*V09 - 7.94125479229651329e-11*V04*V05*V06*V09 - 
      2.83782175221970736e-11*V03*V062*V09 - 3.86516654716933898e-11*V014*V07*V09 + 
      8.31912471394392337e-11*V023*V07*V09 + 4.38232746904444785e-10*V01*V02*V03*V07*V09 + 
      1.31238727592392633e-10*V012*V04*V07*V09 - 2.9289154646082385e-11*V042*V07*V09 - 
      4.98077375263285322e-11*V03*V05*V07*V09 - 2.57386696300187456e-11*V02*V06*V07*V09 - 
      5.07729690116426888e-12*V01*V072*V09 + 8.80826733090481605e-11*V01*V022*V08*V09 + 
      7.14320907923061499e-11*V012*V03*V08*V09 - 3.25160503607965922e-11*V03*V04*V08*V09 - 
      1.99887537618312879e-11*V02*V05*V08*V09 - 8.98843796485071897e-12*V01*V06*V08*V09 + 
      1.30883673907849959e-11*V012*V02*V092 - 4.05326230632449257e-12*V032*V092 - 
      5.86359466285590627e-12*V02*V04*V092 - 3.13447692082000853e-12*V01*V05*V092 + 
      8.14222107503231745e-14*V08*V092 + 2.57242234950944531e-10*V014*V022*V10 - 
      5.87301313679052441e-11*V025*V10 + 6.460284856182689e-11*V015*V03*V10 - 
      1.09713114453516043e-9*V01*V023*V03*V10 - 1.3119364205979096e-9*V012*V02*V032*V10 + 
      6.68681476847252555e-11*V034*V10 - 9.82804181968081521e-10*V012*V022*V04*V10 - 
      4.88387406314574565e-10*V013*V03*V04*V10 + 5.8256690412993581e-10*V02*V032*V04*V10 + 
      2.0505713664970509e-10*V022*V042*V10 + 3.621811975504736e-10*V01*V03*V042*V10 - 
      3.02814254531642585e-10*V013*V02*V05*V10 + 3.55598901672197009e-10*V022*V03*V05*V10 + 
      3.03353265594763652e-10*V01*V032*V05*V10 + 4.46412441089847844e-10*V01*V02*V04*V05*V10 + 
      5.59799407823170449e-11*V012*V052*V10 - 2.51745013553585784e-11*V04*V052*V10 - 
      2.79153744073092494e-11*V014*V06*V10 + 5.94184616169428093e-11*V023*V06*V10 + 
      3.1669088230577897e-10*V01*V02*V03*V06*V10 + 9.49799676693291079e-11*V012*V04*V06*V10 - 
      2.107428769023373e-11*V042*V06*V10 - 3.59669998312640944e-11*V03*V05*V06*V10 - 
      9.25931070080285951e-12*V02*V062*V10 + 7.19612109412063777e-11*V01*V022*V07*V10 + 
      5.83105868595580086e-11*V012*V03*V07*V10 - 2.65648270006084215e-11*V03*V04*V07*V10 - 
      1.63347006978280897e-11*V02*V05*V07*V10 - 7.34124330143065495e-12*V01*V06*V07*V10 + 
      2.37844377442280042e-11*V012*V02*V08*V10 - 7.35572861887589855e-12*V032*V08*V10 - 
      1.06068293236070169e-11*V02*V04*V08*V10 - 5.69038571165579452e-12*V01*V05*V08*V10 + 
      7.38118704042372502e-14*V082*V10 + 2.21424581520748837e-12*V013*V09*V10 - 
      5.33325309661845308e-12*V02*V03*V09*V10 - 3.35493174987895847e-12*V01*V04*V09*V10 + 1.33055696769074783e-13*V07*V09*V10 - 
      4.34122908129308479e-13*V022*V102 - 7.54941039233087581e-13*V01*V03*V102 + 
      4.80271780163465663e-14*V06*V102 + 1.86521692396520398e-11*V015*V02*V11 - 
      8.10942926747239152e-11*V01*V024*V11 - 3.96477722595544085e-10*V012*V022*V03*V11 - 
      9.77436962938848269e-11*V013*V032*V11 + 8.0375823741328775e-11*V02*V033*V11 - 
      1.4824222216426174e-10*V013*V02*V04*V11 + 1.7298258566256559e-10*V022*V03*V04*V11 + 
      1.48590409606267406e-10*V01*V032*V04*V11 + 1.09067321886929221e-10*V01*V02*V042*V11 - 
      1.60624841726723269e-11*V014*V05*V11 + 3.49526394288851528e-11*V023*V05*V11 + 
      1.83606679979698007e-10*V01*V02*V03*V05*V11 + 5.49248057153216295e-11*V012*V04*V05*V11 - 
      1.22923391293521476e-11*V042*V05*V11 - 1.0446792304868878e-11*V03*V052*V11 + 
      4.76413757370896413e-11*V01*V022*V06*V11 + 3.8658068197123744e-11*V012*V03*V06*V11 - 
      1.75847032334727575e-11*V03*V04*V06*V11 - 1.08076661904845378e-11*V02*V05*V06*V11 - 
      2.43224858269392821e-12*V01*V062*V11 + 1.77843616743720234e-11*V012*V02*V07*V11 - 
      5.50850002975259586e-12*V032*V07*V11 - 7.97072545840528282e-12*V02*V04*V07*V11 - 
      4.25971711984207076e-12*V01*V05*V07*V11 + 1.84277925954200593e-12*V013*V08*V11 - 
      4.43579732906346624e-12*V02*V03*V08*V11 - 2.79114913508688147e-12*V01*V04*V08*V11 + 1.10664397215694492e-13*V07*V08*V11 - 
      7.98333217385680069e-13*V022*V09*V11 - 1.38379684282090099e-12*V01*V03*V09*V11 + 
      8.81269760956428437e-14*V06*V09*V11 - 4.60197858864066942e-13*V01*V02*V10*V11 + 5.59270822439706111e-14*V05*V10*V11 - 
      2.87074769954414473e-14*V012*V112 + 1.3707384175085021e-14*V04*V112 + 
      4.8941551940777947e-13*V016*V12 - 3.68939674505308105e-11*V012*V023*V12 - 
      5.46897890062243706e-11*V013*V02*V03*V12 + 3.32330990814048066e-11*V022*V032*V12 + 
      1.8721759496117176e-11*V01*V033*V12 - 7.23538697441937466e-12*V014*V04*V12 + 
      1.55021592504695736e-11*V023*V04*V12 + 8.29336363766594459e-11*V01*V02*V03*V04*V12 + 
      1.24423928025188784e-11*V012*V042*V12 - 1.83942195507536128e-12*V043*V12 + 
      2.5529052654857421e-11*V01*V022*V05*V12 + 2.06395758967976596e-11*V012*V03*V05*V12 - 
      9.42960630802113288e-12*V03*V04*V05*V12 - 2.90095001374260037e-12*V02*V052*V12 + 
      1.08881724313547913e-11*V012*V02*V06*V12 - 3.36603551200924369e-12*V032*V06*V12 - 
      4.85085477426325783e-12*V02*V04*V06*V12 - 2.60477467870958926e-12*V01*V05*V06*V12 + 
      1.27177044032302656e-12*V013*V07*V12 - 3.06610095035663138e-12*V02*V03*V07*V12 - 
      1.92812417912411146e-12*V01*V04*V07*V12 + 3.82298429511408287e-14*V072*V12 - 
      6.10756068809190184e-13*V022*V08*V12 - 1.06242185727121409e-12*V01*V03*V08*V12 + 
      6.75539400924665015e-14*V06*V08*V12 - 3.89206143623505356e-13*V01*V02*V09*V12 + 4.72915247454560573e-14*V05*V09*V12 - 
      5.2991199283453253e-14*V012*V10*V12 + 2.52667401380365162e-14*V04*V10*V12 + 1.05459953346924882e-14*V03*V11*V12 + 
      1.4766341583303441e-15*V02*V122 - 7.11555785716754929e-12*V013*V022*V13 - 
      2.46339144768582333e-12*V014*V03*V13 + 5.62440125972049555e-12*V023*V03*V13 + 
      1.46009104023688775e-11*V01*V02*V032*V13 + 1.06921309271487798e-11*V01*V022*V04*V13 + 
      8.6847501660786755e-12*V012*V03*V04*V13 - 1.97549110248894333e-12*V03*V042*V13 + 
      5.3986102204678356e-12*V012*V02*V05*V13 - 1.67557339451327477e-12*V032*V05*V13 - 
      2.42717978677294722e-12*V02*V04*V05*V13 - 6.4764122026905492e-13*V01*V052*V13 + 
      7.22983502990573396e-13*V013*V06*V13 - 1.73922308420895268e-12*V02*V03*V06*V13 - 
      1.09495221645456034e-12*V01*V04*V06*V13 - 3.93396483661090429e-13*V022*V07*V13 - 
      6.81518970387004692e-13*V01*V03*V07*V13 + 4.33824756032214481e-14*V06*V07*V13 - 2.77472319191368747e-13*V01*V02*V08*V13 + 
      3.36948446010558919e-14*V05*V08*V13 - 4.16044141348250533e-14*V012*V09*V13 + 
      1.98581958233045517e-14*V04*V09*V13 + 9.03400927755136257e-15*V03*V10*V13 + 2.74481174903921748e-15*V02*V11*V13 + 
      6.6957340331953677e-16*V01*V12*V13 - 5.94290273566589356e-13*V014*V02*V14 + 
      3.26526205412169494e-13*V024*V14 + 3.53165157621617237e-12*V01*V022*V03*V14 + 
      1.41422904995290895e-12*V012*V032*V14 + 2.1222078205886351e-12*V012*V02*V04*V14 - 
      6.56529547573298755e-13*V032*V04*V14 - 4.72246285669338679e-13*V02*V042*V14 + 
      3.34290021298459873e-13*V013*V05*V14 - 8.09457743294230293e-13*V02*V03*V05*V14 - 
      5.08530535522526643e-13*V01*V04*V05*V14 - 2.07562923318431888e-13*V022*V06*V14 - 
      3.61469907005137093e-13*V01*V03*V06*V14 + 1.14763722080072174e-14*V062*V14 - 
      1.66218031724160062e-13*V01*V02*V07*V14 + 2.01778356332199215e-14*V05*V07*V14 - 
      2.77021573058864015e-14*V012*V08*V14 + 1.3193158382616169e-14*V04*V08*V14 + 6.62064796499135065e-15*V03*V09*V14 + 
      2.19238390252560255e-15*V02*V10*V14 + 5.8025038393457835e-16*V01*V11*V14 - 1.50517840249464591e-18*V142 - 
      1.74791256931349811e-14*V015*V15 + 2.65481762915105492e-13*V01*V023*V15 + 
      6.48795028717106641e-13*V012*V02*V03*V15 - 6.8066566646838548e-14*V033*V15 + 
      1.23328862829272428e-13*V013*V04*V15 - 2.96958128500775342e-13*V02*V03*V04*V15 - 
      9.36089208510382596e-14*V01*V042*V15 - 9.10448282076277624e-14*V022*V05*V15 - 
      1.57393480343731102e-13*V01*V03*V05*V15 - 8.26574011863596269e-14*V01*V02*V06*V15 + 1.00222724476427083e-14*V05*V06*V15 - 
      1.55511745103155895e-14*V012*V07*V15 + 7.41676406594806596e-15*V04*V07*V15 + 
      4.12915890603179722e-15*V03*V08*V15 + 1.50809968969394093e-15*V02*V09*V15 + 4.35022301807857333e-16*V01*V10*V15 - 
      2.82305945583492788e-18*V13*V15 + 7.00422583869988146e-14*V012*V022*V16 + 
      3.52314758148065441e-14*V013*V03*V16 - 4.36975629226566795e-14*V02*V032*V16 - 
      3.12776227931096133e-14*V022*V04*V16 - 5.46391859924164651e-14*V01*V03*V04*V16 - 
      3.39318000839200582e-14*V01*V02*V05*V16 + 2.05813842385241595e-15*V052*V16 - 
      7.29186541920561205e-15*V012*V06*V16 + 3.46486059113790441e-15*V04*V06*V16 + 
      2.18328689576093845e-15*V03*V07*V16 + 8.84553654206952134e-16*V02*V08*V16 + 2.81413332699775377e-16*V01*V09*V16 - 
      2.32407253900997186e-18*V12*V16 + 7.22265459542068317e-15*V013*V02*V17 - 
      8.78123007453968083e-15*V022*V03*V17 - 7.52219119988421526e-15*V01*V032*V17 - 
      1.11206514163389709e-14*V01*V02*V04*V17 - 2.82233898517299869e-15*V012*V05*V17 + 
      1.34680644218868476e-15*V04*V05*V17 + 9.65298560004194491e-16*V03*V06*V17 + 4.42539636628884607e-16*V02*V07*V17 + 
      1.56176711841481682e-16*V01*V08*V17 - 1.67907457044042887e-18*V11*V17 + 2.48797078965430631e-16*V014*V18 - 
      5.5087191625477166e-16*V023*V18 - 2.91318761552249684e-15*V01*V02*V03*V18 - 
      8.80213908158000793e-16*V012*V04*V18 + 2.08558130520634468e-16*V042*V18 + 
      3.55172489983697327e-16*V03*V05*V18 + 1.85183531263893339e-16*V02*V06*V18 + 7.39438321894901071e-17*V01*V07*V18 - 
      1.0599208202361611e-18*V10*V18 - 2.67017067071484894e-16*V01*V022*V19 - 
      2.17131996188012187e-16*V012*V03*V19 + 1.04869644185134165e-16*V03*V04*V19 + 
      6.49398072626889921e-17*V02*V05*V19 + 2.9490651356157321e-17*V01*V06*V19 - 5.83257469694119294e-19*V09*V19 - 
      3.84253266402165086e-17*V012*V02*V20 + 1.25254190812490606e-17*V032*V20 + 
      1.822142416423011e-17*V02*V04*V20 + 9.82353545915093166e-18*V01*V05*V20 - 2.77454967888408531e-19*V08*V20 - 
      1.65864719310287087e-18*V013*V21 + 4.18347680927057431e-18*V02*V03*V21 + 2.64922815565041876e-18*V01*V04*V21 - 
      1.13621569374272333e-19*V07*V21 + 3.31729438620574175e-19*V022*V22 + 5.75919164271830164e-19*V01*V03*V22 - 
      3.94083799893853967e-20*V06*V22 + 8.92151141744726e-20*V01*V02*V23 - 1.15268084351751672e-20*V05*V23 + 
      5.44505391675184883e-21*V012*V24 - 2.73504432370179073e-21*V04*V24 - 5.31988026349318564e-22*V03*V25 - 
      7.30179644008868617e-23*V02*V26 - 8.42514973856386865e-24*V01*V27 + 4.85319685401144508e-27*V30) + 
   delta6*eps12*(5.11979806754947562e-9*V023*V034 + 
      6.28439861063648883e-9*V01*V02*V035 + 6.53023637886137954e-9*V024*V032*V04 + 
      3.49980746918015368e-8*V01*V022*V033*V04 + 8.12007747685893213e-9*V012*V034*V04 + 
      3.28023733515722384e-11*V025*V042 + 1.68287738767928895e-8*V01*V023*V03*V042 + 
      2.86971448111571193e-8*V012*V02*V032*V042 - 1.14011502994645109e-8*V034*V042 + 
      5.31442780537228258e-9*V012*V022*V043 + 3.3217247603230432e-9*V013*V03*V043 - 
      2.44669543095360546e-8*V02*V032*V043 - 2.2483490443839068e-9*V022*V044 - 
      7.44902850484399929e-9*V01*V03*V044 + 1.1932876828753958e-9*V025*V03*V05 + 
      1.75728789142813378e-8*V01*V023*V032*V05 + 1.68148565221743299e-8*V012*V02*V033*V05 - 
      4.1049971768015793e-9*V035*V05 + 3.91814182731682773e-9*V01*V024*V04*V05 + 
      2.92665774374379783e-8*V012*V022*V03*V04*V05 + 8.38741865123177882e-9*V013*V032*V04*V05 - 
      4.74196353548498438e-8*V02*V033*V04*V05 + 5.15464435388368656e-9*V013*V02*V042*V05 - 
      3.63871166639014982e-8*V022*V03*V042*V05 - 4.13378911271000792e-8*V01*V032*V042*V05 - 
      1.50406776685619115e-8*V01*V02*V043*V05 + 2.47093865671367944e-9*V012*V023*V052 + 
      4.35277990005716866e-9*V013*V02*V03*V052 - 
      1.83047795249389219e-8*V022*V032*V052 - 1.22535420198100562e-8*V01*V033*V052 + 
      5.20406508665299024e-10*V014*V04*V052 - 5.92348005622407077e-9*V023*V04*V052 - 
      4.31842619130223981e-8*V01*V02*V03*V04*V052 - 6.14380375992455298e-9*V012*V042*V052 + 
      1.95886723402046206e-9*V043*V052 - 3.72248018267106585e-9*V01*V022*V053 - 
      3.58469188452092172e-9*V012*V03*V053 + 3.71483687960949889e-9*V03*V04*V053 + 
      4.91686207259443451e-10*V02*V054 + 3.53516909891734025e-12*V026*V06 + 
      2.89822592784347662e-9*V01*V024*V03*V06 + 9.8192521769111579e-9*V012*V022*V032*V06 + 
      1.81960754075656323e-9*V013*V033*V06 - 8.34065762220297975e-9*V02*V034*V06 + 
      3.68238259078683943e-9*V012*V023*V04*V06 + 6.78462467642534162e-9*V013*V02*V03*V04*V06 - 
      2.65313239174880345e-8*V022*V032*V04*V06 - 1.91516830337312622e-8*V01*V033*V04*V06 + 
      4.11328034025504827e-10*V014*V042*V06 - 3.16575486934029777e-9*V023*V042*V06 - 
      3.24246916566614558e-8*V01*V02*V03*V042*V06 - 3.19738692173967551e-9*V012*V043*V06 + 
      6.84929102303401647e-10*V044*V06 + 1.75213121024745504e-9*V013*V022*V05*V06 + 
      6.69738984358509069e-10*V014*V03*V05*V06 - 8.7274680127617514e-9*V023*V03*V05*V06 - 
      3.01789381324240246e-8*V01*V02*V032*V05*V06 - 1.62986003298929212e-8*V01*V022*V04*V05*V06 - 
      1.69439953449533837e-8*V012*V03*V04*V05*V06 + 8.53085614730325306e-9*V03*V042*V05*V06 - 
      4.4749593140078434e-9*V012*V02*V052*V06 + 3.97697790915409732e-9*V032*V052*V06 + 
      4.43407216018668314e-9*V02*V04*V052*V06 + 8.43257909093604133e-10*V01*V053*V06 + 
      1.37410959782366922e-10*V014*V02*V062 - 2.77651142359177797e-10*V024*V062 - 
      5.86181969526591239e-9*V01*V022*V03*V062 - 
      2.90489936779296046e-9*V012*V032*V062 - 
      3.47910405228289676e-9*V012*V02*V04*V062 + 3.07630464250431054e-9*V032*V04*V062 + 
      1.53447542271686522e-9*V02*V042*V062 - 5.54327998196170465e-10*V013*V05*V062 + 
      3.22275771746109623e-9*V02*V03*V05*V062 + 1.96603510686366572e-9*V01*V04*V05*V062 + 
      1.90167457525560969e-10*V022*V063 + 4.67302790292369799e-10*V01*V03*V063 - 
      9.74159399052878431e-12*V064 + 1.704696689821994e-10*V01*V025*V07 + 
      2.23064717845634598e-9*V012*V023*V03*V07 + 1.91530648761817301e-9*V013*V02*V032*V07 - 
      5.91122341729889937e-9*V022*V033*V07 - 2.9345597027074377e-9*V01*V034*V07 + 
      1.18110466033672231e-9*V013*V022*V04*V07 + 4.53053758965853336e-10*V014*V03*V04*V07 - 
      5.77498970741263911e-9*V023*V03*V04*V07 - 2.07863171360354468e-8*V01*V02*V032*V04*V07 - 
      5.44857058956791019e-9*V01*V022*V042*V07 - 5.87404784004939108e-9*V012*V03*V042*V07 + 
      1.97545842080561341e-9*V03*V043*V07 + 2.3500403965242191e-10*V014*V02*V05*V07 - 
      6.95192346142862497e-10*V024*V05*V07 - 1.07656539437527827e-8*V01*V022*V03*V05*V07 - 
      5.11715779114514648e-9*V012*V032*V05*V07 - 6.1791537751692598e-9*V012*V02*V04*V05*V07 + 
      5.59153958991555632e-9*V032*V04*V05*V07 + 3.05700850431379675e-9*V02*V042*V05*V07 - 
      4.84061761895630746e-10*V013*V052*V07 + 2.96246128582513109e-9*V02*V03*V052*V07 + 
      1.77927481862708762e-9*V01*V04*V052*V07 + 1.34343265327384121e-11*V015*V06*V07 - 
      1.30512177049964425e-9*V01*V023*V06*V07 - 4.26971068766919061e-9*V012*V02*V03*V06*V07 + 
      1.3270401978967495e-9*V033*V06*V07 - 7.72603172167892948e-10*V013*V04*V06*V07 + 
      4.46415591730487322e-9*V02*V03*V04*V06*V07 + 1.37165986795685994e-9*V01*V042*V06*V07 + 
      1.14508847898528788e-9*V022*V05*V06*V07 + 2.51878644127009434e-9*V01*V03*V05*V06*V07 + 
      5.16319316726959078e-10*V01*V02*V062*V07 - 1.08850614769310101e-10*V05*V062*V07 - 
      3.84773749074983452e-10*V012*V022*V072 - 2.27884497215983798e-10*V013*V03*V072 + 
      7.41772174069159035e-10*V02*V032*V072 + 3.9144279022788022e-10*V022*V04*V072 + 
      8.85677405563816411e-10*V01*V03*V04*V072 + 4.71370770236882858e-10*V01*V02*V05*V072 - 
      4.94855862918812107e-11*V052*V072 + 9.67103795229027201e-11*V012*V06*V072 - 
      7.6625570113420455e-11*V04*V06*V072 - 1.68312526894861991e-11*V03*V073 + 
      1.61156100279536366e-10*V012*V024*V08 + 5.73405955238421412e-10*V013*V022*V03*V08 + 
      1.06432770053926362e-10*V014*V032*V08 - 1.673633831909941e-9*V023*V032*V08 - 
      3.70147417166368546e-9*V01*V02*V033*V08 + 1.36352717407068972e-10*V014*V02*V04*V08 - 
      2.86027394978351203e-10*V024*V04*V08 - 6.16804076535413498e-9*V01*V022*V03*V04*V08 - 
      3.07698365846992364e-9*V012*V032*V04*V08 - 1.83312092233597914e-9*V012*V02*V042*V08 + 
      1.67630450366641758e-9*V032*V042*V08 + 5.5157774023424302e-10*V02*V043*V08 + 
      9.79694205516454494e-12*V015*V05*V08 - 1.0268241252494614e-9*V01*V023*V05*V08 - 
      3.26109401547046174e-9*V012*V02*V03*V05*V08 + 1.02963562449849968e-9*V033*V05*V08 - 
      5.86127182393026158e-10*V013*V04*V05*V08 + 3.50203179509138935e-9*V02*V03*V04*V05*V08 + 
      1.06953985887064151e-9*V01*V042*V05*V08 + 4.51264040776772681e-10*V022*V052*V08 + 
      9.74958549557480348e-10*V01*V03*V052*V08 - 6.61751944627894005e-10*V012*V022*V06*V08 - 
      3.95913008205852347e-10*V013*V03*V06*V08 + 1.26516276710161553e-9*V02*V032*V06*V08 + 
      6.13746680956556656e-10*V022*V04*V06*V08 + 1.52608371743575697e-9*V01*V03*V04*V06*V08 + 
      8.05647184182053699e-10*V01*V02*V05*V06*V08 - 8.51846151754080845e-11*V052*V06*V08 + 
      8.40794836246013737e-11*V012*V062*V08 - 6.4371827522933752e-11*V04*V062*V08 - 
      1.47386887486764788e-10*V013*V02*V07*V08 + 4.53075924877154874e-10*V022*V03*V07*V08 + 
      4.83526849808222882e-10*V01*V032*V07*V08 + 5.59542013331216125e-10*V01*V02*V04*V07*V08 + 
      1.49151659534563166e-10*V012*V05*V07*V08 - 1.20125921231230535e-10*V04*V05*V07*V08 - 
      8.70140862613131953e-11*V03*V06*V07*V08 - 1.62674219902326489e-11*V02*V072*V08 - 
      4.7563091534383478e-12*V014*V082 + 2.02446178250942866e-11*V023*V082 + 
      1.559941386553093e-10*V01*V02*V03*V082 + 4.56477230215849797e-11*V012*V04*V082 - 
      1.77076067842490649e-11*V042*V082 - 3.39867060567049583e-11*V03*V05*V082 - 
      1.3599319053460568e-11*V02*V06*V082 - 5.66297273293752118e-12*V01*V07*V082 + 
      4.98262978091958905e-11*V013*V023*V09 + 5.61403622262468725e-11*V014*V02*V03*V09 - 
      2.01899918293381204e-10*V024*V03*V09 - 1.53316860284183457e-9*V01*V022*V032*V09 - 
      4.77549691948423172e-10*V012*V033*V09 + 4.9842697976512906e-12*V015*V04*V09 - 
      5.14644174798481903e-10*V01*V023*V04*V09 - 1.74223362108663988e-9*V012*V02*V03*V04*V09 + 
      5.67132202535366518e-10*V033*V04*V09 - 1.58258307111341508e-10*V013*V042*V09 + 
      9.38739487460745643e-10*V02*V03*V042*V09 + 1.93317012840331813e-10*V01*V043*V09 - 
      4.54691469248870354e-10*V012*V022*V05*V09 - 2.68115364654485169e-10*V013*V03*V05*V09 + 
      9.02147166076120031e-10*V02*V032*V05*V09 + 4.77820900689788176e-10*V022*V04*V05*V09 + 
      1.07451264921469746e-9*V01*V03*V04*V05*V09 + 2.85961725017197014e-10*V01*V02*V052*V09 - 
      2.02339587700019931e-11*V053*V09 - 1.14219378179443237e-10*V013*V02*V06*V09 + 
      3.50740721736689704e-10*V022*V03*V06*V09 + 3.78863656404391676e-10*V01*V032*V06*V09 + 
      4.34933526502581131e-10*V01*V02*V04*V06*V09 + 1.16892418034049972e-10*V012*V05*V06*V09 - 
      9.41191151745447931e-11*V04*V05*V06*V09 - 3.41386592126541537e-11*V03*V062*V09 - 
      8.48420562756683746e-12*V014*V07*V09 + 4.01108025868168489e-11*V023*V07*V09 + 
      2.83803228930310805e-10*V01*V02*V03*V07*V09 + 8.22932008262253215e-11*V012*V04*V07*V09 - 
      3.30369962928504209e-11*V042*V07*V09 - 6.19049816386646244e-11*V03*V05*V07*V09 - 
      2.54234090504837223e-11*V02*V06*V07*V09 - 5.14561535828993438e-12*V01*V072*V09 + 
      4.38188657597689247e-11*V01*V022*V08*V09 + 4.42347429883074868e-11*V012*V03*V08*V09 - 
      3.76567929567064099e-11*V03*V04*V08*V09 - 1.99748141911944075e-11*V02*V05*V08*V09 - 
      8.89594472467524737e-12*V01*V06*V08*V09 + 6.53698262961084901e-12*V012*V02*V092 - 
      4.82472953064684911e-12*V032*V092 - 5.44781387945981346e-12*V02*V04*V092 - 
      3.14651554524169159e-12*V01*V05*V092 + 1.07575291861976373e-13*V08*V092 + 
      6.56127536018746889e-12*V014*V022*V10 - 6.28774044833033701e-12*V025*V10 + 
      1.79296987110024606e-12*V015*V03*V10 - 2.41757644247508925e-10*V01*V023*V03*V10 - 
      3.68971152625495764e-10*V012*V02*V032*V10 + 6.36323062085581609e-11*V034*V10 - 
      2.16798786742613556e-10*V012*V022*V04*V10 - 1.30720790092825723e-10*V013*V03*V04*V10 + 
      4.38357008930931796e-10*V02*V032*V04*V10 + 1.0446570949042646e-10*V022*V042*V10 + 
      2.64822088351250341e-10*V01*V03*V042*V10 - 6.98241988643341569e-11*V013*V02*V05*V10 + 
      2.26747723384300617e-10*V022*V03*V05*V10 + 2.38870613282232708e-10*V01*V032*V05*V10 + 
      2.78428969089413285e-10*V01*V02*V04*V05*V10 + 3.67017671466749688e-11*V012*V052*V10 - 
      3.02380994200035547e-11*V04*V052*V10 - 5.9430069882674303e-12*V014*V06*V10 + 
      2.56284495868919324e-11*V023*V06*V10 + 1.98967827109950021e-10*V01*V02*V03*V06*V10 + 
      5.8256138568474289e-11*V012*V04*V06*V10 - 2.27353181971655497e-11*V042*V06*V10 - 
      4.3724148612602726e-11*V03*V05*V06*V10 - 8.72301578279986702e-12*V02*V062*V10 + 
      3.59582341691263453e-11*V01*V022*V07*V10 + 3.60209595550557504e-11*V012*V03*V07*V10 - 
      3.08701492905044799e-11*V03*V04*V07*V10 - 1.6400310605246681e-11*V02*V05*V07*V10 - 
      7.28110082862992133e-12*V01*V06*V07*V10 + 1.18147269427759815e-11*V012*V02*V08*V10 - 
      8.68518815762356603e-12*V032*V08*V10 - 9.56691528282165788e-12*V02*V04*V08*V10 - 
      5.66887034209853768e-12*V01*V05*V08*V10 + 9.62247634512707986e-14*V082*V10 + 
      1.04787292123532807e-12*V013*V09*V10 - 5.12984446506550949e-12*V02*V03*V09*V10 - 
      3.14826839683573533e-12*V01*V04*V09*V10 + 1.76413003057521021e-13*V07*V09*V10 - 
      3.19252624712480135e-13*V022*V102 - 7.15818092995833094e-13*V01*V03*V102 + 
      6.20539464634700527e-14*V06*V102 + 3.78067014992252924e-13*V015*V02*V11 - 
      1.19717337164059396e-11*V01*V024*V11 - 8.46960314502890135e-11*V012*V022*V03*V11 - 
      2.44333268665229764e-11*V013*V032*V11 + 6.15338385818178016e-11*V02*V033*V11 - 
      3.08448921279165463e-11*V013*V02*V04*V11 + 9.89506946202887356e-11*V022*V03*V04*V11 + 
      1.08874762208412445e-10*V01*V032*V04*V11 + 6.1640059570193134e-11*V01*V02*V042*V11 - 
      3.28346763377738487e-12*V014*V05*V11 + 1.65657775138424744e-11*V023*V05*V11 + 
      1.16013706631553032e-10*V01*V02*V03*V05*V11 + 3.35097210103525611e-11*V012*V04*V05*V11 - 
      1.3775121634296125e-11*V042*V05*V11 - 1.28639116910717489e-11*V03*V052*V11 + 
      2.29290783794404451e-11*V01*V022*V06*V11 + 2.33583671552289551e-11*V012*V03*V06*V11 - 
      2.00275499582776916e-11*V03*V04*V06*V11 - 1.05972587995833547e-11*V02*V05*V06*V11 - 
      2.36722937397376589e-12*V01*V062*V11 + 8.81100105228480801e-12*V012*V02*V07*V11 - 
      6.5419696088928592e-12*V032*V07*V11 - 7.39754261427104556e-12*V02*V04*V07*V11 - 
      4.2642394709697889e-12*V01*V05*V07*V11 + 8.67444323067818835e-13*V013*V08*V11 - 
      4.24148487064918072e-12*V02*V03*V08*V11 - 2.60631376470732166e-12*V01*V04*V08*V11 + 1.46154500206913671e-13*V07*V08*V11 - 
      6.01627874460204652e-13*V022*V09*V11 - 1.31544886072074995e-12*V01*V03*V09*V11 + 
      1.14951150502220865e-13*V06*V09*V11 - 3.52765740749065523e-13*V01*V02*V10*V11 + 7.38298834827120743e-14*V05*V10*V11 - 
      2.16031149964390739e-14*V012*V112 + 1.70547328854261923e-14*V04*V112 + 
      7.76850030805999158e-15*V016*V12 - 5.80492553852773915e-12*V012*V023*V12 - 
      1.06214388878599787e-11*V013*V02*V03*V12 + 1.97197142892801617e-11*V022*V032*V12 + 
      1.35352057718260657e-11*V01*V033*V12 - 1.33915997810440822e-12*V014*V04*V12 + 
      6.01591230281355151e-12*V023*V04*V12 + 4.7889397352850306e-11*V01*V02*V03*V04*V12 + 
      7.02444858191099965e-12*V012*V042*V12 - 1.87036436876604568e-12*V043*V12 + 
      1.24670955283429506e-11*V01*V022*V05*V12 + 1.23472438047503549e-11*V012*V03*V05*V12 - 
      1.08735697945315405e-11*V03*V04*V05*V12 - 2.89291843869845839e-12*V02*V052*V12 + 
      5.24950725762423915e-12*V012*V02*V06*V12 - 3.91570200497004835e-12*V032*V06*V12 - 
      4.29197145083369922e-12*V02*V04*V06*V12 - 2.55405751841666671e-12*V01*V05*V06*V12 + 
      5.94197492894031914e-13*V013*V07*V12 - 2.94768185112356462e-12*V02*V03*V07*V12 - 
      1.80584512202607689e-12*V01*V04*V07*V12 + 5.07296905825507555e-14*V072*V12 - 
      4.46579170970001173e-13*V022*V08*V12 - 1.00327225406175927e-12*V01*V03*V08*V12 + 
      8.70451114595495944e-14*V06*V08*V12 - 2.98609512458644278e-13*V01*V02*V09*V12 + 6.25058680994150899e-14*V05*V09*V12 - 
      3.98329661776719889e-14*V012*V10*V12 + 3.11752051737664818e-14*V04*V10*V12 + 
      1.34757903197493909e-14*V03*V11*V12 + 1.5242600261923723e-15*V02*V122 - 
      1.05457391681914386e-12*V013*V022*V13 - 4.1561476648120955e-13*V014*V03*V13 + 
      2.46716357999120439e-12*V023*V03*V13 + 8.4271512529546842e-12*V01*V02*V032*V13 + 
      4.64959415930984757e-12*V01*V022*V04*V13 + 4.81392178513526814e-12*V012*V03*V04*V13 - 
      2.121851497377257e-12*V03*V042*V13 + 2.58010539095283279e-12*V012*V02*V05*V13 - 
      1.96569597824408638e-12*V032*V05*V13 - 2.23359220316250296e-12*V02*V04*V05*V13 - 
      6.39027559710706371e-13*V01*V052*V13 + 3.2953117820731517e-13*V013*V06*V13 - 
      1.62961536632294704e-12*V02*V03*V06*V13 - 1.00300437532686563e-12*V01*V04*V06*V13 - 
      2.95880855578268284e-13*V022*V07*V13 - 6.44690952420211278e-13*V01*V03*V07*V13 + 
      5.65583100846434713e-14*V06*V07*V13 - 2.11163145684643087e-13*V01*V02*V08*V13 + 4.43021613255248087e-14*V05*V08*V13 - 
      3.12441950867249054e-14*V012*V09*V13 + 2.47039189381940438e-14*V04*V09*V13 + 
      1.15280407549107147e-14*V03*V10*V13 + 2.85359927240368288e-15*V02*V11*V13 + 6.96948686726006253e-16*V01*V12*V13 - 
      7.76850030805999158e-14*V014*V02*V14 + 9.40120931201604073e-14*V024*V14 + 
      1.57530362297593423e-12*V01*V022*V03*V14 + 7.61492253441465227e-13*V012*V032*V14 + 
      9.2858843731490628e-13*V012*V02*V04*V14 - 7.21538883562920543e-13*V032*V04*V14 - 
      3.90055797864802146e-13*V02*V042*V14 + 1.49319909022559885e-13*V013*V05*V14 - 
      7.69518552471470787e-13*V02*V03*V05*V14 - 4.69609309231927464e-13*V01*V04*V05*V14 - 
      1.48032747489434744e-13*V022*V06*V14 - 3.3506035137855168e-13*V01*V03*V06*V14 + 
      1.45962351557873286e-14*V062*V14 - 1.26969285076618503e-13*V01*V02*V07*V14 + 
      2.66592566671645643e-14*V05*V07*V14 - 2.06883186243081459e-14*V012*V08*V14 + 
      1.62116115495872565e-14*V04*V08*V14 + 8.45993826501182513e-15*V03*V09*V14 + 2.26003067224343582e-15*V02*V10*V14 + 
      6.04094333616496415e-16*V01*V11*V14 - 2.00270726228861898e-18*V142 - 1.9421250770149979e-15*V015*V15 + 
      8.68225295600984184e-14*V01*V023*V15 + 2.77836472974131076e-13*V012*V02*V03*V15 - 
      7.55807605983034929e-14*V033*V15 + 5.0945599846335452e-14*V013*V04*V15 - 
      2.60303008435242253e-13*V02*V03*V04*V15 - 8.03462851894543522e-14*V01*V042*V15 - 
      6.77323235479431739e-14*V022*V05*V15 - 1.4623953982237985e-13*V01*V03*V05*V15 - 
      6.14571865194268863e-14*V01*V02*V06*V15 + 1.3005073880775731e-14*V05*V06*V15 - 
      1.15858695629143599e-14*V012*V07*V15 + 9.21976298918643866e-15*V04*V07*V15 + 
      5.24658998541442498e-15*V03*V08*V15 + 1.56728430766123504e-15*V02*V09*V15 + 4.52070968700141329e-16*V01*V10*V15 - 
      3.76401171276961936e-18*V13*V15 + 2.32351340735634893e-14*V012*V022*V16 + 
      1.38693062565092785e-14*V013*V03*V16 - 3.92994616343351408e-14*V02*V032*V16 - 
      2.06111743188892094e-14*V022*V04*V16 - 4.74978352666795154e-14*V01*V03*V04*V16 - 
      2.54617947711181351e-14*V01*V02*V05*V16 + 2.70437149860113534e-15*V052*V16 - 
      5.32649917667271211e-15*V012*V06*V16 + 4.19608175913933472e-15*V04*V06*V16 + 
      2.78561256612454225e-15*V03*V07*V16 + 9.0681178229854095e-16*V02*V08*V16 + 2.9268286813651306e-16*V01*V09*V16 - 
      3.09136437900701946e-18*V12*V16 + 2.2634670281636147e-15*V013*V02*V17 - 
      6.17770127909519067e-15*V022*V03*V17 - 6.53047934152318814e-15*V01*V032*V17 - 
      7.67783317950771849e-15*V01*V02*V04*V17 - 2.0511501350392163e-15*V012*V05*V17 + 
      1.66542502867832306e-15*V04*V05*V17 + 1.20968981248612763e-15*V03*V06*V17 + 4.59361781662771704e-16*V02*V07*V17 + 
      1.61506163075077877e-16*V01*V08*V17 - 2.23869853224362068e-18*V11*V17 + 7.0366850616485431e-17*V014*V18 - 
      2.84125705711453396e-16*V023*V18 - 2.0406386678780775e-15*V01*V02*V03*V18 - 
      5.98352786408847782e-16*V012*V04*V18 + 2.39743769319844557e-16*V042*V18 + 
      4.49730179367873164e-16*V03*V05*V18 + 1.8656693397329227e-16*V02*V06*V18 + 7.66568652077034898e-17*V01*V07*V18 - 
      1.40818661755944889e-18*V10*V18 - 1.45659380776124842e-16*V01*V022*V19 - 
      1.45307546523042415e-16*V012*V03*V19 + 1.24989118407532247e-16*V03*V04*V19 + 
      6.69560129963252344e-17*V02*V05*V19 + 3.00247453260576178e-17*V01*V06*V19 - 7.77609064581874575e-19*V09*V19 - 
      2.07347653149910403e-17*V012*V02*V20 + 1.52043457177860856e-17*V032*V20 + 
      1.73045010189520295e-17*V02*V04*V20 + 1.006317766724534e-17*V01*V05*V20 - 3.67331530825485335e-19*V08*V20 - 
      8.44402207397825172e-19*V013*V21 + 4.13600710845786589e-18*V02*V03*V21 + 2.55163603545017408e-18*V01*V04*V21 - 
      1.5142786415541196e-19*V07*V21 + 2.56336384388625499e-19*V022*V22 + 5.59584002521574618e-19*V01*V03*V22 - 
      5.15649425762435032e-20*V06*V22 + 7.0366850616485431e-20*V01*V02*V23 - 1.53015162366157393e-20*V05*V23 + 
      4.18850301288603756e-21*V012*V24 - 3.42109223098484861e-21*V04*V24 - 6.83640721643468199e-22*V03*V25 - 
      7.6495010324738617e-23*V02*V26 - 8.82634734516214811e-24*V01*V27 + 6.47092913868192677e-27*V30) + 
   delta2*eps14*(-6.77936059264516573e-13*V028 - 1.48040897261592484e-8*V01*V026*V03 - 
      1.0920431292139003e-7*V012*V024*V032 - 
      1.07964182500246926e-7*V013*V022*V033 - 8.92507451554681558e-9*V014*V034 + 
      7.16508135962120041e-8*V023*V034 + 7.57774721395485856e-8*V01*V02*V035 - 
      2.96224161095630517e-8*V012*V025*V04 - 1.4644677288380603e-7*V013*V023*V03*V04 - 
      7.2639238722338629e-8*V014*V02*V032*V04 + 1.2940615229427052e-7*V024*V032*V04 + 
      5.05016599550344609e-7*V01*V022*V033*V04 + 1.03441260132924524e-7*V012*V034*V04 - 
      2.46279691325938992e-8*V014*V022*V042 + 1.18453251754498057e-8*V025*V042 - 
      6.12267071585173826e-9*V015*V03*V042 + 3.22712172227540327e-7*V01*V023*V03*V042 + 
      4.25770866093976561e-7*V012*V02*V032*V042 - 3.30997366463326056e-8*V034*V042 + 
      9.65038343425999201e-8*V012*V022*V043 + 5.06341396258389646e-8*V013*V03*V043 - 
      8.6350273137192877e-8*V02*V032*V043 - 1.26192122113177278e-8*V022*V044 - 
      2.64956794647521221e-8*V01*V03*V044 - 1.88743499761483344e-8*V013*V024*V05 - 
      3.74446296044101833e-8*V014*V022*V03*V05 + 2.63101690059325117e-8*V025*V03*V05 - 
      4.65396263472438387e-9*V015*V032*V05 + 2.76000471266865928e-7*V01*V023*V032*V05 + 
      2.32938477713765083e-7*V012*V02*V033*V05 - 1.12923567412594535e-8*V035*V05 - 
      6.30933179733950042e-9*V015*V02*V04*V05 + 8.41258680984350279e-8*V01*V024*V04*V05 + 
      4.7303392047082652e-7*V012*V022*V03*V04*V05 + 1.22747958597260093e-7*V013*V032*V04*V05 - 
      1.50625866327595507e-7*V02*V033*V04*V05 + 8.56954301256626993e-8*V013*V02*V042*V05 - 
      1.43644128220758013e-7*V022*V03*V042*V05 - 1.35481906677124622e-7*V01*V032*V042*V05 - 
      5.97025578326132457e-8*V01*V02*V043*V05 - 1.6179936498758472e-10*V016*V052 + 
      4.30610085160696067e-8*V012*V023*V052 + 
      6.89960454252874742e-8*V013*V02*V03*V052 - 
      6.35442194507606639e-8*V022*V032*V052 - 3.81480440064081809e-8*V01*V033*V052 + 
      8.73826353934827941e-9*V014*V04*V052 - 2.60823277846440233e-8*V023*V04*V052 - 
      1.54285479010351589e-7*V01*V02*V03*V04*V052 - 2.25413187427161668e-8*V012*V042*V052 + 
      3.90532729857493823e-9*V043*V052 - 1.44700335087487811e-8*V01*V022*V053 - 
      1.2548990277193841e-8*V012*V03*V053 + 6.82133692581095513e-9*V03*V04*V053 + 
      9.76207031356627678e-10*V02*V054 - 5.19540431859526164e-9*V014*V023*V06 + 
      1.38886154515450825e-9*V026*V06 - 3.8735695758921716e-9*V015*V02*V03*V06 + 
      6.05037934744465566e-8*V01*V024*V03*V06 + 1.62813979656106218e-7*V012*V022*V032*V06 + 
      2.77706287178561103e-8*V013*V033*V06 - 2.68152680018224238e-8*V02*V034*V06 - 
      2.61381180936503065e-10*V016*V04*V06 + 7.28294581997430096e-8*V012*V023*V04*V06 + 
      1.1605961161004761e-7*V013*V02*V03*V04*V06 - 1.03812989500712505e-7*V022*V032*V04*V06 - 
      6.37045359727982307e-8*V01*V033*V04*V06 + 7.32743954930033309e-9*V014*V042*V06 - 
      1.98537041988457781e-8*V023*V042*V06 - 1.27794949774625604e-7*V01*V02*V03*V042*V06 - 
      1.26114910845384246e-8*V012*V043*V06 + 1.57281609314195526e-9*V044*V06 + 
      3.23875808705728429e-8*V013*V022*V05*V06 + 1.17184474854237752e-8*V014*V03*V05*V06 - 
      3.80028671413827997e-8*V023*V03*V05*V06 - 1.09151784957895969e-7*V01*V02*V032*V05*V06 - 
      7.13545647343056767e-8*V01*V022*V04*V05*V06 - 6.31167276173674111e-8*V012*V03*V04*V05*V06 + 
      1.68878402086659347e-8*V03*V042*V05*V06 - 1.80483951533649046e-8*V012*V02*V052*V06 + 
      7.32499751470139244e-9*V032*V052*V06 + 9.60483973802659006e-9*V02*V04*V052*V06 + 
      1.7207268319421702e-9*V01*V053*V06 + 2.754461247299629e-9*V014*V02*V062 - 
      1.93139129787781293e-9*V024*V062 - 2.54888909561111366e-8*V01*V022*V03*V062 - 
      1.10211399583123908e-8*V012*V032*V062 - 
      1.51314059819809196e-8*V012*V02*V04*V062 + 6.06637024576421478e-9*V032*V04*V062 + 
      3.8565665577134839e-9*V02*V042*V062 - 2.33763648977358349e-9*V013*V05*V062 + 
      6.93392617221292808e-9*V02*V03*V05*V062 + 4.29258599213449928e-9*V01*V04*V05*V062 + 
      5.22374495747423834e-10*V022*V063 + 1.01967876714698683e-9*V01*V03*V063 - 
      1.61981873814974697e-11*V064 - 6.76014896807380468e-10*V015*V022*V07 + 
      4.33593802567739913e-9*V01*V025*V07 - 1.34612573338063534e-10*V016*V03*V07 + 
      4.29779447460624464e-8*V012*V023*V03*V07 + 3.38617434007307793e-8*V013*V02*V032*V07 - 
      2.19839631920941821e-8*V022*V033*V07 - 9.78909311560696705e-9*V01*V034*V07 + 
      2.35149281507133859e-8*V013*V022*V04*V07 + 8.47854989254558951e-9*V014*V03*V04*V07 - 
      2.73069340166947404e-8*V023*V03*V04*V07 - 7.9489428303064087e-8*V01*V02*V032*V04*V07 - 
      2.5800452177153592e-8*V01*V022*V042*V07 - 2.30477711618587558e-8*V012*V03*V042*V07 + 
      4.09879309868663075e-9*V03*V043*V07 + 4.75385163937119807e-9*V014*V02*V05*V07 - 
      3.64980746805947723e-9*V024*V05*V07 - 4.48016354102446272e-8*V01*V022*V03*V05*V07 - 
      1.91957479173865686e-8*V012*V032*V05*V07 - 2.6321071798170227e-8*V012*V02*V04*V05*V07 + 
      1.07016491827136303e-8*V032*V04*V05*V07 + 6.97162671891715349e-9*V02*V042*V05*V07 - 
      2.02895847836695065e-9*V013*V052*V07 + 6.13683665942584858e-9*V02*V03*V052*V07 + 
      3.77504031698813832e-9*V01*V04*V052*V07 + 3.00013932968485403e-10*V015*V06*V07 - 
      6.77525654269573126e-9*V01*V023*V06*V07 - 1.84281357169532686e-8*V012*V02*V03*V06*V07 + 
      2.55043702902929874e-9*V033*V06*V07 - 3.41800311567959914e-9*V013*V04*V06*V07 + 
      1.0085871061286609e-8*V02*V03*V04*V06*V07 + 3.13455186563870756e-9*V01*V042*V06*V07 + 
      2.83842094588102551e-9*V022*V05*V06*V07 + 5.3701181453537078e-9*V01*V03*V05*V06*V07 + 
      1.28296863415100783e-9*V01*V02*V062*V07 - 1.72806439901323266e-10*V05*V062*V07 - 
      1.89915492800495541e-9*V012*V022*V072 - 1.0244667592580363e-9*V013*V03*V072 + 
      1.60608676981416515e-9*V02*V032*V072 + 1.02721000574645548e-9*V022*V04*V072 + 
      1.96454191897263409e-9*V01*V03*V04*V072 + 1.13026648804552892e-9*V01*V02*V05*V072 - 
      7.6328448375778562e-11*V052*V072 + 2.3815653771309217e-10*V012*V06*V072 - 
      1.26247187420585492e-10*V04*V06*V072 - 2.6781123079734594e-11*V03*V073 - 
      4.04428126037603162e-11*V016*V02*V08 + 3.70619912339080818e-9*V012*V024*V08 + 
      1.20260728100298047e-8*V013*V022*V03*V08 + 2.15443241954833434e-9*V014*V032*V08 - 
      7.71747719679084377e-9*V023*V032*V08 - 1.44395558776375155e-8*V01*V02*V033*V08 + 
      3.02428678807099327e-9*V014*V02*V04*V08 - 2.15236742635870427e-9*V024*V04*V08 - 
      2.86230162779463422e-8*V01*V022*V03*V04*V08 - 1.23979177772740746e-8*V012*V032*V04*V08 - 
      8.50286385362641119e-9*V012*V02*V042*V08 + 3.43557114958981696e-9*V032*V042*V08 + 
      1.45164007832770004e-9*V02*V043*V08 + 2.27482774949404145e-10*V015*V05*V08 - 
      5.2602606225267868e-9*V01*V023*V05*V08 - 1.4191644784518425e-8*V012*V02*V03*V05*V08 + 
      1.97693136346455981e-9*V033*V05*V08 - 2.62535428067254653e-9*V013*V04*V05*V08 + 
      7.84435726611310563e-9*V02*V03*V04*V05*V08 + 2.43079260218527503e-9*V01*V042*V05*V08 + 
      1.10593892775909009e-9*V022*V052*V08 + 2.07867591963896903e-9*V01*V03*V052*V08 - 
      3.3660280812323271e-9*V012*V022*V06*V08 - 1.81316226771450397e-9*V013*V03*V06*V08 + 
      2.82333895319990764e-9*V02*V032*V06*V08 + 1.76789753886470859e-9*V022*V04*V06*V08 + 
      3.46571021569908854e-9*V01*V03*V04*V06*V08 + 1.99041597847113882e-9*V01*V02*V05*V06*V08 - 
      1.34333730514286088e-10*V052*V06*V08 + 2.10717422450450759e-10*V012*V062*V08 - 
      1.10394309545070329e-10*V04*V062*V08 - 7.59700899347595125e-10*V013*V02*V07*V08 + 
      1.1623311866377635e-9*V022*V03*V07*V08 + 1.07988656194421328e-9*V01*V032*V07*V08 + 
      1.4516277931883932e-9*V01*V02*V04*V07*V08 + 3.68058935720497847e-10*V012*V05*V07*V08 - 
      1.96387338771770464e-10*V04*V05*V07*V08 - 1.41486611519128464e-10*V03*V06*V07*V08 - 
      2.97897738597556043e-11*V02*V072*V08 - 2.6304195850885473e-11*V014*V082 + 
      6.69250966893665661e-11*V023*V082 + 4.01963981237859868e-10*V01*V02*V03*V082 + 
      1.19344716084984716e-10*V012*V04*V082 - 3.13507667480873498e-11*V042*V082 - 
      5.49646827795237187e-11*V03*V05*V082 - 2.60236645579306164e-11*V02*V06*V082 - 
      1.04049193000107398e-11*V01*V07*V082 - 8.8560903511883904e-13*V017*V09 + 
      1.26348276242485571e-9*V013*V023*V09 + 1.36659295722797768e-9*V014*V02*V03*V09 - 
      1.17867330162185437e-9*V024*V03*V09 - 7.06709184954519616e-9*V01*V022*V032*V09 - 
      1.98966279088787719e-9*V012*V033*V09 + 1.28624502322035063e-10*V015*V04*V09 - 
      2.99767945928471044e-9*V01*V023*V04*V09 - 8.21467894032972682e-9*V012*V02*V03*V04*V09 + 
      1.14767620547007992e-9*V033*V04*V09 - 7.61934606059657645e-10*V013*V042*V09 + 
      2.25942171059143868e-9*V02*V03*V042*V09 + 4.69453392948443198e-10*V01*V043*V09 - 
      2.32137801159080445e-9*V012*V022*V05*V09 - 1.24889421106117333e-9*V013*V03*V05*V09 + 
      1.97845454436777427e-9*V02*V032*V05*V09 + 1.26790266671206678e-9*V022*V04*V05*V09 + 
      2.4168111085869988e-9*V01*V03*V04*V05*V09 + 6.95470218757794505e-10*V01*V02*V052*V09 - 
      3.13955417032004739e-11*V053*V09 - 6.03075372380114091e-10*V013*V02*V06*V09 + 
      9.20556279457317563e-10*V022*V03*V06*V09 + 8.58027639641721463e-10*V01*V032*V06*V09 + 
      1.15164715012412271e-9*V01*V02*V04*V06*V09 + 2.92551756297764259e-10*V012*V05*V06*V09 - 
      1.5587211714914697e-10*V04*V05*V06*V09 - 5.61799912315210078e-11*V03*V062*V09 - 
      4.71894390005186623e-11*V014*V07*V09 + 1.23183751740294702e-10*V023*V07*V09 + 
      7.24053685037420673e-10*V01*V02*V03*V07*V09 + 2.14416071472199152e-10*V012*V04*V07*V09 - 
      5.69109190781872441e-11*V042*V07*V09 - 9.91441248502297078e-11*V03*V05*V07*V09 - 
      4.72626720917242638e-11*V02*V06*V07*V09 - 9.37359839638285725e-12*V01*V072*V09 + 
      1.32215555519699599e-10*V01*V022*V08*V09 + 1.16668487953866229e-10*V012*V03*V08*V09 - 
      6.38887627485246274e-11*V03*V04*V08*V09 - 3.67997757187780279e-11*V02*V05*V08*V09 - 
      1.65412582801487421e-11*V01*V06*V08*V09 + 1.96601932915358918e-11*V012*V02*V092 - 
      8.04602612395276514e-12*V032*V092 - 1.06428913065741181e-11*V02*V04*V092 - 
      5.78054069214448597e-12*V01*V05*V092 + 1.62632558940427334e-13*V08*V092 + 
      1.9412705419811113e-10*V014*V022*V10 - 5.89145968178609168e-11*V025*V10 + 
      5.19246560590729837e-11*V015*V03*V10 - 1.36312053847988926e-9*V01*V023*V03*V10 - 
      1.79732212015054018e-9*V012*V02*V032*V10 + 1.29601038036394919e-10*V034*V10 - 
      1.22012956609610616e-9*V012*V022*V04*V10 - 6.57258348854173704e-10*V013*V03*V04*V10 + 
      1.03588313558849776e-9*V02*V032*V04*V10 + 3.2271738633025647e-10*V022*V042*V10 + 
      6.3658428055647338e-10*V01*V03*V042*V10 - 3.765897500234988e-10*V013*V02*V05*V10 + 
      5.86238396084506771e-10*V022*V03*V05*V10 + 5.42017894611096117e-10*V01*V032*V05*V10 + 
      7.30121262429277007e-10*V01*V02*V04*V05*V10 + 9.22147741274854067e-11*V012*V052*V10 - 
      4.95502197888923637e-11*V04*V052*V10 - 3.39419945042495016e-11*V014*V06*V10 + 
      8.66163518400452365e-11*V023*V06*V10 + 5.21265209735285932e-10*V01*V02*V03*V06*V10 + 
      1.54798501770924273e-10*V012*V04*V06*V10 - 4.06784605136035292e-11*V042*V06*V10 - 
      7.13592261235662384e-11*V03*V05*V06*V10 - 1.68821023675533033e-11*V02*V062*V10 + 
      1.08049422230365136e-10*V01*V022*V07*V10 + 9.51787234038196936e-11*V012*V03*V07*V10 - 
      5.22225283382564195e-11*V03*V04*V07*V10 - 3.0094626591773042e-11*V02*V05*V07*V10 - 
      1.35129524767109043e-11*V01*V06*V07*V10 + 3.57152687395549535e-11*V012*V02*V08*V10 - 
      1.45855281201946647e-11*V032*V08*V10 - 1.91696225099222167e-11*V02*V04*V08*V10 - 
      1.04839019807551887e-11*V01*V05*V08*V10 + 1.4713929172631016e-13*V082*V10 + 
      3.27819589554603023e-12*V013*V09*V10 - 9.80933643597082688e-12*V02*V03*V09*V10 - 
      6.11262980200101886e-12*V01*V04*V09*V10 + 2.65918018350277643e-13*V07*V09*V10 - 
      7.28143247993447997e-13*V022*V102 - 1.38379506279499121e-12*V01*V03*V102 + 
      9.56054332045064385e-14*V06*V102 + 1.32957882772446756e-11*V015*V02*V11 - 
      8.68807341148996196e-11*V01*V024*V11 - 4.88946218755240774e-10*V012*V022*V03*V11 - 
      1.29527858681071958e-10*V013*V032*V11 + 1.44206716454350163e-10*V02*V033*V11 - 
      1.81419637337055474e-10*V013*V02*V04*V11 + 2.79732194370144444e-10*V022*V03*V04*V11 + 
      2.62230714485338964e-10*V01*V032*V04*V11 + 1.75445358954831996e-10*V01*V02*V042*V11 - 
      1.93660851697481006e-11*V014*V05*V11 + 5.16989741219468034e-11*V023*V05*V11 + 
      3.02356972436665113e-10*V01*V02*V03*V05*V11 + 8.93626099442325906e-11*V012*V04*V05*V11 - 
      2.38801446825827763e-11*V042*V05*V11 - 2.07784261180881639e-11*V03*V052*V11 + 
      7.11866337992756831e-11*V01*V022*V06*V11 + 6.29234847190653318e-11*V012*V03*V06*V11 - 
      3.44669003995249385e-11*V03*V04*V06*V11 - 1.98395331355610534e-11*V02*V05*V06*V11 - 
      4.46521002108368282e-12*V01*V062*V11 + 2.66763769286107457e-11*V012*V02*V07*V11 - 
      1.09315029182250901e-11*V032*V07*V11 - 1.44657640966603623e-11*V02*V04*V07*V11 - 
      7.85227128068329769e-12*V01*V05*V07*V11 + 2.72634164282573239e-12*V013*V08*V11 - 
      8.15182677906967336e-12*V02*V03*V08*V11 - 5.08212081601418996e-12*V01*V04*V08*V11 + 2.21038981336943604e-13*V07*V08*V11 - 
      1.34370108884726639e-12*V022*V09*V11 - 2.5371484700633984e-12*V01*V03*V09*V11 + 
      1.75676362412669289e-13*V06*V09*V11 - 7.79611618767132229e-13*V01*V02*V10*V11 + 1.11766482746642467e-13*V05*V10*V11 - 
      4.83756686640468386e-14*V012*V112 + 2.70814602647639111e-14*V04*V112 + 
      3.26277012938519646e-13*V016*V12 - 4.02756511239172396e-11*V012*V023*V12 - 
      6.57591528398230099e-11*V013*V02*V03*V12 + 5.44939173456632224e-11*V022*V032*V12 + 
      3.30799528352632082e-11*V01*V033*V12 - 8.57822774195545892e-12*V014*V04*V12 + 
      2.21675498707230582e-11*V023*V04*V12 + 1.34501481579439527e-10*V01*V02*V03*V04*V12 + 
      1.99894366419085294e-11*V012*V042*V12 - 3.51285763980346816e-12*V043*V12 + 
      3.82125520792679901e-11*V01*V022*V05*V12 + 3.35204196381054197e-11*V012*V03*V05*V12 - 
      1.85276925409456902e-11*V03*V04*V05*V12 - 5.34314323034669448e-12*V02*V052*V12 + 
      1.62804051213802143e-11*V012*V02*V06*V12 - 6.66003485802059185e-12*V032*V06*V12 - 
      8.74143070000553672e-12*V02*V04*V06*V12 - 4.78773954294365829e-12*V01*V05*V06*V12 + 
      1.8785836646914791e-12*V013*V07*V12 - 5.63893970098855739e-12*V02*V03*V07*V12 - 
      3.51171089485861346e-12*V01*V04*V07*V12 + 7.64176113497140217e-14*V072*V12 - 
      1.02349834383406234e-12*V022*V08*V12 - 1.94627804910327678e-12*V01*V03*V08*V12 + 
      1.34421930926666523e-13*V06*V08*V12 - 6.5937823064122352e-13*V01*V02*V09*V12 + 9.45263141379961822e-14*V05*V09*V12 - 
      8.92900822274547796e-14*V012*V10*V12 + 4.98582285777993878e-14*V04*V10*V12 + 
      2.10554191507460786e-14*V03*V11*V12 + 2.73367901264936733e-15*V02*V122 - 
      7.67883886700446585e-12*V013*V022*V13 - 2.84812642544249441e-12*V014*V03*V13 + 
      8.28486616371376446e-12*V023*V03*V13 + 2.37708585199823394e-11*V01*V02*V032*V13 + 
      1.56915366812789102e-11*V01*V022*V04*V13 + 1.39250811534182378e-11*V012*V03*V04*V13 - 
      3.8317759348780895e-12*V03*V042*V13 + 8.05162484985795154e-12*V012*V02*V05*V13 - 
      3.32098005943193082e-12*V032*V05*V13 - 4.40302957590590206e-12*V02*V04*V05*V13 - 
      1.19163275497142891e-12*V01*V052*V13 + 1.0645704326658664e-12*V013*V06*V13 - 
      3.18661047020081131e-12*V02*V03*V06*V13 - 1.98819927437716755e-12*V01*V04*V06*V13 - 
      6.61923698739859333e-13*V022*V07*V13 - 1.24857508865107947e-12*V01*V03*V07*V13 + 
      8.64789162414414022e-14*V06*V07*V13 - 4.69573425370452756e-13*V01*V02*V08*V13 + 6.72970639484009865e-14*V05*V08*V13 - 
      7.00838913454008995e-14*V012*V09*V13 + 3.92328863562626869e-14*V04*V09*V13 + 
      1.80332553128012751e-14*V03*V10*V13 + 5.08665613983146216e-15*V02*V11*V13 + 1.24192598405031732e-15*V01*V12*V13 - 
      6.21480024644799327e-13*V014*V02*V14 + 4.18259528017247027e-13*V024*V14 + 
      5.23025907843860777e-12*V01*V022*V03*V14 + 2.25848421073776013e-12*V012*V032*V14 + 
      3.11904302232700031e-12*V012*V02*V04*V14 - 1.28593290472853242e-12*V032*V04*V14 - 
      8.40404354685060075e-13*V02*V042*V14 + 4.90003317166595845e-13*V013*V05*V14 - 
      1.48716504495359629e-12*V02*V03*V05*V14 - 9.24523562360027521e-13*V01*V04*V05*V14 - 
      3.46489932206207614e-13*V022*V06*V14 - 6.60401436972625256e-13*V01*V03*V06*V14 + 
      2.27906452953688396e-14*V062*V14 - 2.81370861279224713e-13*V01*V02*V07*V14 + 
      4.03313985028964391e-14*V05*V07*V14 - 4.66334872556251264e-14*V012*V08*V14 + 
      2.60180000244437969e-14*V04*V08*V14 + 1.32184006254634684e-14*V03*V09*V14 + 4.05787048516569194e-15*V02*V10*V14 + 
      1.07626420210453919e-15*V01*V11*V14 - 3.00945075209797647e-18*V142 - 1.74791256931349811e-14*V015*V15 + 
      3.50887818941635426e-13*V01*V023*V15 + 9.50691335254026416e-13*V012*V02*V03*V15 - 
      1.34268202327189588e-13*V033*V15 + 1.78420075417641964e-13*V013*V04*V15 - 
      5.3755497302158974e-13*V02*V03*V04*V15 - 1.68020548512624352e-13*V01*V042*V15 - 
      1.53067225843757269e-13*V022*V05*V15 - 2.87650864332847304e-13*V01*V03*V05*V15 - 
      1.39401480833674252e-13*V01*V02*V06*V15 + 1.99767692321399744e-14*V05*V06*V15 - 
      2.61603343157269433e-14*V012*V07*V15 + 1.46521399827194866e-14*V04*V07*V15 + 8.2374395207120285e-15*V03*V08*V15 + 
      2.79456488207778428e-15*V02*V09*V15 + 8.06693305159312762e-16*V01*V10*V15 - 5.64611770807703596e-18*V13*V15 + 
      9.30348278740800477e-14*V012*V022*V16 + 5.0419255803724141e-14*V013*V03*V16 - 
      7.99581874357534261e-14*V02*V032*V16 - 5.1449212045395228e-14*V022*V04*V16 - 
      9.86891159457388108e-14*V01*V03*V04*V16 - 5.72981683338832929e-14*V01*V02*V05*V16 + 
      4.11288111408038484e-15*V052*V16 - 1.22350361509414043e-14*V012*V06*V16 + 
      6.81791291295605637e-15*V04*V06*V16 + 4.35826189767930515e-15*V03*V07*V16 + 1.63579949301951267e-15*V02*V08*V16 + 
      5.21877956080570993e-16*V01*V09*V16 - 4.6465463027520719e-18*V12*V16 + 9.45730472285564193e-15*V013*V02*V17 - 
      1.47208372960350357e-14*V022*V03*V17 - 1.36339794032332893e-14*V01*V032*V17 - 
      1.85038680862556275e-14*V01*V02*V04*V17 - 4.72902932669898071e-15*V012*V05*V17 + 
      2.66027784544871341e-15*V04*V05*V17 + 1.92177254251781137e-15*V03*V06*V17 + 8.1988815581430706e-16*V02*V07*V17 + 
      2.89404615675360765e-16*V01*V08*V17 - 3.35814793728803795e-18*V11*V17 + 3.1665082777418444e-16*V014*V18 - 
      8.29424120623744702e-16*V023*V18 - 4.8804939726509656e-15*V01*V02*V03*V18 - 
      1.45787548968319155e-15*V012*V04*V18 + 4.0645987167588428e-16*V042*V18 + 
      7.08583714450476075e-16*V03*V05*V18 + 3.41523594722877577e-16*V02*V06*V18 + 1.37054101336150478e-16*V01*V07*V18 - 
      2.11874812168677405e-18*V10*V18 - 4.08102602557538184e-16*V01*V022*V19 - 
      3.59172510361003493e-16*V012*V03*V19 + 2.06870163806441395e-16*V03*V04*V19 + 
      1.20265743559900662e-16*V02*V05*V19 + 5.45211453611642815e-17*V01*V06*V19 - 1.16651373579541879e-18*V09*V19 - 
      5.85804031382241213e-17*V012*V02*V20 + 2.49212937478852888e-17*V032*V20 + 
      3.32330189624136686e-17*V02*V04*V20 + 1.81795989698585766e-17*V01*V05*V20 - 5.54337713361920317e-19*V08*V20 - 
      2.48797078965430631e-18*V013*V21 + 7.73323311269149115e-18*V02*V03*V21 + 4.84819223741558848e-18*V01*V04*V21 - 
      2.27241935155724871e-19*V07*V21 + 5.6209710432930624e-19*V022*V22 + 1.0596912622601675e-18*V01*V03*V22 - 
      7.85935794816145506e-20*V06*V22 + 1.52042659367763163e-19*V01*V02*V23 - 2.30524132775305395e-20*V05*V23 + 
      9.21470662834928263e-21*V012*V24 - 5.40846469503008574e-21*V04*V24 - 1.06277245987884229e-21*V03*V25 - 
      1.35604791030218457e-22*V02*V26 - 1.56467066573328989e-23*V01*V27 + 9.70639370802289015e-27*V30) + 
   delta4*eps13*(3.18505244927949122e-8*V023*V034 + 
      3.63721924280541002e-8*V01*V02*V035 + 4.86280695245372734e-8*V024*V032*V04 + 
      2.20211288493910388e-7*V01*V022*V033*V04 + 4.81455433084979275e-8*V012*V034*V04 + 
      2.55551047231023315e-9*V025*V042 + 1.22467626134807859e-7*V01*V023*V03*V042 + 
      1.82618989316787222e-7*V012*V02*V032*V042 - 2.63043652949928417e-8*V034*V042 + 
      3.73852520711127092e-8*V012*V022*V043 + 2.13886804421684309e-8*V013*V03*V043 - 
      6.22302068234421287e-8*V02*V032*V043 - 7.48454109323006102e-9*V022*V044 - 
      1.89889705506979006e-8*V01*V03*V044 + 9.08877376716545462e-9*V025*V03*V05 + 
      1.127081971564928e-7*V01*V023*V032*V05 + 1.02227016938670972e-7*V012*V02*V033*V05 - 
      9.18722452646237804e-9*V035*V05 + 2.91768417147223641e-8*V01*V024*V04*V05 + 
      1.90491982020819433e-7*V012*V022*V03*V04*V05 + 5.2436987914532368e-8*V013*V032*V04*V05 - 
      1.1342515053938193e-7*V02*V033*V04*V05 + 3.41235578420273205e-8*V013*V02*V042*V05 - 
      9.68540158679057273e-8*V022*V03*V042*V05 - 1.00369376300120491e-7*V01*V032*V042*V05 - 
      4.01248891726478198e-8*V01*V02*V043*V05 + 1.63956984563859441e-8*V012*V023*V052 + 
      2.79747121631947565e-8*V013*V02*V03*V052 - 
      4.53148478367601859e-8*V022*V032*V052 - 2.89100329191507154e-8*V01*V033*V052 + 
      3.45255048570379637e-9*V014*V04*V052 - 1.64487535725404588e-8*V023*V04*V052 - 
      1.08434403511903222e-7*V01*V02*V03*V04*V052 - 1.56374099398400389e-8*V012*V042*V052 + 
      3.51432810587743948e-9*V043*V052 - 9.6527288121086455e-9*V01*V022*V053 - 
      8.89236660403888461e-9*V012*V03*V053 + 6.37070244243975691e-9*V03*V04*V053 + 
      8.70665404797237582e-10*V02*V054 + 2.88337306258509828e-10*V026*V06 + 
      2.14127839125225537e-8*V01*V024*V03*V06 + 6.46748847236896075e-8*V012*V022*V032*V06 + 
      1.15939507572439985e-8*V013*V033*V06 - 2.01311269479684964e-8*V02*V034*V06 + 
      2.62297576837808744e-8*V012*V023*V04*V06 + 4.53983681217831457e-8*V013*V02*V03*V04*V06 - 
      7.04622926468160372e-8*V022*V032*V04*V06 - 4.69515380809358884e-8*V01*V033*V04*V06 + 
      2.81550684672345435e-9*V014*V042*V06 - 1.10057452915525098e-8*V023*V042*V06 - 
      8.62832503087032985e-8*V01*V02*V03*V042*V06 - 8.49593548288469685e-9*V012*V043*V06 + 
      1.33994572989674115e-9*V044*V06 + 1.20600599618847086e-8*V013*V022*V05*V06 + 
      4.53345299684557244e-9*V014*V03*V05*V06 - 2.41832286704071995e-8*V023*V03*V05*V06 - 
      7.64383659411645021e-8*V01*V02*V032*V05*V06 - 4.52448497920386642e-8*V01*V022*V04*V05*V06 - 
      4.35333307398547151e-8*V012*V03*V04*V05*V06 + 1.52791783583975097e-8*V03*V042*V05*V06 - 
      1.18566082543781223e-8*V012*V02*V052*V06 + 6.84649330739555099e-9*V032*V052*V06 + 
      8.24900618460748895e-9*V02*V04*V052*V06 + 1.51752357682272738e-9*V01*V053*V06 + 
      9.89573025098675417e-10*V014*V02*V062 - 1.00621175759930092e-9*V024*V062 - 
      1.62398406121865215e-8*V01*V022*V03*V062 - 
      7.54303035550392635e-9*V012*V032*V062 - 
      9.62212950083595293e-9*V012*V02*V04*V062 + 5.50852218256165074e-9*V032*V04*V062 + 
      3.12314385202035802e-9*V02*V042*V062 - 1.50463180780930825e-9*V013*V05*V062 + 
      5.98730146085247858e-9*V02*V03*V05*V062 + 3.67732894685077508e-9*V01*V04*V05*V062 + 
      4.02216236474883255e-10*V022*V063 + 8.74923136859372532e-10*V01*V03*V063 - 
      1.56326322935584384e-11*V064 + 1.2983962524522078e-9*V01*V025*V07 + 
      1.53358521940482015e-8*V012*V023*V03*V07 + 1.28821030582685537e-8*V013*V02*V032*V07 - 
      1.52057234858673829e-8*V022*V033*V07 - 7.1966015555823278e-9*V01*V034*V07 + 
      8.33788698921045719e-9*V013*V022*V04*V07 + 3.1524744417257051e-9*V014*V03*V04*V07 - 
      1.66690503320626575e-8*V023*V03*V04*V07 - 5.41831353659940985e-8*V01*V02*V032*V04*V07 - 
      1.57423995044342967e-8*V01*V022*V042*V07 - 1.55071770654304034e-8*V012*V03*V042*V07 + 
      3.63056176385854998e-9*V03*V043*V07 + 1.68644227601874988e-9*V014*V02*V05*V07 - 
      2.08275626822208695e-9*V024*V05*V07 - 2.89353723479750314e-8*V01*V022*V03*V05*V07 - 
      1.31723789622309176e-8*V012*V032*V05*V07 - 1.68135074683681121e-8*V012*V02*V04*V05*V07 + 
      9.82556959504886347e-9*V032*V04*V05*V07 + 5.84401911197995448e-9*V02*V042*V05*V07 - 
      1.30597937309827061e-9*V013*V052*V07 + 5.37533867082611707e-9*V02*V03*V052*V07 + 
      3.26748690758610518e-9*V01*V04*V052*V07 + 1.01868714468176768e-10*V015*V06*V07 - 
      3.90428078727924281e-9*V01*V023*V06*V07 - 1.17152393177145516e-8*V012*V02*V03*V06*V07 + 
      2.34193868762891403e-9*V033*V06*V07 - 2.14733137714440164e-9*V013*V04*V06*V07 + 
      8.51170268603944697e-9*V02*V03*V04*V06*V07 + 2.62917968353437623e-9*V01*V042*V06*V07 + 
      2.26767323426982697e-9*V022*V05*V06*V07 + 4.64599993088529148e-9*V01*V03*V05*V06*V07 + 
      1.02554412273967743e-9*V01*V02*V062*V07 - 1.69692547625464458e-10*V05*V062*V07 - 
      1.11385142759241345e-9*V012*V022*V072 - 6.36928455389441702e-10*V013*V03*V072 + 
      1.38039185954295375e-9*V02*V032*V072 + 7.97930242680080783e-10*V022*V04*V072 + 
      1.66777940865396535e-9*V01*V03*V04*V072 + 9.15168885829463326e-10*V01*V02*V05*V072 - 
      7.5808356099106596e-11*V052*V072 + 1.90681145709286893e-10*V012*V06*V072 - 
      1.21840726101504731e-10*V04*V06*V072 - 2.6258350610958125e-11*V03*V073 + 
      1.17873064363543779e-9*V012*V024*V08 + 4.1417004738106205e-9*V013*V022*V03*V08 + 
      7.69598135768425156e-10*V014*V032*V08 - 4.78582454024383036e-9*V023*V032*V08 - 
      9.78364364295661489e-9*V01*V02*V033*V08 + 1.02236238518465225e-9*V014*V02*V04*V08 - 
      1.07335922095479893e-9*V024*V04*V08 - 1.7666598363670202e-8*V01*V022*V03*V04*V08 - 
      8.25645236091534951e-9*V012*V032*V04*V08 - 5.24241953228154301e-9*V012*V02*V042*V08 + 
      3.06749469303890093e-9*V032*V042*V08 + 1.15147301410125573e-9*V02*V043*V08 + 
      7.5684614251274468e-11*V015*V05*V08 - 3.05268802684342601e-9*V01*V023*V05*V08 - 
      9.00080673055107691e-9*V012*V02*V03*V05*V08 + 1.81776654893730941e-9*V033*V05*V08 - 
      1.64167928677275453e-9*V013*V04*V05*V08 + 6.64996784730874228e-9*V02*V03*V04*V05*V08 + 
      2.04479743791149181e-9*V01*V042*V05*V08 + 8.88924442047801394e-10*V022*V052*V08 + 
      1.79996744733944907e-9*V01*V03*V052*V08 - 1.96127162358134322e-9*V012*V022*V06*V08 - 
      1.12213642527512182e-9*V013*V03*V06*V08 + 2.40249365253839521e-9*V02*V032*V06*V08 + 
      1.33104575196264348e-9*V022*V04*V06*V08 + 2.92046432769812936e-9*V01*V03*V04*V06*V08 + 
      1.59613241280570689e-9*V01*V02*V05*V06*V08 - 1.32373220655687102e-10*V052*V06*V08 + 
      1.67849912174092015e-10*V012*V062*V08 - 1.05064239499054197e-10*V04*V062*V08 - 
      4.38134433995168848e-10*V013*V02*V07*V08 + 9.1562977374539827e-10*V022*V03*V07*V08 + 
      9.16073224999735284e-10*V01*V032*V07*V08 + 1.13678748467010487e-9*V01*V02*V04*V07*V08 + 
      2.94635690820664217e-10*V012*V05*V07*V08 - 1.90277073571282235e-10*V04*V05*V07*V08 - 
      1.37676614479106501e-10*V03*V06*V07*V08 - 2.71602960967982247e-11*V02*V072*V08 - 
      1.46974476899703569e-11*V014*V082 + 4.67020500796749011e-11*V023*V082 + 
      3.16437915317272677e-10*V01*V02*V03*V082 + 9.31924276075612557e-11*V012*V04*V082 - 
      2.9411372146011677e-11*V042*V082 - 5.36415084260776916e-11*V03*V05*V082 - 
      2.33647418122495086e-11*V02*V06*V082 - 9.48457735842490118e-12*V01*V07*V082 + 
      3.91230923728553628e-10*V013*V023*V09 + 4.42135871640047214e-10*V014*V02*V03*V09 - 
      6.43958473146301573e-10*V024*V03*V09 - 4.37396336505996984e-9*V01*V022*V032*V09 - 
      1.30616120901256233e-9*V012*V033*V09 + 4.06848568776442996e-11*V015*V04*V09 - 
      1.63998021246363375e-9*V01*V023*V04*V09 - 5.02644834460716071e-9*V012*V02*V03*V04*V09 + 
      1.0317800007922306e-9*V033*V04*V09 - 4.61641505642926528e-10*V013*V042*V09 + 
      1.85715228858623926e-9*V02*V03*V042*V09 + 3.83987891618186205e-10*V01*V043*V09 - 
      1.34869854465960826e-9*V012*V022*V05*V09 - 7.67563284728317524e-10*V013*V03*V05*V09 + 
      1.69535068127518958e-9*V02*V032*V05*V09 + 9.83370620053382776e-10*V022*V04*V05*V09 + 
      2.04414704178147889e-9*V01*V03*V04*V05*V09 + 5.61122958220973023e-10*V01*V02*V052*V09 - 
      3.11475340296209412e-11*V053*V09 - 3.45447052772571488e-10*V013*V02*V06*V09 + 
      7.19545429367092386e-10*V022*V03*V06*V09 + 7.24520732552396125e-10*V01*V032*V06*V09 + 
      8.95806134417942697e-10*V01*V02*V04*V06*V09 + 2.33114762235612664e-10*V012*V05*V06*V09 - 
      1.50326399455284042e-10*V04*V05*V06*V09 - 5.44357367725202814e-11*V03*V062*V09 - 
      2.63007328148715229e-11*V014*V07*V09 + 8.808547805048216e-11*V023*V07*V09 + 
      5.71606658686828422e-10*V01*V02*V03*V07*V09 + 1.6750913293993274e-10*V012*V04*V07*V09 - 
      5.38933383863524193e-11*V042*V07*V09 - 9.70805070320080759e-11*V03*V05*V07*V09 - 
      4.28576455668270535e-11*V02*V06*V07*V09 - 8.56808169350499234e-12*V01*V072*V09 + 
      9.56567284175025444e-11*V01*V022*V08*V09 + 9.07855616440092102e-11*V012*V03*V08*V09 - 
      6.10575889780192126e-11*V03*V04*V08*V09 - 3.35235469163562455e-11*V02*V05*V08*V09 - 
      1.50159266354684833e-11*V01*V06*V08*V09 + 1.4237649197214055e-11*V012*V02*V092 - 
      7.75804452920970187e-12*V032*V092 - 9.44547422724473388e-12*V02*V04*V092 - 
      5.27275798192250623e-12*V01*V05*V092 + 1.62209010435199681e-13*V08*V092 + 
      5.66129459949871887e-11*V014*V022*V10 - 2.60147233692765675e-11*V025*V10 + 
      1.55641903671981931e-11*V015*V03*V10 - 7.58058485366556084e-10*V01*V023*V03*V10 - 
      1.08531681094815636e-9*V012*V02*V032*V10 + 1.16495112081095023e-10*V034*V10 - 
      6.78578220258866758e-10*V012*V022*V04*V10 - 3.90624018049454307e-10*V013*V03*V04*V10 + 
      8.60439499924655013e-10*V02*V032*V04*V10 + 2.35713014144629767e-10*V022*V042*V10 + 
      5.23776101821119376e-10*V01*V03*V042*V10 - 2.13815204239396951e-10*V013*V02*V05*V10 + 
      4.61452611775551575e-10*V022*V03*V05*V10 + 4.5768945085936976e-10*V01*V032*V05*V10 + 
      5.70409450823507391e-10*V01*V02*V04*V05*V10 + 7.34056698297882596e-11*V012*V052*V10 - 
      4.80236999816768472e-11*V04*V052*V10 - 1.87661492815095823e-11*V014*V06*V10 + 
      5.99864583279271968e-11*V023*V06*V10 + 4.08055882260348244e-10*V01*V02*V03*V06*V10 + 
      1.20220118169600808e-10*V012*V04*V06*V10 - 3.80214936113489014e-11*V042*V06*V10 - 
      6.9418737144367214e-11*V03*V05*V06*V10 - 1.50966009032377833e-11*V02*V062*V10 + 
      7.82649779494927435e-11*V01*V022*V07*V10 + 7.40002881260226992e-11*V012*V03*V07*V10 - 
      4.9960064984061922e-11*V03*V04*V07*V10 - 2.74551878188769003e-11*V02*V05*V07*V10 - 
      1.22743487738676006e-11*V01*V06*V07*V10 + 2.58338107903474653e-11*V012*V02*V08*V10 - 
      1.4031300967953815e-11*V032*V08*V10 - 1.68679055416063672e-11*V02*V04*V08*V10 - 
      9.54269372783091531e-12*V01*V05*V08*V10 + 1.46184206223479291e-13*V082*V10 + 
      2.33285777480705712e-12*V013*V09*V10 - 8.80977169171704396e-12*V02*V03*V09*V10 - 
      5.44534025109327628e-12*V01*V04*V09*V10 + 2.65515777874997473e-13*V07*V09*V10 - 
      5.98556989462812633e-13*V022*V102 - 1.23709872544326281e-12*V01*V03*V102 + 
      9.4728248490629138e-14*V06*V102 + 3.6006998927858061e-12*V015*V02*V11 - 
      4.22611965687255014e-11*V01*V024*V11 - 2.69223481997489627e-10*V012*V022*V03*V11 - 
      7.52158684916149196e-11*V013*V032*V11 + 1.20466492812944193e-10*V02*V033*V11 - 
      9.90726554912275802e-11*V013*V02*V04*V11 + 2.11889475625539213e-10*V022*V03*V04*V11 + 
      2.15882504608447582e-10*V01*V032*V04*V11 + 1.3239082818032087e-10*V01*V02*V042*V11 - 
      1.05676574369177507e-11*V014*V05*V11 + 3.68766460694458115e-11*V023*V05*V11 + 
      2.37258763444041042e-10*V01*V02*V03*V05*V11 + 6.93111458769612241e-11*V012*V04*V05*V11 - 
      2.25927798366105915e-11*V042*V05*V11 - 2.03066668092039309e-11*V03*V052*V11 + 
      5.10166528102996563e-11*V01*V022*V06*V11 + 4.86208624060895373e-11*V012*V03*V06*V11 - 
      3.27779746623279576e-11*V03*V04*V06*V11 - 1.79715269198994481e-11*V02*V05*V06*V11 - 
      4.03359948842296111e-12*V01*V062*V11 + 1.92723621175207832e-11*V012*V02*V07*V11 - 
      1.05337095924375969e-11*V032*V07*V11 - 1.28352990708805977e-11*V02*V04*V07*V11 - 
      7.15694508662561397e-12*V01*V05*V07*V11 + 1.93735860627909373e-12*V013*V08*V11 - 
      7.308725112011296e-12*V02*V03*V08*V11 - 4.52103645943165979e-12*V01*V04*V08*V11 + 2.20451685999036251e-13*V07*V08*V11 - 
      1.11236124366589006e-12*V022*V09*V11 - 2.26969308599313256e-12*V01*V03*V09*V11 + 
      1.74545415140438758e-13*V06*V09*V11 - 6.49342593590556008e-13*V01*V02*V10*V11 + 1.11535517267321896e-13*V05*V10*V11 - 
      4.00456907400402159e-14*V012*V112 + 2.6471027975282667e-14*V04*V112 + 
      8.15692532346299116e-14*V016*V12 - 2.00220764487376347e-11*V012*V023*V12 - 
      3.51011363026503513e-11*V013*V02*V03*V12 + 4.17954534326439906e-11*V022*V032*V12 + 
      2.71142029427501048e-11*V01*V033*V12 - 4.50989187526839868e-12*V014*V04*V12 + 
      1.47773497138961349e-11*V023*V04*V12 + 1.02231643770260481e-10*V01*V02*V03*V04*V12 + 
      1.50829757112720278e-11*V012*V042*V12 - 3.21772792392402653e-12*V043*V12 + 
      2.75369411008746056e-11*V01*V022*V05*V12 + 2.58349588575002053e-11*V012*V03*V05*V12 - 
      1.76999490677589296e-11*V03*V04*V05*V12 - 4.86997794082214239e-12*V02*V052*V12 + 
      1.16751937284455787e-11*V012*V02*V06*V12 - 6.37893891160118162e-12*V032*V06*V12 - 
      7.64809430805109003e-12*V02*V04*V06*V12 - 4.33755560748989182e-12*V01*V05*V06*V12 + 
      1.33162343252392584e-12*V013*V07*V12 - 5.06384511615505956e-12*V02*V03*V07*V12 - 
      3.12657910430170865e-12*V01*V04*V07*V12 + 7.6325566608852036e-14*V072*V12 - 
      8.39941755135893245e-13*V022*V08*V12 - 1.73792092326055824e-12*V01*V03*V08*V12 + 
      1.33082218080737001e-13*V06*V08*V12 - 5.49319219559307979e-13*V01*V02*V09*V12 + 9.43649626429614981e-14*V05*V09*V12 - 
      7.38962920359087716e-14*V012*V10*V12 + 4.86168110418902168e-14*V04*V10*V12 + 
      2.07659253560811614e-14*V03*V11*V12 + 2.51193328373489934e-15*V02*V122 - 
      3.74830139863894594e-12*V013*V022*V13 - 1.45173849506871093e-12*V014*V03*V13 + 
      5.74286457874053768e-12*V023*V03*V13 + 1.80651852232010083e-11*V01*V02*V032*V13 + 
      1.08460109051957683e-11*V01*V022*V04*V13 + 1.04432046814520366e-11*V012*V03*V04*V13 - 
      3.57219783345162278e-12*V03*V042*V13 + 5.76120195662436643e-12*V012*V02*V05*V13 - 
      3.19113738750312649e-12*V032*V05*V13 - 3.90162991167765306e-12*V02*V04*V05*V13 - 
      1.08233472484424937e-12*V01*V052*V13 + 7.49500111372576426e-13*V013*V06*V13 - 
      2.83998617873802873e-12*V02*V03*V06*V13 - 1.75880291043392719e-12*V01*V04*V06*V13 - 
      5.47705382846011738e-13*V022*V07*V13 - 1.11537468855877233e-12*V01*V03*V07*V13 + 
      8.5915233489542932e-14*V06*V07*V13 - 3.90304155294798801e-13*V01*V02*V08*V13 + 6.70794781977199116e-14*V05*V08*V13 - 
      5.79802142644036248e-14*V012*V09*V13 + 3.83471522803672365e-14*V04*V09*V13 + 
      1.77783711966391176e-14*V03*V10*V13 + 4.68364899080586693e-15*V02*V11*V13 + 1.14416186673276144e-15*V01*V12*V13 - 
      2.91318761552249684e-13*V014*V02*V14 + 2.52540059289842007e-13*V024*V14 + 
      3.64672614610554305e-12*V01*V022*V03*V14 + 1.67736648427608526e-12*V012*V032*V14 + 
      2.16095643264539821e-12*V012*V02*V04*V14 - 1.20810668715732339e-12*V032*V04*V14 - 
      7.18035830608108554e-13*V02*V042*V14 + 3.42893139470879588e-13*V013*V05*V14 - 
      1.33245749293661185e-12*V02*V03*V05*V14 - 8.20379330291747371e-13*V01*V04*V05*V14 - 
      2.82251563338370215e-13*V022*V06*V14 - 5.86499596277395136e-13*V01*V03*V06*V14 + 
      2.24758463681045585e-14*V062*V14 - 2.34106216881593815e-13*V01*V02*V07*V14 + 
      4.02608362610552551e-14*V05*V07*V14 - 3.85218541191054779e-14*V012*V08*V14 + 
      2.53398129021924342e-14*V04*V08*V14 + 1.3036682773732178e-14*V03*V09*V14 + 3.72723483358878026e-15*V02*V10*V14 + 
      9.91590347838307129e-16*V01*V11*V14 - 3.00764386188423156e-18*V142 - 7.76850030805999158e-15*V015*V15 + 
      2.20677982838721506e-13*V01*V023*V15 + 6.54111143757109806e-13*V012*V02*V03*V15 - 
      1.26586780996767497e-13*V033*V15 + 1.21334063138367375e-13*V013*V04*V15 - 
      4.68214925541707296e-13*V02*V03*V04*V15 - 1.45347384212898577e-13*V01*V042*V15 - 
      1.26430357163248255e-13*V022*V05*V15 - 2.55796628759366927e-13*V01*V03*V05*V15 - 
      1.1508045222300198e-13*V01*V02*V06*V15 + 1.98341955813692e-14*V05*V06*V15 - 2.1591020985915333e-14*V012*V07*V15 + 
      1.43192025798299961e-14*V04*V07*V15 + 8.11096627607026363e-15*V03*V08*V15 + 2.57288500931838043e-15*V02*V09*V15 + 
      7.42846303717552481e-16*V01*V10*V15 - 5.64610486975362482e-18*V13*V15 + 
      5.88020587176660504e-14*V012*V022*V16 + 3.37409048706047642e-14*V013*V03*V16 - 
      7.02484835213412716e-14*V02*V032*V16 - 4.07633155139853916e-14*V022*V04*V16 - 
      8.57325247053663237e-14*V01*V03*V04*V16 - 4.74695276879172264e-14*V01*V02*V05*V16 + 
      4.10209108608402237e-15*V052*V16 - 1.00416846632135019e-14*V012*V06*V16 + 
      6.61145782073216814e-15*V04*V06*V16 + 4.2966690724044799e-15*V03*V07*V16 + 1.50007808449502892e-15*V02*V08*V16 + 
      4.80674763472474975e-16*V01*V09*V16 - 4.64335918335409983e-18*V12*V16 + 5.86859534141488495e-15*V013*V02*V17 - 
      1.19149926357267822e-14*V022*V03*V17 - 1.18390969611332872e-14*V01*V032*V17 - 
      1.4884523993778622e-14*V01*V02*V04*V17 - 3.87688676573334214e-15*V012*V05*V17 + 
      2.59785490964646764e-15*V04*V05*V17 + 1.8845229885090693e-15*V03*V06*V17 + 7.54640493580170944e-16*V02*V07*V17 + 
      2.66124915929740168e-16*V01*V08*V17 - 3.3581350989646268e-18*V11*V17 + 1.89990496664510664e-16*V014*V18 - 
      6.05825075783836473e-16*V023*V18 - 3.94506721777710106e-15*V01*V02*V03*V18 - 
      1.16688343136594698e-15*V012*V04*V18 + 3.87179633840501464e-16*V042*V18 + 
      6.97503727813721544e-16*V03*V05*V18 + 3.11560799350905788e-16*V02*V06*V18 + 1.26116523801834072e-16*V01*V07*V18 - 
      2.11657151525344931e-18*V10*V18 - 3.03582698373980002e-16*V01*V022*V19 - 
      2.85990985719858645e-16*V012*V03*V19 + 1.99407647605149438e-16*V03*V04*V19 + 
      1.10578573791697835e-16*V02*V05*V19 + 4.99049164096528102e-17*V01*V06*V19 - 1.16650089747200765e-18*V09*V19 - 
      4.34263992376024374e-17*V012*V02*V20 + 2.41702552671699376e-17*V032*V20 + 
      2.97024699370947006e-17*V02*V04*V20 + 1.66810124276052793e-17*V01*V05*V20 - 5.5320369966989838e-19*V08*V20 - 
      1.80943330156676823e-18*V013*V21 + 7.00387512138093581e-18*V02*V03*V21 + 4.35325079805955504e-18*V01*V04*V21 - 
      2.27229096832313726e-19*V07*V21 + 4.69112337443236207e-19*V022*V22 + 9.54280603102535557e-19*V01*V03*V22 - 
      7.81576496250736201e-20*V06*V22 + 1.27749341893024146e-19*V01*V02*V23 - 2.30395749541193945e-20*V05*V23 + 
      7.67892219029106886e-21*V012*V24 - 5.29564792805464956e-21*V04*V24 - 1.04993413646769735e-21*V03*V25 - 
      1.25173653258663191e-22*V02*V26 - 1.44431138375380606e-23*V01*V27 + 9.70639370802289015e-27*V30) + 
   1.21612504155351795e-34*delta30*V30 + 9.12093781165138462e-34*delta28*eps*V30 + 
   delta28*eps2*(-2.35802875569598315e-27*V152 - 3.88381206820514871e-27*V14*V16 - 
      3.64107381394232692e-27*V13*V17 - 2.299625566700417e-27*V12*V18 - 1.66084068706141228e-27*V11*V19 - 
      7.90876517648291561e-28*V10*V20 - 4.34982084706560358e-28*V09*V21 - 1.51298116419673168e-28*V08*V22 - 
      6.1894683989866296e-29*V07*V23 - 1.48547241575679111e-29*V06*V24 - 4.33262787929064072e-30*V05*V25 - 
      6.41870796931946774e-31*V04*V26 - 1.23436691717682072e-31*V03*V27 - 8.51287529087462565e-33*V02*V28 - 
      9.12093781165138462e-34*V01*V29 + 6.90980137246317017e-36*V32) + 
   delta26*eps3*(-3.3012402579743764e-26*V152 - 5.43733689548720819e-26*V14*V16 - 
      5.09750333951925768e-26*V13*V17 - 3.2194757933805838e-26*V12*V18 - 2.32517696188597719e-26*V11*V19 - 
      1.10722712470760818e-26*V10*V20 - 6.08974918589184502e-27*V09*V21 - 2.11817362987542435e-27*V08*V22 - 
      8.66525575858128145e-28*V07*V23 - 2.07966138205950755e-28*V06*V24 - 6.06567903100689701e-29*V05*V25 - 
      8.98619115704725483e-30*V04*V26 - 1.72811368404754901e-30*V03*V27 - 1.19180254072244759e-31*V02*V28 - 
      1.27693129363119385e-32*V01*V29 + 4.83686096072421912e-35*V32) + 
   delta24*eps4*(5.82653552668301284e-21*V092*V10 + 3.78906976049804394e-21*V08*V102 + 
      9.37178201117267674e-21*V08*V09*V11 + 7.62746468947594408e-21*V07*V10*V11 + 2.31034800014561205e-21*V06*V112 + 
      2.56133770803090351e-21*V082*V12 + 6.41182552076610282e-21*V07*V09*V12 + 3.14022056007147858e-21*V06*V10*V12 + 
      2.44815156247433017e-21*V05*V11*V12 + 3.37091638217619308e-22*V04*V122 + 4.32543785131046619e-21*V07*V08*V13 + 
      3.25818307712842725e-21*V06*V09*V13 + 2.05354818562813879e-21*V05*V10*V13 + 8.32371531241272257e-22*V04*V11*V13 + 
      3.13865584932606432e-22*V03*V12*V13 + 2.67609159992692984e-23*V02*V132 + 
      1.27167872828527706e-21*V072*V14 + 1.53007662427225882e-21*V06*V08*V14 + 1.4836251829994899e-21*V05*V09*V14 + 
      4.85955699038520547e-22*V04*V10*V14 + 2.69750033272634528e-22*V03*V11*V14 + 3.72376329778067631e-23*V02*V12*V14 + 
      1.03750012797167126e-23*V01*V13*V14 + 1.11709134072974648e-21*V06*V07*V15 + 8.65087570262093237e-22*V05*V08*V15 + 
      4.36004135412094992e-22*V04*V09*V15 + 1.95576017678870361e-22*V03*V10*V15 + 3.97590751989143862e-23*V02*V11*V15 + 
      8.96758814093161233e-24*V01*V12*V15 - 2.90992945153344817e-25*V152 + 1.7231972553420606e-22*V062*V16 + 
      4.4389561297611481e-22*V05*V07*V16 + 1.78560337579527806e-22*V04*V08*V16 + 1.2330433693780967e-22*V03*V09*V16 + 
      2.02411691387662042e-23*V02*V10*V16 + 6.72569110569870925e-24*V01*V11*V16 - 4.86547904958251906e-25*V14*V16 + 
      1.72492045259740266e-22*V05*V06*V17 + 1.15412859373789851e-22*V04*V07*V17 + 6.36093801663303851e-23*V03*V08*V17 + 
      1.60790377642668473e-23*V02*V09*V17 + 4.31417686056331679e-24*V01*V10*V17 - 4.5030038736910881e-25*V13*V17 + 
      3.01992380239432175e-23*V052*V18 + 3.13441830481553256e-23*V04*V06*V18 + 2.87611790704221119e-23*V03*V07*V18 + 
      5.79619763982404466e-24*V02*V08*V18 + 2.39676492253517599e-24*V01*V09*V18 - 2.89316685520912808e-25*V12*V18 + 
      1.41735090459040168e-23*V04*V05*V19 + 1.00872541087567407e-23*V03*V06*V19 + 3.38506058195091523e-24*V02*V07*V19 + 
      1.11595403800579623e-24*V01*V08*V19 - 2.06731712762756309e-25*V11*V19 + 1.13738035553550752e-24*V042*V20 + 
      3.12467130641622944e-24*V03*V05*V20 + 8.11896995766535808e-25*V02*V06*V20 + 4.46381615202318492e-25*V01*V07*V20 - 
      1.00345867127134096e-25*V10*V20 + 6.7492900218590556e-25*V03*V04*V21 + 3.38506058195091523e-25*V02*V05*V21 + 
      1.44103630125096296e-25*V01*V06*V21 - 5.47252460707546713e-26*V09*V21 + 6.55016500568619526e-26*V032*V22 + 
      4.76916705401665496e-26*V02*V04*V22 + 3.93009900341171716e-26*V01*V05*V22 - 1.94391993717138698e-26*V08*V22 + 
      1.33796860946676491e-26*V02*V03*V23 + 8.00311069785658766e-27*V01*V04*V23 - 7.90277728080956647e-27*V07*V23 + 
      4.03448996085362958e-28*V022*V24 + 1.33385178297609794e-27*V01*V03*V24 - 1.94033431409887059e-27*V06*V24 + 
      1.33796860946676491e-28*V01*V02*V25 - 5.63615126711170418e-28*V05*V25 + 5.1460331133337112e-30*V012*V26 - 
      8.55569505358772501e-29*V04*V26 - 1.64202723266857935e-29*V03*V27 - 1.1620074772043864e-30*V02*V28 - 
      1.245008011290414e-31*V01*V29 + 3.14395962447074243e-34*V32) + 
   delta22*eps5*(9.2361377978530722e-20*V092*V10 + 6.23514970647636699e-20*V08*V102 + 
      1.48308450326807609e-19*V08*V09*V11 + 1.20909440262803854e-19*V07*V10*V11 + 3.65104994568465661e-20*V06*V112 + 
      4.21687784249326233e-20*V082*V12 + 1.01854519991336529e-19*V07*V09*V12 + 5.17177686442779896e-20*V06*V10*V12 + 
      3.88899076330557657e-20*V05*V11*V12 + 5.55793177798659469e-21*V04*V122 + 6.84500539969881274e-20*V07*V08*V13 + 
      5.14891659006810548e-20*V06*V09*V13 + 3.25525416092164223e-20*V05*V10*V13 + 1.31387534063292489e-20*V04*V11*V13 + 
      4.98588559398150842e-21*V03*V12*V13 + 4.21999059988477397e-22*V02*V132 + 
      2.02560254576869131e-20*V072*V14 + 2.52289625490870287e-20*V06*V08*V14 + 2.3632029700634732e-20*V05*V09*V14 + 
      8.01786339498781064e-21*V04*V10*V14 + 4.29673267284267855e-21*V03*V11*V14 + 6.15215295305554607e-22*V02*V12*V14 + 
      1.65258948955487636e-22*V01*V13*V14 + 1.76534283088049331e-20*V06*V07*V15 + 1.36900107993976255e-20*V05*V08*V15 + 
      6.88220416522008275e-21*V04*V09*V15 + 3.10024205802061165e-21*V03*V10*V15 + 6.26970031982880705e-22*V02*V11*V15 + 
      1.42453874113757383e-22*V01*V12*V15 - 2.01916376123518971e-24*V152 + 2.84855994289744897e-21*V062*V16 + 
      7.09616459077094648e-21*V05*V07*V16 + 2.95253996288112937e-21*V04*V08*V16 + 1.97115683076970736e-21*V03*V09*V16 + 
      3.34980788003237315e-22*V02*V10*V16 + 1.0751764531471131e-22*V01*V11*V16 - 3.45645881614850631e-24*V14*V16 + 
      2.72589701827134996e-21*V05*V06*V17 + 1.82175992608766896e-21*V04*V07*V17 + 1.00661844113217834e-21*V03*V08*V17 + 
      2.53554057051900285e-22*V02*V09*V17 + 6.83876924563370217e-23*V01*V10*V17 - 3.13534121661268234e-24*V13*V17 + 
      4.85201090918021028e-22*V052*V18 + 5.20446290236962824e-22*V04*V06*V18 + 4.62096277064781931e-22*V03*V07*V18 + 
      9.62899250853849753e-23*V02*V08*V18 + 3.85080230887318276e-23*V01*V09*V18 - 2.06871144083036133e-24*V12*V18 + 
      2.2372490320374882e-22*V04*V05*V19 + 1.59409182355049705e-22*V03*V06*V19 + 5.33798014846105863e-23*V02*V07*V19 + 
      1.76599726514417253e-23*V01*V08*V19 - 1.45412329189078581e-24*V11*V19 + 1.90229989134620048e-23*V042*V20 + 
      5.05806167726127141e-23*V03*V05*V20 + 1.35822927698154735e-23*V02*V06*V20 + 7.22580239608753059e-24*V01*V07*V20 - 
      7.26679161698495756e-25*V10*V20 + 1.06535668192261343e-23*V03*V04*V21 + 5.33798014846105863e-24*V02*V05*V21 + 
      2.27727403364356722e-24*V01*V06*V21 - 3.91303883649129194e-25*V09*V21 + 1.07349926482079311e-24*V032*V22 + 
      8.08170679674412105e-25*V02*V04*V22 + 6.44099558892475867e-25*V01*V05*V22 - 1.43383659777995782e-25*V08*V22 + 
      2.10987357646682159e-25*V02*V03*V23 + 1.26326879279361276e-25*V01*V04*V23 - 5.77637474084047024e-26*V07*V23 + 
      7.02330599307784905e-27*V022*V24 + 2.23975945224736446e-26*V01*V03*V24 - 1.4649319178699472e-26*V06*V24 + 
      2.10987357646682159e-27*V01*V02*V25 - 4.23103522556934294e-27*V05*V25 + 9.26285960400068017e-29*V012*V26 - 
      6.63871471833683156e-28*V04*V26 - 1.27073817685708256e-28*V03*V27 - 9.29605981763509121e-30*V02*V28 - 
      9.96006409032331201e-31*V01*V29 + 1.88637577468244546e-33*V32) + 
   delta20*eps6*(-1.00257334254113693e-16*V062*V072 - 
      7.07017039248663037e-17*V05*V073 - 3.21511343539348473e-17*V063*V08 - 
      3.10536733348784157e-16*V05*V06*V07*V08 - 1.03868407139048437e-16*V04*V072*V08 - 
      5.98907530363443355e-17*V052*V082 - 4.97247204249392338e-17*V04*V06*V082 - 
      5.70388124155660338e-17*V03*V07*V082 - 3.03453078856873406e-18*V02*V083 - 
      1.16966889963132642e-16*V05*V062*V09 - 1.23142261607194048e-16*V052*V07*V09 - 
      1.55879790772999087e-16*V04*V06*V07*V09 - 5.83602577837486021e-17*V03*V072*V09 - 
      1.21179808328889843e-16*V04*V05*V08*V09 - 8.62602037079955991e-17*V03*V06*V08*V09 - 
      2.88162624805777843e-17*V02*V07*V08*V09 - 4.75323436796383615e-18*V01*V082*V09 - 
      1.50680551293317459e-17*V042*V092 - 3.38351134387826651e-17*V03*V05*V092 - 
      1.07546870972581649e-17*V02*V06*V092 - 4.78710189908625505e-18*V01*V07*V092 - 
      7.34059059105801365e-17*V052*V06*V10 - 3.03274486872751006e-17*V04*V062*V10 - 
      9.85802097791482619e-17*V04*V05*V07*V10 - 6.9910386581504892e-17*V03*V06*V07*V10 - 
      1.17670890594686313e-17*V02*V072*V10 - 1.56135147412818006e-17*V042*V08*V10 - 
      5.3681509330387116e-17*V03*V05*V08*V10 - 1.10895426134636786e-17*V02*V06*V08*V10 - 
      7.66878704719815944e-18*V01*V07*V08*V10 - 2.73833916053189616e-17*V03*V04*V09*V10 - 
      1.37282705693800699e-17*V02*V05*V09*V10 - 5.825865548458741e-18*V01*V06*V09*V10 + 
      8.26881442330332379e-19*V092*V10 - 2.98487498319749016e-18*V032*V102 - 
      1.73189650589126786e-18*V02*V04*V102 - 1.7909249899184941e-18*V01*V05*V102 + 
      5.87948314960381391e-19*V08*V102 - 1.55235590471245558e-17*V053*V11 - 
      5.95177382951451058e-17*V04*V05*V06*V11 - 2.12667072660241167e-17*V03*V062*V11 - 
      1.9725453987488831e-17*V042*V07*V11 - 4.40802502248347676e-17*V03*V05*V07*V11 - 
      1.40788631091379613e-17*V02*V06*V07*V11 - 3.11389181534335473e-18*V01*V072*V11 - 
      2.20326924234345169e-17*V03*V04*V08*V11 - 1.10025729471296995e-17*V02*V05*V08*V11 - 
      4.70510202043612359e-18*V01*V06*V08*V11 - 6.02310011731896899e-18*V032*V09*V11 - 
      5.39545714446703834e-18*V02*V04*V09*V11 - 3.5961109715634425e-18*V01*V05*V09*V11 + 1.32826102027122081e-18*V08*V09*V11 - 
      2.49604919443273998e-18*V02*V03*V10*V11 - 1.493639542108307e-18*V01*V04*V10*V11 + 1.0858541942881714e-18*V07*V10*V11 - 
      1.18434506068070517e-19*V022*V112 - 3.1461063663210527e-19*V01*V03*V112 + 
      3.28222803322434213e-19*V06*V112 - 1.57453370380350096e-17*V04*V052*V12 - 
      6.40336718127529185e-18*V042*V06*V12 - 2.22288804271319921e-17*V03*V05*V06*V12 - 
      2.27087938858978355e-18*V02*V062*V12 - 1.49955590838428663e-17*V03*V04*V07*V12 - 
      7.54594593076355941e-18*V02*V05*V07*V12 - 3.17555434673314173e-18*V01*V06*V07*V12 - 
      4.03381227828263949e-18*V032*V08*V12 - 2.32910919761252539e-18*V02*V04*V08*V12 - 
      2.4202873669695837e-18*V01*V05*V08*V12 + 3.98904689800207498e-19*V082*V12 - 
      2.0960960918787665e-18*V02*V03*V09*V12 - 1.24962992365357219e-18*V01*V04*V09*V12 + 9.17526789885770638e-19*V07*V09*V12 - 
      1.27038081069734319e-19*V022*V10*V12 - 5.29948267474020914e-19*V01*V03*V10*V12 + 
      4.90740637360763913e-19*V06*V10*V12 - 1.14332514102478173e-19*V01*V02*V11*V12 + 3.52501397062798547e-19*V05*V11*V12 - 
      5.60200664336703829e-21*V012*V122 + 5.32241053887221532e-20*V04*V122 - 
      5.31069915047776218e-18*V042*V05*V13 - 5.83981680004042109e-18*V03*V052*V13 - 
      7.63047926860834689e-18*V03*V04*V06*V13 - 3.79046314476791266e-18*V02*V05*V06*V13 - 
      8.17950279462466026e-19*V01*V062*V13 - 2.75258605595038739e-18*V032*V07*V13 - 
      2.49021098975401769e-18*V02*V04*V07*V13 - 1.64106026341282726e-18*V01*V05*V07*V13 - 
      1.41058627527303839e-18*V02*V03*V08*V13 - 8.47411247055173728e-19*V01*V04*V08*V13 + 6.16894705202644531e-19*V07*V08*V13 - 
      1.67023021378048164e-19*V022*V09*V13 - 4.41406141554515266e-19*V01*V03*V09*V13 + 
      4.64330137582514102e-19*V06*V09*V13 - 9.60018920935669222e-20*V01*V02*V10*V13 + 2.95084418461763211e-19*V05*V10*V13 - 
      1.07885191878654216e-20*V012*V11*V13 + 1.19322884705943999e-19*V04*V11*V13 + 
      4.57496627975743437e-20*V03*V12*V13 + 3.88383232429395271e-21*V02*V132 - 
      3.22571087842829421e-19*V043*V14 - 3.4344369110388403e-18*V03*V04*V05*V14 - 
      8.68112974725472814e-19*V02*V052*V14 - 1.20323699243800299e-18*V032*V06*V14 - 
      6.83671844607442443e-19*V02*V04*V06*V14 - 7.21942195462801794e-19*V01*V05*V06*V14 - 
      8.26774261643307442e-19*V02*V03*V07*V14 - 4.90633844434120043e-19*V01*V04*V07*V14 + 
      1.84237755293049424e-19*V072*V14 - 6.12208350036181333e-20*V022*V08*V14 - 
      2.57975509100448935e-19*V01*V03*V08*V14 + 2.40946893499779723e-19*V06*V08*V14 - 6.88978551369422868e-20*V01*V02*V09*V14 + 
      2.15600719549873064e-19*V05*V09*V14 - 8.07305876889015493e-21*V012*V10*V14 + 
      7.70330401876741074e-20*V04*V10*V14 + 3.95583153952398679e-20*V03*V11*V14 + 5.98132870229315157e-21*V02*V12*V14 + 
      1.54443421827782952e-21*V01*V13*V14 - 5.05780871474072589e-19*V03*V042*V15 - 
      5.38061703240646675e-19*V032*V05*V15 - 4.98042197950803539e-19*V02*V04*V05*V15 - 
      1.59721765756633786e-19*V01*V052*V15 - 3.60996489977896444e-19*V02*V03*V06*V15 - 
      2.18013693388809911e-19*V01*V04*V06*V15 - 5.72650359010450849e-20*V022*V07*V15 - 
      1.48779710086225498e-19*V01*V03*V07*V15 + 1.6069221023886202e-19*V06*V07*V15 - 4.0302465007801097e-20*V01*V02*V08*V15 + 
      1.24919403994592107e-19*V05*V08*V15 - 5.58611408438394283e-21*V012*V09*V15 + 
      6.28913000809248522e-20*V04*V09*V15 + 2.85380491330412075e-20*V03*V10*V15 + 5.78800383184195968e-21*V02*V11*V15 + 
      1.33101219398718638e-21*V01*V12*V15 - 1.18875479835463805e-23*V152 - 
      1.40031751146054429e-19*V032*V04*V16 - 3.85026606869805059e-20*V02*V042*V16 - 
      1.4261556602098269e-19*V02*V03*V05*V16 - 8.40190506876326572e-20*V01*V04*V05*V16 - 
      1.344539111595315e-20*V022*V06*V16 - 5.79760731178861744e-20*V01*V03*V06*V16 + 
      2.75582557653692663e-20*V062*V16 - 2.03736522887118128e-20*V01*V02*V07*V16 + 
      6.55935895232913327e-20*V05*V07*V16 - 2.9626315336860409e-21*V012*V08*V16 + 2.86472605072315212e-20*V04*V08*V16 + 
      1.8329134330323056e-20*V03*V09*V16 + 3.27845539164299015e-21*V02*V10*V16 + 1.0116283594076718e-21*V01*V11*V16 - 
      2.08775768575703593e-23*V14*V16 - 1.26052588362944713e-20*V033*V17 - 3.66207498493237896e-20*V02*V03*V04*V17 - 
      1.115693098839866e-20*V01*V042*V17 - 8.84239524942607929e-21*V022*V05*V17 - 
      2.21743085279628405e-20*V01*V03*V05*V17 - 7.96315786715948039e-21*V01*V02*V06*V17 + 2.51970744293095874e-20*V05*V06*V17 - 
      1.43942670737023234e-21*V012*V07*V17 + 1.68535517844642569e-20*V04*V07*V17 + 
      9.35515429600639037e-21*V03*V08*V17 + 2.36225801738255783e-21*V02*V09*V17 + 6.42942546861701544e-22*V01*V10*V17 - 
      1.85264880642948968e-23*V13*V17 - 4.52106459417288227e-21*V02*V032*V18 - 
      1.16471831828220255e-21*V022*V04*V18 - 5.24821151178411817e-21*V01*V03*V04*V18 - 
      2.71263875650372936e-21*V01*V02*V05*V18 + 4.57399978942371463e-21*V052*V18 - 
      5.18514652310937149e-22*V012*V06*V18 + 5.13320239899415715e-21*V04*V06*V18 + 
      4.36877575729247613e-21*V03*V07*V18 + 9.55020615345528831e-22*V02*V08*V18 + 3.67211016853750464e-22*V01*V09*V18 - 
      1.25819842424408317e-23*V12*V18 - 5.1709913739333797e-22*V022*V03*V19 - 
      6.02649144341677966e-22*V01*V032*V19 - 6.42469295602171748e-22*V01*V02*V04*V19 - 
      1.67573890255026373e-22*V012*V05*V19 + 2.10765503307989388e-21*V04*V05*V19 + 
      1.50497682864813637e-21*V03*V06*V19 + 5.04868766334202272e-22*V02*V07*V19 + 1.68099876591606439e-22*V01*V08*V19 - 
      8.68571954026019155e-24*V11*V19 - 9.1178296879151838e-24*V023*V20 - 1.34572412245711139e-22*V01*V02*V03*V20 - 
      3.73662168506598181e-23*V012*V04*V20 + 1.92019351889600554e-22*V042*V20 + 
      4.89503939154259134e-22*V03*V05*V20 + 1.37463865331431084e-22*V02*V06*V20 + 7.03144040113485441e-23*V01*V07*V20 - 
      4.48000184903091806e-24*V10*V20 - 7.38713053419054243e-24*V01*V022*V21 - 
      7.11134432758076218e-24*V012*V03*V21 + 1.02772182744048584e-22*V03*V04*V21 + 
      5.15440570920910515e-23*V02*V05*V21 + 2.20775737503692354e-23*V01*V06*V21 - 2.37867703114447843e-24*V09*V21 - 
      7.68261575555816413e-25*V012*V02*V22 + 1.07121479369226675e-23*V032*V22 + 
      8.41072239364208502e-24*V02*V04*V22 + 6.44370460778513506e-24*V01*V05*V22 - 9.01560694156798152e-25*V08*V22 - 
      1.96990147578414465e-26*V013*V23 + 2.09103909527202021e-24*V02*V03*V23 + 1.25432910406912944e-24*V01*V04*V23 - 
      3.59528018465730163e-25*V07*V23 + 7.59430982733335765e-26*V022*V24 + 2.32584229416721079e-25*V01*V03*V24 - 
      9.44639180783800301e-26*V06*V24 + 2.15670247779815837e-26*V01*V02*V25 - 2.71071444271557539e-26*V05*V25 + 
      1.01891455644007482e-27*V012*V26 - 4.41127918539056048e-27*V04*V26 - 8.4179141670049192e-28*V03*V27 - 
      6.3910411246241252e-29*V02*V28 - 6.84754406209727701e-30*V01*V29 + 1.037506676075345e-32*V32) + 
   delta18*eps7*(-1.58043972825023154e-15*V062*V072 - 
      1.10109211030529489e-15*V05*V073 - 5.75571536039813033e-16*V063*V08 - 
      4.90798627307351825e-15*V05*V06*V07*V08 - 1.63831048183928858e-15*V04*V072*V08 - 
      9.49791644806858495e-16*V052*V082 - 8.91923363162739066e-16*V04*V06*V082 - 
      9.04563471244627138e-16*V03*V07*V082 - 5.46404022115575157e-17*V02*V083 - 
      1.84384634962527013e-15*V05*V062*V09 - 1.92007778998550959e-15*V052*V07*V09 - 
      2.45450885449180344e-15*V04*V06*V07*V09 - 9.1106875568416815e-16*V03*V072*V09 - 
      1.91136222881250335e-15*V04*V05*V08*V09 - 1.36332952029819951e-15*V03*V06*V08*V09 - 
      4.54211301395479557e-16*V02*V07*V08*V09 - 7.53802892703855948e-17*V01*V082*V09 - 
      2.37300917153591611e-16*V042*V092 - 5.29025787684384527e-16*V03*V05*V092 - 
      1.69447293855703259e-16*V02*V06*V092 - 7.50327789510425139e-17*V01*V07*V092 - 
      1.16502689986907764e-15*V052*V06*V10 - 5.45167959798795072e-16*V04*V062*V10 - 
      1.56015693375287046e-15*V04*V05*V07*V10 - 1.10954942844674061e-15*V03*V06*V07*V10 - 
      1.85936742004213574e-16*V02*V072*V10 - 2.81326420557122804e-16*V042*V08*V10 - 
      8.55688206330917209e-16*V03*V05*V08*V10 - 2.001888044589259e-16*V02*V06*V08*V10 - 
      1.22241172332988173e-16*V01*V07*V08*V10 - 4.33376926042464016e-16*V03*V04*V09*V10 - 
      2.16926199004915837e-16*V02*V05*V09*V10 - 9.24624523705617172e-17*V01*V06*V09*V10 + 
      5.40267516591402899e-18*V092*V10 - 4.78924371923628945e-17*V032*V102 - 
      3.14516562733555531e-17*V02*V04*V102 - 2.87354623154177367e-17*V01*V05*V102 + 
      4.06071735525354572e-18*V08*V102 - 2.42634125222108663e-16*V053*V11 - 
      9.37176108078688587e-16*V04*V05*V06*V11 - 3.35244790840958206e-16*V03*V062*V11 - 
      3.10648473364701745e-16*V042*V07*V11 - 6.90057975496373754e-16*V03*V05*V07*V11 - 
      2.21821911956556994e-16*V02*V06*V07*V11 - 4.88850513842416242e-17*V01*V072*V11 - 
      3.47520405238636972e-16*V03*V04*V08*V11 - 1.73426133260092195e-16*V02*V05*V08*V11 - 
      7.43634283799017917e-17*V01*V06*V08*V11 - 9.46845554714946566e-17*V032*V09*V11 - 
      8.52141910898151561e-17*V02*V04*V09*V11 - 5.66036604632375068e-17*V01*V05*V09*V11 + 8.69953340039142333e-18*V08*V09*V11 - 
      3.94411270918028794e-17*V02*V03*V10*V11 - 2.36387414204980372e-17*V01*V04*V10*V11 + 7.13355003836431577e-18*V07*V10*V11 - 
      1.88547733660368262e-18*V022*V112 - 5.00218765116219884e-18*V01*V03*V112 + 
      2.16632692400698551e-18*V06*V112 - 2.50505293213447478e-16*V04*V052*V12 - 
      1.15917746045849191e-16*V042*V06*V12 - 3.54987364060232191e-16*V03*V05*V06*V12 - 
      4.12020279499965024e-17*V02*V062*V12 - 2.38576469727092836e-16*V03*V04*V07*V12 - 
      1.19770615487532887e-16*V02*V05*V07*V12 - 5.07124805800331702e-17*V01*V06*V07*V12 - 
      6.47918718478982389e-17*V032*V08*V12 - 4.24039803675174197e-17*V02*V04*V08*V12 - 
      3.88751231087389433e-17*V01*V05*V08*V12 + 2.7690975495761338e-18*V082*V12 - 
      3.32696154132035796e-17*V02*V03*V09*V12 - 1.98813724772577363e-17*V01*V04*V09*V12 + 6.04557472487351499e-18*V07*V09*V12 - 
      2.34226984133969081e-18*V022*V10*V12 - 8.59383164855601717e-18*V01*V03*V10*V12 + 
      3.42382501628455562e-18*V06*V10*V12 - 1.8147062952656498e-18*V01*V02*V11*V12 + 2.34757931763448804e-18*V05*V11*V12 - 
      9.26981661958688945e-20*V012*V122 + 3.76888059955406127e-19*V04*V122 - 
      8.36361274443427775e-17*V042*V05*V13 - 9.17950176693134434e-17*V03*V052*V13 - 
      1.20150783087011357e-16*V03*V04*V06*V13 - 5.97212839883038061e-17*V02*V05*V06*V13 - 
      1.2894030416959931e-17*V01*V062*V13 - 4.3381990495060169e-17*V032*V07*V13 - 
      3.93296266568377643e-17*V02*V04*V07*V13 - 2.5906794978533041e-17*V01*V05*V07*V13 - 
      2.22341196487297685e-17*V02*V03*V08*V13 - 1.33661694322552682e-17*V01*V04*V08*V13 + 4.08410497891344671e-18*V07*V08*V13 - 
      2.65900650033852678e-18*V022*V09*V13 - 7.02781940296473079e-18*V01*V03*V09*V13 + 
      3.08097699294414781e-18*V06*V09*V13 - 1.51696642660780306e-18*V01*V02*V10*V13 + 1.96980574001331081e-18*V05*V10*V13 - 
      1.77086450414364689e-19*V012*V11*V13 + 8.01746199349538041e-19*V04*V11*V13 + 3.1104067357809533e-19*V03*V12*V13 + 
      2.66761044808716141e-20*V02*V132 - 5.90103938233287271e-18*V043*V14 - 
      5.50682285659106775e-17*V03*V04*V05*V14 - 1.38738789171722352e-17*V02*V052*V14 - 
      1.93926680625653441e-17*V032*V06*V14 - 1.25492421857998436e-17*V02*V04*V06*V14 - 
      1.16356008375392065e-17*V01*V05*V06*V14 - 1.32132180163545098e-17*V02*V03*V07*V14 - 
      7.86688979513009678e-18*V01*V04*V07*V14 + 1.2304500964992028e-18*V072*V14 - 
      1.13516611217384931e-18*V022*V08*V14 - 4.19421178736286001e-18*V01*V03*V08*V14 + 
      1.69777863381400679e-18*V06*V08*V14 - 1.10110150136287581e-18*V01*V02*V09*V14 + 1.44747653766767693e-18*V05*V09*V14 - 
      1.33775615240206106e-19*V012*V10*V14 + 5.4812363379690805e-19*V04*V10*V14 + 2.69696511440635989e-19*V03*V11*V14 + 
      4.33755457330274038e-20*V02*V12*V14 + 1.07908247437053586e-20*V01*V13*V14 - 
      7.96534547088978833e-18*V03*V042*V15 - 8.53108383960200778e-18*V032*V05*V15 - 
      7.86592533136755287e-18*V02*V04*V05*V15 - 2.53952979103239981e-18*V01*V052*V15 - 
      5.68774133221941011e-18*V02*V03*V06*V15 - 3.43287951677175307e-18*V01*V04*V06*V15 - 
      9.11659371544637752e-19*V022*V07*V15 - 2.37967679913771554e-18*V01*V03*V07*V15 + 
      1.08297554670887428e-18*V06*V07*V15 - 6.35260561392279101e-19*V01*V02*V08*V15 + 8.44395282660420642e-19*V05*V08*V15 - 
      9.20010607677467524e-20*V012*V09*V15 + 4.26880052629373688e-19*V04*V09*V15 + 
      1.95415558705760191e-19*V03*V10*V15 + 3.99479308061092295e-20*V02*V11*V15 + 9.31840351033379809e-21*V01*V12*V15 - 
      6.12384811015537016e-23*V152 - 2.27157433676915669e-18*V032*V04*V16 - 
      7.1824699484293292e-19*V02*V042*V16 - 2.30281582805059822e-18*V02*V03*V05*V16 - 
      1.36294460206149401e-18*V01*V04*V05*V16 - 2.52502728426838716e-19*V022*V06*V16 - 
      9.48012680406330993e-19*V01*V03*V06*V16 + 1.97961255518899566e-19*V062*V16 - 
      3.28973689721514032e-19*V01*V02*V07*V16 + 4.4839281691218025e-19*V05*V07*V16 - 
      4.93178802854843446e-20*V012*V08*V16 + 2.06760867595212884e-19*V04*V08*V16 + 
      1.26551333845250423e-19*V03*V09*V16 + 2.39944514758723903e-20*V02*V10*V16 + 7.12073896521733431e-21*V01*V11*V16 - 
      1.10042011555249594e-22*V14*V16 - 2.02299032055652735e-19*V033*V17 - 5.78376862600555358e-19*V02*V03*V04*V17 - 
      1.75706150093157096e-19*V01*V042*V17 - 1.40770932370863182e-19*V022*V05*V17 - 
      3.58128088297557497e-19*V01*V03*V05*V17 - 1.25464882328369341e-19*V01*V02*V06*V17 + 1.7408019632622931e-19*V05*V06*V17 - 
      2.38952988815568314e-20*V012*V07*V17 + 1.16660003318832422e-19*V04*V07*V17 + 
      6.51291700718395288e-20*V03*V08*V17 + 1.65374140254543315e-20*V02*V09*V17 + 4.55198328438344892e-21*V01*V10*V17 - 
      9.57259928920731273e-23*V13*V17 - 7.41687604647488302e-20*V02*V032*V18 - 
      2.23977797796657247e-20*V022*V04*V18 - 8.67209726684453999e-20*V01*V03*V04*V18 - 
      4.45012562788492981e-20*V01*V02*V05*V18 + 3.21252948859191099e-20*V052*V18 - 
      8.71008822387751992e-21*V012*V06*V18 + 3.79093646077924198e-20*V04*V06*V18 + 
      3.08302381717588055e-20*V03*V07*V18 + 7.11644160570608499e-21*V02*V08*V18 + 2.62786632251028996e-21*V01*V09*V18 - 
      6.6722431671602705e-23*V12*V18 - 8.23221826730194049e-21*V022*V03*V19 - 
      9.93815294533100975e-21*V01*V032*V19 - 1.01469625017641291e-20*V01*V02*V04*V19 - 
      2.8272025980454044e-21*V012*V05*V19 + 1.5001309082161753e-20*V04*V05*V19 + 1.07414409217579733e-20*V03*V06*V19 + 
      3.61559622704554929e-21*V02*V07*V19 + 1.21375810982002089e-21*V01*V08*V19 - 4.52894551504162315e-23*V11*V19 - 
      1.83369685945849808e-22*V023*V20 - 2.2664560722386206e-21*V01*V02*V03*V20 - 
      6.38416926851987221e-22*V012*V04*V20 + 1.46241105846946899e-21*V042*V20 + 
      3.55995847855737364e-21*V03*V05*V20 + 1.05139593517469164e-21*V02*V06*V20 + 5.1592415100404636e-22*V01*V07*V20 - 
      2.40512366917859673e-23*V10*V20 - 1.17603118104313436e-22*V01*V022*V21 - 
      1.24497773269557942e-22*V012*V03*V21 + 7.57182464732729506e-22*V03*V04*V21 + 3.8032457584596206e-22*V02*V05*V21 + 
      1.63758977116233168e-22*V01*V06*V21 - 1.25958062256123308e-23*V09*V21 - 1.35923201829105981e-23*V012*V02*V22 + 
      8.08743212615649862e-23*V032*V22 + 6.65285218507904166e-23*V02*V04*V22 + 4.88529096695696825e-23*V01*V05*V22 - 
      4.93104038705642046e-24*V08*V22 - 3.9398029515682893e-25*V013*V23 + 1.59862033269023072e-23*V02*V03*V23 + 
      9.61334562728361257e-24*V01*V04*V23 - 1.94602637215429881e-24*V07*V23 + 6.26292814025165988e-25*V022*V24 + 
      1.83642366889049485e-24*V01*V03*V24 - 5.29717661161560126e-25*V06*V24 + 1.71517283667412594e-25*V01*V02*V25 - 
      1.50953652345996998e-25*V05*V25 + 8.49095463700062349e-27*V012*V26 - 2.5516688192999293e-26*V04*V26 - 
      4.85262622533960364e-27*V03*V27 - 3.83462467477447512e-28*V02*V28 - 4.1085264372583662e-29*V01*V29 + 
      5.187533380376725e-32*V32) + delta16*eps8*
    (6.57341069930505957e-14*V04*V054 + 2.41780447542352583e-13*V042*V052*V06 + 
      1.83112615511333405e-13*V03*V053*V06 + 2.32956591566679322e-14*V043*V062 + 
      3.45808799634908851e-13*V03*V04*V05*V062 + 8.59054206453527902e-14*V02*V052*V062 + 
      4.08755785254966719e-14*V032*V063 + 1.63216045054023066e-14*V02*V04*V063 + 
      2.45253471152980031e-14*V01*V05*V063 + 1.06575856533959433e-13*V043*V05*V07 + 
      3.71942032371744272e-13*V03*V04*V052*V07 + 6.31908045484744048e-14*V02*V053*V07 + 
      2.30267092897478651e-13*V03*V042*V06*V07 + 2.58305758632705182e-13*V032*V05*V06*V07 + 
      2.26633190383634135e-13*V02*V04*V05*V06*V07 + 7.65066199604802214e-14*V01*V052*V06*V07 + 
      8.18146863289074192e-14*V02*V03*V062*V07 + 4.94012570907012644e-14*V01*V04*V062*V07 + 
      8.75230216216234051e-14*V032*V04*V072 + 3.71114629736766969e-14*V02*V042*V072 + 
      8.94495658668934249e-14*V02*V03*V05*V072 + 5.1987893521549269e-14*V01*V04*V05*V072 + 
      1.30574923577339216e-14*V022*V06*V072 + 3.57165169095362713e-14*V01*V03*V06*V072 - 
      1.32248749498565307e-14*V062*V072 + 4.18112103561410767e-15*V01*V02*V073 - 
      9.03563399349047416e-15*V05*V073 + 5.94143953285383414e-15*V044*V08 + 
      1.78345979057117686e-13*V03*V042*V05*V08 + 9.82531923133393398e-14*V032*V052*V08 + 
      8.83878801351799419e-14*V02*V04*V052*V08 + 1.93436890765980784e-14*V01*V053*V08 + 
      1.26589697667744646e-13*V032*V04*V06*V08 + 2.49265623564595054e-14*V02*V042*V06*V08 + 
      1.26834862741470223e-13*V02*V03*V05*V06*V08 + 7.59538186006467876e-14*V01*V04*V05*V06*V08 + 
      4.3336715890727296e-15*V022*V062*V08 + 2.66296006059710312e-14*V01*V03*V062*V08 - 
      5.43812770565260411e-15*V063*V08 + 3.07042683755525054e-14*V033*V07*V08 + 
      8.41789334620761351e-14*V02*V03*V04*V07*V08 + 2.54779970081596694e-14*V01*V042*V07*V08 + 
      2.05115037806444606e-14*V022*V05*V07*V08 + 5.41097980697126504e-14*V01*V03*V05*V07*V08 + 
      1.81192661059243176e-14*V01*V02*V06*V07*V08 - 4.12183254424205178e-14*V05*V06*V07*V08 + 
      1.7939909602322838e-15*V012*V072*V08 - 1.37796983210993712e-14*V04*V072*V08 + 
      1.16146829828271081e-14*V02*V032*V082 + 2.1990236776215582e-15*V022*V04*V082 + 
      1.37435035871653669e-14*V01*V03*V04*V082 + 6.96880978969626487e-15*V01*V02*V05*V082 - 
      8.00851101498600685e-15*V052*V082 + 1.40784056642455447e-15*V012*V06*V082 - 
      8.46931173233439395e-15*V04*V06*V082 - 7.66342714227269836e-15*V03*V07*V082 - 
      5.23952960440792423e-16*V02*V083 + 2.96044045927665092e-14*V03*V043*V09 + 
      1.01087570736345801e-13*V032*V04*V05*V09 + 4.32967068026228131e-14*V02*V042*V05*V09 + 
      5.16988230543136584e-14*V02*V03*V052*V09 + 2.99641594241599094e-14*V01*V04*V052*V09 + 
      2.33091087441817556e-14*V033*V06*V09 + 6.29536639954539265e-14*V02*V03*V04*V06*V09 + 
      1.91889244081232209e-14*V01*V042*V06*V09 + 1.52337410840229085e-14*V022*V05*V06*V09 + 
      4.11219877114971314e-14*V01*V03*V05*V06*V09 + 6.8178905274089516e-15*V01*V02*V062*V09 - 
      1.55037245837375691e-14*V05*V062*V09 + 2.43170011425591047e-14*V02*V032*V07*V09 + 
      9.87839952988575414e-15*V022*V04*V07*V09 + 2.79710193924951744e-14*V01*V03*V04*V07*V09 + 
      1.44530320089523658e-14*V01*V02*V05*V07*V09 - 1.58497379529772237e-14*V052*V07*V09 + 
      2.73265372150795585e-15*V012*V06*V07*V09 - 2.06796744078499653e-14*V04*V06*V07*V09 - 
      7.56448599141625129e-15*V03*V072*V09 + 5.69763993906790572e-15*V022*V03*V08*V09 + 
      7.23262705798848703e-15*V01*V032*V08*V09 + 7.01491112183967793e-15*V01*V02*V04*V08*V09 + 
      2.05644786002459425e-15*V012*V05*V08*V09 - 1.61536848501606446e-14*V04*V05*V08*V09 - 
      1.15594564821288158e-14*V03*V06*V08*V09 - 3.86557441838306075e-15*V02*V07*V08*V09 - 
      6.47687377189469251e-16*V01*V082*V09 + 2.14994544742205222e-16*V023*V092 + 
      1.93895018150289569e-15*V01*V02*V03*V092 + 5.35156556246168981e-16*V012*V04*V092 - 
      2.01438365652205319e-15*V042*V092 - 4.41902722268736452e-15*V03*V05*V092 - 
      1.44555196446747675e-15*V02*V06*V092 - 6.33921551039423799e-16*V01*V07*V092 + 
      1.99321445674657569e-14*V032*V042*V10 + 2.55431108489700907e-15*V02*V043*V10 + 
      1.42299538645535757e-14*V033*V05*V10 + 3.98080867587723904e-14*V02*V03*V04*V05*V10 + 
      1.19592867404794541e-14*V01*V042*V05*V10 + 4.88039496854636973e-15*V022*V052*V10 + 
      1.24958261172754114e-14*V01*V03*V052*V10 + 1.41722753693654577e-14*V02*V032*V06*V10 + 
      2.65582856876743328e-15*V022*V04*V06*V10 + 1.6784793402493961e-14*V01*V03*V04*V06*V10 + 
      8.50336522161927461e-15*V01*V02*V05*V06*V10 - 9.87448412387743231e-15*V052*V06*V10 + 
      8.59825375650939611e-16*V012*V062*V10 - 5.20320313645630389e-15*V04*V062*V10 + 
      4.64799520813939974e-15*V022*V03*V07*V10 + 5.80223512212028792e-15*V01*V032*V07*V10 + 
      5.68686953696748434e-15*V01*V02*V04*V07*V10 + 1.64618455001600879e-15*V012*V05*V07*V10 - 
      1.32381228876402594e-14*V04*V05*V07*V10 - 9.44870927140571033e-15*V03*V06*V07*V10 - 
      1.58791494464337547e-15*V02*V072*V10 + 1.5412653690466652e-16*V023*V08*V10 + 
      3.07548384717876884e-15*V01*V02*V03*V08*V10 + 8.86711993854333713e-16*V012*V04*V08*V10 - 
      2.69889549547964424e-15*V042*V08*V10 - 7.31861079360522991e-15*V03*V05*V08*V10 - 
      1.92975459403414375e-15*V02*V06*V08*V10 - 1.05524665511427683e-15*V01*V07*V08*V10 + 
      3.87332934011616645e-16*V01*V022*V09*V10 + 4.32580441605811431e-16*V012*V03*V09*V10 - 
      3.71212347626428978e-15*V03*V04*V09*V10 - 1.86132365585678973e-15*V02*V05*V09*V10 - 
      7.98502108592990989e-16*V01*V06*V09*V10 + 2.82138140922191058e-17*V092*V10 + 
      4.93991666333490436e-17*V012*V02*V102 - 4.15662638368108303e-16*V032*V102 - 
      3.06501935556147459e-16*V02*V04*V102 - 2.50529207807130243e-16*V01*V05*V102 + 
      2.23256692586103702e-17*V08*V102 + 5.91823460217204586e-15*V033*V04*V11 + 
      7.8721285095677842e-15*V02*V03*V042*V11 + 1.61478570505999141e-15*V01*V043*V11 + 
      9.1100948478713529e-15*V02*V032*V05*V11 + 3.77175254777456067e-15*V022*V04*V05*V11 + 
      1.04366080795315093e-14*V01*V03*V04*V05*V11 + 2.69849460045561286e-15*V01*V02*V052*V11 - 
      2.02663203964642575e-15*V053*V11 + 2.76977110618598336e-15*V022*V03*V06*V11 + 
      3.56300142280697567e-15*V01*V032*V06*V11 + 3.43383621793385053e-15*V01*V02*V04*V06*V11 + 
      1.01352512914148214e-15*V012*V05*V06*V11 - 7.97212456601129004e-15*V04*V05*V06*V11 - 
      2.85960654735498527e-15*V03*V062*V11 + 2.81447404026159563e-16*V023*V07*V11 + 
      2.513322296406864e-15*V01*V02*V03*V07*V11 + 6.92600106185518575e-16*V012*V04*V07*V11 - 
      2.64970193783630049e-15*V042*V07*V11 - 5.79811596929875449e-15*V03*V05*V07*V11 - 
      1.90141480325951133e-15*V02*V06*V07*V11 - 4.15492266218342613e-16*V01*V072*V11 + 
      3.10780360312794857e-16*V01*V022*V08*V11 + 3.49711972591764083e-16*V012*V03*V08*V11 - 
      2.97923550487177807e-15*V03*V04*V08*V11 - 1.49003463605366678e-15*V02*V05*V08*V11 - 
      6.42507259426517807e-16*V01*V06*V08*V11 + 9.54170451377835256e-17*V012*V02*V09*V11 - 
      8.05485824683980561e-16*V032*V09*V11 - 7.3679754894332965e-16*V02*V04*V09*V11 - 
      4.84199819571286264e-16*V01*V05*V09*V11 + 4.56225859076305136e-17*V08*V09*V11 + 
      6.46173058740241587e-18*V013*V10*V11 - 3.43198603122789953e-16*V02*V03*V10*V11 - 
      2.06283148005663802e-16*V01*V04*V10*V11 + 3.75046213739546606e-17*V07*V10*V11 - 
      1.66465901990895724e-17*V022*V112 - 4.36595881941384573e-17*V01*V03*V112 + 
      1.14830628944247647e-17*V06*V112 + 5.17154743166072874e-16*V034*V12 + 
      2.9940711579334275e-15*V02*V032*V04*V12 + 2.7105075742152509e-16*V022*V042*V12 + 
      1.77898762447333379e-15*V01*V03*V042*V12 + 1.47940473406824506e-15*V022*V03*V05*V12 + 
      1.79863434046842553e-15*V01*V032*V05*V12 + 1.7964426947600565e-15*V01*V02*V04*V05*V12 + 
      2.53820788057461147e-16*V012*V052*V12 - 2.15621926055858269e-15*V04*V052*V12 + 
      6.19942905068133179e-17*V023*V06*V12 + 1.26319781573573173e-15*V01*V02*V03*V06*V12 + 
      3.64658350040870808e-16*V012*V04*V06*V12 - 1.1235358944972902e-15*V042*V06*V12 - 
      3.06767648175326695e-15*V03*V05*V06*V12 - 4.01334351954426353e-16*V02*V062*V12 + 
      2.11343533438320723e-16*V01*V022*V07*V12 + 2.32716550302900594e-16*V012*V03*V07*V12 - 
      2.06305941185996262e-15*V03*V04*V07*V12 - 1.03707975547416775e-15*V02*V05*V07*V12 - 
      4.42264188776665289e-16*V01*V06*V07*V12 + 6.65286577728386295e-17*V012*V02*V08*V12 - 
      5.65245253233530121e-16*V032*V08*V12 - 4.15372423348237056e-16*V02*V04*V08*V12 - 
      3.40675459874727449e-16*V01*V05*V08*V12 + 1.53177381298335791e-17*V082*V12 + 
      5.36865718394245333e-18*V013*V09*V12 - 2.90741855524162567e-16*V02*V03*V09*V12 - 
      1.74300932391753565e-16*V01*V04*V09*V12 + 3.18474612554683783e-17*V07*V09*V12 - 
      2.3358425889680214e-17*V022*V10*V12 - 7.64945763017664179e-17*V01*V03*V10*V12 + 
      1.90634692583689766e-17*V06*V10*V12 - 1.61492807380700035e-17*V01*V02*V11*V12 + 1.25373810388224363e-17*V05*V11*V12 - 
      8.49560846249707254e-19*V012*V122 + 2.13892624329950476e-18*V04*V122 + 
      3.7202097604764324e-16*V02*V033*V13 + 4.83558018945456496e-16*V022*V03*V04*V13 + 
      6.31120587797658768e-16*V01*V032*V04*V13 + 3.02774173444914777e-16*V01*V02*V042*V13 + 
      7.57743010839660363e-17*V023*V05*V13 + 6.54379759647705099e-16*V01*V02*V03*V05*V13 + 
      1.79259399636296167e-16*V012*V04*V05*V13 - 7.23631395529061765e-16*V042*V05*V13 - 
      7.85019520623106138e-16*V03*V052*V13 + 1.06529657930230129e-16*V01*V022*V06*V13 + 
      1.20276950978568476e-16*V012*V03*V06*V13 - 1.04161824769735271e-15*V03*V04*V06*V13 - 
      5.1923372499637944e-16*V02*V05*V06*V13 - 1.12596888496343837e-16*V01*V062*V13 + 
      4.30794147028714385e-17*V012*V02*V07*V13 - 3.73360364506457781e-16*V032*V07*V13 - 
      3.43286538490323088e-16*V02*V04*V07*V13 - 2.24225765515909625e-16*V01*V05*V07*V13 + 
      3.64499609263614672e-18*V013*V08*V13 - 1.94642399479642116e-16*V02*V03*V08*V13 - 
      1.17291230684277417e-16*V01*V04*V08*V13 + 2.16926049087650371e-17*V07*V08*V13 - 
      2.35855594531104357e-17*V022*V09*V13 - 6.16926254909953721e-17*V01*V03*V09*V13 + 
      1.64298498920636811e-17*V06*V09*V13 - 1.35061078277827723e-17*V01*V02*V10*V13 + 1.05620300270921628e-17*V05*V10*V13 - 
      1.6080322422110843e-18*V012*V11*V13 + 4.34887966859934512e-18*V04*V11*V13 + 1.70538614916588182e-18*V03*V12*V13 + 
      1.48919167728081617e-19*V02*V132 + 7.97996092208283075e-17*V022*V032*V14 + 
      6.14434655541117718e-17*V01*V033*V14 + 8.94934693116887551e-18*V023*V04*V14 + 
      1.9145389635651338e-16*V01*V02*V03*V04*V14 + 2.77225760465336647e-17*V012*V042*V14 - 
      5.83947259339738379e-17*V043*V14 + 4.78797655324969845e-17*V01*V022*V05*V14 + 
      5.12981545461121592e-17*V012*V03*V05*V14 - 4.8566892188305365e-16*V03*V04*V05*V14 - 
      1.22466613018192245e-16*V02*V052*V14 + 1.96189271597697757e-17*V012*V02*V06*V14 - 
      1.71800313314396063e-16*V032*V06*V14 - 1.24859404698336948e-16*V02*V04*V06*V14 - 
      1.03535058690555155e-16*V01*V05*V06*V14 + 2.06172503052072802e-18*V013*V07*V14 - 
      1.17157958253506907e-16*V02*V03*V07*V14 - 7.00013809147757549e-17*V01*V04*V07*V14 + 
      6.57441371335224691e-18*V072*V14 - 1.14380942270563129e-17*V022*V08*V14 - 
      3.77155120207839055e-17*V01*V03*V08*V14 + 9.56156649599143882e-18*V06*V08*V14 - 9.89393536588510121e-18*V01*V02*V09*V14 + 
      7.78819442939398486e-18*V05*V09*V14 - 1.23222178722002194e-18*V012*V10*V14 + 
      3.12730837746796199e-18*V04*V10*V14 + 1.48095695499180276e-18*V03*V11*V14 + 2.53751811624488645e-19*V02*V12*V14 + 
      6.11899048689692215e-20*V01*V13*V14 + 7.2166001032348606e-18*V023*V03*V15 + 
      2.89515710731464457e-17*V01*V02*V032*V15 + 1.38159433984416142e-17*V01*V022*V04*V15 + 
      1.55936770454600639e-17*V012*V03*V04*V15 - 7.05442764905669477e-17*V03*V042*V15 + 
      8.17104337095175903e-18*V012*V02*V05*V15 - 7.51502606106501204e-17*V032*V05*V15 - 
      6.99477602123483788e-17*V02*V04*V05*V15 - 2.25065944765418917e-17*V01*V052*V15 + 
      9.18247510040250246e-19*V013*V06*V15 - 5.06118396644249416e-17*V02*V03*V06*V15 - 
      3.0598421176122501e-17*V01*V04*V06*V15 - 8.19920784031163526e-18*V022*V07*V15 - 
      2.12535339976096911e-17*V01*V03*V07*V15 + 5.87786098911316112e-18*V06*V07*V15 - 5.71602503945978419e-18*V01*V02*V08*V15 + 
      4.59640263565529704e-18*V05*V08*V15 - 8.44980821185848679e-19*V012*V09*V15 + 
      2.34101112310480958e-18*V04*V09*V15 + 1.08096251899080156e-18*V03*V10*V15 + 2.2412326322593601e-19*V02*V11*V15 + 
      5.30158579798794711e-20*V01*V12*V15 - 2.78882693889320646e-22*V152 + 8.09865894724377548e-20*V024*V16 + 
      3.82097849454898969e-18*V01*V022*V03*V16 + 1.92474345435326892e-18*V012*V032*V16 + 
      2.23003878507029565e-18*V012*V02*V04*V16 - 2.06371515802387261e-17*V032*V04*V16 - 
      7.33867015969240774e-18*V02*V042*V16 + 3.36697136162206631e-19*V013*V05*V16 - 
      2.09249964440749156e-17*V02*V03*V05*V16 - 1.24349747811721972e-17*V01*V04*V05*V16 - 
      2.59810512352910115e-18*V022*V06*V16 - 8.69843038276021982e-18*V01*V03*V06*V16 + 
      1.13989383200724868e-18*V062*V16 - 3.01489212442883254e-18*V01*V02*V07*V16 + 
      2.45796843725963388e-18*V05*V07*V16 - 4.61149709146992944e-19*V012*V08*V16 + 
      1.19832231092828045e-18*V04*V08*V16 + 7.03296688339591914e-19*V03*V09*V16 + 1.4173084544723974e-19*V02*V10*V16 + 
      4.06273155604436202e-20*V01*V11*V16 - 5.10072355542201605e-22*V14*V16 + 1.59189708159592513e-19*V01*V023*V17 + 
      5.3604860463964355e-19*V012*V02*V03*V17 - 1.84639533684677162e-18*V033*V17 + 
      8.96738549806458327e-20*V013*V04*V17 - 5.28554698410103093e-18*V02*V03*V04*V17 - 
      1.60636935676806851e-18*V01*V042*V17 - 1.29506562955975255e-18*V022*V05*V17 - 
      3.29319330297358961e-18*V01*V03*V05*V17 - 1.15229232048020444e-18*V01*V02*V06*V17 + 9.71759090696062791e-19*V05*V06*V17 - 
      2.24564926931514711e-19*V012*V07*V17 + 6.53511261296693495e-19*V04*V07*V17 + 
      3.67051651008345705e-19*V03*V08*V17 + 9.41548313034706551e-20*V02*V09*V17 + 2.62230295177210131e-20*V01*V10*V17 - 
      4.36793441115767937e-22*V13*V17 + 3.4332427870703965e-20*V012*V022*V18 + 
      1.89080993153141124e-20*V013*V03*V18 - 6.97448753315938279e-19*V02*V032*V18 - 
      2.38086794995216372e-19*V022*V04*V18 - 8.19745443100803979e-19*V01*V03*V04*V18 - 
      4.20152631295694308e-19*V01*V02*V05*V18 + 1.81276939988217018e-19*V052*V18 - 
      8.34875341739188238e-20*V012*V06*V18 + 2.2535205110324967e-19*V04*V06*V18 + 1.75153620517778455e-19*V03*V07*V18 + 
      4.28390673519808981e-20*V02*V08*V18 + 1.52279513929838322e-20*V01*V09*V18 - 3.10732187824734333e-22*V12*V18 + 
      2.31364928330847789e-21*V013*V02*V19 - 7.81100408424239576e-20*V022*V03*V19 - 
      9.53883281010232309e-20*V01*V032*V19 - 9.60582353100381104e-20*V01*V02*V04*V19 - 
      2.75291972400230836e-20*V012*V05*V19 + 8.66306705167854345e-20*V04*V05*V19 + 
      6.22218848410562899e-20*V03*V06*V19 + 2.10787683945755804e-20*V02*V07*V19 + 7.14065175512557432e-21*V01*V08*V19 - 
      2.07957700973409441e-22*V11*V19 + 4.7868605861554715e-23*V014*V20 - 2.04442003446809343e-21*V023*V20 - 
      2.2276757475428443e-20*V01*V02*V03*V20 - 6.33309253739775475e-21*V012*V04*V20 + 
      8.99451089582690859e-21*V042*V20 + 2.08686557677241261e-20*V03*V05*V20 + 6.50644600213535392e-21*V02*V06*V20 + 
      3.06399018964562627e-21*V01*V07*V20 - 1.13136039711155753e-22*V10*V20 - 1.15948400864654754e-21*V01*V022*V21 - 
      1.27693938414017716e-21*V012*V03*V21 + 4.54271184634224831e-21*V03*V04*V21 + 
      2.28859264599378179e-21*V02*V05*V21 + 9.914318835664949e-22*V01*V06*V21 - 5.85194080533412181e-23*V09*V21 - 
      1.4094645059235555e-22*V012*V02*V22 + 4.93342234764797947e-22*V032*V22 + 
      4.26699291235306349e-22*V02*V04*V22 + 2.99898358650397184e-22*V01*V05*V22 - 2.35766756601138548e-23*V08*V22 - 
      4.43227832051432546e-24*V013*V23 + 9.99657071323357404e-23*V02*V03*V23 + 6.02952877918978675e-23*V01*V04*V23 - 
      9.21031173761934736e-24*V07*V23 + 4.19792797253310825e-24*V022*V24 + 1.1753179408536263e-23*V01*V03*V24 - 
      2.59300372556460543e-24*V06*V24 + 1.1208060120840823e-24*V01*V02*V25 - 7.33579449635699915e-25*V05*V25 + 
      5.73139437997542085e-26*V012*V26 - 1.28868040231045914e-25*V04*V26 - 2.44149183534078412e-26*V03*V27 - 
      2.01317795425659944e-27*V02*V28 - 2.15697637956064226e-28*V01*V29 + 2.33439002116952625e-31*V32) + 
   delta14*eps9*(9.2027749790270834e-13*V04*V054 + 
      3.51529378509599537e-12*V042*V052*V06 + 2.57531395795744542e-12*V03*V053*V06 + 
      4.68821101206714135e-13*V043*V062 + 5.04156046388224925e-12*V03*V04*V05*V062 + 
      1.25149090147969733e-12*V02*V052*V062 + 5.98358979870006177e-13*V032*V063 + 
      3.30697160923354823e-13*V02*V04*V063 + 3.59015387922003706e-13*V01*V05*V063 + 
      1.54770902073339786e-12*V043*V05*V07 + 5.22245322432256504e-12*V03*V04*V052*V07 + 
      8.85278289269602908e-13*V02*V053*V07 + 3.34789884294856701e-12*V03*V042*V06*V07 + 
      3.64502686791704488e-12*V032*V05*V06*V07 + 3.29942086561925675e-12*V02*V04*V05*V06*V07 + 
      1.08331013876846461e-12*V01*V052*V06*V07 + 1.19189609664733079e-12*V02*V03*V062*V07 + 
      7.20222923411749893e-13*V01*V04*V062*V07 + 1.23310841865774471e-12*V032*V04*V072 + 
      5.40925590449820538e-13*V02*V042*V072 + 1.25698600504328181e-12*V02*V03*V05*V072 + 
      7.34682860463006455e-13*V01*V04*V05*V072 + 1.91100149922503923e-13*V022*V06*V072 + 
      5.08254138526707268e-13*V01*V03*V06*V072 - 7.64611433933906598e-14*V062*V072 + 
      5.91234035409310189e-14*V01*V02*V073 - 5.09638760898725948e-14*V05*V073 + 
      1.20313122609575115e-13*V044*V08 + 2.60592257462469684e-12*V03*V042*V05*V08 + 
      1.39241176895067665e-12*V032*V052*V08 + 1.29118006840152097e-12*V02*V04*V052*V08 + 
      2.75199123413025202e-13*V01*V053*V08 + 1.85702844856635765e-12*V032*V04*V06*V08 + 
      5.0847178291301488e-13*V02*V042*V06*V08 + 1.85678350730495815e-12*V02*V03*V05*V06*V08 + 
      1.11421706913981459e-12*V01*V04*V05*V06*V08 + 8.91774259222156834e-14*V022*V062*V08 + 
      3.9259879858883196e-13*V01*V03*V062*V08 - 3.48925646605874004e-14*V063*V08 + 
      4.3682400541750032e-13*V033*V07*V08 + 1.22969530323954378e-12*V02*V03*V04*V07*V08 + 
      3.72274653517813835e-13*V01*V042*V07*V08 + 3.00655553353100408e-13*V022*V05*V07*V08 + 
      7.73721533059789961e-13*V01*V03*V05*V07*V08 + 2.65254786757851164e-13*V01*V02*V06*V07*V08 - 
      2.39155899875248433e-13*V05*V06*V07*V08 + 2.60987866884088243e-14*V012*V072*V08 - 
      8.03549017520770582e-14*V04*V072*V08 + 1.71100672519167696e-13*V02*V032*V082 + 
      4.56040427967957179e-14*V022*V04*V082 + 2.03079145860440213e-13*V01*V03*V04*V082 + 
      1.02660403511500618e-13*V01*V02*V05*V082 - 4.66375552613764763e-14*V052*V082 + 
      2.09028597185041321e-14*V012*V06*V082 - 5.47894665822828697e-14*V04*V06*V082 - 
      4.50199147508528373e-14*V03*V07*V082 - 3.44520757465401424e-15*V02*V083 + 
      4.29919172425943851e-13*V03*V043*V09 + 1.42855000645584588e-12*V032*V04*V05*V09 + 
      6.31079855524790627e-13*V02*V042*V05*V09 + 7.28751764825826351e-13*V02*V03*V052*V09 + 
      4.24948513106750662e-13*V01*V04*V052*V09 + 3.31207474432659181e-13*V033*V06*V09 + 
      9.16505796005349097e-13*V02*V03*V04*V06*V09 + 2.78991570245713918e-13*V01*V042*V06*V09 + 
      2.22950174909587911e-13*V022*V05*V06*V09 + 5.87297649610798002e-13*V01*V03*V05*V06*V09 + 
      9.93246747206108994e-14*V01*V02*V062*V09 - 9.04268197055167876e-14*V05*V062*V09 + 
      3.44151421213524009e-13*V02*V032*V07*V09 + 1.45157255056839087e-13*V022*V04*V07*V09 + 
      3.98847476489227382e-13*V01*V03*V04*V07*V09 + 2.05207975171136871e-13*V01*V02*V05*V07*V09 - 
      9.02489860168251114e-14*V052*V07*V09 + 3.97090115973782429e-14*V012*V06*V07*V09 - 
      1.21234299171397313e-13*V04*V06*V07*V09 - 4.34832118647183069e-14*V03*V072*V09 + 
      8.35154314869723357e-14*V022*V03*V08*V09 + 1.04413777520522874e-13*V01*V032*V08*V09 + 
      1.02474608603295315e-13*V01*V02*V04*V08*V09 + 3.00577237106305179e-14*V012*V05*V08*V09 - 
      9.5014677101806047e-14*V04*V05*V08*V09 - 6.82441520888817785e-14*V03*V06*V08*V09 - 
      2.30417568730342737e-14*V02*V07*V08*V09 - 3.90245842614702283e-15*V01*V082*V09 + 
      3.2017162874205049e-15*V023*V092 + 2.78331917136132001e-14*V01*V02*V03*V092 + 
      7.8025080030448711e-15*V012*V04*V092 - 1.19727635571010697e-14*V042*V092 - 
      2.56376154508285016e-14*V03*V05*V092 - 8.662679858761405e-15*V02*V06*V092 - 
      3.7461848025400631e-15*V01*V07*V092 + 2.93788533084772445e-13*V032*V042*V10 + 
      5.28025030799124843e-14*V02*V043*V10 + 2.03935806565913325e-13*V033*V05*V10 + 
      5.85903411589022774e-13*V02*V03*V04*V05*V10 + 1.76273119850863467e-13*V01*V042*V05*V10 + 
      7.19706540314973582e-14*V022*V052*V10 + 1.80101432318692569e-13*V01*V03*V052*V10 + 
      2.09325361211895904e-13*V02*V032*V06*V10 + 5.54394432999439431e-14*V022*V04*V06*V10 + 
      2.48633844172469484e-13*V01*V03*V04*V06*V10 + 1.25595216727137542e-13*V01*V02*V05*V06*V10 - 
      5.79874161533721794e-14*V052*V06*V10 + 1.27982079382029731e-14*V012*V062*V10 - 
      3.39279746520210285e-14*V04*V062*V10 + 6.8543480029997484e-14*V022*V03*V07*V10 + 
      8.41241136800300692e-14*V01*V032*V07*V10 + 8.37004873698603963e-14*V01*V02*V04*V07*V10 + 
      2.41714358542785016e-14*V012*V05*V07*V10 - 7.81109406429775976e-14*V04*V05*V07*V10 - 
      5.59662970004502383e-14*V03*V06*V07*V10 - 9.49277390328420895e-15*V02*V072*V10 + 
      3.28404349954127821e-15*V023*V08*V10 + 4.57808003036391903e-14*V01*V02*V03*V08*V10 + 
      1.32332447076646551e-14*V012*V04*V08*V10 - 1.77418016790767639e-14*V042*V08*V10 - 
      4.35126924047974853e-14*V03*V05*V08*V10 - 1.27886819195980349e-14*V02*V06*V08*V10 - 
      6.37991662579634914e-15*V01*V07*V08*V10 + 5.711956669166457e-15*V01*V022*V09*V10 + 
      6.44120888090042317e-15*V012*V03*V09*V10 - 2.22738805660703071e-14*V03*V04*V09*V10 - 
      1.12188685089209663e-14*V02*V05*V09*V10 - 4.84890467791860813e-15*V01*V06*V09*V10 + 
      1.2237837696252004e-16*V092*V10 + 7.43930962391029022e-16*V012*V02*V102 - 
      2.52214658863760293e-15*V032*V102 - 2.06377044423568719e-15*V02*V04*V102 - 
      1.53265165654038824e-15*V01*V05*V102 + 1.01125323142554014e-16*V08*V102 + 
      8.45068847845031664e-14*V033*V04*V11 + 1.14741791913598296e-13*V02*V03*V042*V11 + 
      2.34501366777787555e-14*V01*V043*V11 + 1.29770516663555942e-13*V02*V032*V05*V11 + 
      5.54236792035203787e-14*V022*V04*V05*V11 + 1.49872878869174096e-13*V01*V03*V04*V05*V11 + 
      3.86020397112071863e-14*V01*V02*V052*V11 - 1.17530390982218168e-14*V053*V11 + 
      4.05363954381068928e-14*V022*V03*V06*V11 + 5.15537110214019871e-14*V01*V032*V06*V11 + 
      4.99912252366554053e-14*V01*V02*V04*V06*V11 + 1.48525946824338485e-14*V012*V05*V06*V11 - 
      4.75301556329565193e-14*V04*V05*V06*V11 - 1.71078685354908802e-14*V03*V062*V11 + 
      4.19133768535047914e-15*V023*V07*V11 + 3.62029277783704558e-14*V01*V02*V03*V07*V11 + 
      1.01356742535066135e-14*V012*V04*V07*V11 - 1.5879023741019962e-14*V042*V07*V11 - 
      3.39376622168137121e-14*V03*V05*V07*V11 - 1.14870728254485135e-14*V02*V06*V07*V11 - 
      2.47668355241084042e-15*V01*V072*V11 + 4.55538717201667285e-15*V01*V022*V08*V11 + 
      5.20364664735906474e-15*V012*V03*V08*V11 - 1.79666458681735426e-14*V03*V04*V08*V11 - 
      9.02748006982243085e-15*V02*V05*V08*V11 - 3.92007640620342944e-15*V01*V06*V08*V11 + 
      1.41294868581686319e-15*V012*V02*V09*V11 - 4.80101285674848197e-15*V032*V09*V11 - 
      4.5117615672932807e-15*V02*V04*V09*V11 - 2.91205994069570784e-15*V01*V05*V09*V11 + 1.98987849141275601e-16*V08*V09*V11 + 
      1.01382179741128823e-16*V013*V10*V11 - 2.11832097712529705e-15*V02*V03*V10*V11 - 
      1.27781861860006245e-15*V01*V04*V10*V11 + 1.63809950617857517e-16*V07*V10*V11 - 
      1.05000649236920804e-16*V022*V112 - 2.69645596502875988e-16*V01*V03*V112 + 
      5.07351112155322568e-17*V06*V112 + 7.52792251420101996e-15*V034*V12 + 
      4.46011011930481941e-14*V02*V032*V04*V12 + 5.78095019588847463e-15*V022*V042*V12 + 
      2.65628844296234408e-14*V01*V03*V042*V12 + 2.20514774157545545e-14*V022*V03*V05*V12 + 
      2.63862457128973345e-14*V01*V032*V05*V12 + 2.67606607158289165e-14*V01*V02*V04*V05*V12 + 
      3.77537735499442164e-15*V012*V052*V12 - 1.29735202951829402e-14*V04*V052*V12 + 
      1.33921405092791676e-15*V023*V06*V12 + 1.89108122040942112e-14*V01*V02*V03*V06*V12 + 
      5.4719887384553758e-15*V012*V04*V06*V12 - 7.49855846149601526e-15*V042*V06*V12 - 
      1.85304353138881422e-14*V03*V05*V06*V12 - 2.70008681145409571e-15*V02*V062*V12 + 
      3.15021105939350778e-15*V01*V022*V07*V12 + 3.49355814691473433e-15*V012*V03*V07*V12 - 
      1.25150906872672888e-14*V03*V04*V07*V12 - 6.31790237770523476e-15*V02*V05*V07*V12 - 
      2.71523072084925534e-15*V01*V06*V07*V12 + 1.00483949267842707e-15*V012*V02*V08*V12 - 
      3.45611541419847227e-15*V032*V08*V12 - 2.8171879183297578e-15*V02*V04*V08*V12 - 
      2.09988005142195356e-15*V01*V05*V08*V12 + 6.98212136754078664e-17*V082*V12 + 
      8.45496230065122585e-17*V013*V09*V12 - 1.79928869216053129e-15*V02*V03*V09*V12 - 
      1.08276349214077716e-15*V01*V04*V09*V12 + 1.39186627752246642e-16*V07*V09*V12 - 
      1.62337166319143067e-16*V022*V10*V12 - 4.81023338203284534e-16*V01*V03*V10*V12 + 
      8.75552642883807605e-17*V06*V10*V12 - 1.02977471513988916e-16*V01*V02*V11*V12 + 5.56393997174238829e-17*V05*V11*V12 - 
      5.54077265548279723e-18*V012*V122 + 1.00445090975560777e-17*V04*V122 + 
      5.3822077559896121e-15*V02*V033*V13 + 7.10559989788722804e-15*V022*V03*V04*V13 + 
      9.22461146488819956e-15*V01*V032*V04*V13 + 4.41314584283070369e-15*V01*V02*V042*V13 + 
      1.12843706913282131e-15*V023*V05*V13 + 9.53695715464842802e-15*V01*V02*V03*V05*V13 + 
      2.65711563990588481e-15*V012*V04*V05*V13 - 4.44117347051323363e-15*V042*V05*V13 - 
      4.71486853673569615e-15*V03*V052*V13 + 1.55909213223488049e-15*V01*V022*V06*V13 + 
      1.80249127836553536e-15*V012*V03*V06*V13 - 6.41173686302829501e-15*V03*V04*V06*V13 - 
      3.21127287044997652e-15*V02*V05*V06*V13 - 7.00727545533834012e-16*V01*V062*V13 + 
      6.43158990957590464e-16*V012*V02*V07*V13 - 2.26257553466836103e-15*V032*V07*V13 - 
      2.13450667892601588e-15*V02*V04*V07*V13 - 1.37083677811336777e-15*V01*V05*V07*V13 + 
      5.74582058724160969e-17*V013*V08*V13 - 1.21627138194233472e-15*V02*V03*V08*V13 - 
      7.35335740537542279e-16*V01*V04*V08*V13 + 9.57762462415141741e-17*V07*V08*V13 - 
      1.49851145945854778e-16*V022*V09*V13 - 3.84000231414231224e-16*V01*V03*V09*V13 + 
      7.2975442599378158e-17*V06*V09*V13 - 8.65076467340518385e-17*V01*V02*V10*V13 + 4.70906904971313136e-17*V05*V10*V13 - 
      1.04009323388158306e-17*V012*V11*V13 + 1.97274593329572516e-17*V04*V11*V13 + 
      7.79642821349782592e-18*V03*V12*V13 + 6.99281933109341025e-19*V02*V132 + 
      1.20918254911157337e-15*V022*V032*V14 + 9.22899758304467769e-16*V01*V033*V14 + 
      1.9940595681185048e-16*V023*V04*V14 + 2.90293171933157416e-15*V01*V02*V03*V04*V14 + 
      4.21109080578041838e-16*V012*V042*V14 - 4.01374864411482494e-16*V043*V14 + 
      7.2550952946694402e-16*V01*V022*V05*V14 + 7.83986824111663623e-16*V012*V03*V05*V14 - 
      3.02379252836987497e-15*V03*V04*V05*V14 - 7.65360648320548073e-16*V02*V052*V14 + 
      2.99147570501439979e-16*V012*V02*V06*V14 - 1.07407823184664435e-15*V032*V06*V14 - 
      8.65123363569163036e-16*V02*V04*V06*V14 - 6.52305652880766051e-16*V01*V05*V06*V14 + 
      3.28924241612832803e-17*V013*V07*V14 - 7.37761014004200049e-16*V02*V03*V07*V14 - 
      4.42544687089150515e-16*V01*V04*V07*V14 + 2.90916430685724583e-17*V072*V14 - 
      8.0580724296064444e-17*V022*V08*V14 - 2.40538546610949604e-16*V01*V03*V08*V14 + 
      4.4409170889184152e-17*V06*V08*V14 - 6.36916122107933323e-17*V01*V02*V09*V14 + 3.47529083491382786e-17*V05*V09*V14 - 
      8.08998779911127836e-18*V012*V10*V14 + 1.47581619731088094e-17*V04*V10*V14 + 
      6.77207458530948982e-18*V03*V11*V14 + 1.23471324692631095e-18*V02*V12*V14 + 2.90820549264459201e-19*V01*V13*V14 + 
      1.07470197060268696e-16*V023*V03*V15 + 4.3293175588755746e-16*V01*V02*V032*V15 + 
      2.03017139939635087e-16*V01*V022*V04*V15 + 2.3802483427702605e-16*V012*V03*V04*V15 - 
      4.49326313713130555e-16*V03*V042*V15 + 1.24426462836134556e-16*V012*V02*V05*V15 - 
      4.70133422928142077e-16*V032*V05*V15 - 4.47763410316850013e-16*V02*V04*V05*V15 - 
      1.42017807553593255e-16*V01*V052*V15 + 1.46999169866849912e-17*V013*V06*V15 - 
      3.2466081582771324e-16*V02*V03*V06*V15 - 1.96826503222040197e-16*V01*V04*V06*V15 - 
      5.32015089535069257e-17*V022*V07*V15 - 1.35338612147965536e-16*V01*V03*V07*V15 + 
      2.65277284905838324e-17*V06*V07*V15 - 3.7274988436417146e-17*V01*V02*V08*V15 + 2.07931374226637448e-17*V05*V08*V15 - 
      5.54441914974749562e-18*V012*V09*V15 + 1.07161842163489028e-17*V04*V09*V15 + 4.9831954404502506e-18*V03*V10*V15 + 
      1.05644237631522361e-18*V02*V11*V15 + 2.52842595525402064e-19*V01*V12*V15 - 1.12033920274682871e-21*V152 + 
      1.91221960873082364e-18*V024*V16 + 5.93191593324854952e-17*V01*V022*V03*V16 + 
      3.04768137804471482e-17*V012*V032*V16 + 3.46389996975772999e-17*V012*V02*V04*V16 - 
      1.33610264626806295e-16*V032*V04*V16 - 5.26363320834647129e-17*V02*V042*V16 + 
      5.5155271420480266e-18*V013*V05*V16 - 1.35884442226750404e-16*V02*V03*V05*V16 - 
      8.10896753785914545e-17*V01*V04*V05*V16 - 1.87960192688186679e-17*V022*V06*V16 - 
      5.69970708070561785e-17*V01*V03*V06*V16 + 5.41409458652628806e-18*V062*V16 - 
      1.98558026188562011e-17*V01*V02*V07*V16 + 1.11465390127505871e-17*V05*V07*V16 - 
      3.08687715956669848e-18*V012*V08*V16 + 5.7394607252150346e-18*V04*V08*V16 + 3.24581636355680891e-18*V03*V09*V16 + 
      6.95561579046622471e-19*V02*V10*V16 + 1.93867968278118237e-19*V01*V11*V16 - 2.07401591047088363e-21*V14*V16 + 
      2.37066611162357417e-18*V01*V023*V17 + 8.52252658759120145e-18*V012*V02*V03*V17 - 
      1.20833784666049087e-17*V033*V17 + 1.48520327786450429e-18*V013*V04*V17 - 
      3.52247442731117845e-17*V02*V03*V04*V17 - 1.07255887538915187e-17*V01*V042*V17 - 
      8.68434375033919486e-18*V022*V05*V17 - 2.17454493824073747e-17*V01*V03*V05*V17 - 
      7.74300533661429941e-18*V01*V02*V06*V17 + 4.50522888153391548e-18*V05*V06*V17 - 
      1.51498818817836056e-18*V012*V07*V17 + 3.04769655172028932e-18*V04*V07*V17 + 
      1.72124923794889901e-18*V03*V08*V17 + 4.49065809988584381e-19*V02*V09*V17 + 1.26429679884675416e-19*V01*V10*V17 - 
      1.75645199897746736e-21*V13*V17 + 5.51446339525110316e-19*V012*V022*V18 + 
      3.26783016014880188e-19*V013*V03*V18 - 4.72408686148464432e-18*V02*V032*V18 - 
      1.79051684424090686e-18*V022*V04*V18 - 5.57956115340016117e-18*V01*V03*V04*V18 - 
      2.86476890060310458e-18*V01*V02*V05*V18 + 8.44869019859857331e-19*V052*V18 - 
      5.76287359963741462e-19*V012*V06*V18 + 1.10660891058769752e-18*V04*V06*V18 + 
      8.23858967896625434e-19*V03*V07*V18 + 2.13937771039224332e-19*V02*V08*V18 + 7.35521136839532837e-20*V01*V09*V18 - 
      1.267601613744915e-21*V12*V18 + 4.14861250800140863e-20*V013*V02*V19 - 
      5.46287167560031642e-19*V022*V03*V19 - 6.61290859959799628e-19*V01*V032*V19 - 
      6.71801691405590743e-19*V01*V02*V04*V19 - 1.93290391192395301e-19*V012*V05*V19 + 
      4.15744703723045899e-19*V04*V05*V19 + 2.9953781427900864e-19*V03*V06*V19 + 1.0260987191946225e-19*V02*V07*V19 + 
      3.50795018458547218e-20*V01*V08*V19 - 8.39237718103130917e-22*V11*V19 + 9.57372117231094299e-22*V014*V20 - 
      1.61892131569871819e-20*V023*V20 - 1.58916173268955058e-19*V01*V02*V03*V20 - 
      4.55131665255099592e-20*V012*V04*V20 + 4.57461870444357997e-20*V042*V20 + 
      1.01096312919064441e-19*V03*V05*V20 + 3.33750935988706813e-20*V02*V06*V20 + 1.51164678889381545e-20*V01*V07*V20 - 
      4.6499615399327846e-22*V10*V20 - 8.50997437538750488e-21*V01*V022*V21 - 
      9.44961737933654188e-21*V012*V03*V21 + 2.26600769161009802e-20*V03*V04*V21 + 
      1.14769975234403985e-20*V02*V05*V21 + 5.00502474861152637e-21*V01*V06*V21 - 2.38009237285182019e-22*V09*V21 - 
      1.06374679692343811e-21*V012*V02*V22 + 2.48802923168207927e-21*V032*V22 + 
      2.26992387515185322e-21*V02*V04*V22 + 1.52635511163447262e-21*V01*V05*V22 - 9.82107324566903839e-23*V08*V22 - 
      3.54582265641146037e-23*V013*V23 + 5.21276687074742277e-22*V02*V03*V23 + 3.15509949145338488e-22*V01*V04*V23 - 
      3.80026780719730825e-23*V07*V23 + 2.33902025576383575e-23*V022*V24 + 6.23606275978018991e-23*V01*V03*V24 - 
      1.10341497183457654e-23*V06*V24 + 6.12877105698705003e-24*V01*V02*V25 - 3.09848629792276946e-24*V05*V25 + 
      3.20958085278623568e-25*V012*V26 - 5.65530447035739591e-25*V04*V26 - 1.0669843157559977e-25*V03*V27 - 
      9.20309921945874029e-27*V02*V28 - 9.86046344942007889e-28*V01*V29 + 9.33756008467810501e-31*V32) + 
   delta12*eps10*(-1.2623608842908231e-11*V032*V044 - 
      5.54575148020670988e-13*V02*V045 - 5.74705646606385813e-11*V033*V042*V05 - 
      4.91651886754433664e-11*V02*V03*V043*V05 - 7.57416530574493862e-12*V01*V044*V05 - 
      1.41673422599600606e-11*V034*V052 - 8.76270248886472824e-11*V02*V032*V04*V052 - 
      1.76417730163233288e-11*V022*V042*V052 - 
      5.04242420550523057e-11*V01*V03*V042*V052 - 1.46846020733457747e-11*V022*V03*V053 - 
      1.62450823703169877e-11*V01*V032*V053 - 1.71882686550962415e-11*V01*V02*V04*V053 - 
      1.13663327425446239e-12*V012*V054 + 6.41329382557683476e-12*V04*V054 - 
      1.98433346915017425e-11*V034*V04*V06 - 5.33577966938719842e-11*V02*V032*V042*V06 - 
      1.89201755779574989e-12*V022*V043*V06 - 2.16414031925669668e-11*V01*V03*V043*V06 - 
      4.05651856948794135e-11*V02*V033*V05*V06 - 5.16478589392089559e-11*V022*V03*V04*V05*V06 - 
      6.91490655018469102e-11*V01*V032*V04*V05*V06 - 3.20146780163231905e-11*V01*V02*V042*V05*V06 - 
      4.0916891147178767e-12*V023*V052*V06 - 3.5540896278702817e-11*V01*V02*V03*V052*V06 - 
      9.85457633704859201e-12*V012*V04*V052*V06 + 2.56710944023287782e-11*V042*V052*V06 + 
      1.80666387454398935e-11*V03*V053*V06 - 9.36271046026096767e-12*V022*V032*V062 - 
      7.8656417166148862e-12*V01*V033*V062 - 6.42053512793598194e-13*V023*V04*V062 - 
      2.29077178922460593e-11*V01*V02*V03*V04*V062 - 3.41880572570803806e-12*V012*V042*V062 + 
      4.31644238115062414e-12*V043*V062 - 5.6176262761565806e-12*V01*V022*V05*V062 - 
      6.66533109398845298e-12*V012*V03*V05*V062 + 3.69451619234321807e-11*V03*V04*V05*V062 + 
      9.22110298447443794e-12*V02*V052*V062 - 8.0509151259731452e-13*V012*V02*V063 + 
      4.4016956586828841e-12*V032*V063 + 3.07126590536725037e-12*V02*V04*V063 + 
      2.66220968483005777e-12*V01*V05*V063 - 2.62035237653655311e-12*V035*V07 - 
      2.72829661192003833e-11*V02*V033*V04*V07 - 1.68016885869745988e-11*V022*V03*V042*V07 - 
      2.33928456740618515e-11*V01*V032*V042*V07 - 7.02359838220619519e-12*V01*V02*V043*V07 - 
      2.06196699555050425e-11*V022*V032*V05*V07 - 1.49358422060442242e-11*V01*V033*V05*V07 - 
      5.26432182117911787e-12*V023*V04*V05*V07 - 4.79303538704672626e-11*V01*V02*V03*V04*V05*V07 - 
      6.68789515999118757e-12*V012*V042*V05*V07 + 1.13615334084914975e-11*V043*V05*V07 - 
      6.07840108472626493e-12*V01*V022*V052*V07 - 6.22703868096533244e-12*V012*V03*V052*V07 + 
      3.67793703319310409e-11*V03*V04*V052*V07 + 6.25390255486669154e-12*V02*V053*V07 - 
      3.89684677592178734e-12*V023*V03*V06*V07 - 1.64633930628638866e-11*V01*V02*V032*V06*V07 - 
      7.37826556274413655e-12*V01*V022*V04*V06*V07 - 9.05860517039494058e-12*V012*V03*V04*V06*V07 + 
      2.46484257981910765e-11*V03*V042*V06*V07 - 4.69504492380407939e-12*V012*V02*V05*V06*V07 + 
      2.58459906844252572e-11*V032*V05*V06*V07 + 2.44444701875073728e-11*V02*V04*V05*V06*V07 + 
      7.76237663392838207e-12*V01*V052*V06*V07 - 2.77992294859931609e-13*V013*V062*V07 + 
      8.85302253565730085e-12*V02*V03*V062*V07 + 5.36332983926226054e-12*V01*V04*V062*V07 - 
      1.44555442391423374e-13*V024*V072 - 2.82437452891535005e-12*V01*V022*V03*V072 - 
      1.41762982314936759e-12*V012*V032*V072 - 
      1.59021466306590077e-12*V012*V02*V04*V072 + 8.7767295508406923e-12*V032*V04*V072 + 
      4.03241202203771409e-12*V02*V042*V072 - 2.52551080557655571e-13*V013*V05*V072 + 
      8.971792482394812e-12*V02*V03*V05*V072 + 5.28267580081846432e-12*V01*V04*V05*V072 + 
      1.43889096411765657e-12*V022*V06*V072 + 3.68278361233013768e-12*V01*V03*V06*V072 - 
      3.3500491079814692e-13*V062*V072 + 4.30586229197610898e-13*V01*V02*V073 - 
      2.17257522058938345e-13*V05*V073 - 3.58632999260539863e-12*V02*V034*V08 - 
      9.57281375529056349e-12*V022*V032*V04*V08 - 8.05607528509525142e-12*V01*V033*V04*V08 - 
      3.21252770897937729e-13*V023*V042*V08 - 1.17373432292264333e-11*V01*V02*V03*V042*V08 - 
      1.17010706412317977e-12*V012*V043*V08 + 1.11695017650896361e-12*V044*V08 - 
      3.06196843775062607e-12*V023*V03*V05*V08 - 1.24603347419112635e-11*V01*V02*V032*V05*V08 - 
      5.7436882531743381e-12*V01*V022*V04*V05*V08 - 6.81706928987549431e-12*V012*V03*V04*V05*V08 + 
      1.92682630402366226e-11*V03*V042*V05*V08 - 1.76868599157390636e-12*V012*V02*V052*V08 + 
      9.9324897728717118e-12*V032*V052*V08 + 9.60169276410335796e-12*V02*V04*V052*V08 + 
      1.9841301864990341e-12*V01*V053*V08 - 5.40914475902372699e-14*V024*V06*V08 - 
      4.1207846214552146e-12*V01*V022*V03*V06*V08 - 2.29425089407388893e-12*V012*V032*V06*V08 - 
      2.47672754008752081e-12*V012*V02*V04*V06*V08 + 1.37815491666856249e-11*V032*V04*V06*V08 + 
      4.76271969257700908e-12*V02*V042*V06*V08 - 4.15641843517677158e-13*V013*V05*V06*V08 + 
      1.38485882612334574e-11*V02*V03*V05*V06*V08 + 8.33457278314632135e-12*V01*V04*V05*V06*V08 + 
      8.4339725366479097e-13*V022*V062*V08 + 2.94792451247931615e-12*V01*V03*V062*V08 - 
      1.66141210703491369e-13*V063*V08 - 4.37424062535803724e-13*V01*V023*V07*V08 - 
      1.62011238747969584e-12*V012*V02*V03*V07*V08 + 3.14985411960212745e-12*V033*V07*V08 - 
      2.8334630268833478e-13*V013*V04*V07*V08 + 9.21762404573449882e-12*V02*V03*V04*V07*V08 + 
      2.79669868260047833e-12*V01*V042*V07*V08 + 2.27046049284179341e-12*V022*V05*V07*V08 + 
      5.64136173788458123e-12*V01*V03*V05*V07*V08 + 2.0097338213921578e-12*V01*V02*V06*V07*V08 - 
      1.05042485432129021e-12*V05*V06*V07*V08 + 1.95164092362449316e-13*V012*V072*V08 - 
      3.55990647149046823e-13*V04*V072*V08 - 1.11364999840402184e-13*V012*V022*V082 - 
      7.00444587472482508e-14*V013*V03*V082 + 1.29188979576842434e-12*V02*V032*V082 + 
      4.3514659203188036e-13*V022*V04*V082 + 1.53804125430683321e-12*V01*V03*V04*V082 + 
      7.81158054281493919e-13*V01*V02*V05*V082 - 2.05384806979681607e-13*V052*V082 + 
      1.60081659777896363e-13*V012*V06*V082 - 2.63816131929522945e-13*V04*V06*V082 - 
      2.00679702456063537e-13*V03*V07*V082 - 1.69696312815928487e-14*V02*V083 - 
      1.84287073543241269e-12*V022*V033*V09 - 9.75596461380281964e-13*V01*V034*V09 - 
      1.46231161699419941e-12*V023*V03*V04*V09 - 6.3594614014276299e-12*V01*V02*V032*V04*V09 - 
      1.40014071558121657e-12*V01*V022*V042*V09 - 1.75463229527355072e-12*V012*V03*V042*V09 + 
      3.20761402166334979e-12*V03*V043*V09 - 1.6864801612332727e-13*V024*V05*V09 - 
      3.2353814493316596e-12*V01*V022*V03*V05*V09 - 1.61078053185556068e-12*V012*V032*V05*V09 - 
      1.81511516373959674e-12*V012*V02*V04*V05*V09 + 1.02744290732339591e-11*V032*V04*V05*V09 + 
      4.74259025875859382e-12*V02*V042*V05*V09 - 1.43006632377705003e-13*V013*V052*V09 + 
      5.25553216885621094e-12*V02*V03*V052*V09 + 3.08784485034891785e-12*V01*V04*V052*V09 - 
      3.24737231326815611e-13*V01*V023*V06*V09 - 1.22737193544647799e-12*V012*V02*V03*V06*V09 + 
      2.3989213956727763e-12*V033*V06*V09 - 2.15156813341901962e-13*V013*V04*V06*V09 + 
      6.90006915887170832e-12*V02*V03*V04*V06*V09 + 2.10397659884255448e-12*V01*V042*V06*V09 + 
      1.6921578391716141e-12*V022*V05*V06*V09 + 4.300662772680902e-12*V01*V03*V05*V06*V09 + 
      7.55506801296615058e-13*V01*V02*V062*V09 - 4.00597981312185625e-13*V05*V062*V09 - 
      2.14063562850636073e-13*V012*V022*V07*V09 - 1.28513085209432488e-13*V013*V03*V07*V09 + 
      2.50790594225781283e-12*V02*V032*V07*V09 + 1.10980779444743086e-12*V022*V04*V07*V09 + 
      2.93047942673694445e-12*V01*V03*V04*V07*V09 + 1.51017894607246057e-12*V01*V02*V05*V07*V09 - 
      3.89129192910370228e-13*V052*V07*V09 + 2.98141461712608913e-13*V012*V06*V07*V09 - 
      5.41712906584305521e-13*V04*V06*V07*V09 - 1.89858088690570852e-13*V03*V072*V09 - 
      3.79053328758700677e-14*V013*V02*V08*V09 + 6.40676542313120632e-13*V022*V03*V08*V09 + 
      7.78174727088949434e-13*V01*V032*V08*V09 + 7.86424023791652476e-13*V01*V02*V04*V08*V09 + 
      2.27198971324947864e-13*V012*V05*V08*V09 - 4.25537514808091988e-13*V04*V05*V08*V09 - 
      3.06702885911666218e-13*V03*V06*V08*V09 - 1.05270324241776306e-13*V02*V07*V08*V09 - 
      1.80097439383379314e-14*V01*V082*V09 - 1.01101831876375727e-15*V014*V092 + 
      2.51551265392364768e-14*V023*V092 + 2.0926639912543473e-13*V01*V02*V03*V092 + 
      5.93770226614903069e-14*V012*V04*V092 - 5.45316567881394302e-14*V042*V092 - 
      1.13184122999392208e-13*V03*V05*V092 - 3.9904838880104603e-14*V02*V06*V092 - 
      1.6959878620480182e-14*V01*V07*V092 - 3.44644620572231875e-13*V023*V032*V10 - 
      8.77283007707745707e-13*V01*V02*V033*V10 - 1.61031759883486528e-14*V024*V04*V10 - 
      1.27944533477919338e-12*V01*V022*V03*V04*V10 - 7.10055025965905666e-13*V012*V032*V04*V10 - 
      3.85706574334752339e-13*V012*V02*V042*V10 + 2.21886023175204245e-12*V032*V042*V10 + 
      5.02865499693221607e-13*V02*V043*V10 - 2.06786772343339125e-13*V01*V023*V05*V10 - 
      7.37794811625309912e-13*V012*V02*V03*V05*V10 + 1.49370603604755817e-12*V033*V05*V10 - 
      1.28176814577713295e-13*V013*V04*V05*V10 + 4.44861446587975325e-12*V02*V03*V04*V05*V10 + 
      1.34165672601200623e-12*V01*V042*V05*V10 + 5.50240246801894186e-13*V022*V052*V10 + 
      1.33404059581068825e-12*V01*V03*V052*V10 - 1.3530407725362115e-13*V012*V022*V06*V10 - 
      8.47647083836181451e-14*V013*V03*V06*V10 + 1.59437366872526792e-12*V02*V032*V06*V10 + 
      5.33286892200087703e-13*V022*V04*V06*V10 + 1.8993219805302427e-12*V01*V03*V04*V06*V10 + 
      9.63977042288914403e-13*V01*V02*V05*V06*V10 - 2.57915244920401319e-13*V052*V06*V10 + 
      9.884993686014354e-14*V012*V062*V10 - 1.65002084758868242e-13*V04*V062*V10 - 
      3.02035724286660697e-14*V013*V02*V07*V10 + 5.28095906055248916e-13*V022*V03*V07*V10 + 
      6.30253366843431312e-13*V01*V032*V07*V10 + 6.45373748905365607e-13*V01*V02*V04*V07*V10 + 
      1.83697218384306175e-13*V012*V05*V07*V10 - 3.50306945395216703e-13*V04*V05*V07*V10 - 
      2.51917241416638518e-13*V03*V06*V07*V10 - 4.34221384518788821e-14*V02*V072*V10 - 
      1.77457277176351891e-15*V014*V08*V10 + 3.22329983572826521e-14*V023*V08*V10 + 
      3.55670260028069726e-13*V01*V02*V03*V08*V10 + 1.03079127775903e-13*V012*V04*V08*V10 - 
      8.72303491342608571e-14*V042*V08*V10 - 1.96424063287615967e-13*V03*V05*V08*V10 - 
      6.36060582977409347e-14*V02*V06*V08*V10 - 2.94988919233595527e-14*V01*V07*V08*V10 + 
      4.5022386113203404e-14*V01*V022*V09*V10 + 5.00967541677195804e-14*V012*V03*V09*V10 - 
      1.02139971643221833e-13*V03*V04*V09*V10 - 5.18521279891981853e-14*V02*V05*V09*V10 - 
      2.25856342350204916e-14*V01*V06*V09*V10 + 4.46736304504691193e-16*V092*V10 + 
      5.94348777483171396e-15*V012*V02*V102 - 1.16659141852572711e-14*V032*V102 - 
      1.0473826241200665e-14*V02*V04*V102 - 7.17554024043429019e-15*V01*V05*V102 + 
      3.81814750433060077e-16*V08*V102 - 3.06632756587867763e-14*V024*V03*V11 - 
      2.7583193085567989e-13*V01*V022*V032*V11 - 8.86070125026075195e-14*V012*V033*V11 - 
      7.97624518360472405e-14*V01*V023*V04*V11 - 3.04860204586883083e-13*V012*V02*V03*V04*V11 + 
      6.27008891132999071e-13*V033*V04*V11 - 2.66946478864830395e-14*V013*V042*V11 + 
      8.83076174164068353e-13*V02*V03*V042*V11 + 1.80593403287593678e-13*V01*V043*V11 - 
      7.84757875755383847e-14*V012*V022*V05*V11 - 4.65260579918639509e-14*V013*V03*V05*V11 + 
      9.65075413675485715e-13*V02*V032*V05*V11 + 4.30480932880596467e-13*V022*V04*V05*V11 + 
      1.12404150024869981e-12*V01*V03*V04*V05*V11 + 2.89945629202873823e-13*V01*V02*V052*V11 - 
      5.17376721776157793e-14*V053*V11 - 1.84549849560625706e-14*V013*V02*V06*V11 + 
      3.15002360413574256e-13*V022*V03*V06*V11 + 3.89766896073366935e-13*V01*V032*V06*V11 + 
      3.88360705163631883e-13*V01*V02*V04*V06*V11 + 1.13867613156787662e-13*V012*V05*V06*V11 - 
      2.16666577671350176e-13*V04*V05*V06*V11 - 7.82387665307883403e-14*V03*V062*V11 - 
      1.29196990073744539e-15*V014*V07*V11 + 3.31868423522073003e-14*V023*V07*V11 + 
      2.74930430127039705e-13*V01*V02*V03*V07*V11 + 7.79159789178759675e-14*V012*V04*V07*V11 - 
      7.29893729061787253e-14*V042*V07*V11 - 1.51239574207863572e-13*V03*V05*V07*V11 - 
      5.33946958497341718e-14*V02*V06*V07*V11 - 1.1315461675910363e-14*V01*V072*V11 + 
      3.60361465348199395e-14*V01*V022*V08*V11 + 4.06627079658199657e-14*V012*V03*V08*V11 - 
      8.30248544527045802e-14*V03*V04*V08*V11 - 4.20489482942805629e-14*V02*V05*V08*V11 - 
      1.83917933207467423e-14*V01*V06*V08*V11 + 1.11111795349747364e-14*V012*V02*V09*V11 - 
      2.18888012801646063e-14*V032*V09*V11 - 2.13589351297865403e-14*V02*V04*V09*V11 - 
      1.34460384740768309e-14*V01*V05*V09*V11 + 7.30837081501005168e-16*V08*V09*V11 + 
      8.33132508586688696e-16*V013*V10*V11 - 1.00876934675486252e-14*V02*V03*V10*V11 - 
      6.10957266555290063e-15*V01*V04*V10*V11 + 6.01673246089016685e-16*V07*V10*V11 - 
      5.16052179932381176e-16*V022*V112 - 1.28444987392723747e-15*V01*V03*V112 + 
      1.88971753164141039e-16*V06*V112 - 2.10634336771470859e-16*V025*V12 - 
      3.08756064357409596e-14*V01*V023*V03*V12 - 5.09985706305427914e-14*V012*V02*V032*V12 + 
      5.71366116719396223e-14*V034*V12 - 2.81783620735586578e-14*V012*V022*V04*V12 - 
      1.74007453477845086e-14*V013*V03*V04*V12 + 3.48622551449117888e-13*V02*V032*V04*V12 + 
      5.70006008859766131e-14*V022*V042*V12 + 2.08136520692186794e-13*V01*V03*V042*V12 - 
      9.09472921879830237e-15*V013*V02*V05*V12 + 1.73469968941489005e-13*V022*V03*V05*V12 + 
      2.02664083648281323e-13*V01*V032*V05*V12 + 2.10728538867726186e-13*V01*V02*V04*V05*V12 + 
      2.942489983509629e-14*V012*V052*V12 - 5.93918201775679571e-14*V04*V052*V12 - 
      7.13639681822197556e-16*V014*V06*V12 + 1.33545228888177281e-14*V023*V06*V12 + 
      1.49408535947464649e-13*V01*V02*V03*V06*V12 + 4.33403587146936055e-14*V012*V04*V06*V12 - 
      3.75418653104261691e-14*V042*V06*V12 - 8.51599654085987912e-14*V03*V05*V06*V12 - 
      1.36716812703581842e-14*V02*V062*V12 + 2.51492445678535304e-14*V01*V022*V07*V12 + 
      2.75679930753845956e-14*V012*V03*V07*V12 - 5.79524683559761532e-14*V03*V04*V07*V12 - 
      2.94774631467785703e-14*V02*V05*V07*V12 - 1.27732210931508868e-14*V01*V06*V07*V12 + 
      8.0939288218037996e-15*V012*V02*V08*V12 - 1.61166326322169352e-14*V032*V08*V12 - 
      1.44152296899114129e-14*V02*V04*V08*V12 - 9.91018349492233588e-15*V01*V05*V08*V12 + 
      2.6514303168598345e-16*V082*V12 + 6.97967481666152568e-16*V013*V09*V12 - 
      8.57301228001231678e-15*V02*V03*V09*V12 - 5.18119683469824639e-15*V01*V04*V09*V12 + 5.1094392037277086e-16*V07*V09*V12 - 
      8.56775192399938843e-16*V022*V10*V12 - 2.32443604594001879e-15*V01*V03*V10*V12 + 
      3.35198893347679453e-16*V06*V10*V12 - 5.10447325025000943e-16*V01*V02*V11*V12 + 2.07416814381082479e-16*V05*V11*V12 - 
      2.79569907542884659e-17*V012*V122 + 3.93981774199138512e-17*V04*V122 - 
      1.1793567561071837e-15*V01*V024*V13 - 9.07143167856833355e-15*V012*V022*V03*V13 - 
      2.59355144618755459e-15*V013*V032*V13 + 4.16688009877662522e-14*V02*V033*V13 - 
      3.15361439006697602e-15*V013*V02*V04*V13 + 5.69170782249564593e-14*V022*V03*V04*V13 + 
      7.20966798190456952e-14*V01*V032*V04*V13 + 3.52969705581026537e-14*V01*V02*V042*V13 - 
      3.20006097921040348e-16*V014*V05*V13 + 9.14208803851306967e-15*V023*V05*V13 + 
      7.46184390171179079e-14*V01*V02*V03*V05*V13 + 2.10548643689094511e-14*V012*V04*V05*V13 - 
      2.09654581574581239e-14*V042*V05*V13 - 2.15980016099090461e-14*V03*V052*V13 + 
      1.25858150637277314e-14*V01*V022*V06*V13 + 1.4422115897797496e-14*V012*V03*V06*V13 - 
      3.03559839019422268e-14*V03*V04*V06*V13 - 1.53232765721389445e-14*V02*V05*V06*V13 - 
      3.3657356770042768e-15*V01*V062*V13 + 5.15745170276996653e-15*V012*V02*V07*V13 - 
      1.04875282143891458e-14*V032*V07*V13 - 1.02678072611734215e-14*V02*V04*V07*V13 - 
      6.43390953339681743e-15*V01*V05*V07*V13 + 4.78931136207132883e-16*V013*V08*V13 - 
      5.87710472952073096e-15*V02*V03*V08*V13 - 3.56630553536189456e-15*V01*V04*V08*V13 + 3.5524446204504246e-16*V07*V08*V13 - 
      7.4170932822848788e-16*V022*V09*V13 - 1.84245920933777043e-15*V01*V03*V09*V13 + 
      2.72812350927235332e-16*V06*V09*V13 - 4.31493565475889119e-16*V01*V02*V10*V13 + 1.76296246386168792e-16*V05*V10*V13 - 
      5.21696991270911686e-17*V012*V11*V13 + 7.55607383446355763e-17*V04*V11*V13 + 
      2.99786520677454106e-17*V03*V12*V13 + 2.78624804879448725e-18*V02*V132 - 
      4.85916983842313913e-16*V012*V023*V14 - 8.67562953657879805e-16*V013*V02*V03*V14 + 
      9.86077693956324572e-15*V022*V032*V14 + 7.41256457128787944e-15*V01*V033*V14 - 
      1.02588166594015141e-16*V014*V04*V14 + 2.05432819173900256e-15*V023*V04*V14 + 
      2.37028081247648606e-14*V01*V02*V03*V04*V14 + 3.44591103084061639e-15*V012*V042*V14 - 
      2.08098496225918251e-15*V043*V14 + 5.95802862328810874e-15*V01*V022*V05*V14 + 
      6.39780463824400655e-15*V012*V03*V05*V14 - 1.43830008044455745e-14*V03*V04*V05*V14 - 
      3.66600887873959378e-15*V02*V052*V14 + 2.46853193870987996e-15*V012*V02*V06*V14 - 
      5.12998038632044226e-15*V032*V06*V14 - 4.53486667684704666e-15*V02*V04*V06*V14 - 
      3.1517811154101444e-15*V01*V05*V06*V14 + 2.77918733480979708e-16*V013*V07*V14 - 
      3.57183389173664081e-15*V02*V03*V07*V14 - 2.15231415515267976e-15*V01*V04*V07*V14 + 
      1.07794471732842449e-16*V072*V14 - 4.31512046830488541e-16*V022*V08*V14 - 
      1.1790352521702102e-15*V01*V03*V08*V14 + 1.7166945810462688e-16*V06*V08*V14 - 3.18004427627191559e-16*V01*V02*V09*V14 + 
      1.29964290421125924e-16*V05*V09*V14 - 4.10770317730565991e-17*V012*V10*V14 + 
      5.81131278938362626e-17*V04*V10*V14 + 2.60254312143105024e-17*V03*V11*V14 + 5.03923528126035453e-18*V02*V12*V14 + 
      1.16788187493497208e-18*V01*V13*V14 - 6.65335326590921294e-17*V013*V022*V15 - 
      2.5157824496598696e-17*V014*V03*V15 + 9.03559010602518899e-16*V023*V03*V15 + 
      3.56001794964679816e-15*V01*V02*V032*V15 + 1.70022573650460167e-15*V01*V022*V04*V15 + 
      1.98566778632737594e-15*V012*V03*V04*V15 - 2.21175841958250368e-15*V03*V042*V15 + 
      1.0374151278364344e-15*V012*V02*V05*V15 - 2.25080045874697054e-15*V032*V05*V15 - 
      2.22132026845410529e-15*V02*V04*V05*V15 - 6.88253200922256239e-16*V01*V052*V15 + 
      1.26574699492521439e-16*V013*V06*V15 - 1.61436779303792881e-15*V02*V03*V06*V15 - 
      9.81917063849471799e-16*V01*V04*V06*V15 - 2.68866486615148015e-16*V022*V07*V15 - 
      6.63501180839524423e-16*V01*V03*V07*V15 + 1.00379449772884666e-16*V06*V07*V15 - 1.89513438863776316e-16*V01*V02*V08*V15 + 
      7.87869318843107489e-17*V05*V08*V15 - 2.81628145083251068e-17*V012*V09*V15 + 
      4.12886709486348294e-17*V04*V09*V15 + 1.92854247368759764e-17*V03*V10*V15 + 4.21851742999858811e-18*V02*V11*V15 + 
      1.01815063212727581e-18*V01*V12*V15 - 3.92667508847153465e-21*V152 - 
      3.61886660313353645e-18*V014*V02*V16 + 2.07693158109551136e-17*V024*V16 + 
      5.08220222534432624e-16*V01*V022*V03*V16 + 2.62414069800443655e-16*V012*V032*V16 + 
      2.97229577004034461e-16*V012*V02*V04*V16 - 6.63080462614977798e-16*V032*V04*V16 - 
      2.86857981909223124e-16*V02*V042*V16 + 4.85978042908457318e-17*V013*V05*V16 - 
      6.78533113428835737e-16*V02*V03*V05*V16 - 4.06863406682664178e-16*V01*V04*V05*V16 - 
      1.03563856431089257e-16*V022*V06*V16 - 2.8728585544271663e-16*V01*V03*V06*V16 + 
      2.13639238860347667e-17*V062*V16 - 1.01225227713622024e-16*V01*V02*V07*V16 + 
      4.21906230659045533e-17*V05*V07*V16 - 1.59697381318424224e-17*V012*V08*V16 + 2.288296989061798e-17*V04*V08*V16 + 
      1.25468514310608598e-17*V03*V09*V16 + 2.85766021228006416e-18*V02*V10*V16 + 7.8013399682482647e-19*V01*V11*V16 - 
      7.32393077862487092e-21*V14*V16 - 6.7016048206176601e-20*V015*V17 + 
      2.09469828009772662e-17*V01*V023*V17 + 7.54176267829576075e-17*V012*V02*V03*V17 - 
      6.06371354086839863e-17*V033*V17 + 1.34456531384325654e-17*V013*V04*V17 - 
      1.82538112651459403e-16*V02*V03*V04*V17 - 5.57265247253640908e-17*V01*V042*V17 - 
      4.53802521230535162e-17*V022*V05*V17 - 1.1045249453227598e-16*V01*V03*V05*V17 - 
      4.06096110161841348e-17*V01*V02*V06*V17 + 1.74446249533159852e-17*V05*V06*V17 - 
      7.89169814334567957e-18*V012*V07*V17 + 1.19056320750458795e-17*V04*V07*V17 + 
      6.75295051061236243e-18*V03*V08*V17 + 1.80669295888737295e-18*V02*V09*V17 + 5.13178422030603162e-19*V01*V10*V17 - 
      6.1585577541364041e-21*V13*V17 + 4.98934478894984794e-18*V012*V022*V18 + 
      3.0671011395693491e-18*V013*V03*V18 - 2.46654515625294006e-17*V02*V032*V18 - 
      1.02857294533636771e-17*V022*V04*V18 - 2.9284008789842638e-17*V01*V03*V04*V18 - 
      1.51106163281421692e-17*V01*V02*V05*V18 + 3.27436644330377925e-18*V052*V18 - 
      3.07429029500522334e-18*V012*V06*V18 + 4.51335073260408059e-18*V04*V06*V18 + 
      3.23075213153644842e-18*V03*V07*V18 + 8.91821518254287834e-19*V02*V08*V18 + 2.98362752787039479e-19*V01*V09*V18 - 
      4.48551214014881302e-21*V12*V18 + 4.02096289237059606e-19*V013*V02*V19 - 
      2.98435493560366716e-18*V022*V03*V19 - 3.52819991780909541e-18*V01*V032*V19 - 
      3.67470001313705541e-18*V01*V02*V04*V19 - 1.04574288238550892e-18*V012*V05*V19 + 
      1.66444844273646399e-18*V04*V05*V19 + 1.20266664938861187e-18*V03*V06*V19 + 4.19184647911154002e-19*V02*V07*V19 + 
      1.44536708112573362e-19*V01*V08*V19 - 2.94737211092377531e-21*V11*V19 + 1.00524072309264901e-20*V014*V20 - 
      9.82547458091615668e-20*V023*V20 - 8.78202761870067418e-19*V01*V02*V03*V20 - 
      2.53198331337701356e-19*V012*V04*V20 + 1.93172581089076808e-19*V042*V20 + 
      4.06777029872161843e-19*V03*V05*V20 + 1.42566871168044458e-19*V02*V06*V20 + 6.23354298408211361e-20*V01*V07*V20 - 
      1.65393718735925556e-21*V10*V20 - 4.90520241731320399e-20*V01*V022*V21 - 
      5.38300202026464827e-20*V012*V03*V21 + 9.41877570179047379e-20*V03*V04*V21 + 4.8115129691199e-20*V02*V05*V21 + 
      2.11288235910752555e-20*V01*V06*V21 - 8.3959711892327816e-22*V09*V21 - 6.23621559696365592e-21*V012*V02*V22 + 
      1.04116255577994385e-20*V032*V22 + 1.00520037407621399e-20*V02*V04*V22 + 6.46984506289619178e-21*V01*V05*V22 - 
      3.52962766690107534e-22*V08*V22 - 2.17181637705201948e-22*V013*V23 + 2.27060014329888473e-21*V02*V03*V23 + 
      1.37978454380901256e-21*V01*V04*V23 - 1.35418900751564703e-22*V07*V23 + 1.08740599292397665e-22*V022*V24 + 
      2.75296448346318055e-22*V01*V03*V24 - 4.03984995274373026e-23*V06*V24 + 2.80838324618795622e-23*V01*V02*V25 - 
      1.12597042981571607e-23*V05*V25 + 1.49780439796690998e-24*V012*V26 - 2.13316336033029277e-24*V04*V26 - 
      4.00622412897063288e-25*V03*V27 - 3.62372031766187899e-26*V02*V28 - 3.88255748320915606e-27*V01*V29 + 
      3.26814602963733675e-30*V32) + delta10*eps11*
    (-1.56922126002266075e-10*V032*V044 - 1.49854878334381416e-11*V02*V045 - 
      6.6529736244638615e-10*V033*V042*V05 - 6.13146595992018253e-10*V02*V03*V043*V05 - 
      9.41532756013596447e-11*V01*V044*V05 - 1.59325970188415257e-10*V034*V052 - 
      1.01477262016199264e-9*V02*V032*V04*V052 - 
      2.21492200878613889e-10*V022*V042*V052 - 
      5.88319745968770027e-10*V01*V03*V042*V052 - 1.70276514917027796e-10*V022*V03*V053 - 
      1.84887345597786957e-10*V01*V032*V053 - 2.00505276187654521e-10*V01*V02*V04*V053 - 
      1.31550796375767866e-11*V012*V054 + 2.89509273809282301e-11*V04*V054 - 
      2.31188293302868268e-10*V034*V04*V06 - 6.66612877643652993e-10*V02*V032*V042*V06 - 
      5.2051863226839263e-11*V022*V043*V06 - 2.69652268180291631e-10*V01*V03*V043*V06 - 
      4.72848079140894006e-10*V02*V033*V05*V06 - 6.4819300947376496e-10*V022*V03*V04*V05*V06 - 
      8.12727784477607083e-10*V01*V032*V04*V05*V06 - 3.99967726586191796e-10*V01*V02*V042*V05*V06 - 
      5.1771895711441771e-11*V023*V052*V06 - 4.17833953754584124e-10*V01*V02*V03*V052*V06 - 
      1.17206680594029671e-10*V012*V04*V052*V06 + 1.21938911329772902e-10*V042*V052*V06 + 
      8.21545348193250561e-11*V03*V053*V06 - 1.17645825287794466e-10*V022*V032*V062 - 
      9.31031601174729937e-11*V01*V033*V062 - 1.8011962025833183e-11*V023*V04*V062 - 
      2.86713374746781636e-10*V01*V02*V03*V04*V062 - 4.24902503144277951e-11*V012*V042*V062 + 
      2.42425683147481127e-11*V043*V062 - 7.05874951726766794e-11*V01*V022*V05*V062 - 
      7.99403297140652917e-11*V012*V03*V05*V062 + 1.76056392941749065e-10*V03*V04*V05*V062 + 
      4.44625135312468101e-11*V02*V052*V062 - 1.00445231311265149e-11*V012*V02*V063 + 
      2.10448468067930321e-11*V032*V063 + 1.75042383288447039e-11*V02*V04*V063 + 
      1.29251853057287628e-11*V01*V05*V063 - 2.97436752330203269e-11*V035*V07 - 
      3.18262343155007177e-10*V02*V033*V04*V07 - 2.10944953217727514e-10*V022*V03*V042*V07 - 
      2.75177078921805962e-10*V01*V032*V042*V07 - 8.75923708560026075e-11*V01*V02*V043*V07 - 
      2.40845712949532486e-10*V022*V032*V05*V07 - 1.71799265285156248e-10*V01*V033*V05*V07 - 
      6.68346459501218082e-11*V023*V04*V05*V07 - 5.63879486277508066e-10*V01*V02*V03*V04*V05*V07 - 
      7.96146793101129729e-11*V012*V042*V05*V07 + 5.46306257636557172e-11*V043*V05*V07 - 
      7.15317785195647217e-11*V01*V022*V052*V07 - 7.29563574799599191e-11*V012*V03*V052*V07 + 
      1.68829831915586707e-10*V03*V04*V052*V07 + 2.89485849844917644e-11*V02*V053*V07 - 
      4.93065673442302581e-11*V023*V03*V06*V07 - 1.95287922039220782e-10*V01*V02*V032*V06*V07 - 
      9.25990013533949943e-11*V01*V022*V04*V06*V07 - 1.0883254274487797e-10*V012*V03*V04*V06*V07 + 
      1.18878895376251127e-10*V03*V042*V06*V07 - 5.64297930116890578e-11*V012*V02*V05*V06*V07 + 
      1.1950650646382469e-10*V032*V05*V06*V07 + 1.19293899150755687e-10*V02*V04*V05*V06*V07 + 
      3.65081872111144395e-11*V01*V052*V06*V07 - 3.4397762347973565e-12*V013*V062*V07 + 
      4.33244733205692087e-11*V02*V03*V062*V07 + 2.63388723912757238e-11*V01*V04*V062*V07 - 
      1.86541795883426248e-12*V024*V072 - 3.35530585270003366e-11*V01*V022*V03*V072 - 
      1.68273165828826881e-11*V012*V032*V072 - 
      1.91275890892575566e-11*V012*V02*V04*V072 + 4.0950341413254113e-11*V032*V04*V072 + 
      1.99142144652717262e-11*V02*V042*V072 - 3.08146818295135875e-12*V013*V05*V072 + 
      4.21963509649030337e-11*V02*V03*V05*V072 + 2.50601550341836847e-11*V01*V04*V05*V072 + 
      7.21137147050450377e-12*V022*V06*V072 + 1.76017463557478092e-11*V01*V03*V06*V072 - 
      1.15219777810401066e-12*V062*V072 + 2.08968082175743025e-12*V01*V02*V073 - 
      7.27023147830099414e-13*V05*V073 - 4.23894484352428601e-11*V02*V034*V08 - 
      1.20965804826214873e-10*V022*V032*V04*V08 - 9.60772185585057123e-11*V01*V033*V04*V08 - 
      9.15060794686521137e-12*V023*V042*V08 - 1.47650746266870707e-10*V01*V02*V03*V042*V08 - 
      1.46083141656007071e-11*V012*V043*V08 + 6.35984687876048916e-12*V044*V08 - 
      3.89466985288962726e-11*V023*V03*V05*V08 - 1.48792730142952374e-10*V01*V02*V032*V05*V08 - 
      7.2579482895728924e-11*V01*V022*V04*V05*V08 - 8.24363379617677921e-11*V012*V03*V04*V05*V08 + 
      9.31483158677247527e-11*V03*V042*V05*V08 - 2.14153382701963469e-11*V012*V02*V052*V08 + 
      4.61920636716576164e-11*V032*V052*V08 + 4.69598288098069129e-11*V02*V04*V052*V08 + 
      9.38640831217085405e-12*V01*V053*V08 - 1.57473531060472821e-12*V024*V06*V08 - 
      5.21242914077008215e-11*V01*V022*V03*V06*V08 - 2.79692730859181083e-11*V012*V032*V06*V08 - 
      3.10487188039249292e-11*V012*V02*V04*V06*V08 + 6.6839098689497404e-11*V032*V04*V06*V08 + 
      2.75166867422992434e-11*V02*V042*V06*V08 - 5.1753940092710417e-12*V013*V05*V06*V08 + 
      6.79263768165786627e-11*V02*V03*V05*V06*V08 + 4.1030532923315486e-11*V01*V04*V05*V06*V08 + 
      4.94529771038454355e-12*V022*V062*V08 + 1.45589120548237437e-11*V01*V03*V062*V08 - 
      6.08468234038831303e-13*V063*V08 - 5.56381407555661037e-12*V01*V023*V07*V08 - 
      1.98513767967695796e-11*V012*V02*V03*V07*V08 + 1.48886505636800798e-11*V033*V07*V08 - 
      3.54142954666633783e-12*V013*V04*V07*V08 + 4.57359638541604758e-11*V02*V03*V04*V07*V08 + 
      1.39219209866179298e-11*V01*V042*V07*V08 + 1.14009338759232433e-11*V022*V05*V07*V08 + 
      2.71202826593336162e-11*V01*V03*V05*V07*V08 + 1.01425542698418191e-11*V01*V02*V06*V07*V08 - 
      3.61566337787909831e-12*V05*V06*V07*V08 + 9.70304932719996091e-13*V012*V072*V08 - 
      1.24030427474001362e-12*V04*V072*V08 - 1.41028831786113505e-12*V012*V022*V082 - 
      8.8976805107051436e-13*V013*V03*V082 + 6.4438550314276841e-12*V02*V032*V082 + 
      2.58589495949236358e-12*V022*V04*V082 + 7.69963295582269488e-12*V01*V03*V04*V082 + 
      3.95197019146199652e-12*V01*V02*V05*V082 - 7.07797398630384574e-13*V052*V082 + 
      8.15013515817570697e-13*V012*V06*V082 - 9.79423576048223815e-13*V04*V06*V082 - 
      7.0194913754179623e-13*V03*V07*V082 - 6.48538542462613738e-14*V02*V083 - 
      2.18548898624289191e-11*V022*V033*V09 - 1.14549402137967409e-11*V01*V034*V09 - 
      1.85651794305893912e-11*V023*V03*V04*V09 - 7.6095681095975047e-11*V01*V02*V032*V04*V09 - 
      1.75787461014772928e-11*V01*V022*V042*V09 - 2.12859918533664998e-11*V012*V03*V042*V09 + 
      1.5878184032746685e-11*V03*V043*V09 - 2.17632095197330623e-12*V024*V05*V09 - 
      3.87441597452253794e-11*V01*V022*V03*V05*V09 - 1.93138035517508853e-11*V012*V032*V05*V09 - 
      2.20239434797595296e-11*V012*V02*V04*V05*V09 + 4.86695030053447292e-11*V032*V04*V05*V09 + 
      2.37495385253358106e-11*V02*V042*V05*V09 - 1.764283786161869e-12*V013*V052*V09 + 
      2.50873783636678499e-11*V02*V03*V052*V09 + 1.48663963105311829e-11*V01*V04*V052*V09 - 
      4.10888061201918817e-12*V01*V023*V06*V09 - 1.50615046086262874e-11*V012*V02*V03*V06*V09 + 
      1.14452401219597558e-11*V033*V06*V09 - 2.69673769880929319e-12*V013*V04*V06*V09 + 
      3.46386647750844639e-11*V02*V03*V04*V06*V09 + 1.05932243326139705e-11*V01*V042*V06*V09 + 
      8.59624039298200643e-12*V022*V05*V06*V09 + 2.08598882178596402e-11*V01*V03*V05*V06*V09 + 
      3.8551783613214481e-12*V01*V02*V062*V09 - 1.39347115441546306e-12*V05*V062*V09 - 
      2.63036409119751009e-12*V012*V022*V07*V09 - 1.61226495561203606e-12*V013*V03*V07*V09 + 
      1.21547897831790074e-11*V02*V032*V07*V09 + 5.70256871090663302e-12*V022*V04*V07*V09 + 
      1.43274815099104221e-11*V01*V03*V04*V07*V09 + 7.43357219102010163e-12*V01*V02*V05*V07*V09 - 
      1.31718651614503007e-12*V052*V07*V09 + 1.49436246329253495e-12*V012*V06*V07*V09 - 
      1.90771640918804961e-12*V04*V06*V07*V09 - 6.52449989900935826e-13*V03*V072*V09 - 
      4.88502923294358511e-13*V013*V02*V08*V09 + 3.30445480859409369e-12*V022*V03*V08*V09 + 
      3.85542049251293728e-12*V01*V032*V08*V09 + 4.0644096633375603e-12*V01*V02*V04*V08*V09 + 
      1.14566861972612382e-12*V012*V05*V08*V09 - 1.49943560870502909e-12*V04*V05*V08*V09 - 
      1.08363272954607881e-12*V03*V06*V08*V09 - 3.81119557316415921e-13*V02*V07*V08*V09 - 
      6.57399642517522831e-14*V01*V082*V09 - 1.3672309536623213e-14*V014*V092 + 
      1.34275284265812889e-13*V023*V092 + 1.0597278810072115e-12*V01*V02*V03*V092 + 
      3.03866031999320828e-13*V012*V04*V092 - 1.96617668356892374e-13*V042*V092 - 
      3.93449226968134618e-13*V03*V05*V092 - 1.46022563204140642e-13*V02*V06*V092 - 
      6.08818045029647192e-14*V01*V07*V092 - 4.43778189372115618e-12*V023*V032*V10 - 
      1.0730381935067733e-11*V01*V02*V033*V10 - 4.82756926875573625e-13*V024*V04*V10 - 
      1.63633684721436374e-11*V01*V022*V03*V04*V10 - 8.80455935115634191e-12*V012*V032*V04*V10 - 
      4.8845746457398594e-12*V012*V02*V042*V10 + 1.10552638765312001e-11*V032*V042*V10 + 
      2.98073930495935198e-12*V02*V043*V10 - 2.66266913623269371e-12*V01*V023*V05*V10 - 
      9.17891467411430681e-12*V012*V02*V03*V05*V10 + 7.19798393823591189e-12*V033*V05*V10 - 
      1.62640979803162099e-12*V013*V04*V05*V10 + 2.24067859631364092e-11*V02*V03*V04*V05*V10 + 
      6.78031192748195653e-12*V01*V042*V05*V10 + 2.80349815531331405e-12*V022*V052*V10 + 
      6.53656342900806976e-12*V01*V03*V052*V10 - 1.72259983079063792e-12*V012*V022*V06*V10 - 
      1.08638982632081299e-12*V013*V03*V06*V10 + 8.05431200260468374e-12*V02*V032*V06*V10 + 
      3.20746920720187607e-12*V022*V04*V06*V10 + 9.62914453138276597e-12*V01*V03*V04*V06*V10 + 
      4.93757408155804046e-12*V01*V02*V05*V06*V10 - 8.97722150090213084e-13*V052*V06*V10 + 
      5.09525340614492258e-13*V012*V062*V10 - 6.19150924140375002e-13*V04*V062*V10 - 
      3.91526501867666716e-13*V013*V02*V07*V10 + 2.726822881978324e-12*V022*V03*V07*V10 + 
      3.13628235144787501e-12*V01*V032*V07*V10 + 3.33996439631173268e-12*V01*V02*V04*V07*V10 + 
      9.30532567539012022e-13*V012*V05*V07*V10 - 1.23367777697183735e-12*V04*V05*V07*V10 - 
      8.89945358062026764e-13*V03*V06*V07*V10 - 1.57084196009018042e-13*V02*V072*V10 - 
      2.4278249017839326e-14*V014*V08*V10 + 1.9935667910102446e-13*V023*V08*V10 + 
      1.85098658188588493e-12*V01*V02*V03*V08*V10 + 5.38127227356842203e-13*V012*V04*V08*V10 - 
      3.31723147690850762e-13*V042*V08*V10 - 6.9507863861203009e-13*V03*V05*V08*V10 - 
      2.45643656701424999e-13*V02*V06*V08*V10 - 1.07727084797919002e-13*V01*V07*V08*V10 + 
      2.41441399870557036e-13*V01*V022*V09*V10 + 2.61239380405392769e-13*V012*V03*V09*V10 - 
      3.69139476097666154e-13*V03*V04*V09*V10 - 1.89681522777605376e-13*V02*V05*V09*V10 - 
      8.32491260590072139e-14*V01*V06*V09*V10 + 1.36794697472808766e-15*V092*V10 + 
      3.21862642306851063e-14*V012*V02*V102 - 4.23987889903701045e-14*V032*V102 - 
      4.14059203836150082e-14*V02*V04*V102 - 2.65204783412023643e-14*V01*V05*V102 + 
      1.19794923666809842e-15*V08*V102 - 3.95694718540601133e-13*V024*V03*V11 - 
      3.39521521201775859e-12*V01*V022*V032*V11 - 1.10049064767962365e-12*V012*V033*V11 - 
      1.01264615075942134e-12*V01*V023*V04*V11 - 3.81508583125936463e-12*V012*V02*V03*V04*V11 + 
      3.10131706285434043e-12*V033*V04*V11 - 3.42260471218526235e-13*V013*V042*V11 + 
      4.59970972234403651e-12*V02*V03*V042*V11 + 9.42774788278072168e-13*V01*V043*V11 - 
      9.82444005569503125e-13*V012*V022*V05*V11 - 5.9693867468328123e-13*V013*V03*V05*V11 + 
      4.8062221195149609e-12*V02*V032*V05*V11 + 2.26840538639846653e-12*V022*V04*V05*V11 + 
      5.64654078653829002e-12*V01*V03*V04*V05*V11 + 1.4656930869583549e-12*V01*V02*V052*V11 - 
      1.78524293224988015e-13*V053*V11 - 2.40908449344777059e-13*V013*V02*V06*V11 + 
      1.66275662275677501e-12*V022*V03*V06*V11 + 1.97246960715301193e-12*V01*V032*V06*V11 + 
      2.05317850408183086e-12*V01*V02*V04*V06*V11 + 5.86098871409768281e-13*V012*V05*V06*V11 - 
      7.77539587898587087e-13*V04*V05*V06*V11 - 2.81445124796412342e-13*V03*V062*V11 - 
      1.7673366631887235e-14*V014*V07*V11 + 1.79249586020880299e-13*V023*V07*V11 + 
      1.40975932178320167e-12*V01*V02*V03*V07*V11 + 4.03746924135305121e-13*V012*V04*V07*V11 - 
      2.6517515145568587e-13*V042*V07*V11 - 5.29816717885658922e-13*V03*V05*V07*V11 - 
      1.96875281901392601e-13*V02*V06*V07*V11 - 4.09371277473678743e-14*V01*V072*V11 + 
      1.95246123954086745e-13*V01*V022*V08*V11 + 2.13702144834016469e-13*V012*V03*V08*V11 - 
      3.0248864463170033e-13*V03*V04*V08*V11 - 1.55109889972973452e-13*V02*V05*V08*V11 - 
      6.83045682998040385e-14*V01*V06*V08*V11 + 5.94750377791165904e-14*V012*V02*V09*V11 - 
      7.87362200983820255e-14*V032*V09*V11 - 8.05978799490893614e-14*V02*V04*V09*V11 - 
      4.92025765160774791e-14*V01*V05*V09*V11 + 2.25079343036096795e-15*V08*V09*V11 + 
      4.61611676379027922e-15*V013*V10*V11 - 3.81326311714226798e-14*V02*V03*V10*V11 - 
      2.31952018576234043e-14*V01*V04*V10*V11 + 1.85094285759087006e-15*V07*V10*V11 - 
      2.03651062879723674e-15*V022*V112 - 4.86180727660997464e-15*V01*V03*V112 + 
      5.90028305795501004e-16*V06*V112 - 6.75128020234787436e-15*V025*V12 - 
      4.04832653425374421e-13*V01*V023*V03*V12 - 6.58716245088369999e-13*V012*V02*V032*V12 + 
      2.88257141340156025e-13*V034*V12 - 3.64890993816015221e-13*V012*V022*V04*V12 - 
      2.29780507648557659e-13*V013*V03*V04*V12 + 1.82655886326303188e-12*V02*V032*V04*V12 + 
      3.55163758808754611e-13*V022*V042*V12 + 1.09411286557086103e-12*V01*V03*V042*V12 - 
      1.20983325308449388e-13*V013*V02*V05*V12 + 9.18470686312687476e-13*V022*V03*V05*V12 + 
      1.03912177910466923e-12*V01*V032*V05*V12 + 1.11843978220431307e-12*V01*V02*V04*V05*V12 + 
      1.53544097014393399e-13*V012*V052*V12 - 2.13000766311781401e-13*V04*V052*V12 - 
      9.97016026267345522e-15*V014*V06*V12 + 8.44341519033306796e-14*V023*V06*V12 + 
      7.95446048387897921e-13*V01*V02*V03*V06*V12 + 2.31462404808753328e-13*V012*V04*V06*V12 - 
      1.45411699732690495e-13*V042*V06*V12 - 3.0650120151625333e-13*V03*V05*V06*V12 - 
      5.37678118898051551e-14*V02*V062*V12 + 1.364896867757377e-13*V01*V022*V07*V12 + 
      1.46029306347281841e-13*V012*V03*V07*V12 - 2.10897482500563507e-13*V03*V04*V07*V12 - 
      1.08539214589577744e-13*V02*V05*V07*V12 - 4.74319379315964474e-14*V01*V06*V07*V12 + 
      4.42930148566727395e-14*V012*V02*V08*V12 - 5.89859374240992122e-14*V032*V08*V12 - 
      5.74289100485794227e-14*V02*V04*V08*V12 - 3.68832032236925508e-14*V01*V05*V08*V12 + 
      8.35805916312076048e-16*V082*V12 + 3.88156689550779196e-15*V013*V09*V12 - 
      3.23731867780951408e-14*V02*V03*V09*V12 - 1.9658983913525166e-14*V01*V04*V09*V12 + 1.56992497981666107e-15*V07*V09*V12 - 
      3.5446499869017245e-15*V022*V10*V12 - 8.8833366081989014e-15*V01*V03*V10*V12 + 
      1.06521661876890755e-15*V06*V10*V12 - 2.02184584031280276e-15*V01*V02*V11*V12 + 6.46153160095712129e-16*V05*V11*V12 - 
      1.12278939190792471e-16*V012*V122 + 1.2837672381141367e-16*V04*V122 - 
      1.52190276361769666e-14*V01*V024*V13 - 1.18991302275192557e-13*V012*V022*V03*V13 - 
      3.51648019952198737e-14*V013*V032*V13 + 2.18342790023408337e-13*V02*V033*V13 - 
      4.27330512028613343e-14*V013*V02*V04*V13 + 3.14170169924634943e-13*V022*V03*V04*V13 + 
      3.81136355144762139e-13*V01*V032*V04*V13 + 1.94963951413656301e-13*V01*V02*V042*V13 - 
      4.54962122251329371e-15*V014*V05*V13 + 5.10630298337388618e-14*V023*V05*V13 + 
      3.96620873395049548e-13*V01*V02*V03*V05*V13 + 1.13099733196138602e-13*V012*V04*V05*V13 - 
      7.79855928794921459e-14*V042*V05*V13 - 7.7517302070799046e-14*V03*V052*V13 + 
      7.03498588260794131e-14*V01*V022*V06*V13 + 7.80947366405379117e-14*V012*V03*V06*V13 - 
      1.13161254740707608e-13*V03*V04*V06*V13 - 5.7841315161336787e-14*V02*V05*V06*V13 - 
      1.27827217710707626e-14*V01*V062*V13 + 2.82250758468861961e-14*V012*V02*V07*V13 - 
      3.82084331408955793e-14*V032*V07*V13 - 3.92286283839355442e-14*V02*V04*V07*V13 - 
      2.3846553961852646e-14*V01*V05*V07*V13 + 2.69949323798906058e-15*V013*V08*V13 - 
      2.25078192114582938e-14*V02*V03*V08*V13 - 1.37119418245046624e-14*V01*V04*V08*V13 + 1.10136330838635727e-15*V07*V08*V13 - 
      2.94111717413138581e-15*V022*V09*V13 - 7.00883081039284023e-15*V01*V03*V09*V13 + 
      8.53504614903455699e-16*V06*V09*V13 - 1.7189016813385428e-15*V01*V02*V10*V13 + 5.50986153732985579e-16*V05*V10*V13 - 
      2.08827267126445038e-16*V012*V11*V13 + 2.42602441984774821e-16*V04*V11*V13 + 
      9.62599920821583685e-17*V03*V12*V13 + 9.34343349255274892e-18*V02*V132 - 
      6.49733990568523382e-15*V012*V023*V14 - 1.22195721978178291e-14*V013*V02*V03*V14 + 
      5.46589770837718418e-14*V022*V032*V14 + 4.00724929688669916e-14*V01*V033*V14 - 
      1.50625269948202528e-15*V014*V04*V14 + 1.35570036465602403e-14*V023*V04*V14 + 
      1.31721575602572221e-13*V01*V02*V03*V04*V14 + 1.92075309671340111e-14*V012*V042*V14 - 
      8.36247924829051364e-15*V043*V14 + 3.34129051796852647e-14*V01*V022*V05*V14 + 
      3.52000499590133283e-14*V012*V03*V05*V14 - 5.35875155953537993e-14*V03*V04*V05*V14 - 
      1.38126008328285604e-14*V02*V052*V14 + 1.39232159287826885e-14*V012*V02*V06*V14 - 
      1.91882704459756881e-14*V032*V06*V14 - 1.84963172766463855e-14*V02*V04*V06*V14 - 
      1.19855319020319255e-14*V01*V05*V06*V14 + 1.58409163639456545e-15*V013*V07*V14 - 
      1.36485299754388283e-14*V02*V03*V07*V14 - 8.26745364699971611e-15*V01*V04*V07*V14 + 
      3.33190390238662118e-16*V072*V14 - 1.80879560594266161e-15*V022*V08*V14 - 
      4.55910935670118506e-15*V01*V03*V08*V14 + 5.49609332985696543e-16*V06*V08*V14 - 1.26494334909771631e-15*V01*V02*V09*V14 + 
      4.05398052549426815e-16*V05*V09*V14 - 1.65750582700820046e-16*V012*V10*V14 + 
      1.89871368811768894e-16*V04*V10*V14 + 8.35032058146495524e-17*V03*V11*V14 + 1.7146727704914883e-17*V02*V12*V14 + 
      3.93284879498150998e-18*V01*V13*V14 - 9.78729174422285551e-16*V013*V022*V15 - 
      3.88103338371609931e-16*V014*V03*V15 + 5.30814981036248204e-15*V023*V03*V15 + 
      2.00114343002824938e-14*V01*V02*V032*V15 + 9.97696056385597653e-15*V01*V022*V04*V15 + 
      1.12867825244408776e-14*V012*V03*V04*V15 - 8.57029209245383136e-15*V03*V042*V15 + 
      5.92163854357007373e-15*V012*V02*V05*V15 - 8.43112954258054942e-15*V032*V05*V15 - 
      8.71495496852743328e-15*V02*V04*V05*V15 - 2.62258932363178751e-15*V01*V052*V15 + 
      7.39522091955158792e-16*V013*V06*V15 - 6.3454844923473991e-15*V02*V03*V06*V15 - 
      3.87339449708707427e-15*V01*V04*V06*V15 - 1.08282438301590603e-15*V022*V07*V15 - 
      2.56543578717180271e-15*V01*V03*V07*V15 + 3.16465105928351824e-16*V06*V07*V15 - 7.67061617727595964e-16*V01*V02*V08*V15 + 
      2.48416830315984065e-16*V05*V08*V15 - 1.13686482796883841e-16*V012*V09*V15 + 
      1.32958003589628937e-16*V04*V09*V15 + 6.21886730913371259e-17*V03*V10*V15 + 1.41590027241651129e-17*V02*V11*V15 + 
      3.43461768413402559e-18*V01*V12*V15 - 1.17848895216747797e-20*V152 - 
      5.89741224214354088e-17*V014*V02*V16 + 1.45983589524891168e-16*V024*V16 + 
      2.99695387820415258e-15*V01*V022*V03*V16 + 1.53059337496416333e-15*V012*V032*V16 + 
      1.75726689270894359e-15*V012*V02*V04*V16 - 2.57599886273407615e-15*V032*V04*V16 - 
      1.21771410014017265e-15*V02*V042*V16 + 2.89481404897263676e-16*V013*V05*V16 - 
      2.66365751468332216e-15*V02*V03*V05*V16 - 1.60611644734069043e-15*V01*V04*V05*V16 - 
      4.46050662757591766e-16*V022*V06*V16 - 1.1389784943048891e-15*V01*V03*V06*V16 + 
      6.96035564000206077e-17*V062*V16 - 4.0907750836487084e-16*V01*V02*V07*V16 + 1.32628018838235911e-16*V05*V07*V16 - 
      6.5416639138109311e-17*V012*V08*V16 + 7.54670638892426999e-17*V04*V08*V16 + 4.03772138732376978e-17*V03*V09*V16 + 
      9.76773385755790816e-18*V02*V10*V16 + 2.62923349003821696e-18*V01*V11*V16 - 2.20758400978923311e-20*V14*V16 - 
      1.20628886771117882e-18*V015*V17 + 1.30834313978781808e-16*V01*V023*V17 + 
      4.57022642346841948e-16*V012*V02*V03*V17 - 2.37693689899143784e-16*V033*V17 + 
      8.27346623129353227e-17*V013*V04*V17 - 7.47225387243934369e-16*V02*V03*V04*V17 - 
      2.28831378650312306e-16*V01*V042*V17 - 1.88083629475079693e-16*V022*V05*V17 - 
      4.40314400660602421e-16*V01*V03*V05*V17 - 1.69016867006270465e-16*V01*V02*V06*V17 + 5.59917955053447297e-17*V05*V06*V17 - 
      3.24735755523191262e-17*V012*V07*V17 + 3.86727403256427713e-17*V04*V07*V17 + 
      2.19902798681250644e-17*V03*V08*V17 + 6.08687490031123333e-18*V02*V09*V17 + 1.73996766721273613e-18*V01*V10*V17 - 
      1.84854017749295638e-20*V13*V17 + 3.13579258898068012e-17*V012*V022*V18 + 
      1.94681620038943026e-17*V013*V03*V18 - 1.01175750190730123e-16*V02*V032*V18 - 
      4.62128839721433835e-17*V022*V04*V18 - 1.20823419466605255e-16*V01*V03*V04*V18 - 
      6.29231228429941343e-17*V01*V02*V05*V18 + 1.04869987804805465e-17*V052*V18 - 
      1.29428678961327177e-17*V012*V06*V18 + 1.51744906346414701e-17*V04*V06*V18 + 
      1.04956807161393385e-17*V03*V07*V18 + 3.0821266464416291e-18*V02*V08*V18 + 1.01007465822602649e-18*V01*V09*V18 - 
      1.35366312825614059e-20*V12*V18 + 2.64713390414397574e-18*V013*V02*V19 - 
      1.29206010163061179e-17*V022*V03*V19 - 1.47494476969167388e-17*V01*V032*V19 - 
      1.59440353498617598e-17*V01*V02*V04*V19 - 4.44794287855468719e-18*V012*V05*V19 + 
      5.51181703928822303e-18*V04*V05*V19 + 3.99194592012692394e-18*V03*V06*V19 + 1.42630085136583279e-18*V02*V07*V19 + 
      4.95426857892580663e-19*V01*V08*V19 - 8.8518448452916774e-21*V11*V19 + 7.0366850616485431e-20*V014*V20 - 
      4.67942215966620425e-19*V023*V20 - 3.82845131579737685e-18*V01*V02*V03*V20 - 
      1.11099842964277723e-18*V012*V04*V20 + 6.71413490199719079e-19*V042*V20 + 
      1.3491003904533701e-18*V03*V05*V20 + 5.03159754534212754e-19*V02*V06*V20 + 2.13427398623557061e-19*V01*V07*V20 - 
      5.0076879957602313e-21*V10*V20 - 2.25062228559076418e-19*V01*V022*V21 - 
      2.40624844198066318e-19*V012*V03*V21 + 3.23029538062408962e-19*V03*V04*V21 + 1.671535265017234e-19*V02*V05*V21 + 
      7.39172201791050052e-20*V01*V06*V21 - 2.52678221472134795e-21*V09*V21 - 2.89285941423328994e-20*V012*V02*V22 + 
      3.58317988498014016e-20*V032*V22 + 3.67304310523110038e-20*V02*V04*V22 + 2.26610010716036714e-20*V01*V05*V22 - 
      1.07666005985679865e-21*V08*V22 - 1.04247186098496935e-21*V013*V23 + 8.17961680332572162e-21*V02*V03*V23 + 
      4.99297375503406491e-21*V01*V04*V23 - 4.10092299280725401e-22*V07*V23 + 4.18186987912361267e-22*V022*V24 + 
      1.00228790870808568e-21*V01*V03*V24 - 1.25138550008783256e-22*V06*V24 + 1.0677205636935544e-22*V01*V02*V25 - 
      3.46229220541556052e-23*V05*V25 + 5.77724553501522422e-24*V012*V26 - 6.79671885105076618e-24*V04*V26 - 
      1.27002769228530616e-24*V03*V27 - 1.20790677255395966e-25*V02*V28 - 1.29418582773638535e-26*V01*V29 + 
      9.80443808891201026e-30*V32) + delta8*eps12*
    (2.11565241127717922e-10*V02*V036 + 1.65171690028240725e-9*V022*V034*V04 + 
      6.86689914806456036e-10*V01*V035*V04 + 1.38805864074911309e-9*V023*V032*V042 + 
      3.76858510988269074e-9*V01*V02*V033*V042 + 8.85933436332280376e-12*V024*V043 + 
      1.76471696230472504e-9*V01*V022*V03*V043 + 
      1.03561112056353754e-9*V012*V032*V043 + 2.75037209033877212e-10*V012*V02*V044 - 
      9.02642591238259719e-10*V032*V044 - 1.2695043367275619e-10*V02*V045 + 
      1.09616111845060817e-9*V023*V033*V05 + 1.77421339320927151e-9*V01*V02*V034*V05 + 
      6.4324973752423922e-10*V024*V03*V04*V05 + 5.71344091228259897e-9*V01*V022*V032*V04*V05 + 
      1.86741308684926255e-9*V012*V033*V04*V05 + 8.32835184449467856e-10*V01*V023*V042*V05 + 
      3.18498806713256585e-9*V012*V02*V03*V042*V05 - 3.5781292071240821e-9*V033*V042*V05 + 
      1.88918926040067581e-10*V013*V043*V05 - 3.58448967695805344e-9*V02*V03*V043*V05 - 
      5.50364208970795713e-10*V01*V044*V05 + 2.9274133874502564e-11*V025*V052 + 
      9.54022580261324613e-10*V01*V023*V03*V052 + 
      1.45271116847806153e-9*V012*V02*V032*V052 - 8.30433660106480456e-10*V034*V052 + 
      8.10800334410740495e-10*V012*V022*V04*V052 + 
      4.93439900752214855e-10*V013*V03*V04*V052 - 5.51835642197186262e-9*V02*V032*V04*V052 - 
      1.31670334299521288e-9*V022*V042*V052 - 
      3.23098882822089369e-9*V01*V03*V042*V052 + 8.55819964015475075e-11*V013*V02*V053 - 
      9.36404301292205982e-10*V022*V03*V053 - 9.8734287517198592e-10*V01*V032*V053 - 
      1.11268245493696315e-9*V01*V02*V04*V053 - 7.20765262229931161e-11*V012*V054 + 
      9.23355852248475813e-11*V04*V054 + 2.39330317100315281e-10*V024*V032*V06 + 
      1.3051647236924731e-9*V01*V022*V033*V06 + 3.09561341377391052e-10*V012*V034*V06 + 
      3.48977325642452677e-12*V025*V04*V06 + 1.22416291811533812e-9*V01*V023*V03*V04*V06 + 
      2.15050441693153037e-9*V012*V02*V032*V04*V06 - 1.2540967336963881e-9*V034*V04*V06 + 
      5.75471315858418555e-10*V012*V022*V042*V06 + 
      3.76511674913909224e-10*V013*V03*V042*V06 - 3.90098211999087102e-9*V02*V032*V042*V06 - 
      4.47687665627033096e-10*V022*V043*V06 - 1.57662395238450447e-9*V01*V03*V043*V06 + 
      1.43598190260189168e-10*V01*V024*V05*V06 + 1.09951143292722396e-9*V012*V022*V03*V05*V06 + 
      3.24078789664336084e-10*V013*V032*V05*V06 - 2.59365065239942983e-9*V02*V033*V05*V06 + 
      3.90316666526930781e-10*V013*V02*V04*V05*V06 - 3.85671637616173572e-9*V022*V03*V04*V05*V06 - 
      4.50292997806951258e-9*V01*V032*V04*V05*V06 - 2.37779552204089659e-9*V01*V02*V042*V05*V06 + 
      2.04524990081220648e-11*V014*V052*V06 - 3.13399965991355314e-10*V023*V052*V06 - 
      2.3394258109460173e-9*V01*V02*V03*V052*V06 - 6.63580681882650984e-10*V012*V04*V052*V06 + 
      4.09063986133841212e-10*V042*V052*V06 + 2.63730090622421793e-10*V03*V053*V06 + 
      6.66782966486021182e-11*V012*V023*V062 + 
      1.29243357535212139e-10*V013*V02*V03*V062 - 
      7.0044339247857499e-10*V022*V032*V062 - 5.20296516473443331e-10*V01*V033*V062 + 
      1.59408858439325945e-11*V014*V04*V062 - 1.57378488160745354e-10*V023*V04*V062 - 
      1.70453294570014247e-9*V01*V02*V03*V04*V062 - 2.51569453030911035e-10*V012*V042*V062 + 
      9.18834098837043378e-11*V043*V062 - 4.26817577269560114e-10*V01*V022*V05*V062 - 
      4.56738967892153493e-10*V012*V03*V05*V062 + 5.91846382721704868e-10*V03*V04*V05*V062 + 
      1.52311401988866355e-10*V02*V052*V062 - 6.04509826524235903e-11*V012*V02*V063 + 
      7.09198988758169537e-11*V032*V063 + 6.77843207385101356e-11*V02*V04*V063 + 
      4.45704132424626415e-11*V01*V05*V063 + 2.78801274995262514e-11*V025*V03*V07 + 
      4.38809597103381844e-10*V01*V023*V032*V07 + 4.35422603833789192e-10*V012*V02*V033*V07 - 
      1.58617165714471135e-10*V035*V07 + 9.18928196463198886e-11*V01*V024*V04*V07 + 
      7.38942233429171834e-10*V012*V022*V03*V04*V07 + 
      2.19920699276369752e-10*V013*V032*V04*V07 - 1.7664033638278381e-9*V02*V033*V04*V07 + 
      1.31976714457564486e-10*V013*V02*V042*V07 - 1.27386361796512544e-9*V022*V03*V042*V07 - 
      1.54269150627059114e-9*V01*V032*V042*V07 - 5.28466126686766646e-10*V01*V02*V043*V07 + 
      1.24762180525692819e-10*V012*V023*V05*V07 + 2.28771155503092297e-10*V013*V02*V03*V05*V07 - 
      1.35112199883971345e-9*V022*V032*V05*V07 - 9.38465205954234216e-10*V01*V033*V05*V07 + 
      2.77676792983138696e-11*V014*V04*V05*V07 - 4.10747423448674162e-10*V023*V04*V05*V07 - 
      3.19278471436932968e-9*V01*V02*V03*V04*V05*V07 - 4.55811658613011584e-10*V012*V042*V05*V07 + 
      1.86665463694660622e-10*V043*V05*V07 - 4.09094681168330782e-10*V01*V022*V052*V07 - 
      4.08870225319252979e-10*V012*V03*V052*V07 + 5.49719273193079439e-10*V03*V04*V052*V07 + 
      9.56476465248094328e-11*V02*V053*V07 + 4.52017998159628711e-11*V013*V022*V06*V07 + 
      1.79896574088346691e-11*V014*V03*V06*V07 - 3.0310827457471207e-10*V023*V03*V06*V07 - 
      1.11577873665124817e-9*V01*V02*V032*V06*V07 - 5.68252949385511473e-10*V01*V022*V04*V06*V07 - 
      6.29019906495363498e-10*V012*V03*V04*V06*V07 + 4.06868983273823627e-10*V03*V042*V06*V07 - 
      3.29181431827900208e-10*V012*V02*V05*V06*V07 + 3.91643481167665928e-10*V032*V05*V06*V07 + 
      4.1601667451417486e-10*V02*V04*V05*V06*V07 + 1.22552309158309918e-10*V01*V052*V06*V07 - 
      2.05459036375128528e-11*V013*V062*V07 + 1.51330543601968553e-10*V02*V03*V062*V07 + 
      9.23677171347181746e-11*V01*V04*V062*V07 + 3.17451693919720325e-12*V014*V02*V072 - 
      1.18601173153377088e-11*V024*V072 - 1.9561645196749617e-10*V01*V022*V03*V072 - 
      9.64188505470931113e-11*V012*V032*V072 - 
      1.12705649373862715e-10*V012*V02*V04*V072 + 1.36065768023441505e-10*V032*V04*V072 + 
      7.06903374005472804e-11*V02*V042*V072 - 1.81655173837418371e-11*V013*V05*V072 + 
      1.42209629640025305e-10*V02*V03*V05*V072 + 8.52417210864674562e-11*V01*V04*V05*V072 + 
      2.61069676607456382e-11*V022*V06*V072 + 6.02627002374851982e-11*V01*V03*V06*V072 - 
      3.12491251924210466e-12*V062*V072 + 7.34232527128604452e-12*V01*V02*V073 - 
      1.92307434159209845e-12*V05*V073 + 9.33899039438782262e-14*V026*V08 + 
      5.36898446670225014e-11*V01*V024*V03*V08 + 1.87105027552625145e-10*V012*V022*V032*V08 + 
      3.5535647133409023e-11*V013*V033*V08 - 2.39015346507024879e-10*V02*V034*V08 + 
      6.78449176370001325e-11*V012*V023*V04*V08 + 1.30249691643408376e-10*V013*V02*V03*V04*V08 - 
      7.32106839125128782e-10*V022*V032*V04*V08 - 5.47258162504973128e-10*V01*V033*V04*V08 + 
      7.99919562132077166e-12*V014*V042*V08 - 8.10150432776255557e-11*V023*V042*V08 - 
      8.92060173335578148e-10*V01*V02*V03*V042*V08 - 8.78861131794236595e-11*V012*V043*V08 + 
      2.45634439070379662e-11*V044*V08 + 3.3680102907807188e-11*V013*V022*V05*V08 + 
      1.3260963424348544e-11*V014*V03*V05*V08 - 2.39777671233591518e-10*V023*V03*V05*V08 - 
      8.56336569042266343e-10*V01*V02*V032*V05*V08 - 4.45979580078837503e-10*V01*V022*V04*V05*V08 - 
      4.79942155427837879e-10*V012*V03*V04*V05*V08 + 3.18777285542879122e-10*V03*V042*V05*V08 - 
      1.25880495810415435e-10*V012*V02*V052*V08 + 1.51976211089163639e-10*V032*V052*V08 + 
      1.63688124948446059e-10*V02*V04*V052*V08 + 3.16367014179809657e-11*V01*V053*V08 + 
      5.39224161534457042e-12*V014*V02*V06*V08 - 1.41750190832167476e-11*V024*V06*V08 - 
      3.20178509616809358e-10*V01*V022*V03*V06*V08 - 1.64320036339773029e-10*V012*V032*V06*V08 - 
      1.89843943138212606e-10*V012*V02*V04*V06*V08 + 2.29316143204970521e-10*V032*V04*V06*V08 + 
      1.08531575888440868e-10*V02*V042*V06*V08 - 3.11484139606328914e-11*V013*V05*V06*V08 + 
      2.3727014010970781e-10*V02*V03*V05*V06*V08 + 1.43964229244591958e-10*V01*V04*V05*V06*V08 + 
      1.99122421911040609e-11*V022*V062*V08 + 5.12191263133403411e-11*V01*V03*V062*V08 - 
      1.72600891797293642e-12*V063*V08 + 2.73169840919134062e-13*V015*V07*V08 - 
      3.52875350509699961e-11*V01*V023*V07*V08 - 1.19056232548406994e-10*V012*V02*V03*V07*V08 + 
      4.99902156869209214e-11*V033*V07*V08 - 2.15452724095297597e-11*V013*V04*V07*V08 + 
      1.62491163306568752e-10*V02*V03*V04*V07*V08 + 4.96549282666049462e-11*V01*V042*V07*V08 + 
      4.1244746339553127e-11*V022*V05*V07*V08 + 9.32363518019342652e-11*V01*V03*V05*V07*V08 + 
      3.68800466262529626e-11*V01*V02*V06*V07*V08 - 9.79663515522813358e-12*V05*V06*V07*V08 + 
      3.48053732398600019e-12*V012*V072*V08 - 3.41200177100048083e-12*V04*V072*V08 - 
      8.9014842370156752e-12*V012*V022*V082 - 5.51185694124867139e-12*V013*V03*V082 + 
      2.29549714896332041e-11*V02*V032*V082 + 1.05963505154423349e-11*V022*V04*V082 + 
      2.7554415634859315e-11*V01*V03*V04*V082 + 1.43805891122775009e-11*V01*V02*V05*V082 - 
      1.91695324165125744e-12*V052*V082 + 2.98555011525104552e-12*V012*V06*V082 - 
      2.82096528228637575e-12*V04*V06*V082 - 1.93324877614192731e-12*V03*V07*V082 - 
      1.9350678485850944e-13*V02*V083 + 2.32334395829385428e-12*V01*V025*V09 + 
      3.20750163091827084e-11*V012*V023*V03*V09 + 2.84063060734221734e-11*V013*V02*V032*V09 - 
      1.27451402748070915e-10*V022*V033*V09 - 6.53203540288510474e-11*V01*V034*V09 + 
      1.7157321453101102e-11*V013*V022*V04*V09 + 6.80036076588052531e-12*V014*V03*V04*V09 - 
      1.17617197101646543e-10*V023*V03*V04*V09 - 4.48063471216427861e-10*V01*V02*V032*V04*V09 - 
      1.11120410037133987e-10*V01*V022*V042*V09 - 1.26804432487348757e-10*V012*V03*V042*V09 + 
      5.61876405754966581e-11*V03*V043*V09 + 3.53568774626835455e-12*V014*V02*V05*V09 - 
      1.40447766577962634e-11*V024*V05*V09 - 2.30190516477929056e-10*V01*V022*V03*V05*V09 - 
      1.12950925991023589e-10*V012*V032*V05*V09 - 1.32272563402436007e-10*V012*V02*V04*V05*V09 + 
      1.64243262359489933e-10*V032*V04*V05*V09 + 8.55971026152041424e-11*V02*V042*V05*V09 - 
      1.06125407792588808e-11*V013*V052*V09 + 8.58495928842687739e-11*V02*V03*V052*V09 + 
      5.13421228081671382e-11*V01*V04*V052*V09 + 2.06410622579155605e-13*V015*V06*V09 - 
      2.64170520031527579e-11*V01*V023*V06*V09 - 9.13674565074522247e-11*V012*V02*V03*V06*V09 + 
      3.88736980485894685e-11*V033*V06*V09 - 1.65966151998362668e-11*V013*V04*V06*V09 + 
      1.24993087622714682e-10*V02*V03*V04*V06*V09 + 3.83498824297580126e-11*V01*V042*V06*V09 + 
      3.15874205059106237e-11*V022*V05*V06*V09 + 7.2512193034044794e-11*V01*V03*V05*V06*V09 + 
      1.42226540451068014e-11*V01*V02*V062*V09 - 3.816095382756888e-12*V05*V062*V09 - 
      1.62197452894669368e-11*V012*V022*V07*V09 - 9.90975700474691904e-12*V013*V03*V07*V09 + 
      4.24024936280090997e-11*V02*V032*V07*V09 + 2.13122349695748975e-11*V022*V04*V07*V09 + 
      5.04392021761214844e-11*V01*V03*V04*V07*V09 + 2.65078091269298211e-11*V01*V02*V05*V07*V09 - 
      3.51880541311691857e-12*V052*V07*V09 + 5.41602918842199384e-12*V012*V06*V07*V09 - 
      5.30725063759252805e-12*V04*V06*V07*V09 - 1.77277488312182913e-12*V03*V072*V09 - 
      3.11624408895051199e-12*V013*V02*V08*V09 + 1.23525685228935338e-11*V022*V03*V08*V09 + 
      1.37205569954248304e-11*V01*V032*V08*V09 + 1.52354434673470733e-11*V01*V02*V04*V08*V09 + 
      4.17111144051216047e-12*V012*V05*V08*V09 - 4.16587199946322352e-12*V04*V05*V08*V09 - 
      3.0153477853378167e-12*V03*V06*V08*V09 - 1.09639205734423692e-12*V02*V07*V08*V09 - 
      1.90216358700110283e-13*V01*V082*V09 - 9.05362137174969968e-14*V014*V092 + 
      5.27174469924945277e-13*V023*V092 + 3.90596557221585395e-12*V01*V02*V03*V092 + 
      1.1306835924901323e-12*V012*V04*V092 - 5.61505141000528238e-13*V042*V092 - 
      1.08014467389071212e-12*V03*V05*V092 - 4.25065391033742532e-13*V02*V06*V092 - 
      1.73923801996343946e-13*V01*V07*V092 + 1.80204750757133097e-12*V012*V024*V10 + 
      6.6754075772133836e-12*V013*V022*V03*V10 + 1.27289035464315201e-12*V014*V032*V10 - 
      2.8182928186279854e-11*V023*V032*V10 - 6.45684737602794604e-11*V01*V02*V033*V10 + 
      1.60898588880435859e-12*V014*V02*V04*V10 - 4.45586359623285591e-12*V024*V04*V10 - 
      1.03634195138969052e-10*V01*V022*V03*V04*V10 - 5.36316695781623018e-11*V012*V032*V04*V10 - 
      3.07895100297339906e-11*V012*V02*V042*V10 + 3.91409558305249101e-11*V032*V042*V10 + 
      1.21490706789575671e-11*V02*V043*V10 + 1.19030688053496982e-13*V015*V05*V10 - 
      1.71538098636217616e-11*V01*V023*V05*V10 - 5.64226522852279638e-11*V012*V02*V03*V05*V10 + 
      2.46015300577810465e-11*V033*V05*V10 - 1.01466292237250705e-11*V013*V04*V05*V10 + 
      8.07046332883337161e-11*V02*V03*V04*V05*V10 + 2.4528164923518728e-11*V01*V042*V05*V10 + 
      1.02745451867309303e-11*V022*V052*V10 + 2.28718856216303335e-11*V01*V03*V052*V10 - 
      1.10329441033408518e-11*V012*V022*V06*V10 - 6.84933658942219803e-12*V013*V03*V06*V10 + 
      2.90846049241629619e-11*V02*V032*V06*V10 + 1.33360211355181273e-11*V022*V04*V06*V10 + 
      3.49307369582445036e-11*V01*V03*V04*V06*V10 + 1.82067196026489306e-11*V01*V02*V05*V06*V10 - 
      2.45290667983252177e-12*V052*V06*V10 + 1.89149491028716843e-12*V012*V062*V10 - 
      1.80105123076651693e-12*V04*V062*V10 - 2.51311522921836783e-12*V013*V02*V07*V10 + 
      1.01747257982938607e-11*V022*V03*V07*V10 + 1.11889968578439228e-11*V01*V032*V07*V10 + 
      1.25048991749510642e-11*V01*V02*V04*V07*V10 + 3.3971497589202656e-12*V012*V05*V07*V10 - 
      3.42121342347917974e-12*V04*V05*V07*V10 - 2.47315595448135342e-12*V03*V06*V07*V10 - 
      4.50892257805768417e-13*V02*V072*V10 - 1.62588390006639376e-13*V014*V08*V10 + 
      8.59499561964646982e-13*V023*V08*V10 + 6.95588461777906527e-12*V01*V02*V03*V08*V10 + 
      2.03021315588309362e-12*V012*V04*V08*V10 - 9.79842131694492942e-13*V042*V08*V10 - 
      1.93208350279529558e-12*V03*V05*V08*V10 - 7.40293769613125126e-13*V02*V06*V08*V10 - 
      3.11511131111510033e-13*V01*V07*V08*V10 + 9.47758744988983046e-13*V01*V022*V09*V10 + 
      9.86274402564482025e-13*V012*V03*V09*V10 - 1.05186250479343965e-12*V03*V04*V09*V10 - 
      5.50099709147661638e-13*V02*V05*V09*V10 - 2.43125269058403076e-13*V01*V06*V09*V10 + 
      3.45189681029132362e-15*V092*V10 + 1.27201107034834102e-13*V012*V02*V102 - 
      1.21093493406528216e-13*V032*V102 - 1.27970167265699324e-13*V02*V04*V102 - 
      7.74812828034231128e-14*V01*V05*V102 + 3.07202744047901961e-15*V08*V102 + 
      4.66750200453430365e-13*V013*V023*V11 + 5.42370796507721746e-13*V014*V02*V03*V11 - 
      2.66703564136419506e-12*V024*V03*V11 - 2.13059097056447515e-11*V01*V022*V032*V11 - 
      6.82976327923866823e-12*V012*V033*V11 + 4.88120769356436138e-14*V015*V04*V11 - 
      6.79955881515809613e-12*V01*V023*V04*V11 - 2.42237763853084244e-11*V012*V02*V03*V04*V11 + 
      1.09544496770453688e-11*V033*V04*V11 - 2.20585234394790884e-12*V013*V042*V11 + 
      1.73194020880645824e-11*V02*V03*V042*V11 + 3.55871308433789742e-12*V01*V043*V11 - 
      6.27773061253633616e-12*V012*V022*V05*V11 - 3.80976620701538267e-12*V013*V03*V05*V11 + 
      1.72016917343696099e-11*V02*V032*V05*V11 + 8.69399362817637592e-12*V022*V04*V05*V11 + 
      2.03930402881128102e-11*V01*V03*V04*V05*V11 + 5.3601529741255157e-12*V01*V02*V052*V11 - 
      4.8408032750926247e-13*V053*V11 - 1.57999691929495994e-12*V013*V02*V06*V11 + 
      6.3774308803590843e-12*V022*V03*V06*V11 + 7.17086151700619201e-12*V01*V032*V06*V11 + 
      7.89137369416447332e-12*V01*V02*V04*V06*V11 + 2.1786338776490303e-12*V012*V05*V06*V11 - 
      2.1948985742278733e-12*V04*V05*V06*V11 - 7.95425404155999254e-13*V03*V062*V11 - 
      1.19129491031840952e-13*V014*V07*V11 + 7.11190437305240347e-13*V023*V07*V11 + 
      5.25078827852685582e-12*V01*V02*V03*V07*V11 + 1.51817855758664337e-12*V012*V04*V07*V11 - 
      7.6082824039735212e-13*V042*V07*V11 - 1.46176680935142483e-12*V03*V05*V07*V11 - 
      5.75877537811953966e-13*V02*V06*V07*V11 - 1.1757563085783203e-13*V01*V072*V11 + 
      7.7554313589238595e-13*V01*V022*V08*V11 + 8.12999497213678129e-13*V012*V03*V08*V11 - 
      8.67601644012943141e-13*V03*V04*V08*V11 - 4.53037785871116828e-13*V02*V05*V08*V11 - 
      2.00709512347576198e-13*V01*V06*V08*V11 + 2.33554036863628865e-13*V012*V02*V09*V11 - 
      2.23426021833423486e-13*V032*V09*V11 - 2.421526232633391e-13*V02*V04*V09*V11 - 
      1.4285317101964436e-13*V01*V05*V09*V11 + 5.70595511638944445e-15*V08*V09*V11 + 
      1.86274770782752983e-14*V013*V10*V11 - 1.14236985058244151e-13*V02*V03*V10*V11 - 
      6.98171286704933682e-14*V01*V04*V10*V11 + 4.68375957413181823e-15*V07*V10*V11 - 
      6.43954982350461098e-15*V022*V112 - 1.4602310028890657e-14*V01*V03*V112 + 
      1.51372590659393389e-15*V06*V112 + 5.22431645717034434e-14*V014*V022*V12 - 
      6.57217855442747685e-14*V025*V12 + 1.46306755801796508e-14*V015*V03*V12 - 
      2.71939234770633937e-12*V01*V023*V03*V12 - 4.29677451809475364e-12*V012*V02*V032*V12 + 
      1.0330317940464957e-12*V034*V12 - 2.43842661783255919e-12*V012*V022*V04*V12 - 
      1.52423875771479026e-12*V013*V03*V04*V12 + 6.8645872335942034e-12*V02*V032*V04*V12 + 
      1.54051768008388797e-12*V022*V042*V12 + 4.13024414267126726e-12*V01*V03*V042*V12 - 
      8.0839600778865117e-13*V013*V02*V05*V12 + 3.50780059491054455e-12*V022*V03*V05*V12 + 
      3.80986187474230955e-12*V01*V032*V05*V12 + 4.28793473543833178e-12*V01*V02*V04*V05*V12 + 
      5.7602928447429103e-13*V012*V052*V12 - 5.98818735288428096e-13*V04*V052*V12 - 
      6.90320401992348523e-14*V014*V06*V12 + 3.7321417263518253e-13*V023*V06*V12 + 
      3.05832467602295418e-12*V01*V02*V03*V06*V12 + 8.93420165366179107e-13*V012*V04*V06*V12 - 
      4.36442316544916737e-13*V042*V06*V12 - 8.64026530790864853e-13*V03*V05*V06*V12 - 
      1.64662162941884957e-13*V02*V062*V12 + 5.40451934513128061e-13*V01*V022*V07*V12 + 
      5.58198669033631988e-13*V012*V03*V07*V12 - 6.0318700912628082e-13*V03*V04*V07*V12 - 
      3.15829576008743453e-13*V02*V05*V07*V12 - 1.39145649346753406e-13*V01*V06*V07*V12 + 
      1.76734768373571843e-13*V012*V02*V08*V12 - 1.69315230776424095e-13*V032*V08*V12 - 
      1.7856793078242808e-13*V02*V04*V08*V12 - 1.08309224778875102e-13*V01*V05*V08*V12 + 
      2.1506540682560739e-15*V082*V12 + 1.56987163742290443e-14*V013*V09*V12 - 
      9.68292325181963708e-14*V02*V03*V09*V12 - 5.91101433663662984e-14*V01*V04*V09*V12 + 3.96754019856724787e-15*V07*V09*V12 - 
      1.15265254280716767e-14*V022*V10*V12 - 2.68246320444907719e-14*V01*V03*V10*V12 + 
      2.76121289853093939e-15*V06*V10*V12 - 6.3861679185112356e-15*V01*V02*V11*V12 + 1.65050392776819855e-15*V05*V11*V12 - 
      3.58419591865898841e-16*V012*V122 + 3.41028946379174518e-16*V04*V122 + 
      2.58950010268666386e-15*V015*V02*V13 - 1.09850081424343276e-13*V01*V024*V13 - 
      8.13748530819934345e-13*V012*V022*V03*V13 - 2.41130510066692234e-13*V013*V032*V13 + 
      8.22332189207356192e-13*V02*V033*V13 - 2.96942078157229963e-13*V013*V02*V04*V13 + 
      1.2638334897962086e-12*V022*V03*V04*V13 + 1.44847505401729767e-12*V01*V032*V04*V13 + 
      7.85344983807370767e-13*V01*V02*V042*V13 - 3.22736890192028368e-14*V014*V05*V13 + 
      2.09019379269443467e-13*V023*V05*V13 + 1.52521533953256487e-12*V01*V02*V03*V05*V13 + 
      4.39118436195342929e-13*V012*V04*V05*V13 - 2.27633508924967209e-13*V042*V05*V13 - 
      2.17778790902937634e-13*V03*V052*V13 + 2.88288117752141297e-13*V01*V022*V06*V13 + 
      3.05349264555693289e-13*V012*V03*V06*V13 - 3.30632631205406418e-13*V03*V04*V06*V13 - 
      1.72181414944930764e-13*V02*V05*V06*V13 - 3.8255480537344902e-14*V01*V062*V13 + 
      1.12778191787630349e-13*V012*V02*V07*V13 - 1.09260484377106008e-13*V032*V07*V13 - 
      1.18701140944617636e-13*V02*V04*V07*V13 - 6.97930098512891936e-14*V01*V05*V07*V13 + 
      1.10478559955210139e-14*V013*V08*V13 - 6.80655901877191312e-14*V02*V03*V08*V13 - 
      4.16452299968607051e-14*V01*V04*V08*V13 + 2.8020716062433473e-15*V07*V08*V13 - 
      9.31985174971273256e-15*V022*V09*V13 - 2.11056434780531011e-14*V01*V03*V09*V13 + 
      2.19137817815699156e-15*V06*V09*V13 - 5.4502716511860758e-15*V01*V02*V10*V13 + 1.41035705767413631e-15*V05*V10*V13 - 
      6.65707849928832573e-16*V012*V11*V13 + 6.39061426001479399e-16*V04*V11*V13 + 
      2.52801041778552297e-16*V03*V12*V13 + 2.57926127768524185e-17*V02*V132 + 
      4.62410732622618547e-17*V016*V14 - 4.64266742077688608e-14*V012*V023*V14 - 
      8.78229227890374873e-14*V013*V02*V03*V14 + 2.18986707714845588e-13*V022*V032*V14 + 
      1.54927629419260848e-13*V01*V033*V14 - 1.11135058301989874e-14*V014*V04*V14 + 
      6.28934153347653924e-14*V023*V04*V14 + 5.29799725035523053e-13*V01*V02*V03*V04*V14 + 
      7.75494233196318679e-14*V012*V042*V14 - 2.60048530426178278e-14*V043*V14 + 
      1.36353083619310579e-13*V01*V022*V05*V14 + 1.39202726516384512e-13*V012*V03*V05*V14 - 
      1.55998600726292586e-13*V03*V04*V05*V14 - 4.08950718528632656e-14*V02*V052*V14 + 
      5.71862002559481535e-14*V012*V02*V06*V14 - 5.60444193844106971e-14*V032*V06*V14 - 
      5.86789049118273296e-14*V02*V04*V06*V14 - 3.58172282858980172e-14*V01*V05*V06*V14 + 
      6.53284368801179545e-15*V013*V07*V14 - 4.11073930825690663e-14*V02*V03*V07*V14 - 
      2.50461755064385383e-14*V01*V04*V07*V14 + 8.44616400886231065e-16*V072*V14 - 
      5.94088722559848644e-15*V022*V08*V14 - 1.38794379503494743e-14*V01*V03*V08*V14 + 
      1.43192703654689982e-15*V06*V08*V14 - 4.00273982181643707e-15*V01*V02*V09*V14 + 1.03578235953022005e-15*V05*V09*V14 - 
      5.30646576258819308e-16*V012*V10*V14 + 5.05220993342412293e-16*V04*V10*V14 + 2.1917107047179425e-16*V03*V11*V14 + 
      4.7720572861647374e-17*V02*V12*V14 + 1.08749680718856481e-17*V01*V13*V14 - 
      7.37394332424612684e-15*V013*V022*V15 - 2.9820466050543433e-15*V014*V03*V15 + 
      2.28585299444413014e-14*V023*V03*V15 + 8.12600104725178516e-14*V01*V02*V032*V15 + 
      4.29690750230386677e-14*V01*V022*V04*V15 + 4.62867692716653729e-14*V012*V03*V04*V15 - 
      2.59520107413750305e-14*V03*V042*V15 + 2.45375072003902738e-14*V012*V02*V05*V15 - 
      2.46155995453615031e-14*V032*V05*V15 - 2.68891515513532826e-14*V02*V04*V05*V15 - 
      7.83903760415543155e-15*V01*V052*V15 + 3.1231098018576612e-15*V013*V06*V15 - 
      1.9594933789074624e-14*V02*V03*V06*V15 - 1.20086681997827743e-14*V01*V04*V06*V15 - 
      3.4618108242359122e-15*V022*V07*V15 - 7.80396387108720409e-15*V01*V03*V07*V15 + 
      8.15742589427790721e-16*V06*V07*V15 - 2.45930942200419554e-15*V01*V02*V08*V15 + 6.39569809340514948e-16*V05*V08*V15 - 
      3.64051837137481534e-16*V012*V09*V15 + 3.50617706073352386e-16*V04*V09*V15 + 
      1.63725927627113307e-16*V03*V10*V15 + 3.90961486919211966e-17*V02*V11*V15 + 9.50627247036134867e-18*V01*V12*V15 - 
      2.94654087338811119e-20*V152 - 4.77489343469008282e-16*V014*V02*V16 + 
      7.26535871058317459e-16*V024*V16 + 1.28743022347801229e-14*V01*V022*V03*V16 + 
      6.4100403335553211e-15*V012*V032*V16 + 7.57457261856336804e-15*V012*V02*V04*V16 - 
      7.79229585851794524e-15*V032*V04*V16 - 4.01457158249064096e-15*V02*V042*V16 + 
      1.24134943026437688e-15*V013*V05*V16 - 8.18940865357343808e-15*V02*V03*V05*V16 - 
      4.96954818182556857e-15*V01*V04*V05*V16 - 1.49942046655474542e-15*V022*V06*V16 - 
      3.53759209286139809e-15*V01*V03*V06*V16 + 1.8384284867523702e-16*V062*V16 - 
      1.30742879622852254e-15*V01*V02*V07*V16 + 3.40247927044035842e-16*V05*V07*V16 - 
      2.11616016953575468e-16*V012*V08*V16 + 2.02073999477768511e-16*V04*V08*V16 + 
      1.06105889737457533e-16*V03*V09*V16 + 2.72593643679791138e-17*V02*V10*V16 + 7.27235157781215875e-18*V01*V11*V16 - 
      5.53254507285150897e-20*V14*V16 - 1.05550275924728147e-17*V015*V17 + 
      6.03130472178879788e-16*V01*V023*V17 + 2.00591597790125225e-15*V012*V02*V03*V17 - 
      7.23327045603310504e-16*V033*V17 + 3.67457369320492075e-16*V013*V04*V17 - 
      2.39675187569321659e-15*V02*V03*V04*V17 - 7.36639843415224813e-16*V01*V042*V17 - 
      6.14465399032351983e-16*V022*V05*V17 - 1.37150047973024232e-15*V01*V03*V05*V17 - 
      5.54395324879716279e-16*V01*V02*V06*V17 + 1.46140331824485412e-16*V05*V06*V17 - 
      1.05302276655860408e-16*V012*V07*V17 + 1.0243805050847984e-16*V04*V07*V17 + 5.82637435987304793e-17*V03*V08*V17 + 
      1.68312061391460624e-17*V02*V09*V17 + 4.82984981109450236e-18*V01*V10*V17 - 4.62198742967122348e-20*V13*V17 + 
      1.44503353944568296e-16*V012*V022*V18 + 8.87543788430551359e-17*V013*V03*V18 - 
      3.24024188697059251e-16*V02*V032*V18 - 1.61829395836158025e-16*V022*V04*V18 - 
      3.89525893611553126e-16*V01*V03*V04*V18 - 2.05918236743127053e-16*V01*V02*V05*V18 + 
      2.72609762436915104e-17*V052*V18 - 4.28114671595534402e-17*V012*V06*V18 + 
      4.1251457668053768e-17*V04*V06*V18 + 2.77256956549154024e-17*V03*V07*V18 + 8.6666533576628542e-18*V02*V08*V18 + 
      2.79975827398951377e-18*V01*V09*V18 - 3.39474875653093372e-20*V12*V18 + 1.26073940687869731e-17*V013*V02*V19 - 
      4.39632257070873312e-17*V022*V03*V19 - 4.80112144165172634e-17*V01*V032*V19 - 
      5.44097511262739552e-17*V01*V02*V04*V19 - 1.48112646826529521e-17*V012*V05*V19 + 
      1.47988454044105047e-17*V04*V05*V19 + 1.07335518730035352e-17*V03*V06*V19 + 3.964825259953388e-18*V02*V07*V19 + 
      1.38510344336724517e-18*V01*V08*V19 - 2.21359819726175189e-20*V11*V19 + 3.51834253082427155e-19*V014*V20 - 
      1.74316187611843803e-18*V023*V20 - 1.30815326098456725e-17*V01*V02*V03*V20 - 
      3.82159014895722067e-18*V012*V04*V20 + 1.88197014979782243e-18*V042*V20 + 
      3.61755067498389409e-18*V03*V05*V20 + 1.4388440920268599e-18*V02*V06*V20 + 5.9556340388130832e-19*V01*V07*V20 - 
      1.2582356312765773e-20*V10*V20 - 8.15082686307622909e-19*V01*V022*V21 - 
      8.39515620549458128e-19*V012*V03*V21 + 8.9490263517029832e-19*V03*V04*V21 + 4.71688427275203759e-19*V02*V05*V21 + 
      2.09996857233704426e-19*V01*V06*V21 - 6.32332539619169525e-21*V09*V21 - 1.05550275924728147e-19*V012*V02*V22 + 
      9.93416856486759721e-20*V032*V22 + 1.08502723500051165e-19*V02*V04*V22 + 6.43287120092937256e-20*V01*V05*V22 - 
      2.71852237765752868e-21*V08*V22 - 3.90926947869363506e-21*V013*V23 + 2.38568144787600898e-20*V02*V03*V23 + 
      1.46369725210463492e-20*V01*V04*V23 - 1.02952297712739778e-21*V07*V23 + 1.30373174240176893e-21*V022*V24 + 
      2.94832097136943609e-21*V01*V03*V24 - 3.19773350595175745e-22*V06*V24 + 3.29784432623785716e-22*V01*V02*V25 - 
      8.78577461946261243e-23*V05*V25 + 1.80538922969225757e-23*V012*V26 - 1.78243900101373234e-23*V04*V26 - 
      3.31203723081536619e-24*V03*V27 - 3.32174362452338908e-25*V02*V28 - 3.55901102627505972e-26*V01*V29 + 
      2.45110952222800256e-29*V32) + eps16*(4.50155213123768602e-9*V012*V027 + 
      3.38153489550767212e-8*V013*V025*V03 + 4.52779596012409971e-8*V014*V023*V032 - 
      1.11947206624759587e-8*V026*V032 + 9.68341366023876528e-9*V015*V02*V033 - 
      9.55704894542685233e-8*V01*V024*V033 - 1.0723884103616799e-7*V012*V022*V034 - 
      9.93836585227746956e-9*V013*V035 + 4.8703063054938864e-9*V02*V036 + 
      1.56114022070560936e-8*V014*V024*V04 - 1.89909954985575877e-9*V027*V04 + 
      2.00192681482072238e-8*V015*V022*V03*V04 - 8.38895469248809872e-8*V01*V025*V03*V04 + 
      1.77987173566655359e-9*V016*V032*V04 - 
      3.23285224281612877e-7*V012*V023*V032*V04 - 
      1.50270666980011994e-7*V013*V02*V033*V04 + 5.31274783400119321e-8*V022*V034*V04 + 
      1.73049890542628694e-8*V01*V035*V04 + 1.22542987345158214e-9*V016*V02*V042 - 
      6.17890385970812357e-8*V012*V024*V042 - 
      1.71284630285987134e-7*V013*V022*V03*V042 - 
      2.80878156156928347e-8*V014*V032*V042 + 
      7.57110438728137147e-8*V023*V032*V042 + 1.2806515617322688e-7*V01*V02*V033*V042 - 
      1.41225680290847202e-8*V014*V02*V043 + 8.35603474047208798e-9*V024*V043 + 
      9.38046625149027808e-8*V01*V022*V03*V043 + 
      3.70617082155040555e-8*V012*V032*V043 + 1.38979980604841815e-8*V012*V02*V044 - 
      4.13660814142975407e-9*V032*V044 - 1.15966243496214952e-9*V02*V045 + 
      3.51628958800994282e-9*V015*V023*V05 - 8.34998774432908832e-9*V01*V026*V05 + 
      1.87401197609968618e-9*V016*V02*V03*V05 - 9.89783807104100307e-8*V012*V024*V03*V05 - 
      1.37976642238229e-7*V013*V022*V032*V05 - 1.50967085425387661e-8*V014*V033*V05 + 
      4.29759057373092835e-8*V023*V033*V05 + 5.31546973976214333e-8*V01*V02*V034*V05 + 
      9.79863139570772624e-11*V017*V04*V05 - 7.02630735920893175e-8*V013*V023*V04*V05 - 
      6.84088766161044771e-8*V014*V02*V03*V04*V05 + 4.53671004867412281e-8*V024*V03*V04*V05 + 
      2.35184910615567518e-7*V01*V022*V032*V04*V05 + 6.09721325863324832e-8*V012*V033*V04*V05 - 
      3.20564150558353558e-9*V015*V042*V05 + 5.69609941188923212e-8*V01*V023*V042*V05 + 
      1.37028218012317002e-7*V012*V02*V03*V042*V05 - 1.39859961076650692e-8*V033*V042*V05 + 
      8.47853021505922014e-9*V013*V043*V05 - 2.01552936055205755e-8*V02*V03*V043*V05 - 
      3.13366648763871686e-9*V01*V044*V05 - 1.04166163720639294e-8*V014*V022*V052 + 
      2.69956015954098336e-9*V025*V052 - 2.58330085793726129e-9*V015*V03*V052 + 
      4.78715917087998313e-8*V01*V023*V03*V052 + 
      5.63793174436091888e-8*V012*V02*V032*V052 - 2.9383600776356961e-9*V034*V052 + 
      4.21731239654223595e-8*V012*V022*V04*V052 + 
      2.07681524916358218e-8*V013*V03*V04*V052 - 2.56786380613002093e-8*V02*V032*V04*V052 - 
      9.16729710029869223e-9*V022*V042*V052 - 
      1.57633187250810967e-8*V01*V03*V042*V052 + 4.27637441860138442e-9*V013*V02*V053 - 
      5.2224404359218289e-9*V022*V03*V053 - 4.38614696068655363e-9*V01*V032*V053 - 
      6.46673965168430089e-9*V01*V02*V04*V053 - 3.99494997353534177e-10*V012*V054 + 
      1.81955734434333532e-10*V04*V054 + 3.99409674838596407e-10*V016*V022*V06 - 
      1.0431003301698729e-8*V012*V025*V06 + 6.06642189056404743e-11*V017*V03*V06 - 
      4.77855954696384765e-8*V013*V023*V03*V06 - 2.32250277878423828e-8*V014*V02*V032*V06 + 
      1.62111803779034047e-8*V024*V032*V06 + 5.505287244419457e-8*V01*V022*V033*V06 + 
      1.06149438820031458e-8*V012*V034*V06 - 1.75099645862543264e-8*V014*V022*V04*V06 + 
      4.27154927977053744e-9*V025*V04*V06 - 4.33978855684080629e-9*V015*V03*V04*V06 + 
      8.05531790027669879e-8*V01*V023*V03*V04*V06 + 9.55327526277752113e-8*V012*V02*V032*V04*V06 - 
      4.95394613466162565e-9*V034*V04*V06 + 3.5829790696304398e-8*V012*V022*V042*V06 + 
      1.76203335311519717e-8*V013*V03*V042*V06 - 2.15354949650039887e-8*V02*V032*V042*V06 - 
      5.01445669080670866e-9*V022*V043*V06 - 8.86629346376300445e-9*V01*V03*V043*V06 - 
      2.60040365527975868e-9*V015*V02*V05*V06 + 1.22131022473066407e-8*V01*V024*V05*V06 + 
      5.88410442621935707e-8*V012*V022*V03*V05*V06 + 1.438783155986732e-8*V013*V032*V05*V06 - 
      1.21485717698657798e-8*V02*V033*V05*V06 + 2.17858954336371354e-8*V013*V02*V04*V05*V06 - 
      2.6199364758221157e-8*V022*V03*V04*V05*V06 - 2.22420204075089984e-8*V01*V032*V04*V05*V06 - 
      1.63375073043803933e-8*V01*V02*V042*V05*V06 + 1.16915374751430838e-9*V014*V052*V06 - 
      2.64403009653177083e-9*V023*V052*V06 - 1.37060208691884838e-8*V01*V02*V03*V052*V06 - 
      4.06210394333847301e-9*V012*V04*V052*V06 + 9.17023430737715776e-10*V042*V052*V06 + 
      5.17886507555759963e-10*V03*V053*V06 - 6.42642714234006087e-11*V016*V062 + 
      5.12713356558674322e-9*V012*V023*V062 + 
      7.53888501579919807e-9*V013*V02*V03*V062 - 
      4.66939828194458353e-9*V022*V032*V062 - 2.61285420173900206e-9*V01*V033*V062 + 
      9.90653896153716564e-10*V014*V04*V062 - 2.16684695625398566e-9*V023*V04*V062 - 
      1.15611782037778741e-8*V01*V02*V03*V04*V062 - 1.72204643614713198e-9*V012*V042*V062 + 
      2.55070338699924464e-10*V043*V062 - 3.54744395378099167e-9*V01*V022*V05*V062 - 
      2.85028450632095188e-9*V012*V03*V05*V062 + 1.30721071936814918e-9*V03*V04*V05*V062 + 
      4.00958262218441905e-10*V02*V052*V062 - 4.99176324286125821e-10*V012*V02*V063 + 
      1.55082715158648328e-10*V032*V063 + 2.22898033937020115e-10*V02*V04*V063 + 
      1.18699873853344444e-10*V01*V05*V063 + 2.16974213604115565e-11*V017*V02*V07 - 
      5.40417943501709903e-9*V013*V024*V07 - 1.03049112194985457e-8*V014*V022*V03*V07 + 
      2.82992660824091027e-9*V025*V03*V07 - 1.27011289999134534e-9*V015*V032*V07 + 
      2.47771140186421124e-8*V01*V023*V032*V07 + 1.92950447738465075e-8*V012*V02*V033*V07 - 
      6.13010334700889407e-10*V035*V07 - 1.88736808123289415e-9*V015*V02*V04*V07 + 
      8.95773284077813425e-9*V01*V024*V04*V07 + 4.33723866450780321e-8*V012*V022*V03*V04*V07 + 
      1.06028313287208905e-8*V013*V032*V04*V07 - 8.94937589581309056e-9*V02*V033*V04*V07 + 
      8.03387532568988885e-9*V013*V02*V042*V07 - 9.621186763472098e-9*V022*V03*V042*V07 - 
      8.20690596717339089e-9*V01*V032*V042*V07 - 4.01205446008562674e-9*V01*V02*V043*V07 - 
      1.1092641589878862e-10*V016*V05*V07 + 8.8934321039206044e-9*V012*V023*V05*V07 + 
      1.30957189103950361e-8*V013*V02*V03*V05*V07 - 8.20115748229856891e-9*V022*V032*V05*V07 - 
      4.56210569349975515e-9*V01*V033*V05*V07 + 1.72149800460836351e-9*V014*V04*V05*V07 - 
      3.87726377417136624e-9*V023*V04*V05*V07 - 2.0220579831841648e-8*V01*V02*V03*V04*V05*V07 - 
      3.00090315187239149e-9*V012*V042*V05*V07 + 4.50375403320601873e-10*V043*V05*V07 - 
      3.10658623103392034e-9*V01*V022*V052*V07 - 2.48456136955212915e-9*V012*V03*V052*V07 + 
      1.1463487571858541e-9*V03*V04*V052*V07 + 2.34762535554733894e-10*V02*V053*V07 + 
      3.43582729184104372e-9*V013*V022*V06*V07 + 1.18547425301235247e-9*V014*V03*V06*V07 - 
      2.77688806343057068e-9*V023*V03*V06*V07 - 7.13756199864560057e-9*V01*V02*V032*V06*V07 - 
      5.22631608043287862e-9*V01*V022*V04*V06*V07 - 4.21196840253792297e-9*V012*V03*V04*V06*V07 + 
      9.63797203854577068e-10*V03*V042*V06*V07 - 2.60957934744077695e-9*V012*V02*V05*V06*V07 + 
      8.15287997197083928e-10*V032*V05*V06*V07 + 1.18134096926053866e-9*V02*V04*V05*V06*V07 + 
      3.11502052229857582e-10*V01*V052*V06*V07 - 1.73037279549798118e-10*V013*V062*V07 + 
      4.2170922907670697e-10*V02*V03*V062*V07 + 2.63085966705188891e-10*V01*V04*V062*V07 + 
      2.68806747356288684e-10*V014*V02*V072 - 1.53382266455400331e-10*V024*V072 - 
      1.62010119740437514e-9*V01*V022*V03*V072 - 
      6.43604471608058537e-10*V012*V032*V072 - 
      9.63982153176219188e-10*V012*V02*V04*V072 + 3.00899320568292916e-10*V032*V04*V072 + 
      2.1745032775758309e-10*V02*V042*V072 - 1.50608906579658684e-10*V013*V05*V072 + 
      3.70176753059612665e-10*V02*V03*V05*V072 + 2.30215797641579889e-10*V01*V04*V05*V072 + 
      9.50090308519678681e-11*V022*V06*V072 + 1.63048557832402032e-10*V01*V03*V06*V072 - 
      5.138954014836295e-12*V062*V072 + 2.48758897967770192e-11*V01*V02*V073 - 
      3.00509695241274037e-12*V05*V073 + 4.4280451755941952e-13*V018*V08 - 
      1.33785560990982633e-9*V014*V023*V08 + 1.71387124331217675e-10*V026*V08 - 
      9.72559639495437938e-10*V015*V02*V03*V08 + 4.90763991641420131e-9*V01*V024*V03*V08 + 
      1.16433214611755886e-8*V012*V022*V032*V08 + 
      1.88309459978729282e-9*V013*V033*V08 - 1.22793674589569673e-9*V02*V034*V08 - 
      7.07254256117606282e-11*V016*V04*V08 + 5.82652721404267178e-9*V012*V023*V04*V08 + 
      8.55277833732601659e-9*V013*V02*V03*V04*V08 - 5.32380451144272764e-9*V022*V032*V04*V08 - 
      2.98194255700710898e-9*V01*V033*V04*V08 + 5.60749206582992815e-10*V014*V042*V08 - 
      1.23328439825600782e-9*V023*V042*V08 - 6.59565558837579339e-9*V01*V02*V03*V042*V08 - 
      6.55152654160803027e-10*V012*V043*V08 + 7.28332603021255111e-11*V044*V08 + 
      2.64280373985464114e-9*V013*V022*V05*V08 + 9.11425348972455468e-10*V014*V03*V05*V08 - 
      2.15521557145600725e-9*V023*V03*V05*V08 - 5.51903945128006319e-9*V01*V02*V032*V05*V08 - 
      4.04697466248475442e-9*V01*V022*V04*V05*V08 - 3.25295878393494051e-9*V012*V03*V04*V05*V08 + 
      7.47076599382134866e-10*V03*V042*V05*V08 - 1.00786502381453251e-9*V012*V02*V052*V08 + 
      3.15720426761199488e-10*V032*V052*V08 + 4.58193083897235425e-10*V02*V04*V052*V08 + 
      8.03678118090333361e-11*V01*V053*V08 + 4.75674311049722304e-10*V014*V02*V06*V08 - 
      2.66251567035031895e-10*V024*V06*V08 - 2.86575931143258801e-9*V01*V022*V03*V06*V08 - 
      1.1405073000981351e-9*V012*V032*V06*V08 - 1.7093371675997801e-9*V012*V02*V04*V06*V08 + 
      5.31967452811226141e-10*V032*V04*V06*V08 + 3.8193060278998328e-10*V02*V042*V06*V08 - 
      2.67013151961746173e-10*V013*V05*V06*V08 + 6.53952866707836784e-10*V02*V03*V05*V06*V08 + 
      4.07408200906976433e-10*V01*V04*V05*V06*V08 + 8.34171470929242389e-11*V022*V062*V08 + 
      1.44333265687358107e-10*V01*V03*V062*V08 - 3.02352892775963599e-12*V063*V08 + 
      2.80843619891727921e-11*V015*V07*V08 - 4.31285614236730667e-10*V01*V023*V07*V08 - 
      1.04509203264779033e-9*V012*V02*V03*V07*V08 + 1.10440712149519286e-10*V033*V07*V08 - 
      1.97415456281569499e-10*V013*V04*V07*V08 + 4.82111985939425843e-10*V02*V03*V04*V07*V08 + 
      1.50508180552319371e-10*V01*V042*V07*V08 + 1.47509606412665845e-10*V022*V05*V07*V08 + 
      2.52396595079484571e-10*V01*V03*V05*V07*V08 + 1.32037118195992703e-10*V01*V02*V06*V07*V08 - 
      1.59401386961235955e-11*V05*V06*V07*V08 + 1.22610005641182252e-11*V012*V072*V08 - 
      5.88715567119459272e-12*V04*V072*V08 - 1.06017459721247339e-10*V012*V022*V082 - 
      5.31162892578734228e-11*V013*V03*V082 + 6.66308582882360057e-11*V02*V032*V082 + 
      4.76588941899221501e-11*V022*V04*V082 + 8.26043690320186853e-11*V01*V03*V04*V082 + 
      5.11355523444654607e-11*V01*V02*V05*V082 - 3.09000590688509293e-12*V052*V082 + 
      1.08677798685781691e-11*V012*V06*V082 - 5.19528406826160834e-12*V04*V06*V082 - 
      3.25890629124482404e-12*V03*V07*V082 - 4.37517170068740584e-13*V02*V083 - 
      1.64835146936540125e-10*V015*V022*V09 + 3.45793764136157995e-10*V01*V025*V09 - 
      3.22388878534335621e-11*V016*V03*V09 + 2.80189943889264182e-9*V012*V023*V03*V09 + 
      2.04261026487676869e-9*V013*V02*V032*V09 - 8.81090672931405571e-10*V022*V033*V09 - 
      3.64752964761148189e-10*V01*V034*V09 + 1.5505707999704561e-9*V013*V022*V04*V09 + 
      5.32960300910522433e-10*V014*V03*V04*V09 - 1.25661330718114231e-9*V023*V03*V04*V09 - 
      3.24117955720727906e-9*V01*V02*V032*V04*V09 - 1.1852681129762065e-9*V01*V022*V042*V09 - 
      9.56761259908936263e-10*V012*V03*V042*V09 + 1.46022401287343066e-10*V03*V043*V09 + 
      3.28335028654464705e-10*V014*V02*V05*V09 - 1.8930956914288632e-10*V024*V05*V09 - 
      1.99457179397421526e-9*V01*V022*V03*V05*V09 - 7.91311708211819611e-10*V012*V032*V05*V09 - 
      1.18559187946897823e-9*V012*V02*V04*V05*V09 + 3.70961374605005304e-10*V032*V04*V05*V09 + 
      2.68297756745542815e-10*V02*V042*V05*V09 - 9.2515876682457129e-11*V013*V052*V09 + 
      2.28259826003975527e-10*V02*V03*V052*V09 + 1.41866770162645143e-10*V01*V04*V052*V09 + 
      2.22907557048817969e-11*V015*V06*V09 - 3.42941566153143681e-10*V01*V023*V06*V09 - 
      8.32001507167224823e-10*V012*V02*V03*V06*V09 + 8.78991395633895806e-11*V033*V06*V09 - 
      1.57180213138673668e-10*V013*V04*V06*V09 + 3.83419071477615378e-10*V02*V03*V04*V06*V09 + 
      1.19789530206304927e-10*V01*V042*V06*V09 + 1.17264278886932301e-10*V022*V05*V06*V09 + 
      2.00949046477051353e-10*V01*V03*V05*V06*V09 + 5.2546656638601498e-11*V01*V02*V062*V09 - 
      6.34219856721068642e-12*V05*V062*V09 - 1.90369660472981793e-10*V012*V022*V07*V09 - 
      9.54136549574522074e-11*V013*V03*V07*V09 + 1.19975271832697301e-10*V02*V032*V07*V09 + 
      8.63018727139487998e-11*V022*V04*V07*V09 + 1.48586651263142707e-10*V01*V03*V04*V07*V09 + 
      9.20144466841806688e-11*V01*V02*V05*V07*V09 - 5.56267504588345565e-12*V052*V07*V09 + 
      1.95324553613661958e-11*V012*V06*V07*V09 - 9.36876349615123451e-12*V04*V06*V07*V09 - 
      2.93308400276163431e-12*V03*V072*V09 - 3.88925566461286497e-11*V013*V02*V08*V09 + 
      4.79600290517914413e-11*V022*V03*V08*V09 + 4.07079363187643114e-11*V01*V032*V08*V09 + 
      6.01510731299387967e-11*V01*V02*V04*V08*V09 + 1.51079218591616224e-11*V012*V05*V08*V09 - 
      7.2674559114300349e-12*V04*V05*V08*V09 - 5.18826488998689133e-12*V03*V06*V08*V09 - 
      2.36764234511997115e-12*V02*V07*V08*V09 - 4.11387566330200618e-13*V01*V082*V09 - 
      1.26219942002800907e-12*V014*V092 + 2.8537383922813534e-12*V023*V092 + 
      1.48692305322023273e-11*V01*V02*V03*V092 + 4.45607965803086444e-12*V012*V04*V092 - 
      1.06786407528361483e-12*V042*V092 - 1.81045474064775228e-12*V03*V05*V092 - 
      9.42014522604963244e-13*V02*V06*V092 - 3.70069521128519166e-13*V01*V07*V092 - 
      9.62517188168632957e-12*V016*V02*V10 + 2.3015694245723401e-10*V012*V024*V10 + 
      6.70941372490118359e-10*V013*V022*V03*V10 + 1.1480421542309853e-10*V014*V032*V10 - 
      2.84804471273139971e-10*V023*V032*V10 - 4.80920728760762741e-10*V01*V02*V033*V10 + 
      1.74125454837983133e-10*V014*V02*V04*V10 - 9.83217365320966071e-11*V024*V04*V10 - 
      1.06220212320912648e-9*V01*V022*V03*V04*V10 - 4.22803348972879228e-10*V012*V032*V04*V10 - 
      3.16914658687702337e-10*V012*V02*V042*V10 + 9.88235079573683299e-11*V032*V042*V10 + 
      4.72330580222764217e-11*V02*V043*V10 + 1.39388397625663201e-11*V015*V05*V10 - 
      2.16987041210307743e-10*V01*V023*V05*V10 - 5.24340665172594658e-10*V012*V02*V03*V05*V10 + 
      5.5583436465140527e-11*V033*V05*V10 - 9.89222489362033276e-11*V013*V04*V05*V10 + 
      2.42914382497724878e-10*V02*V03*V04*V05*V10 + 7.57467217293811935e-11*V01*V042*V05*V10 + 
      3.71890626271298429e-11*V022*V052*V10 + 6.34857888806340332e-11*V01*V03*V052*V10 - 
      1.37749948542499838e-10*V012*V022*V06*V10 - 6.89898336794149189e-11*V013*V03*V06*V10 + 
      8.65967464965198305e-11*V02*V032*V06*V10 + 6.19103788007259522e-11*V022*V04*V06*V10 + 
      1.07380768914807285e-10*V01*V03*V04*V06*V10 + 6.64736463478337488e-11*V01*V02*V05*V06*V10 - 
      4.01637749845117034e-12*V052*V06*V10 + 7.06554901187338597e-12*V012*V062*V10 - 
      3.37610521518621009e-12*V04*V062*V10 - 3.17235160864232235e-11*V013*V02*V07*V10 + 
      3.91851771834627581e-11*V022*V03*V07*V10 + 3.32316178961705747e-11*V01*V032*V07*V10 + 
      4.9119851375945882e-11*V01*V02*V04*V07*V10 + 1.23311190808217009e-11*V012*V05*V07*V10 - 
      5.93534045393409334e-12*V04*V05*V07*V10 - 4.23691167642956704e-12*V03*V06*V07*V10 - 
      9.67072738309773911e-13*V02*V072*V10 - 2.29204394137746031e-12*V014*V08*V10 + 
      5.15098812636614658e-12*V023*V08*V10 + 2.69936407681061786e-11*V01*V02*V03*V08*V10 + 
      8.0947205339313216e-12*V012*V04*V08*V10 - 1.9344749182416599e-12*V042*V08*V10 - 
      3.28543930568488374e-12*V03*V05*V08*V10 - 1.70642818407691646e-12*V02*V06*V08*V10 - 
      6.71842057153603506e-13*V01*V07*V08*V10 + 4.91113619404217309e-12*V01*V022*V09*V10 + 
      3.96519467929314528e-12*V012*V03*V09*V10 - 1.93399244403559764e-12*V03*V04*V09*V10 - 
      1.19473241718193766e-12*V02*V05*V09*V10 - 5.35191368162743611e-13*V01*V06*V09*V10 + 
      5.21656558096304811e-15*V092*V10 + 6.62793960794148948e-13*V012*V02*V102 - 
      2.18496203813111231e-13*V032*V102 - 3.18021774161830446e-13*V02*V04*V102 - 
      1.69362231608752155e-13*V01*V05*V102 + 4.73160579050964191e-15*V08*V102 - 
      2.09749508317619773e-13*V017*V11 + 6.74347906116275928e-11*V013*V023*V11 + 
      6.85939155950927107e-11*V014*V02*V03*V11 - 4.17902267206677153e-11*V024*V03*V11 - 
      2.1731857822775088e-10*V01*V022*V032*V11 - 5.70112786775786726e-11*V012*V033*V11 + 
      6.74024218603440095e-12*V015*V04*V11 - 1.05682023547627407e-10*V01*V023*V04*V11 - 
      2.56702414596368128e-10*V012*V02*V03*V04*V11 + 2.71858135636246717e-11*V033*V04*V11 - 
      2.42303319909972094e-11*V013*V042*V11 + 5.92167081153328239e-11*V02*V03*V042*V11 + 
      1.23522296638299964e-11*V01*V043*V11 - 7.94956886745053048e-11*V012*V022*V05*V11 - 
      3.97772402002834055e-11*V013*V03*V05*V11 + 5.02621728512514009e-11*V02*V032*V05*V11 + 
      3.61986982432801641e-11*V022*V04*V05*V11 + 6.21999968838437168e-11*V01*V03*V04*V05*V11 + 
      1.92660745764212173e-11*V01*V02*V052*V11 - 7.77042349317061748e-13*V053*V11 - 
      2.10177571695828281e-11*V013*V02*V06*V11 + 2.59130886755391951e-11*V022*V03*V06*V11 + 
      2.2015955039070288e-11*V01*V032*V06*V11 + 3.25214247925367166e-11*V01*V02*V04*V06*V11 + 
      8.17252685214397471e-12*V012*V05*V06*V11 - 3.92761700397486609e-12*V04*V05*V06*V11 - 
      1.40240130202731491e-12*V03*V062*V11 - 1.71253420193648365e-12*V014*V07*V11 + 
      3.87870661715828861e-12*V023*V07*V11 + 2.0199387345982931e-11*V01*V02*V03*V07*V11 + 
      6.05239548847634198e-12*V012*V04*V07*V11 - 1.45056681582134048e-12*V042*V07*V11 - 
      2.45910908171086762e-12*V03*V05*V07*V11 - 1.27980794636312446e-12*V02*V06*V07*V11 - 
      2.51363104325421768e-13*V01*V072*V11 + 4.08499083403384318e-12*V01*V022*V08*V11 + 
      3.2991768979620935e-12*V012*V03*V08*V11 - 1.60836022410102871e-12*V03*V04*V08*V11 - 
      9.93469854243646799e-13*V02*V05*V08*V11 - 4.45185772967880226e-13*V01*V06*V08*V11 + 
      1.21426182645472652e-12*V012*V02*V09*V11 - 4.0051438766072584e-13*V032*V09*V11 - 
      5.83938956032071275e-13*V02*V04*V09*V11 - 3.10400016127577045e-13*V01*V05*V09*V11 + 8.67699638375433282e-15*V08*V09*V11 + 
      1.03298080509654978e-13*V013*V10*V11 - 2.65102496788914234e-13*V02*V03*V10*V11 - 
      1.66321564985940782e-13*V01*V04*V10*V11 + 7.08823676269778083e-15*V07*V10*V11 - 
      1.99819749783849114e-14*V022*V112 - 3.42902957155963818e-14*V01*V03*V112 + 
      2.34800551587704945e-15*V06*V112 + 9.44164106190841227e-12*V014*V022*V12 - 
      2.20259071248210634e-12*V025*V12 + 2.43348272149979236e-12*V015*V03*V12 - 
      4.01197114898756025e-11*V01*V023*V03*V12 - 4.79568788669085877e-11*V012*V02*V032*V12 + 
      2.58259556211249994e-12*V034*V12 - 3.59532582927353745e-11*V012*V022*V04*V12 - 
      1.79803376393198365e-11*V013*V03*V04*V12 + 2.26496295114767611e-11*V02*V032*V04*V12 + 
      8.08120012644868402e-12*V022*V042*V12 + 1.40567432330032326e-11*V01*V03*V042*V12 - 
      1.11822403404674748e-11*V013*V02*V05*V12 + 1.3899103160912314e-11*V022*V03*V05*V12 + 
      1.17643124604792878e-11*V01*V032*V05*V12 + 1.74021877459451961e-11*V01*V02*V04*V05*V12 + 
      2.18142417638262221e-12*V012*V052*V12 - 1.05202575182152533e-12*V04*V052*V12 - 
      1.04626071311744807e-12*V014*V06*V12 + 2.35324325374413554e-12*V023*V06*V12 + 
      1.23461144964908204e-11*V01*V02*V03*V06*V12 + 3.7028396294601924e-12*V012*V04*V06*V12 - 
      8.83999537823541165e-13*V042*V06*V12 - 1.50196887543533255e-12*V03*V05*V06*V12 - 
      3.89979751854518848e-13*V02*V062*V12 + 2.82167606968812044e-12*V01*V022*V07*V12 + 
      2.27691962382878011e-12*V012*V03*V07*V12 - 1.11068146333201862e-12*V03*V04*V07*V12 - 
      6.86263413349139655e-13*V02*V05*V07*V12 - 3.07346788275866606e-13*V01*V06*V07*V12 + 
      9.32570483214821455e-13*V012*V02*V08*V12 - 3.07306872467709447e-13*V032*V08*V12 - 
      4.47217470105025973e-13*V02*V04*V08*V12 - 2.38219660370896245e-13*V01*V05*V08*V12 + 
      3.32670968361744601e-15*V082*V12 + 8.73314695623281342e-14*V013*V09*V12 - 
      2.24162502890405889e-13*V02*V03*V09*V12 - 1.40618575675959814e-13*V01*V04*V09*V12 + 5.99226672839614513e-15*V07*V09*V12 - 
      3.68080854296587473e-14*V022*V10*V12 - 6.32743623508256207e-14*V01*V03*V10*V12 + 
      4.32961025146162615e-15*V06*V10*V12 - 1.93832637864596879e-14*V01*V02*V11*V12 + 2.51819033148391868e-15*V05*V11*V12 - 
      1.11518782684456822e-15*V012*V122 + 5.69886352327506205e-16*V04*V122 + 
      6.11769399259724337e-13*V015*V02*V13 - 2.56113606960536598e-12*V01*V024*V13 - 
      1.24784542270071951e-11*V012*V022*V03*V13 - 3.0965624319925974e-12*V013*V032*V13 + 
      2.67495038092800385e-12*V02*V033*V13 - 4.69686589583308908e-12*V013*V02*V04*V13 + 
      5.80522964060048673e-12*V022*V03*V04*V13 + 4.94295042028504447e-12*V01*V032*V04*V13 + 
      3.64847196686029732e-12*V01*V02*V042*V13 - 5.16479665657639014e-13*V014*V05*V13 + 
      1.18035900158523292e-12*V023*V05*V13 + 6.13205893736154949e-12*V01*V02*V03*V05*V13 + 
      1.83560342669867429e-12*V012*V04*V05*V13 - 4.40724623962071141e-13*V042*V05*V13 - 
      3.73436056829920745e-13*V03*V052*V13 + 1.60100402980824299e-12*V01*V022*V06*V13 + 
      1.29351957874461575e-12*V012*V03*V06*V13 - 6.2993047449704062e-13*V03*V04*V06*V13 - 
      3.89057578485850009e-13*V02*V05*V06*V13 - 8.72403249893440794e-14*V01*V062*V13 + 
      5.97596999217374583e-13*V012*V02*V07*V13 - 1.97053423762792739e-13*V032*V07*V13 - 
      2.87367076260369194e-13*V02*V04*V07*V13 - 1.52715129066380491e-13*V01*V05*V07*V13 + 
      6.22716935277264714e-14*V013*V08*V13 - 1.59696879544224903e-13*V02*V03*V08*V13 - 
      1.00209677832945464e-13*V01*V04*V08*V13 + 4.26820099280462187e-15*V07*V08*V13 - 
      2.89484172101587523e-14*V022*V09*V13 - 4.96724712995905341e-14*V01*V03*V09*V13 + 
      3.39999950690605464e-15*V06*V09*V13 - 1.66048795816438788e-14*V01*V02*V10*V13 + 2.15667455498179201e-15*V05*V10*V13 - 
      2.07068718034353406e-15*V012*V11*V13 + 1.05874818066517205e-15*V04*V11*V13 + 
      4.06691627314171604e-16*V03*V12*V13 + 5.32310427834168199e-17*V02*V132 + 
      1.45659380776124842e-14*V016*V14 - 1.01032372280896699e-12*V012*V023*V14 - 
      1.50915784517176304e-12*V013*V02*V03*V14 + 9.65111899530613654e-13*V022*V032*V14 + 
      5.40200388116406428e-13*V01*V033*V14 - 2.02118223368261928e-13*V014*V04*V14 + 
      4.56641952201875545e-13*V023*V04*V14 + 2.4038413774659864e-12*V01*V02*V03*V04*V14 + 
      3.60647266127065417e-13*V012*V042*V14 - 5.73261971211986072e-14*V043*V14 + 
      7.43303685708072962e-13*V01*V022*V05*V14 + 5.98739331928716999e-13*V012*V03*V05*V14 - 
      2.92528783395445379e-13*V03*V04*V05*V14 - 9.04206954985800713e-14*V02*V052*V14 + 
      3.17037274293073352e-13*V012*V02*V06*V14 - 1.04370806006241768e-13*V032*V06*V14 - 
      1.51802857255092993e-13*V02*V04*V06*V14 - 8.09320559072438323e-14*V01*V05*V06*V14 + 
      3.72465173984538715e-14*V013*V07*V14 - 9.5617863329913746e-14*V02*V03*V07*V14 - 
      5.99685041663519115e-14*V01*V04*V07*V14 + 1.27699020344254614e-15*V072*V14 - 
      1.92155649275381042e-14*V022*V08*V14 - 3.30439977799119423e-14*V01*V03*V08*V14 + 
      2.25891019744841029e-15*V06*V08*V14 - 1.2167497565016697e-14*V01*V02*V09*V14 + 1.57972960475843609e-15*V05*V09*V14 - 
      1.65587580125235231e-15*V012*V10*V14 + 8.45759601392870242e-16*V04*V10*V14 + 
      3.52368370073695409e-16*V03*V11*V14 + 9.92999683375833231e-17*V02*V12*V14 + 2.24013315456489625e-17*V01*V13*V14 - 
      1.72619032252818905e-13*V013*V022*V15 - 6.05499712869795485e-14*V014*V03*V15 + 
      1.4410021890658404e-13*V023*V03*V15 + 3.70558310772070201e-13*V01*V02*V032*V15 + 
      2.72933612395391299e-13*V01*V022*V04*V15 + 2.20711675156957162e-13*V012*V03*V04*V15 - 
      5.37076333235959859e-14*V03*V042*V15 + 1.37656207021258872e-13*V012*V02*V05*V15 - 
      4.54363618080454486e-14*V032*V05*V15 - 6.63188309520237084e-14*V02*V04*V05*V15 - 
      1.76018844155561038e-14*V01*V052*V15 + 1.8532735249020438e-14*V013*V06*V15 - 
      4.74740349160641406e-14*V02*V03*V06*V15 - 2.98027690632205116e-14*V01*V04*V06*V15 - 
      1.08112031383457453e-14*V022*V07*V15 - 1.85425990974611844e-14*V01*V03*V07*V15 + 
      1.26801589164715782e-15*V06*V07*V15 - 7.58950805876131731e-15*V01*V02*V08*V15 + 9.8458763702524588e-16*V05*V08*V15 - 
      1.13749039570165188e-15*V012*V09*V15 + 5.81144411006753204e-16*V04*V09*V15 + 
      2.64050499632967369e-16*V03*V10*V15 + 8.07028559738939966e-17*V02*V11*V15 + 1.95990185006105907e-17*V01*V12*V15 - 
      4.41994159530723578e-20*V152 - 1.2982683938741562e-14*V014*V02*V16 + 
      7.48285110418598444e-15*V024*V16 + 7.95515240028311156e-14*V01*V022*V03*V16 + 
      3.17835101870059889e-14*V012*V032*V16 + 4.78014581746824191e-14*V012*V02*V04*V16 - 
      1.57335308346834706e-14*V032*V04*V16 - 1.14248443741623141e-14*V02*V042*V16 + 
      7.56916107267071928e-15*V013*V05*V16 - 1.94858055016765833e-14*V02*V03*V05*V16 - 
      1.22111977484107791e-14*V01*V04*V05*V16 - 5.04266971960898918e-15*V022*V06*V16 - 
      8.68031514418432773e-15*V01*V03*V06*V16 + 2.96178628245633222e-16*V062*V16 - 
      4.01106926748115807e-15*V01*V02*V07*V16 + 5.20043795174939865e-16*V05*V07*V16 - 
      6.68262100187125589e-16*V012*V08*V16 + 3.40796007356322708e-16*V04*V08*V16 + 
      1.70710912079832186e-16*V03*V09*V16 + 5.68961989730199889e-17*V02*V10*V16 + 1.49855395947664554e-17*V01*V11*V16 - 
      8.31855677458577055e-20*V14*V16 - 3.48315910551602883e-16*V015*V17 + 
      5.3532084226852838e-15*V01*V023*V17 + 1.30229815262285386e-14*V012*V02*V03*V17 - 
      1.44935168659944404e-15*V033*V17 + 2.4857843910815798e-15*V013*V04*V17 - 
      6.36720910065059732e-15*V02*V03*V04*V17 - 2.00106485371172764e-15*V01*V042*V17 - 
      1.9623831906871225e-15*V022*V05*V17 - 3.36002286116988272e-15*V01*V03*V05*V17 - 
      1.77386214055104692e-15*V01*V02*V06*V17 + 2.29685692478969508e-16*V05*V06*V17 - 
      3.33522536760390687e-16*V012*V07*V17 + 1.70175681633904587e-16*V04*V07*V17 + 
      9.46420694940513625e-17*V03*V08*V17 + 3.47703530548843402e-17*V02*V09*V17 + 9.98650490727623037e-18*V01*V10*V17 - 
      6.93324171495697322e-20*V13*V17 + 1.26377607156303968e-15*V012*V022*V18 + 
      6.37636756166705928e-16*V013*V03*V18 - 8.37476717118542532e-16*V02*V032*V18 - 
      6.05509142985150212e-16*V022*V04*V18 - 1.04512085644600794e-15*V01*V03*V04*V18 - 
      6.51538098487688052e-16*V01*V02*V05*V18 + 4.2183745764120426e-17*V052*V18 - 
      1.39965489889902678e-16*V012*V06*V18 + 7.11959618138135748e-17*V04*V06*V18 + 
      4.47664484815287733e-17*V03*V07*V18 + 1.82573230342884465e-17*V02*V08*V18 + 5.78002813219706081e-18*V01*V09*V18 - 
      5.10765182941887713e-20*V12*V18 + 1.1817861250857955e-16*V013*V02*V19 - 
      1.52524337214245058e-16*V022*V03*V19 - 1.2956485849658582e-16*V01*V032*V19 - 
      1.92509582047974981e-16*V01*V02*V04*V19 - 4.87852597459248243e-17*V012*V05*V19 + 
      2.48851940330947306e-17*V04*V05*V19 + 1.78217883626003739e-17*V03*V06*V19 + 8.21580161786003365e-18*V02*V07*V19 + 
      2.88732953567971446e-18*V01*V08*V19 - 3.32065786634276583e-20*V11*V19 + 3.73195618448145947e-18*V014*V20 - 
      8.74080743031989095e-18*V023*V20 - 4.56292526435938585e-17*V01*V02*V03*V20 - 
      1.37812519560269486e-17*V012*V04*V20 + 3.49442732489956827e-18*V042*V20 + 
      5.93123291381005684e-18*V03*V05*V20 + 3.11377394730746575e-18*V02*V06*V20 + 1.23683100985051744e-18*V01*V07*V20 - 
      1.89686718341444172e-20*V10*V20 - 3.82410325076495229e-18*V01*V022*V21 - 
      3.09537353490632986e-18*V012*V03*V21 + 1.59461380838318852e-18*V03*V04*V21 + 
      9.91763693091799611e-19*V02*V05*V21 + 4.48611712885502124e-19*V01*V06*V21 - 9.48759379878892284e-21*V09*V21 - 
      5.02201511245035903e-19*V012*V02*V22 + 1.73751375889880365e-19*V032*V22 + 
      2.54695096442820697e-19*V02*V04*V22 + 1.36438307714898283e-19*V01*V05*V22 - 4.1219245473965876e-21*V08*V22 - 
      1.9965197694756779e-20*V013*V23 + 5.34956888638145832e-20*V02*V03*V23 + 3.37705678168462146e-20*V01*V04*V23 - 
      1.54689017019247663e-21*V07*V23 + 3.93045271232202421e-21*V022*V24 + 6.75311859330487918e-21*V01*V03*V24 - 
      4.93883128139586493e-22*V06*V24 + 9.70095812754639734e-22*V01*V02*V25 - 1.33270403343438952e-22*V05*V25 + 
      5.47634733006651463e-23*V012*V26 - 2.93249566706787557e-23*V04*V26 - 5.28836683858780465e-24*V03*V27 - 
      6.79447559561602311e-25*V02*V28 - 7.27979528101716762e-26*V01*V29 + 3.67666428334200385e-29*V32) + 
   delta6*eps13*(1.65299241725011838e-9*V02*V036 + 
      1.38412330601961887e-8*V022*V034*V04 + 5.44985440544305925e-9*V01*V035*V04 + 
      1.34108770484555025e-8*V023*V032*V042 + 
      3.18295977223590002e-8*V01*V02*V033*V042 + 5.22929181665348026e-10*V024*V043 + 
      1.6771240568429414e-8*V01*V022*V03*V043 + 8.82209927607268162e-9*V012*V032*V043 + 
      2.55159137891897729e-9*V012*V02*V044 - 3.04874291577266786e-9*V032*V044 - 
      5.49761548927799316e-10*V02*V045 + 9.27592964607305442e-9*V023*V033*V05 + 
      1.42449846252839573e-8*V01*V02*V034*V05 + 6.32078107755077287e-9*V024*V03*V04*V05 + 
      4.87597195028540828e-8*V01*V022*V032*V04*V05 + 1.5278029055829683e-8*V012*V033*V04*V05 + 
      8.04652622907330149e-9*V01*V023*V042*V05 + 2.74580639339109597e-8*V012*V02*V03*V042*V05 - 
      1.14040427858186809e-8*V033*V042*V05 + 1.64853912404816738e-9*V013*V043*V05 - 
      1.2479363034687977e-8*V02*V03*V043*V05 - 1.91923884678694495e-9*V01*V044*V05 + 
      2.9349207013615954e-10*V025*V052 + 8.22023171581799581e-9*V01*V023*V03*V052 + 
      1.20398180259875802e-8*V012*V02*V032*V052 - 2.56494314147887139e-9*V034*V052 + 
      7.06303846403804599e-9*V012*V022*V04*V052 + 
      4.18353977355287542e-9*V013*V03*V04*V052 - 1.79914303949588447e-8*V02*V032*V04*V052 - 
      4.71917437360211881e-9*V022*V042*V052 - 
      1.06534111489100329e-8*V01*V03*V042*V052 + 7.36504127000701428e-10*V013*V02*V053 - 
      3.12083860944690878e-9*V022*V03*V053 - 3.16201102910204584e-9*V01*V032*V053 - 
      3.74837088702614391e-9*V01*V02*V04*V053 - 2.3914641759682513e-10*V012*V054 + 
      2.12529819577118637e-10*V04*V054 + 2.3403743687526164e-9*V024*V032*V06 + 
      1.12394919004888551e-8*V01*V022*V033*V06 + 2.56518364779073092e-9*V012*V034*V06 + 
      2.1377417119212198e-10*V025*V04*V06 + 1.17542155193462181e-8*V01*V023*V03*V04*V06 + 
      1.87010797223958528e-8*V012*V02*V032*V04*V06 - 4.03012757585034298e-9*V034*V04*V06 + 
      5.38293469895076735e-9*V012*V022*V042*V06 + 
      3.31276694633665213e-9*V013*V03*V042*V06 - 1.3574649187066326e-8*V02*V032*V042*V06 - 
      1.99586494018127562e-9*V022*V043*V06 - 5.49299091591485691e-9*V01*V03*V043*V06 + 
      1.40422462125156984e-9*V01*V024*V05*V06 + 9.68273918898508652e-9*V012*V022*V03*V05*V06 + 
      2.78594595573925018e-9*V013*V032*V05*V06 - 8.52255311341051862e-9*V02*V033*V05*V06 + 
      3.48673243138275131e-9*V013*V02*V04*V05*V06 - 1.38163939439206244e-8*V022*V03*V04*V05*V06 - 
      1.49673481909401681e-8*V01*V032*V04*V05*V06 - 8.52864204194506626e-9*V01*V02*V042*V05*V06 + 
      1.83541696398988688e-10*V014*V052*V06 - 1.1546996614304574e-9*V023*V052*V06 - 
      7.94167223625297521e-9*V01*V02*V03*V052*V06 - 2.2779988712378314e-9*V012*V04*V052*V06 + 
      9.86116932394093112e-10*V042*V052*V06 + 6.09706888293184372e-10*V03*V053*V06 + 
      6.29177335853046002e-10*V012*V023*V062 + 
      1.16582633588763194e-9*V013*V02*V03*V062 - 
      2.50823135561480131e-9*V022*V032*V062 - 1.74412443265324682e-9*V01*V033*V062 + 
      1.46860320781447579e-10*V014*V04*V062 - 7.21851358968479499e-10*V023*V04*V062 - 
      6.10906542412836727e-9*V01*V02*V03*V04*V062 - 9.00272927503056589e-10*V012*V042*V062 + 
      2.42019645270423787e-10*V043*V062 - 1.57299965738742328e-9*V01*V022*V05*V062 - 
      1.58127715231108352e-9*V012*V03*V05*V062 + 1.42717552482394683e-9*V03*V04*V05*V062 + 
      3.77289117736286565e-10*V02*V052*V062 - 2.22244165314694417e-10*V012*V02*V063 + 
      1.71217461009421345e-10*V032*V063 + 1.8376217005164125e-10*V02*V04*V063 + 
      1.11043789513201989e-10*V01*V05*V063 + 2.79516257272532895e-10*V025*V03*V07 + 
      3.8533936905572584e-9*V01*V023*V032*V07 + 3.70476943251936423e-9*V012*V02*V033*V07 - 
      5.05255432851904134e-10*V035*V07 + 9.02968725364396125e-10*V01*V024*V04*V07 + 
      6.57402908281925381e-9*V012*V022*V03*V04*V07 + 1.91690834821799661e-9*V013*V032*V04*V07 - 
      5.9296575144261533e-9*V02*V033*V04*V07 + 1.19432932864222279e-9*V013*V02*V042*V07 - 
      4.69393644944482768e-9*V022*V03*V042*V07 - 5.23488341843352904e-9*V01*V032*V042*V07 - 
      1.94897289818485358e-9*V01*V02*V043*V07 + 1.12020856186591881e-9*V012*V023*V05*V07 + 
      2.02571821434843784e-9*V013*V02*V03*V05*V07 - 4.6315986801641047e-9*V022*V032*V05*V07 - 
      3.09548282291966115e-9*V01*V033*V05*V07 + 2.53045001191738788e-10*V014*V04*V05*V07 - 
      1.55477731533542296e-9*V023*V04*V05*V07 - 1.10580407043791035e-8*V01*V02*V03*V04*V05*V07 - 
      1.59533627447735581e-9*V012*V042*V05*V07 + 4.6010699649585559e-10*V043*V05*V07 - 
      1.44539453478443201e-9*V01*V022*V052*V07 - 1.39581069686466409e-9*V012*V03*V052*V07 + 
      1.29320714327156034e-9*V03*V04*V052*V07 + 2.30126800350706285e-10*V02*V053*V07 + 
      4.1986343552739621e-10*V013*V022*V06*V07 + 1.66509009891878224e-10*V014*V03*V06*V07 - 
      1.146638864482204e-9*V023*V03*V06*V07 - 3.8936520003242313e-9*V01*V02*V032*V06*V07 - 
      2.15038070746904231e-9*V01*V022*V04*V06*V07 - 2.21904170570482477e-9*V012*V03*V04*V06*V07 + 
      1.00232344719667175e-9*V03*V042*V06*V07 - 1.18377161000727918e-9*V012*V02*V05*V06*V07 + 
      9.25557775202590192e-10*V032*V05*V06*V07 + 1.05328385412173983e-9*V02*V04*V05*V06*V07 + 
      2.9907676006314363e-10*V01*V052*V06*V07 - 7.53615391876591318e-11*V013*V062*V07 + 
      3.82992829091679056e-10*V02*V03*V062*V07 + 2.3478771488804818e-10*V01*V04*V062*V07 + 
      3.04398763759249049e-11*V014*V02*V072 - 4.72117729854580865e-11*V024*V072 - 
      7.09141258981743529e-10*V01*V022*V03*V072 - 
      3.38383710927741947e-10*V012*V032*V072 - 
      4.12616644891592206e-10*V012*V02*V04*V072 + 3.27213086168344336e-10*V032*V04*V072 + 
      1.83077374400438577e-10*V02*V042*V072 - 6.59478496412861828e-11*V013*V05*V072 + 
      3.49640824354352004e-10*V02*V03*V05*V072 + 2.11561836854160121e-10*V01*V04*V05*V072 + 
      6.93726837337295552e-11*V022*V06*V072 + 1.50274837672879364e-10*V01*V03*V06*V072 - 
      6.54887605391839151e-12*V062*V072 + 1.90111202989630991e-11*V01*V02*V073 - 
      3.94746966512298185e-12*V05*V073 + 6.09093335156147408e-12*V026*V08 + 
      5.2636774648695792e-10*V01*V024*V03*V08 + 1.69671234867504089e-9*V012*V022*V032*V08 + 
      3.17818017383597536e-10*V013*V033*V08 - 8.12629790789238875e-10*V02*V034*V08 + 
      6.46012362497035845e-10*V012*V023*V04*V08 + 1.2000954023108889e-9*V013*V02*V03*V04*V08 - 
      2.68755864066184612e-9*V022*V032*V04*V08 - 1.8824518802405811e-9*V01*V033*V04*V08 + 
      7.54756663349645166e-11*V014*V042*V08 - 3.80801989155679947e-10*V023*V042*V08 - 
      3.27743942129616699e-9*V01*V02*V03*V042*V08 - 3.22435599953217546e-10*V012*V043*V08 + 
      6.61017147773208875e-11*V044*V08 + 3.15343087900677837e-10*V013*V022*V05*V08 + 
      1.24181582093794721e-10*V014*V03*V05*V08 - 9.04188065492352925e-10*V023*V03*V05*V08 - 
      3.0040038302645991e-9*V01*V02*V032*V05*V08 - 1.68283731729362183e-9*V01*V022*V04*V05*V08 - 
      1.70326664562076568e-9*V012*V03*V04*V05*V08 + 7.83578748184026923e-10*V03*V042*V05*V08 - 
      4.55175440631117712e-10*V012*V02*V052*V08 + 3.59658347646397295e-10*V032*V052*V08 + 
      4.13180586387259782e-10*V02*V04*V052*V08 + 7.73362743234710884e-11*V01*V053*V08 + 
      5.27013155206073566e-11*V014*V02*V06*V08 - 6.84689576973796727e-11*V024*V06*V08 - 
      1.20759245000073034e-9*V01*V022*V03*V06*V08 - 5.88427834527953767e-10*V012*V032*V06*V08 - 
      7.14790921362060381e-10*V012*V02*V04*V06*V08 + 5.64389926867821916e-10*V032*V04*V06*V08 + 
      3.00471476871286937e-10*V02*V042*V06*V08 - 1.15057682150711465e-10*V013*V05*V06*V08 + 
      5.9924804299535571e-10*V02*V03*V05*V06*V08 + 3.65540311783518363e-10*V01*V04*V05*V06*V08 + 
      5.66735473171518737e-11*V022*V062*V08 + 1.30295249697215972e-10*V01*V03*V062*V08 - 
      3.72739486227765171e-12*V063*V08 + 2.7861087387299354e-12*V015*V07*V08 - 
      1.39897526666398188e-10*V01*V023*V07*V08 - 4.41644533093685594e-10*V012*V02*V03*V07*V08 + 
      1.20985720716827986e-10*V033*V07*V08 - 8.08821159417478177e-11*V013*V04*V07*V08 + 
      4.19120793516952112e-10*V02*V03*V04*V07*V08 + 1.28639294701972478e-10*V01*V042*V07*V08 + 
      1.09201923531750455e-10*V022*V05*V07*V08 + 2.32953001308419315e-10*V01*V03*V05*V07*V08 + 
      9.80448459763113357e-11*V01*V02*V06*V07*V08 - 2.04810538021669969e-11*V05*V06*V07*V08 + 
      9.15890383820060886e-12*V012*V072*V08 - 7.25760393961260053e-12*V04*V072*V08 - 
      3.51318043592475557e-11*V012*V022*V082 - 2.10479658012154364e-11*V013*V03*V082 + 
      5.91740926179955156e-11*V02*V032*V082 + 3.07807752589410277e-11*V022*V04*V082 + 
      7.14457374773428863e-11*V01*V03*V04*V082 + 3.81938013880300072e-11*V01*V02*V05*V082 - 
      3.99999100841150985e-12*V052*V082 + 7.98556074491788708e-12*V012*V06*V082 - 
      6.18936358597806188e-12*V04*V06*V082 - 4.10446024429829721e-12*V03*V07*V082 - 
      4.4264013459104522e-13*V02*V083 + 2.32930214393777413e-11*V01*V025*V09 + 
      3.01001984197060529e-10*V012*V023*V03*V09 + 2.65919375151097257e-10*V013*V02*V032*V09 - 
      4.59107130935074397e-10*V022*V033*V09 - 2.26789990403583351e-10*V01*V034*V09 + 
      1.65094806537096671e-10*V013*V022*V04*V09 + 6.5706048470292913e-11*V014*V03*V04*V09 - 
      4.67023676442611738e-10*V023*V03*V04*V09 - 1.62966619665228934e-9*V01*V02*V032*V04*V09 - 
      4.41032537052533317e-10*V01*V022*V042*V09 - 4.65827675810928194e-10*V012*V03*V042*V09 + 
      1.43191814352310845e-10*V03*V043*V09 + 3.48370016871977343e-11*V014*V02*V05*V09 - 
      5.71502821587498283e-11*V024*V05*V09 - 8.52801947297938122e-10*V01*V022*V03*V05*V09 - 
      4.05242381352773127e-10*V012*V032*V05*V09 - 4.94777597563136522e-10*V012*V02*V04*V05*V09 + 
      3.99696083639422689e-10*V032*V04*V05*V09 + 2.24305200835768743e-10*V02*V042*V05*V09 - 
      3.93635658807944627e-11*V013*V052*V09 + 2.13611591267920048e-10*V02*V03*V052*V09 + 
      1.28977256490297231e-10*V01*V04*V052*V09 + 2.13933456676174998e-12*V015*V06*V09 - 
      1.0728446401062576e-10*V01*V023*V06*V09 - 3.44335379363673659e-10*V012*V02*V03*V06*V09 + 
      9.50727055507617348e-11*V033*V06*V09 - 6.32319716824539363e-11*V013*V04*V06*V09 + 
      3.27194317878730776e-10*V02*V03*V04*V06*V09 + 1.00727965507211103e-10*V01*V042*V06*V09 + 
      8.49487432258145688e-11*V022*V05*V06*V09 + 1.8306385170324319e-10*V01*V03*V05*V06*V09 + 
      3.83371866924847836e-11*V01*V02*V062*V09 - 8.05142885260554459e-12*V05*V062*V09 - 
      6.32147404439010862e-11*V012*V022*V07*V09 - 3.77302972743653795e-11*V013*V03*V07*V09 + 
      1.07864467949808638e-10*V02*V032*V07*V09 + 5.86489794023665398e-11*V022*V04*V07*V09 + 
      1.29511233389587309e-10*V01*V03*V04*V07*V09 + 6.94983132104084442e-11*V01*V02*V05*V07*V09 - 
      7.27413456031828447e-12*V052*V07*V09 + 1.4398916765634708e-11*V012*V06*V07*V09 - 
      1.14009159878492438e-11*V04*V06*V07*V09 - 3.72953572398336686e-12*V03*V072*V09 - 
      1.24441331666442167e-11*V013*V02*V08*V09 + 3.38241438168341798e-11*V022*V03*V08*V09 + 
      3.5494255410949495e-11*V01*V032*V08*V09 + 4.18527523327728124e-11*V01*V02*V04*V08*V09 + 
      1.11198562619915316e-11*V012*V05*V08*V09 - 8.92348142246957211e-12*V04*V05*V08*V09 - 
      6.45934970280348913e-12*V03*V06*V08*V09 - 2.45147201272742749e-12*V02*V07*V08*V09 - 
      4.26697537204433116e-13*V01*V082*V09 - 3.73561556533191765e-13*V014*V092 + 
      1.54100891636445927e-12*V023*V092 + 1.05995837611610948e-11*V01*V02*V03*V092 + 
      3.09508263999952405e-12*V012*V04*V092 - 1.23807203005564158e-12*V042*V092 - 
      2.28977255887157722e-12*V03*V05*V092 - 9.60872322161001938e-13*V02*V06*V092 - 
      3.86873773776280376e-13*V01*V07*V092 + 1.76543177060346038e-11*V012*V024*V10 + 
      6.60977299782492912e-11*V013*V022*V03*V10 + 1.27976794360635909e-11*V014*V032*V10 - 
      1.10886969017901137e-10*V023*V032*V10 - 2.38657295244777428e-10*V01*V02*V033*V10 + 
      1.6521491562302843e-11*V014*V02*V04*V10 - 2.24750668084651807e-11*V024*V04*V10 - 
      4.07899374485312101e-10*V01*V022*V03*V04*V10 - 2.0065333486758887e-10*V012*V032*V04*V10 - 
      1.20994451673556809e-10*V012*V02*V042*V10 + 9.93497937618841779e-11*V032*V042*V10 + 
      3.48253665458840755e-11*V02*V043*V10 + 1.26415695727301949e-12*V015*V05*V10 - 
      6.91511024819220775e-11*V01*V023*V05*V10 - 2.14675076789942065e-10*V012*V02*V03*V05*V10 + 
      6.02966023636317714e-11*V033*V05*V10 - 3.91078294783204656e-11*V013*V04*V05*V10 + 
      2.10156217323340596e-10*V02*V03*V04*V05*V10 + 6.4212814221649726e-11*V01*V042*V05*V10 + 
      2.74443153231186192e-11*V022*V052*V10 + 5.78983944070356525e-11*V01*V03*V052*V10 - 
      4.43843017738000093e-11*V012*V022*V06*V10 - 2.66638453083691919e-11*V013*V03*V06*V10 + 
      7.58467396739671493e-11*V02*V032*V06*V10 + 3.92782790449251503e-11*V022*V04*V06*V10 + 
      9.16216212725406214e-11*V01*V03*V04*V06*V10 + 4.89204024853496746e-11*V01*V02*V05*V06*V10 - 
      5.15412808464114329e-12*V052*V06*V10 + 5.11793677411109471e-12*V012*V062*V10 - 
      3.9831139026908763e-12*V04*V062*V10 - 1.00826225007017522e-11*V013*V02*V07*V10 + 
      2.77706129958863272e-11*V022*V03*V07*V10 + 2.89663880439119737e-11*V01*V032*V07*V10 + 
      3.42743461473933231e-11*V01*V02*V04*V07*V10 + 9.0663344942816703e-12*V012*V05*V07*V10 - 
      7.31217987621410814e-12*V04*V05*V07*V10 - 5.28878991680736179e-12*V03*V06*V07*V10 - 
      1.00545023316655181e-12*V02*V072*V10 - 6.75599333947874778e-13*V014*V08*V10 + 
      2.65138718611331927e-12*V023*V08*V10 + 1.90862565125946774e-11*V01*V02*V03*V08*V10 + 
      5.59844233423207949e-12*V012*V04*V08*V10 - 2.20267929978936099e-12*V042*V08*V10 - 
      4.12661434034899481e-12*V03*V05*V08*V10 - 1.70768450714704698e-12*V02*V06*V08*V10 - 
      6.97996635475576539e-13*V01*V07*V08*V10 + 2.75209601676780638e-12*V01*V022*V09*V10 + 
      2.72714820635076047e-12*V012*V03*V09*V10 - 2.30579147262046494e-12*V03*V04*V09*V10 - 
      1.23621169925226518e-12*V02*V05*V09*V10 - 5.49654018379800766e-13*V01*V06*V09*V10 + 
      6.93234108059802744e-15*V092*V10 + 3.70779160585071918e-13*V012*V02*V102 - 
      2.65199736154683223e-13*V032*V102 - 3.02745049527519678e-13*V02*V04*V102 - 
      1.74910018079406859e-13*V01*V05*V102 + 6.22937299983295429e-15*V08*V102 + 
      4.92619511995151302e-12*V013*V023*V11 + 5.84117237448891748e-12*V014*V02*V03*V11 - 
      1.15199860337992746e-11*V024*V03*V11 - 8.38856473565990139e-11*V01*V022*V032*V11 - 
      2.61062454682639616e-11*V012*V033*V11 + 5.44904807322493695e-13*V015*V04*V11 - 
      2.93075920440812251e-11*V01*V023*V04*V11 - 9.62561139242604334e-11*V012*V02*V03*V04*V11 + 
      2.77608797962469534e-11*V033*V04*V11 - 8.85382794057684124e-12*V013*V042*V11 + 
      4.71999151016865312e-11*V02*V03*V042*V11 + 9.72342153979441691e-12*V01*V043*V11 - 
      2.5356992658294002e-11*V012*V022*V05*V11 - 1.50405889015284077e-11*V013*V03*V05*V11 + 
      4.45583421763271917e-11*V02*V032*V05*V11 + 2.43512976285366689e-11*V022*V04*V05*V11 + 
      5.33386073504539976e-11*V01*V03*V04*V05*V11 + 1.4316658309772099e-11*V01*V02*V052*V11 - 
      1.01021636929364818e-12*V053*V11 - 6.49685464857254091e-12*V013*V02*V06*V11 + 
      1.78382540774898195e-11*V022*V03*V06*V11 + 1.88587598327407302e-11*V01*V032*V06*V11 + 
      2.21255655820517824e-11*V01*V02*V04*V06*V11 + 5.90492053889309544e-12*V012*V05*V06*V11 - 
      4.75764534560466503e-12*V04*V05*V06*V11 - 1.72358754274224914e-12*V03*V062*V11 - 
      4.99038274568920124e-13*V014*V07*V11 + 2.09049524630359461e-12*V023*V07*V11 + 
      1.43348991085224613e-11*V01*V02*V03*V07*V11 + 4.18177895602112244e-12*V012*V04*V07*V11 - 
      1.68078951637572008e-12*V042*V07*V11 - 3.10613935406968052e-12*V03*V05*V07*V11 - 
      1.3045500217260653e-12*V02*V06*V07*V11 - 2.62270407632081227e-13*V01*V072*V11 + 
      2.27200606071684525e-12*V01*V022*V08*V11 + 2.25965573310121448e-12*V012*V03*V08*V11 - 
      1.90994914268068194e-12*V03*V04*V08*V11 - 1.0230395414821402e-12*V02*V05*V08*V11 - 
      4.55581045664504838e-13*V01*V06*V08*V11 + 6.79235858264315972e-13*V012*V02*V09*V11 - 
      4.8758101962009306e-13*V032*V09*V11 - 5.63941891229075089e-13*V02*V04*V09*V11 - 
      3.2140172408927778e-13*V01*V05*V09*V11 + 1.14947568913065291e-14*V08*V09*V11 + 
      5.53458873809205168e-14*V013*V10*V11 - 2.6424886314235551e-13*V02*V03*V10*V11 - 
      1.62353246889028885e-13*V01*V04*V10*V11 + 9.41722501530556753e-15*V07*V10*V11 - 
      1.58644176989628236e-14*V022*V112 - 3.3886677205576281e-14*V01*V03*V112 + 
      3.07721381670551646e-15*V06*V112 + 6.05295649003007677e-13*V014*V022*V12 - 
      3.59882482437278407e-13*V025*V12 + 1.72849131854334813e-13*V015*V03*V12 - 
      1.15677929465048907e-11*V01*V023*V03*V12 - 1.7430281941978008e-11*V012*V02*V032*V12 + 
      2.64161000697906492e-12*V034*V12 - 1.0352793416110236e-11*V012*V022*V04*V12 - 
      6.27041153403228283e-12*V013*V03*V04*V12 + 1.8589111159799671e-11*V02*V032*V04*V12 + 
      4.73601963449950958e-12*V022*V042*V12 + 1.12480953815030756e-11*V01*V03*V042*V12 - 
      3.37383115323102257e-12*V013*V02*V05*V12 + 9.73511167772091757e-12*V022*V03*V05*V12 + 
      1.00616014982849948e-11*V01*V032*V05*V12 + 1.19601379146819554e-11*V01*V02*V04*V05*V12 + 
      1.56919078215588999e-12*V012*V052*V12 - 1.29061398334504037e-12*V04*V052*V12 - 
      2.96284601985383221e-13*V014*V06*V12 + 1.17749372433879194e-12*V023*V06*V12 + 
      8.54757581958902108e-12*V01*V02*V03*V06*V12 + 2.5090117192617549e-12*V012*V04*V06*V12 - 
      9.92923634472563931e-13*V042*V06*V12 - 1.86450149477329525e-12*V03*V05*V06*V12 - 
      3.84555095029679187e-13*V02*V062*V12 + 1.57632075026051422e-12*V01*V022*V07*V12 + 
      1.55499848102630278e-12*V012*V03*V07*V12 - 1.32395278817595673e-12*V03*V04*V07*V12 - 
      7.10410700110342782e-13*V02*V05*V07*V12 - 3.15226102723702595e-13*V01*V06*V07*V12 + 
      5.18571513178147662e-13*V012*V02*V08*V12 - 3.71940966196554748e-13*V032*V08*V12 - 
      4.24103808869650398e-13*V02*V04*V08*V12 - 2.45286362640797059e-13*V01*V05*V08*V12 + 
      4.37046007815720245e-15*V082*V12 + 4.67025512767729883e-14*V013*V09*V12 - 
      2.23698521828772384e-13*V02*V03*V09*V12 - 1.37341650884344593e-13*V01*V04*V09*V12 + 7.96939068301365903e-15*V07*V09*V12 - 
      2.8828104171663083e-14*V022*V10*V12 - 6.24104150070226499e-14*V01*V03*V10*V12 + 
      5.64485047550917638e-15*V06*V10*V12 - 1.56651786986489161e-14*V01*V02*V11*V12 + 3.33769492201838502e-15*V05*V11*V12 - 
      8.86411283607056922e-16*V012*V122 + 7.13077267517012585e-16*V04*V122 + 
      3.30161263092549642e-14*V015*V02*V13 - 5.15449824460184014e-13*V01*V024*V13 - 
      3.51332919429006389e-12*V012*V022*V03*V13 - 1.02163371969250649e-12*V013*V032*V13 + 
      2.22821348731493627e-12*V02*V033*V13 - 1.295000356283382e-12*V013*V02*V04*V13 + 
      3.69516336877554542e-12*V022*V03*V04*V13 + 3.96383473765864382e-12*V01*V032*V04*V13 + 
      2.30015305704597514e-12*V01*V02*V042*V13 - 1.41421754999903677e-13*V014*V05*V13 + 
      6.27629052363046747e-13*V023*V05*V13 + 4.25993246488590678e-12*V01*V02*V03*V05*V13 + 
      1.23802976767318278e-12*V012*V04*V05*V13 - 5.08004011562133792e-13*V042*V05*V13 - 
      4.68030384143614972e-13*V03*V052*V13 + 8.65588902541657253e-13*V01*V022*V06*V13 + 
      8.66212342176475281e-13*V012*V03*V06*V13 - 7.37424793181618753e-13*V03*V04*V06*V13 - 
      3.94239422684769086e-13*V02*V05*V06*V13 - 8.79823054201386731e-14*V01*V062*V13 + 
      3.31268813459478383e-13*V012*V02*V07*V13 - 2.39306139916671814e-13*V032*V07*V13 - 
      2.77215501314080526e-13*V02*V04*V07*V13 - 1.57652963731614308e-13*V01*V05*V07*V13 + 
      3.31086536408422936e-14*V013*V08*V13 - 1.58340795847096209e-13*V02*V03*V08*V13 - 
      9.73560685348212048e-14*V01*V04*V08*V13 + 5.65249270251123747e-15*V07*V08*V13 - 
      2.29730119703463972e-14*V022*V09*V13 - 4.90344059398011104e-14*V01*V03*V09*V13 + 
      4.4556374302116013e-15*V06*V09*V13 - 1.33967851141879037e-14*V01*V02*V10*V13 + 2.85541599075351329e-15*V05*V10*V13 - 
      1.64574873419930638e-15*V012*V11*V13 + 1.33023257104290608e-15*V04*V11*V13 + 
      5.23451871006887793e-16*V03*V12*V13 + 5.6436363957087508e-17*V02*V132 + 
      6.47375025671665965e-16*V016*V14 - 2.13778959909429818e-13*V012*V023*V14 - 
      3.93970593392060693e-13*V013*V02*V03*V14 + 6.35112634788320403e-13*V022*V032*V14 + 
      4.2922246645499399e-13*V01*V033*V14 - 5.07780597258200105e-14*V014*V04*V14 + 
      2.08209138357232785e-13*V023*V04*V14 + 1.54459401947502601e-12*V01*V02*V03*V04*V14 + 
      2.27121801799059415e-13*V012*V042*V14 - 6.10564288218587202e-14*V043*V14 + 
      4.06708557569133368e-13*V01*V022*V05*V14 + 3.97770290108845224e-13*V012*V03*V05*V14 - 
      3.46205304889671238e-13*V03*V04*V05*V14 - 9.29924265977742453e-14*V02*V052*V14 + 
      1.71681630555312298e-13*V012*V02*V06*V14 - 1.24636098548669414e-13*V032*V06*V14 - 
      1.41471832885866306e-13*V02*V04*V06*V14 - 8.2148492228427167e-14*V01*V05*V06*V14 + 
      1.96728193688666029e-14*V013*V07*V14 - 9.52557824363161538e-14*V02*V03*V07*V14 - 
      5.84072292155915883e-14*V01*V04*V07*V14 + 1.69830746360725112e-15*V072*V14 - 
      1.49536476563454537e-14*V022*V08*V14 - 3.24484221727777839e-14*V01*V03*V08*V14 + 
      2.93637275808941573e-15*V06*V08*V14 - 9.82497677004151241e-15*V01*V02*V09*V14 + 2.09432703016534729e-15*V05*V09*V14 - 
      1.31435421765251645e-15*V012*V10*V14 + 1.05736133262327091e-15*V04*V10*V14 + 
      4.53666218671016393e-16*V03*V11*V14 + 1.04868532788085482e-16*V02*V12*V14 + 2.38011479809086447e-17*V01*V13*V14 - 
      3.50426916070097446e-14*V013*V022*V15 - 1.41085535486053289e-14*V014*V03*V15 + 
      7.18702737494876399e-14*V023*V03*V15 + 2.38385906905103058e-13*V01*V02*V032*V15 + 
      1.35223172637121579e-13*V01*V022*V04*V15 + 1.3711886117740038e-13*V012*V03*V04*V15 - 
      5.97081709776533282e-14*V03*V042*V15 + 7.4062172478214984e-14*V012*V02*V05*V15 - 
      5.4631535073360603e-14*V032*V05*V15 - 6.35464205981655164e-14*V02*V04*V05*V15 - 
      1.79549661021444243e-14*V01*V052*V15 + 9.5857733703327457e-15*V013*V06*V15 - 
      4.62756549791944176e-14*V02*V03*V06*V15 - 2.84891950863623848e-14*V01*V04*V06*V15 - 
      8.56441975538305829e-15*V022*V07*V15 - 1.82256686723030509e-14*V01*V03*V07*V15 + 
      1.66107264157847099e-15*V06*V07*V15 - 6.0853444830426526e-15*V01*V02*V08*V15 + 1.29933548936433682e-15*V05*V08*V15 - 
      9.01979908299631121e-16*V012*V09*V15 + 7.30040739768721734e-16*V04*V09*V15 + 
      3.39459924769725797e-16*V03*V10*V15 + 8.55532142115370918e-17*V02*V11*V15 + 2.08154976382726338e-17*V01*V12*V15 - 
      5.8932250686124597e-20*V152 - 2.39247292096050465e-15*V014*V02*V16 + 
      2.59662614247925397e-15*V024*V16 + 4.02867476411792183e-14*V01*V022*V03*V16 + 
      1.93037883916566029e-14*V012*V032*V16 + 2.38003641781464343e-14*V012*V02*V04*V16 - 
      1.78645657745856546e-14*V032*V04*V16 - 1.00205655274990807e-14*V02*V042*V16 + 
      3.85289669587673607e-15*V013*V05*V16 - 1.92300298182246161e-14*V02*V03*V05*V16 - 
      1.17524656383676113e-14*V01*V04*V05*V16 - 3.8415350242529435e-15*V022*V06*V16 - 
      8.38983065265123518e-15*V01*V03*V06*V16 + 3.80700548231161266e-16*V062*V16 - 
      3.22539964549769187e-15*V01*V02*V07*V16 + 6.89080303128354176e-16*V05*V07*V16 - 
      5.27400509995494606e-16*V012*V08*V16 + 4.24512688171965718e-16*V04*V08*V16 + 
      2.19720871288794942e-16*V03*V09*V16 + 5.99959411638146868e-17*V02*V10*V16 + 1.59187463593250527e-17*V01*V11*V16 - 
      1.1079025536347802e-19*V14*V16 - 5.62934804931883448e-17*V015*V17 + 
      2.04276642740862361e-15*V01*V023*V17 + 6.38351314780704286e-15*V012*V02*V03*V17 - 
      1.6628606276813098e-15*V033*V17 + 1.18147617586284193e-15*V013*V04*V17 - 
      5.85428921019558605e-15*V02*V03*V04*V17 - 1.80686407381866393e-15*V01*V042*V17 - 
      1.54122167343600823e-15*V022*V05*V17 - 3.25469848517431622e-15*V01*V03*V05*V17 - 
      1.39506948536253869e-15*V01*V02*V06*V17 + 2.99777897313207931e-16*V05*V06*V17 - 
      2.62729715387494746e-16*V012*V07*V17 + 2.13653736186709851e-16*V04*V07*V17 + 
      1.21250528707195404e-16*V03*V08*V17 + 3.68465004390900903e-17*V02*V09*V17 + 1.05918722822414556e-17*V01*V10*V17 - 
      9.24426150301492161e-20*V13*V17 + 4.87994109025326464e-16*V012*V022*V18 + 
      2.91553317720971302e-16*V013*V03*V18 - 7.88222015938509173e-16*V02*V032*V18 - 
      4.30496733094720018e-16*V022*V04*V18 - 9.54780431128739958e-16*V01*V03*V04*V18 - 
      5.16302645159732691e-16*V01*V02*V05*V18 + 5.56489828859292094e-17*V052*V18 - 
      1.08446565922381515e-16*V012*V06*V18 + 8.76006319476780833e-17*V04*V06*V18 + 
      5.75451859511967202e-17*V03*V07*V18 + 1.91629901378329376e-17*V02*V08*V18 + 6.13421501533908222e-18*V01*V09*V18 - 
      6.80043879121880758e-20*V12*V18 + 4.36274473822209672e-17*V013*V02*V19 - 
      1.14258173688518219e-16*V022*V03*V19 - 1.18417157727789631e-16*V01*V032*V19 - 
      1.41925031161350305e-16*V01*V02*V04*V19 - 3.76612240191514414e-17*V012*V05*V19 + 
      3.11138533138566719e-17*V04*V05*V19 + 2.25695577670570253e-17*V03*V06*V19 + 8.69796924638006314e-18*V02*V07*V19 + 
      3.05035150630311125e-18*V01*V08*V19 - 4.42748303819597842e-20*V11*V19 + 1.26660331109673776e-18*V014*V20 - 
      4.95237958775675847e-18*V023*V20 - 3.40857981758372659e-17*V01*V02*V03*V20 - 
      1.00284729279957128e-17*V012*V04*V20 + 4.10538734031304488e-18*V042*V20 + 
      7.57818685878495806e-18*V03*V05*V20 + 3.22087545950950052e-18*V02*V06*V20 + 1.30919575577112974e-18*V01*V07*V20 - 
      2.52313523715603196e-20*V10*V20 - 2.26514242936876911e-18*V01*V022*V21 - 
      2.22604973458183276e-18*V012*V03*V21 + 1.93141229852361064e-18*V03*V04*V21 + 
      1.04437000710130713e-18*V02*V05*V21 + 4.6781280108152058e-19*V01*V06*V21 - 1.26495172291081369e-20*V09*V21 - 
      2.94870612107177044e-19*V012*V02*V22 + 2.1406494365066718e-19*V032*V22 + 
      2.50058077431335303e-19*V02*V04*V22 + 1.43024264459716799e-19*V01*V05*V22 - 5.46742040599416839e-21*V08*V22 - 
      1.11693413676961002e-20*V013*V23 + 5.43349942568181838e-20*V02*V03*V23 + 3.35293678157593289e-20*V01*V04*V23 - 
      2.06191239097954198e-21*V07*V23 + 3.18069462511115956e-21*V022*V24 + 6.76178446160740201e-21*V01*V03*V24 - 
      6.48647415930993752e-22*V06*V24 + 7.98383237130576125e-22*V01*V02*V25 - 1.77086035180825081e-22*V05*V25 + 
      4.41317367258107406e-23*V012*V26 - 3.6993007700016839e-23*V04*V26 - 6.83114419406855403e-24*V03*V27 - 
      7.24744063532375798e-25*V02*V28 - 7.76511496641831212e-26*V01*V29 + 4.90221904445600513e-29*V32) + 
   delta2*eps15*(-7.34513519595647598e-9*V026*V032 - 
      7.66733214743714631e-8*V01*V024*V033 - 9.50223719492931198e-8*V012*V022*V034 - 
      9.30118813003874923e-9*V013*V035 + 7.92541135303655303e-9*V02*V036 - 
      6.94677964495491896e-10*V027*V04 - 5.60732557136975995e-8*V01*V025*V03*V04 - 
      2.55281843345728439e-7*V012*V023*V032*V04 - 
      1.28759511348895787e-7*V013*V02*V033*V04 + 7.8784237823039034e-8*V022*V034*V04 + 
      2.74095856384940716e-8*V01*V035*V04 - 4.30239563261992811e-8*V012*V024*V042 - 
      1.33756322321729296e-7*V013*V022*V03*V042 - 
      2.33303376863546728e-8*V014*V032*V042 + 
      9.9392095205150115e-8*V023*V032*V042 + 1.86446426462638602e-7*V01*V02*V033*V042 - 
      1.08661788982903174e-8*V014*V02*V043 + 8.85485037384606633e-9*V024*V043 + 
      1.22862106534274762e-7*V01*V022*V03*V043 + 
      5.30366946500021783e-8*V012*V032*V043 + 1.82367247328506246e-8*V012*V02*V044 - 
      7.62523189444241833e-9*V032*V044 - 1.89784940868103996e-9*V02*V045 - 
      4.40708111757388559e-9*V01*V026*V05 - 6.77071712216627273e-8*V012*V024*V03*V05 - 
      1.05625519079117807e-7*V013*V022*V032*V05 - 
      1.22790162972445681e-8*V014*V033*V05 + 5.83393132196211667e-8*V023*V033*V05 + 
      7.82712175252762983e-8*V01*V02*V034*V05 - 4.87468976537895407e-8*V013*V023*V04*V05 - 
      5.14051989668392114e-8*V014*V02*V03*V04*V05 + 5.32272774181542503e-8*V024*V03*V04*V05 + 
      3.14664911623860674e-7*V01*V022*V032*V04*V05 + 8.76826166470720832e-8*V012*V033*V04*V05 - 
      2.36033928939316606e-9*V015*V042*V05 + 6.71136227616780994e-8*V01*V023*V042*V05 + 
      1.81191927409187312e-7*V012*V02*V03*V042*V05 - 2.63392400894021651e-8*V033*V042*V05 + 
      1.10969263107718122e-8*V013*V043*V05 - 3.46037844026564338e-8*V02*V03*V043*V05 - 
      5.35425046541173307e-9*V01*V044*V05 - 7.04521275513515611e-9*V014*V022*V052 + 
      2.77576346498354624e-9*V025*V052 - 1.85314363868643768e-9*V015*V03*V052 + 
      5.82041716418391508e-8*V01*V023*V03*V052 + 
      7.50689503172054512e-8*V012*V02*V032*V052 - 5.62337837306412398e-9*V034*V052 + 
      5.10318316615263682e-8*V012*V022*V04*V052 + 
      2.71615916129108854e-8*V013*V03*V04*V052 - 4.52814334226117655e-8*V02*V032*V04*V052 - 
      1.45327752816043505e-8*V022*V042*V052 - 
      2.74621234695733417e-8*V01*V03*V042*V052 + 5.16846854743267365e-9*V013*V02*V053 - 
      8.56178385130490555e-9*V022*V03*V053 - 7.75101010166097229e-9*V01*V032*V053 - 
      1.05080847658167175e-8*V01*V02*V04*V053 - 6.51990468618928513e-10*V012*V054 + 
      3.57149883234819747e-10*V04*V054 - 6.00714401602766817e-9*V012*V025*V06 - 
      3.1984522590089561e-8*V013*V023*V03*V06 - 1.6831526268782988e-8*V014*V02*V032*V06 + 
      1.9331071480799861e-8*V024*V032*V06 + 7.37181143191700339e-8*V01*V022*V033*V06 + 
      1.51727132927482365e-8*V012*V034*V06 - 1.17097119917916548e-8*V014*V022*V04*V06 + 
      4.01048218684418898e-9*V025*V04*V06 - 3.07582745825769643e-9*V015*V03*V04*V06 + 
      9.59460788216942072e-8*V01*V023*V03*V04*V06 + 1.25830110112474634e-7*V012*V02*V032*V04*V06 - 
      9.36979489735362674e-9*V034*V04*V06 + 4.28832324436438457e-8*V012*V022*V042*V06 + 
      2.2856691881741515e-8*V013*V03*V042*V06 - 3.73228480331830138e-8*V02*V032*V042*V06 - 
      7.64165341227448942e-9*V022*V043*V06 - 1.52415075299584514e-8*V01*V03*V043*V06 - 
      1.67666987255979651e-9*V015*V02*V05*V06 + 1.29208613803010814e-8*V01*V024*V05*V06 + 
      7.10384242638056369e-8*V012*V022*V03*V05*V06 + 1.8639489455271313e-8*V013*V032*V05*V06 - 
      2.15473376627685792e-8*V02*V033*V05*V06 + 2.61136077773585444e-8*V013*V02*V04*V05*V06 - 
      4.20451053616803543e-8*V022*V03*V04*V05*V06 - 3.88651879948861813e-8*V01*V032*V04*V05*V06 - 
      2.611037687324363e-8*V01*V02*V042*V05*V06 + 1.38036619399501211e-9*V014*V052*V06 - 
      3.89065652237962201e-9*V023*V052*V06 - 2.23737718204443371e-8*V01*V02*V03*V052*V06 - 
      6.56188115383649758e-9*V012*V04*V052*V06 + 1.77257493552073986e-9*V042*V052*V06 + 
      1.02343274054048332e-9*V03*V053*V06 - 3.92579313424881184e-11*V016*V062 + 
      5.53896626105372376e-9*V012*V023*V062 + 
      8.94612554318519055e-9*V013*V02*V03*V062 - 
      7.57018784023038801e-9*V022*V032*V062 - 4.57423988753967457e-9*V01*V033*V062 + 
      1.16097640437488421e-9*V014*V04*V062 - 3.05490152697411129e-9*V023*V04*V062 - 
      1.85996384776467165e-8*V01*V02*V03*V04*V062 - 2.75370580576689454e-9*V012*V042*V062 + 
      4.82553039614528773e-10*V043*V062 - 5.27207344384687974e-9*V01*V022*V05*V062 - 
      4.60414303651161596e-9*V012*V03*V05*V062 + 2.54771016133387209e-9*V03*V04*V05*V062 + 
      7.32918329149337008e-10*V02*V052*V062 - 7.43797998421722055e-10*V012*V02*V063 + 
      3.0438303047085905e-10*V032*V063 + 3.98131923878671738e-10*V02*V04*V063 + 
      2.17150728211414912e-10*V01*V05*V063 - 3.10045404814854993e-9*V013*V024*V07 - 
      6.54361911268731014e-9*V014*V022*V03*V07 + 2.89657308748128819e-9*V025*V03*V07 - 
      8.5619408960953181e-10*V015*V032*V07 + 2.97425306382492934e-8*V01*V023*V032*V07 + 
      2.52333281303459248e-8*V012*V02*V033*V07 - 1.16601553487689853e-9*V035*V07 - 
      1.18979665036711759e-9*V015*V02*V04*V07 + 9.25633803761605614e-9*V01*V024*V04*V07 + 
      5.16423382847674271e-8*V012*V022*V03*V04*V07 + 1.35789635420893226e-8*V013*V032*V04*V07 - 
      1.57072117980715576e-8*V02*V033*V04*V07 + 9.51817763058136525e-9*V013*V02*V042*V07 - 
      1.52211800623303508e-8*V022*V03*V042*V07 - 1.42045024774269449e-8*V01*V032*V042*V07 - 
      6.33229443401291315e-9*V01*V02*V043*V07 - 6.71627543776257063e-11*V016*V05*V07 + 
      9.57319667608703312e-9*V012*V023*V05*V07 + 1.54846937154151709e-8*V013*V02*V03*V05*V07 - 
      1.33875761956695592e-8*V022*V032*V05*V07 - 7.99951097235749514e-9*V01*V033*V05*V07 + 
      2.0095486361703746e-9*V014*V04*V05*V07 - 5.60933165501704436e-9*V023*V04*V05*V07 - 
      3.26535369779595175e-8*V01*V02*V03*V04*V05*V07 - 4.80157924678221344e-9*V012*V042*V05*V07 + 
      8.61880298416276305e-10*V043*V05*V07 - 4.64372218274195496e-9*V01*V022*V052*V07 - 
      4.01555119610890494e-9*V012*V03*V052*V07 + 2.24598005365667107e-9*V03*V04*V052*V07 + 
      4.32051689154240787e-10*V02*V053*V07 + 3.68970496282504369e-9*V013*V022*V06*V07 + 
      1.36300731511013964e-9*V014*V03*V06*V07 - 4.07651751182822467e-9*V023*V03*V06*V07 - 
      1.15678326592981273e-8*V01*V02*V032*V06*V07 - 7.66091299332580027e-9*V01*V022*V04*V06*V07 - 
      6.74051561116660225e-9*V012*V03*V04*V06*V07 + 1.86082412105481978e-9*V03*V042*V06*V07 - 
      3.89091480242436439e-9*V012*V02*V05*V06*V07 + 1.60720976683344328e-9*V032*V05*V06*V07 + 
      2.13604869253278858e-9*V02*V04*V05*V06*V07 + 5.71960251543224737e-10*V01*V052*V06*V07 - 
      2.55372414563206963e-10*V013*V062*V07 + 7.69818695305583881e-10*V02*V03*V062*V07 + 
      4.76964607089161981e-10*V01*V04*V062*V07 + 2.82151763039381577e-10*V014*V02*V072 - 
      2.00129525632151865e-10*V024*V072 - 2.4056036538132887e-9*V01*V022*V03*V072 - 
      1.02920453151944644e-9*V012*V032*V072 - 
      1.42202040397659846e-9*V012*V02*V04*V072 + 5.88167349435319928e-10*V032*V04*V072 + 
      3.88733334581949205e-10*V02*V042*V072 - 2.22010298539190358e-10*V013*V05*V072 + 
      6.79971755260556443e-10*V02*V03*V05*V072 + 4.19067719551377918e-10*V01*V04*V05*V072 + 
      1.59623433551773797e-10*V022*V06*V072 + 2.98128726367052495e-10*V01*V03*V06*V072 - 
      1.02099467098193178e-11*V062*V072 + 4.2253935331163418e-11*V01*V02*V073 - 
      6.00164403998919045e-12*V05*V073 - 7.35154270081124595e-10*V014*V023*V08 + 
      1.36064413237870857e-10*V026*V08 - 5.75792364547340222e-10*V015*V02*V03*V08 + 
      5.14862181924762414e-9*V01*V024*V03*V08 + 1.37457019311333921e-8*V012*V022*V032*V08 + 
      2.37349856114670404e-9*V013*V033*V08 - 2.16635350918576091e-9*V02*V034*V08 - 
      4.14629276727844225e-11*V016*V04*V08 + 6.17172074238420181e-9*V012*V023*V04*V08 + 
      9.97039015032322844e-9*V013*V02*V03*V04*V08 - 8.53399623295600594e-9*V022*V032*V04*V08 - 
      5.16890231327213456e-9*V01*V033*V04*V08 + 6.45684343456755518e-10*V014*V042*V08 - 
      1.71461107248036818e-9*V023*V042*V08 - 1.04943045204417926e-8*V01*V02*V03*V042*V08 - 
      1.03645064374222073e-9*V012*V043*V08 + 1.36661593658713027e-10*V044*V08 + 
      2.82017506202823854e-9*V013*V022*V05*V08 + 1.04117352450820565e-9*V014*V03*V05*V08 - 
      3.17341019365007678e-9*V023*V03*V05*V08 - 8.94100733202998584e-9*V01*V02*V032*V05*V08 - 
      5.94072564741481163e-9*V01*V022*V04*V05*V08 - 5.19856938577017285e-9*V012*V03*V04*V05*V08 + 
      1.44496123662651443e-9*V03*V042*V05*V08 - 1.50089626953262736e-9*V012*V02*V052*V08 + 
      6.22975547569562934e-10*V032*V052*V08 + 8.30479860600869428e-10*V02*V04*V052*V08 + 
      1.47645429692195384e-10*V01*V053*V08 + 4.98080323050083682e-10*V014*V02*V06*V08 - 
      3.39306898612751522e-10*V024*V06*V08 - 4.23790767418172289e-9*V01*V022*V03*V06*V08 - 
      1.82041666175492764e-9*V012*V032*V06*V08 - 2.5170466032238677e-9*V012*V02*V04*V06*V08 + 
      1.03627799478401073e-9*V032*V04*V06*V08 + 6.76107766667069964e-10*V02*V042*V06*V08 - 
      3.93053587082477803e-10*V013*V05*V06*V08 + 1.19603345297181466e-9*V02*V03*V05*V06*V08 + 
      7.39314927968770367e-10*V01*V04*V05*V06*V08 + 1.38685241610305423e-10*V022*V062*V08 + 
      2.63216266739460886e-10*V01*V03*V062*V08 - 5.97685901741455127e-12*V063*V08 + 
      2.84171068671405223e-11*V015*V07*V08 - 5.74870667308410316e-10*V01*V023*V07*V08 - 
      1.53994277202974889e-9*V012*V02*V03*V07*V08 + 2.17239850847743862e-10*V033*V07*V08 - 
      2.87942096311750344e-10*V013*V04*V07*V08 + 8.72628179962686229e-10*V02*V03*V04*V07*V08 + 
      2.70622355331621154e-10*V01*V042*V07*V08 + 2.48549334649299092e-10*V022*V05*V07*V08 + 
      4.61650946365056781e-10*V01*V03*V05*V07*V08 + 2.23446917972226198e-10*V01*V02*V06*V07*V08 - 
      3.17268330207259314e-11*V05*V06*V07*V08 + 2.07331873524847868e-11*V012*V072*V08 - 
      1.16187132998922594e-11*V04*V072*V08 - 1.42431959775928683e-10*V012*V022*V082 - 
      7.68644377918929679e-11*V013*V03*V082 + 1.21778641118872184e-10*V02*V032*V082 + 
      7.84460664087754784e-11*V022*V04*V082 + 1.49415686061474116e-10*V01*V03*V04*V082 + 
      8.66242901321840204e-11*V01*V02*V05*V082 - 6.16060965419676862e-12*V052*V082 + 
      1.83448453918262831e-11*V012*V06*V082 - 1.02004709800498674e-11*V04*V06*V082 - 
      6.49118474262601466e-12*V03*V07*V082 - 8.08599383298439738e-13*V02*V083 - 
      8.50977060745507598e-11*V015*V022*V09 + 3.04628299402442197e-10*V01*V025*V09 - 
      1.76313882991729569e-11*V016*V03*V09 + 2.9372440748394431e-9*V012*V023*V03*V09 + 
      2.33562886383595467e-9*V013*V02*V032*V09 - 1.42777583671319421e-9*V022*V033*V09 - 
      6.32132575155134399e-10*V01*V034*V09 + 1.62751893431331275e-9*V013*V022*V04*V09 + 
      5.99092792405409933e-10*V014*V03*V04*V09 - 1.81213329742511883e-9*V023*V03*V04*V09 - 
      5.18188038049620332e-9*V01*V02*V032*V04*V09 - 1.70891156100274428e-9*V01*V022*V042*V09 - 
      1.51114982455198454e-9*V012*V03*V042*V09 + 2.79057038501507986e-10*V03*V043*V09 + 
      3.40712895895715053e-10*V014*V02*V05*V09 - 2.46769809181573898e-10*V024*V05*V09 - 
      2.95287771491705013e-9*V01*V022*V03*V05*V09 - 1.26043557682878922e-9*V012*V032*V05*V09 - 
      1.7424144888868091e-9*V012*V02*V04*V05*V09 + 7.24489737645632959e-10*V032*V04*V05*V09 + 
      4.7950747324922868e-10*V02*V042*V05*V09 - 1.35725551914962019e-10*V013*V052*V09 + 
      4.18954689478680718e-10*V02*V03*V052*V09 + 2.57914691933666174e-10*V01*V04*V052*V09 + 
      2.24476298070442001e-11*V015*V06*V09 - 4.55134757164848017e-10*V01*V023*V06*V09 - 
      1.22291026612467966e-9*V012*V02*V03*V06*V09 + 1.7258996461164631e-10*V033*V06*V09 - 
      2.28761566089720646e-10*V013*V04*V06*V09 + 6.92151443527869975e-10*V02*V03*V04*V06*V09 + 
      2.14919704029951069e-10*V01*V042*V06*V09 + 1.96946368925808796e-10*V022*V05*V06*V09 + 
      3.66889162191042186e-10*V01*V03*V05*V06*V09 + 8.87118400372520684e-11*V01*V02*V062*V09 - 
      1.25997636002352934e-11*V05*V062*V09 - 2.55532122476566379e-10*V012*V022*V07*V09 - 
      1.37960292880996678e-10*V013*V03*V07*V09 + 2.19627954296440864e-10*V02*V032*V07*V09 + 
      1.43081975173106543e-10*V022*V04*V07*V09 + 2.68983581686812141e-10*V01*V03*V04*V07*V09 + 
      1.56072852427624416e-10*V01*V02*V05*V07*V09 - 1.11073735200707149e-11*V052*V07*V09 + 
      3.29717536236600114e-11*V012*V06*V07*V09 - 1.84529804458333143e-11*V04*V06*V07*V09 - 
      5.8503001373335711e-12*V03*V072*V09 - 5.17561968317334986e-11*V013*V02*V08*V09 + 
      8.0649042247388488e-11*V022*V03*V08*V09 + 7.39597998211291722e-11*V01*V032*V08*V09 + 
      1.00611239217036138e-10*V01*V02*V04*V08*V09 + 2.54896286156840285e-11*V012*V05*V08*V09 - 
      1.43417788640921348e-11*V04*V05*V08*V09 - 1.03161068685397302e-11*V03*V06*V08*V09 - 
      4.39076407601100194e-12*V02*V07*V08*V09 - 7.64262708926076255e-13*V01*V082*V09 - 
      1.64301507843724227e-12*V014*V092 + 4.35126481161723717e-12*V023*V092 + 
      2.50632734694209118e-11*V01*V02*V03*V092 + 7.44187477585637925e-12*V012*V04*V092 - 
      2.08452198348972177e-12*V042*V092 - 3.60983922172055736e-12*V03*V05*V092 - 
      1.74290785666765095e-12*V02*V06*V092 - 6.88168070545415153e-13*V01*V07*V092 - 
      4.62225768329569499e-12*V016*V02*V10 + 2.10055716704762471e-10*V012*V024*V10 + 
      6.88054777534822111e-10*V013*V022*V03*V10 + 1.25603147587937483e-10*V014*V032*V10 - 
      4.17193941583865808e-10*V023*V032*V10 - 7.69547846416703342e-10*V01*V02*V033*V10 + 
      1.77396109070359545e-10*V014*V02*V04*V10 - 1.22707896049382729e-10*V024*V04*V10 - 
      1.54580578198860123e-9*V01*V022*V03*V04*V10 - 6.65286737270804129e-10*V012*V032*V04*V10 - 
      4.59487775884533935e-10*V012*V02*V042*V10 + 1.9069364260462636e-10*V032*V042*V10 + 
      8.26569288746720253e-11*V02*V043*V10 + 1.3878610764642224e-11*V015*V05*V10 - 
      2.88522259469541449e-10*V01*V023*V05*V10 - 7.68673032968939211e-10*V012*V02*V03*V05*V10 + 
      1.09219894475263005e-10*V033*V05*V10 - 1.4339992201261797e-10*V013*V04*V05*V10 + 
      4.39622301634039777e-10*V02*V03*V04*V05*V10 + 1.36061191625661983e-10*V01*V042*V05*V10 + 
      6.26805369561973959e-11*V022*V052*V10 + 1.15931529500259652e-10*V01*V03*V052*V10 - 
      1.84361690446033944e-10*V012*V022*V06*V10 - 9.94777426884189774e-11*V013*V03*V06*V10 + 
      1.57952539687302153e-10*V02*V032*V06*V10 + 1.01636822911617773e-10*V022*V04*V06*V10 + 
      1.93856767980880931e-10*V01*V03*V04*V06*V10 + 1.12362998927409006e-10*V01*V02*V05*V06*V10 - 
      7.99681409737515064e-12*V052*V06*V10 + 1.19019576481725833e-11*V012*V062*V10 - 
      6.6188898182145276e-12*V04*V062*V10 - 4.21544740054389746e-11*V013*V02*V07*V10 + 
      6.59349710921910917e-11*V022*V03*V07*V10 + 6.0366896315075862e-11*V01*V032*V07*V10 + 
      8.2178251812432052e-11*V01*V02*V04*V07*V10 + 2.07973663538860204e-11*V012*V05*V07*V10 - 
      1.17191046172199895e-11*V04*V05*V07*V10 - 8.42784231988716758e-12*V03*V06*V07*V10 - 
      1.79456129125924123e-12*V02*V072*V10 - 2.98175992258485331e-12*V014*V08*V10 + 
      7.80139595339535172e-12*V023*V08*V10 + 4.54567760157179871e-11*V01*V02*V03*V08*V10 + 
      1.35137765018882454e-11*V012*V04*V08*V10 - 3.7662573011057891e-12*V042*V08*V10 - 
      6.54436921465917419e-12*V03*V05*V08*V10 - 3.14842445842757806e-12*V02*V06*V08*V10 - 
      1.24834023220356032e-12*V01*V07*V08*V10 + 7.58457149592909557e-12*V01*V022*V09*V10 + 
      6.61959784733087023e-12*V012*V03*V09*V10 - 3.81451074325811585e-12*V03*V04*V09*V10 - 
      2.21668527268540445e-12*V02*V05*V09*V10 - 9.92796652435151234e-13*V01*V06*V09*V10 + 
      1.04283059959667998e-14*V092*V10 + 1.02375643064170076e-12*V012*V02*V102 - 
      4.34442917246633889e-13*V032*V102 - 5.81222524485248035e-13*V02*V04*V102 - 
      3.1446474236005332e-13*V01*V05*V102 + 9.44582682284715888e-15*V08*V102 - 
      9.3222003696719899e-14*V017*V11 + 6.12666476081012217e-11*V013*V023*V11 + 
      6.76955440237534874e-11*V014*V02*V03*V11 - 5.42203183875842145e-11*V024*V03*V11 - 
      3.17539260827802005e-10*V01*V022*V032*V11 - 8.91832034059885633e-11*V012*V033*V11 + 
      6.57226223919458231e-12*V015*V04*V11 - 1.37403786372382197e-10*V01*V023*V04*V11 - 
      3.71031403009845362e-10*V012*V02*V03*V04*V11 + 5.28521255406003329e-11*V033*V04*V11 - 
      3.46908330210094506e-11*V013*V042*V11 + 1.0563382833473224e-10*V02*V03*V042*V11 + 
      2.19130439912233479e-11*V01*V043*V11 - 1.06029520363668362e-10*V012*V022*V05*V11 - 
      5.70864550847669276e-11*V013*V03*V05*V11 + 9.18692282914882692e-11*V02*V032*V05*V11 + 
      5.99780132436198432e-11*V022*V04*V05*V11 + 1.12355393626640223e-10*V01*V03*V04*V05*V11 + 
      3.26081158947309791e-11*V01*V02*V052*V11 - 1.55102554111744242e-12*V053*V11 - 
      2.78352412592487337e-11*V013*V02*V06*V11 + 4.34233314864072005e-11*V022*V03*V06*V11 + 
      3.9900219701852198e-11*V01*V032*V06*V11 + 5.42274939330945657e-11*V01*V02*V04*V06*V11 + 
      1.37521919021622801e-11*V012*V05*V06*V11 - 7.73507630461656551e-12*V04*V05*V06*V11 - 
      2.78315638096537635e-12*V03*V062*V11 - 2.22320717375796222e-12*V014*V07*V11 + 
      5.91223051814089438e-12*V023*V07*V11 + 3.40224515494449457e-11*V01*V02*V03*V07*V11 + 
      1.00987213690088394e-11*V012*V04*V07*V11 - 2.831446579732376e-12*V042*V07*V11 - 
      4.90239865640390091e-12*V03*V05*V07*V11 - 2.36770398504686622e-12*V02*V06*V07*V11 - 
      4.6728033142998948e-13*V01*V072*V11 + 6.30256262614238701e-12*V01*V022*V08*V11 + 
      5.50477420372722586e-12*V012*V03*V08*V11 - 3.17047326932478175e-12*V03*V04*V08*V11 - 
      1.84195802305630204e-12*V02*V05*V08*V11 - 8.25436857531729495e-13*V01*V06*V08*V11 + 
      1.87513090029284766e-12*V012*V02*V09*V11 - 7.96677217510591365e-13*V032*V09*V11 - 
      1.06942940642916119e-12*V02*V04*V09*V11 - 5.76514283863079468e-13*V01*V05*V09*V11 + 1.73378815765002234e-14*V08*V09*V11 + 
      1.57617748318863376e-13*V013*V10*V11 - 4.91156026791636878e-13*V02*V03*V10*V11 - 
      3.05682548270651004e-13*V01*V04*V10*V11 + 1.41698573630039782e-14*V07*V10*V11 - 
      3.41155936015299704e-14*V022*V112 - 6.33727158852221694e-14*V01*V03*V112 + 
      4.68392629563206402e-15*V06*V112 + 8.33365870547135597e-12*V014*V022*V12 - 
      2.42284263957588348e-12*V025*V12 + 2.28393909056963753e-12*V015*V03*V12 - 
      5.27138236407577518e-11*V01*V023*V03*V12 - 6.89414642803365036e-11*V012*V02*V032*V12 + 
      5.04512957420392336e-12*V034*V12 - 4.71898197491503617e-11*V012*V022*V04*V12 - 
      2.54655447170499812e-11*V013*V03*V04*V12 + 4.08443206688732217e-11*V02*V032*V04*V12 + 
      1.30807655878756663e-11*V022*V042*V12 + 2.50962918273578771e-11*V01*V03*V042*V12 - 
      1.47260301929318597e-11*V013*V02*V05*V12 + 2.336109331956536e-11*V022*V03*V05*V12 + 
      2.1313341965054303e-11*V01*V032*V05*V12 + 2.90546005596401007e-11*V01*V02*V04*V05*V12 + 
      3.66632963859994052e-12*V012*V052*V12 - 2.07702023754800014e-12*V04*V052*V12 - 
      1.35280078400600651e-12*V014*V06*V12 + 3.54899056870801882e-12*V023*V06*V12 + 
      2.07277037926471394e-11*V01*V02*V03*V06*V12 + 6.16371813226697242e-12*V012*V04*V06*V12 - 
      1.71758022428398171e-12*V042*V06*V12 - 2.9866055130156944e-12*V03*V05*V06*V12 - 
      7.17900922943567351e-13*V02*V062*V12 + 4.35453524384673569e-12*V01*V022*V07*V12 + 
      3.79646612573851643e-12*V012*V03*V07*V12 - 2.19063924301719898e-12*V03*V04*V07*V12 - 
      1.2733722261507823e-12*V02*V05*V07*V12 - 5.69987681594097395e-13*V01*V06*V07*V12 + 
      1.43918328377225742e-12*V012*V02*V08*V12 - 6.10787246625266118e-13*V032*V08*V12 - 
      8.16870940089851135e-13*V02*V04*V08*V12 - 4.42124983472621766e-13*V01*V05*V08*V12 + 
      6.63911307079913218e-15*V082*V12 + 1.33206708719863722e-13*V013*V09*V12 - 
      4.1536730485126651e-13*V02*V03*V09*V12 - 2.58454105653264138e-13*V01*V04*V09*V12 + 1.19807996847481632e-14*V07*V09*V12 - 
      6.27204475261856285e-14*V022*V10*V12 - 1.16911852920432403e-13*V01*V03*V10*V12 + 
      8.63039588272299124e-15*V06*V10*V12 - 3.32890966157486106e-14*V01*V02*V11*V12 + 5.03461684630547786e-15*V05*V11*V12 - 
      1.90638852522379706e-15*V012*V122 + 1.12720530030948256e-15*V04*V122 + 
      5.1660527048598944e-13*V015*V02*V13 - 2.95501982360216111e-12*V01*V024*V13 - 
      1.63029636084274865e-11*V012*V022*V03*V13 - 4.33112798741864457e-12*V013*V032*V13 + 
      4.86142020009076464e-12*V02*V033*V13 - 6.09634509221649093e-12*V013*V02*V04*V13 + 
      9.5939290837826703e-12*V022*V03*V04*V13 + 8.8567416679761702e-12*V01*V032*V04*V13 + 
      6.00367802922400712e-12*V01*V02*V042*V13 - 6.63050347411283497e-13*V014*V05*V13 + 
      1.79722614409188059e-12*V023*V05*V13 + 1.02973013911991893e-11*V01*V02*V03*V05*V13 + 
      3.05120322229944382e-12*V012*V04*V05*V13 - 8.60120558745828219e-13*V042*V05*V13 - 
      7.43964154628784579e-13*V03*V052*V13 + 2.46006945517001994e-12*V01*V022*V06*V13 + 
      2.15126479138368802e-12*V012*V03*V06*V13 - 1.23915903311821046e-12*V03*V04*V06*V13 - 
      7.19560638782095533e-13*V02*V05*V06*V13 - 1.6141143197692674e-13*V01*V062*V13 + 
      9.21353951340793197e-13*V012*V02*V07*V13 - 3.91837733769804848e-13*V032*V07*V13 - 
      5.26200783482104312e-13*V02*V04*V07*V13 - 2.83503923804952085e-13*V01*V05*V07*V13 + 
      9.49076370339617934e-14*V013*V08*V13 - 2.95642191097327827e-13*V02*V03*V08*V13 - 
      1.84053848271840166e-13*V01*V04*V08*V13 + 8.52840996078281124e-15*V07*V08*V13 - 
      4.94189778982346936e-14*V022*V09*V13 - 9.17846986619673058e-14*V01*V03*V09*V13 + 
      6.78246713863473319e-15*V06*V09*V13 - 2.85107866708969911e-14*V01*V02*V10*V13 + 4.31115767533966442e-15*V05*V10*V13 - 
      3.53958913706548344e-15*V012*V11*V13 + 2.0953977529960337e-15*V04*V11*V13 + 8.12348509384368895e-16*V03*V12*V13 + 
      9.91934982586311262e-17*V02*V132 + 1.16527504620899874e-14*V016*V14 - 
      1.18270772978072684e-12*V012*V023*V14 - 1.93186699753212665e-12*V013*V02*V03*V14 + 
      1.61434358577918168e-12*V022*V032*V14 + 9.69279177494868392e-13*V01*V033*V14 - 
      2.55689210411098451e-13*V014*V04*V14 + 6.77129129994328435e-13*V023*V04*V14 + 
      3.9832343084325807e-12*V01*V02*V03*V04*V14 + 5.92744222168406489e-13*V012*V042*V14 - 
      1.10326633806913225e-13*V043*V14 + 1.14366613940136318e-12*V01*V022*V05*V14 + 
      9.93939280198426234e-13*V012*V03*V05*V14 - 5.76640661733708373e-13*V03*V04*V05*V14 - 
      1.67705121975493764e-13*V02*V052*V14 + 4.87373576973145381e-13*V012*V02*V06*V14 - 
      2.07039304650626256e-13*V032*V06*V14 - 2.76544423968569762e-13*V02*V04*V06*V14 - 
      1.49888816630556507e-13*V01*V05*V06*V14 + 5.66886010210439433e-14*V013*V07*V14 - 
      1.7712846891103538e-13*V02*V03*V07*V14 - 1.10167768454567253e-13*V01*V04*V07*V14 + 
      2.55327618906084782e-15*V072*V14 - 3.27099271262744115e-14*V022*V08*V14 - 
      6.10165550339409747e-14*V01*V03*V08*V14 + 4.5008161434460858e-15*V06*V08*V14 - 2.08923848928948841e-14*V01*V02*V09*V14 + 
      3.15847824670863287e-15*V05*V09*V14 - 2.83008551897952341e-15*V012*V10*V14 + 
      1.67265861727876768e-15*V04*V10*V14 + 7.03869511170910609e-16*V03*V11*V14 + 1.8493620106918799e-16*V02*V12*V14 + 
      4.17805191735717951e-17*V01*V13*V14 - 2.00317535660986066e-13*V013*V022*V15 - 
      7.50589122155926795e-14*V014*V03*V15 + 2.18639136850132944e-13*V023*V03*V15 + 
      6.16202946452876259e-13*V01*V02*V032*V15 + 4.12907844209658433e-13*V01*V022*V04*V15 + 
      3.62269660379654355e-13*V012*V03*V04*V15 - 1.04682301101607333e-13*V03*V042*V15 + 
      2.11196602600547796e-13*V012*V02*V05*V15 - 9.02564643809443884e-14*V032*V05*V15 - 
      1.21387582752822401e-13*V02*V04*V05*V15 - 3.26248396940879228e-14*V01*V052*V15 + 
      2.81285788975302985e-14*V013*V06*V15 - 8.7663472662365173e-14*V02*V03*V06*V15 - 
      5.46101692692696134e-14*V01*V04*V06*V15 - 1.84498690677128981e-14*V022*V07*V15 - 
      3.42392401651051056e-14*V01*V03*V07*V15 + 2.52944968389254273e-15*V06*V07*V15 - 1.3019213777381947e-14*V01*V02*V08*V15 + 
      1.96723903639933734e-15*V05*V08*V15 - 1.9436240533962762e-15*V012*V09*V15 + 1.15013409053837597e-15*V04*V09*V15 + 
      5.2734350937139453e-16*V03*V10*V15 + 1.50381675526854445e-16*V02*V11*V15 + 3.65519835025927311e-17*V01*V12*V15 - 
      8.83988270529478617e-20*V152 - 1.4692598408722158e-14*V014*V02*V16 + 
      1.00467510764578888e-14*V024*V16 + 1.21270823444477616e-13*V01*V022*V03*V16 + 
      5.2007965048919046e-14*V012*V032*V16 + 7.23939687966379124e-14*V012*V02*V04*V16 - 
      3.09321632711715506e-14*V032*V04*V16 - 2.05848535483716615e-14*V02*V042*V16 + 
      1.1446357787627015e-14*V013*V05*V16 - 3.6063358079001518e-14*V02*V03*V05*V16 - 
      2.23978727706109381e-14*V01*V04*V05*V16 - 8.55537298052745423e-15*V022*V06*V16 - 
      1.59914553906222964e-14*V01*V03*V06*V16 + 5.8911944963537396e-16*V062*V16 - 
      6.88193396392344736e-15*V01*V02*V07*V16 + 1.03972318572288697e-15*V05*V07*V16 - 
      1.14115993049880796e-15*V012*V08*V16 + 6.73632318508629738e-16*V04*V08*V16 + 
      3.40989021759908309e-16*V03*V09*V16 + 1.05937427597508265e-16*V02*V10*V16 + 2.79481866813596067e-17*V01*V11*V16 - 
      1.66344478883764259e-19*V14*V16 - 3.79980993329021327e-16*V015*V17 + 
      7.36524799199137543e-15*V01*V023*V17 + 1.96814070692863565e-14*V012*V02*V03*V17 - 
      2.86772041805499679e-15*V033*V17 + 3.71582207087582245e-15*V013*V04*V17 - 
      1.16336933717389292e-14*V02*V03*V04*V17 - 3.62979608289536128e-15*V01*V042*V17 - 
      3.34647903749892908e-15*V022*V05*V17 - 6.1918064419508808e-15*V01*V03*V05*V17 - 
      3.0341144843651029e-15*V01*V02*V06*V17 + 4.58150065966977901e-16*V05*V06*V17 - 
      5.69230124960251162e-16*V012*V07*V17 + 3.3677539849001866e-16*V04*V07*V17 + 1.88920650517688056e-16*V03*V08*V17 + 
      6.47852073697767715e-17*V02*V09*V17 + 1.86209967121073254e-17*V01*V10*V17 - 1.38664824592745756e-19*V13*V17 + 
      1.74565077768653965e-15*V012*V022*V18 + 9.44825755634780809e-16*V013*V03*V18 - 
      1.54469996589992834e-15*V02*V032*V18 - 1.01421943749410083e-15*V022*V04*V18 - 
      1.90615868087687968e-15*V01*V03*V04*V18 - 1.11552879428252454e-15*V01*V02*V05*V18 + 
      8.43223181731107831e-17*V052*V18 - 2.38359130004794202e-16*V012*V06*V18 + 
      1.40467719441213164e-16*V04*V06*V18 + 8.94058719652069809e-17*V03*V07*V18 + 3.39691929363352318e-17*V02*V08*V18 + 
      1.07779951318553318e-17*V01*V09*V18 - 1.02131993941341098e-19*V12*V18 + 1.61341136056370167e-16*V013*V02*V19 - 
      2.59473573145277141e-16*V022*V03*V19 - 2.37076650272753382e-16*V01*V032*V19 - 
      3.25438905452792616e-16*V01*V02*V04*V19 - 8.29904003397506788e-17*V012*V05*V19 + 
      4.92415784877586569e-17*V04*V05*V19 + 3.55143593439512367e-17*V03*V06*V19 + 1.53052497815427429e-17*V02*V07*V19 + 
      5.38066674451987935e-18*V01*V08*V19 - 6.64131476204616085e-20*V11*V19 + 4.97594157930861262e-18*V014*V20 - 
      1.34965534226653519e-17*V023*V20 - 7.75926166712871152e-17*V01*V02*V03*V20 - 
      2.32055034065351869e-17*V012*V04*V20 + 6.83621748435512729e-18*V042*V20 + 
      1.18401684109242573e-17*V03*V05*V20 + 5.78015662484870134e-18*V02*V06*V20 + 2.30528866907063254e-18*V01*V07*V20 - 
      3.79243209654162573e-20*V10*V20 - 5.9769937993883756e-18*V01*V022*V21 - 
      5.2077054126883067e-18*V012*V03*V21 + 3.15194608845466797e-18*V03*V04*V21 + 1.84692682269380383e-18*V02*V05*V21 + 
      8.34390722322771706e-19*V01*V06*V21 - 1.89751778911841376e-20*V09*V21 - 7.83250063409689024e-19*V012*V02*V22 + 
      3.46074774869989855e-19*V032*V22 + 4.68200908183354995e-19*V02*V04*V22 + 2.53974362136750028e-19*V01*V05*V22 - 
      8.23762590979865995e-21*V08*V22 - 3.07156887611642754e-20*V013*V23 + 9.94689226039114265e-20*V02*V03*V23 + 
      6.22511044721301555e-20*V01*V04*V23 - 3.09377063399124523e-21*V07*V23 + 6.74589703638611015e-21*V022*V24 + 
      1.25082180204358784e-20*V01*V03*V24 - 9.85532121773120632e-22*V06*V24 + 1.67299401951482535e-21*V01*V02*V25 - 
      2.66531100293169882e-22*V05*V25 + 9.38802399439973936e-23*V012*V26 - 5.80778832054980291e-23*V04*V26 - 
      1.05670272834675864e-23*V03*V27 - 1.26830211118165765e-24*V02*V28 - 1.35889511912320462e-25*V01*V29 + 
      7.35332856668400769e-29*V32) + delta4*eps14*
    (-1.23083020897627674e-9*V026*V032 - 1.65720926455890215e-8*V01*V024*V033 - 
      2.27414063075033116e-8*V012*V022*V034 - 2.33881814428872433e-9*V013*V035 + 
      5.22454832312341654e-9*V02*V036 - 1.97753534590218582e-12*V027*V04 - 
      9.86598382550702319e-9*V01*V025*V03*V04 - 5.48376340540336987e-8*V012*V023*V032*V04 - 
      2.99539857915443774e-8*V013*V02*V033*V04 + 4.74911610452370361e-8*V022*V034*V04 + 
      1.76096755706160509e-8*V01*V035*V04 - 8.10430070227350799e-9*V012*V024*V042 - 
      2.86021258085385271e-8*V013*V022*V03*V042 - 
      5.28412388659160065e-9*V014*V032*V042 + 
      5.26904219089508856e-8*V023*V032*V042 + 
      1.10595294450472584e-7*V01*V02*V033*V042 - 2.30072831001908773e-9*V014*V02*V043 + 
      3.46651613447685113e-9*V024*V043 + 6.53121766150544046e-8*V01*V022*V03*V043 + 
      3.10088733561170214e-8*V012*V032*V043 + 9.77896255642706859e-9*V012*V02*V044 - 
      6.3327266710902895e-9*V032*V044 - 1.3675698718070872e-9*V02*V045 - 
      7.38498125385766041e-10*V01*V026*V05 - 1.37946918550321735e-8*V012*V024*V03*V05 - 
      2.3134408182248895e-8*V013*V022*V032*V05 - 2.78677748352112981e-9*V014*V033*V05 + 
      3.29951922095088513e-8*V023*V033*V05 + 4.76056823797601118e-8*V01*V02*V034*V05 - 
      9.79047533707409354e-9*V013*V023*V04*V05 - 1.09337137973024284e-8*V014*V02*V03*V04*V05 + 
      2.60259872774085781e-8*V024*V03*V04*V05 + 1.75569565323015808e-7*V01*V022*V032*V04*V05 + 
      5.21435011337984776e-8*V012*V033*V04*V05 - 4.89598290552782364e-10*V015*V042*V05 + 
      3.2934948266341763e-8*V01*V023*V042*V05 + 9.99676649873531407e-8*V012*V02*V03*V042*V05 - 
      2.26197059557923488e-8*V033*V042*V05 + 6.06447005308406843e-9*V013*V043*V05 - 
      2.71059106497756439e-8*V02*V03*V043*V05 - 4.17960800511999671e-9*V01*V044*V05 - 
      1.41095727179438807e-9*V014*V022*V052 + 1.26228757571918856e-9*V025*V052 - 
      3.82662489845915117e-10*V015*V03*V052 + 3.05989667212234895e-8*V01*V023*V03*V052 + 
      4.23893789175455697e-8*V012*V02*V032*V052 - 4.9435814437887819e-9*V034*V052 + 
      2.6567303227109088e-8*V012*V022*V04*V052 + 
      1.50401722679105051e-8*V013*V03*V04*V052 - 3.69827762972224178e-8*V02*V032*V04*V052 - 
      1.0710174761278686e-8*V022*V042*V052 - 2.21611076812180129e-8*V01*V03*V042*V052 + 
      2.72604272119853197e-9*V013*V02*V053 - 6.64348520102057389e-9*V022*V03*V053 - 
      6.3987666726280336e-9*V01*V032*V053 - 8.06829384769643841e-9*V01*V02*V04*V053 - 
      5.06918781251540621e-10*V012*V054 + 3.43957776882379446e-10*V04*V054 - 
      1.11189530071841464e-9*V012*V025*V06 - 6.37536715735813357e-9*V013*V023*V03*V06 - 
      3.48080095767883115e-9*V014*V02*V032*V06 + 9.56109781009974108e-9*V024*V032*V06 + 
      4.087558058540725e-8*V01*V022*V033*V06 + 8.90129195979451267e-9*V012*V034*V06 - 
      2.27155513926426604e-9*V014*V022*V04*V06 + 1.45481257294304808e-9*V025*V04*V06 - 
      6.16103852503035714e-10*V015*V03*V04*V06 + 4.76001329783781991e-8*V01*V023*V03*V04*V06 + 
      6.88068829020047773e-8*V012*V02*V032*V04*V06 - 8.03810866830133342e-9*V034*V04*V06 + 
      2.14680994036823617e-8*V012*V022*V042*V06 + 
      1.23355233214193484e-8*V013*V03*V042*V06 - 2.94042865508187802e-8*V02*V032*V042*V06 - 
      5.19095959248134237e-9*V022*V043*V06 - 1.19392081038589253e-8*V01*V03*V043*V06 - 
      3.18230449643242587e-10*V015*V02*V05*V06 + 5.96608248739836308e-9*V01*V024*V05*V06 + 
      3.67884464104577234e-8*V012*V022*V03*V05*V06 + 1.01775912042126525e-8*V013*V032*V05*V06 - 
      1.76004767716552408e-8*V02*V033*V05*V06 + 1.33895162200711009e-8*V013*V02*V04*V05*V06 - 
      3.12359714763980088e-8*V022*V03*V04*V05*V06 - 3.13076733649312107e-8*V01*V032*V04*V05*V06 - 
      1.93308686409280644e-8*V01*V02*V042*V05*V06 + 7.05544034747197757e-10*V014*V052*V06 - 
      2.72265358892293609e-9*V023*V052*V06 - 1.71741819914063159e-8*V01*V02*V03*V052*V06 - 
      4.98155510493677834e-9*V012*V04*V052*V06 + 1.65905201265862902e-9*V042*V052*V06 + 
      9.88056106856857375e-10*V03*V053*V06 - 7.04307035072162761e-12*V016*V062 + 
      2.6076548409405678e-9*V012*V023*V062 + 4.53428072823133368e-9*V013*V02*V03*V062 - 
      5.65657673726306991e-9*V022*V032*V062 - 3.6728840586847907e-9*V01*V033*V062 + 
      5.8011973742157058e-10*V014*V04*V062 - 1.95805686285051041e-9*V023*V04*V062 - 
      1.38213527009044916e-8*V01*V02*V03*V04*V062 - 2.03895922901186537e-9*V012*V042*V062 + 
      4.3349519478626339e-10*V043*V062 - 3.70525792482090506e-9*V01*V022*V05*V062 - 
      3.48158803071492217e-9*V012*V03*V05*V062 + 2.39620528927537535e-9*V03*V04*V05*V062 + 
      6.56938698937138254e-10*V02*V052*V062 - 5.23054073706164849e-10*V012*V02*V063 + 
      2.87265719003188194e-10*V032*V063 + 3.41513030907064747e-10*V02*V04*V063 + 
      1.94196130726893642e-10*V01*V05*V063 - 5.50205181096965808e-10*V013*V024*V07 - 
      1.2113898258519667e-9*V014*V022*V03*V07 + 1.24834810137028935e-9*V025*V03*V07 - 
      1.62298916550251587e-10*V015*V032*V07 + 1.49640561846129793e-8*V01*V023*V032*V07 + 
      1.36513310355933784e-8*V012*V02*V033*V07 - 1.00363995743917084e-9*V035*V07 - 
      2.14598606209910819e-10*V015*V02*V04*V07 + 4.01491721564693395e-9*V01*V024*V04*V07 + 
      2.57861546773648022e-8*V012*V022*V03*V04*V07 + 7.20677428257744977e-9*V013*V032*V04*V07 - 
      1.25587919031859e-8*V02*V033*V04*V07 + 4.72935795429197701e-9*V013*V02*V042*V07 - 
      1.09807351357235457e-8*V022*V03*V042*V07 - 1.12154350801135205e-8*V01*V032*V042*V07 - 
      4.56332362184435567e-9*V01*V02*V043*V07 - 1.18007218965292253e-11*V016*V05*V07 + 
      4.5168996730885781e-9*V012*V023*V05*V07 + 7.8262642721709172e-9*V013*V02*V03*V05*V07 - 
      1.01558580334969456e-8*V022*V032*V05*V07 - 6.45426015987889039e-9*V01*V033*V05*V07 + 
      9.98968803303268848e-10*V014*V04*V05*V07 - 3.79460026050486257e-9*V023*V04*V05*V07 - 
      2.45077031426954608e-8*V01*V02*V03*V04*V05*V07 - 3.57066855453061759e-9*V012*V042*V05*V07 + 
      7.91779633111647078e-10*V043*V05*V07 - 3.31076782433456615e-9*V01*V022*V052*V07 - 
      3.04706419956226199e-9*V012*V03*V052*V07 + 2.13434882718075157e-9*V03*V04*V052*V07 + 
      3.92347012426840491e-10*V02*V053*V07 + 1.72580697566399282e-9*V013*V022*V06*V07 + 
      6.67195213594540565e-10*V014*V03*V06*V07 - 2.78517517133533836e-9*V023*V03*V06*V07 - 
      8.67160195090646296e-9*V01*V02*V032*V06*V07 - 5.2280941150228981e-9*V01*V022*V04*V06*V07 - 
      4.99569214617229949e-9*V012*V03*V04*V06*V07 + 1.7194966872332067e-9*V03*V042*V06*V07 - 
      2.7497146324773924e-9*V012*V02*V05*V06*V07 + 1.53021795231366437e-9*V032*V05*V06*V07 + 
      1.87657245644626741e-9*V02*V04*V05*V06*V07 + 5.15665798155523937e-10*V01*V052*V06*V07 - 
      1.78001582169589989e-10*V013*V062*V07 + 6.80355686229752422e-10*V02*V03*V062*V07 + 
      4.19124557024304363e-10*V01*V04*V062*V07 + 1.28362854075079312e-10*V014*V02*V072 - 
      1.23605022006401984e-10*V024*V072 - 1.67242894460050537e-9*V01*V022*V03*V072 - 
      7.61195608246722452e-10*V012*V032*V072 - 
      9.81573740820518966e-10*V012*V02*V04*V072 + 5.51156116660494219e-10*V032*V04*V072 + 
      3.34309627912877796e-10*V02*V042*V072 - 1.54879529755990491e-10*V013*V05*V072 + 
      6.08451106064456907e-10*V02*V03*V05*V072 + 3.71602656457531987e-10*V01*V04*V05*V072 + 
      1.31070900834882877e-10*V022*V06*V072 + 2.64557637863480296e-10*V01*V03*V06*V072 - 
      1.0076637652846212e-11*V062*V072 + 3.51988382581282913e-11*V01*V02*V073 - 
      5.98146550924216446e-12*V05*V073 - 1.20679213142678792e-10*V014*V023*V08 + 
      4.34508373963109502e-11*V026*V08 - 9.7298246786934806e-11*V015*V02*V03*V08 + 
      2.2886637937773482e-9*V01*V024*V03*V08 + 6.77480635260199307e-9*V012*V022*V032*V08 + 
      1.22999280770531757e-9*V013*V033*V08 - 1.73227794476631344e-9*V02*V034*V08 - 
      6.84970867876815344e-12*V016*V04*V08 + 2.7703722060810885e-9*V012*V023*V04*V08 + 
      4.85589699594030352e-9*V013*V02*V03*V04*V08 - 6.23126406017349287e-9*V022*V032*V04*V08 - 
      4.06819537331349929e-9*V01*V033*V04*V08 + 3.1054892691231753e-10*V014*V042*V08 - 
      1.06702161531254501e-9*V023*V042*V08 - 7.62253363251082295e-9*V01*V02*V03*V042*V08 - 
      7.50537523760239793e-10*V012*V043*V08 + 1.20843758095306063e-10*V044*V08 + 
      1.30806078389470818e-9*V013*V022*V05*V08 + 5.04551551066440582e-10*V014*V03*V05*V08 - 
      2.18239900037469672e-9*V023*V03*V05*V08 - 6.7036088977941448e-9*V01*V02*V032*V05*V08 - 
      4.07194747485407657e-9*V01*V022*V04*V05*V08 - 3.84771521604920608e-9*V012*V03*V04*V05*V08 + 
      1.33965937383941864e-9*V03*V042*V05*V08 - 1.0599810065057773e-9*V012*V02*V052*V08 + 
      5.94155029111328308e-10*V032*V052*V08 + 7.32820052850915188e-10*V02*V04*V052*V08 + 
      1.33292503714675831e-10*V01*V053*V08 + 2.25576600204983589e-10*V014*V02*V06*V08 - 
      1.99343495171366373e-10*V024*V06*V08 - 2.91701282451571851e-9*V01*V022*V03*V06*V08 - 
      1.33993551825662362e-9*V012*V032*V06*V08 - 1.72781485683667997e-9*V012*V02*V04*V06*V08 + 
      9.64200365004229906e-10*V032*V04*V06*V08 + 5.70146087770967936e-10*V02*V042*V06*V08 - 
      2.73145873824467593e-10*V013*V05*V06*V08 + 1.06083045210178932e-9*V02*V03*V05*V06*V08 + 
      6.51136598325184319e-10*V01*V04*V05*V06*V08 + 1.11516053855078373e-10*V022*V062*V08 + 
      2.32216172474786105e-10*V01*V03*V062*V08 - 5.84118071787167106e-12*V063*V08 + 
      1.23781467895568879e-11*V015*V07*V08 - 3.61985178875995186e-10*V01*V023*V07*V08 - 
      1.05902815499704187e-9*V012*V02*V03*V07*V08 + 2.04131158294757994e-10*V033*V07*V08 - 
      1.9604526964524142e-10*V013*V04*V07*V08 + 7.58934586265512337e-10*V02*V03*V04*V07*V08 + 
      2.34069625693895776e-10*V01*V042*V07*V08 + 2.05197058801413467e-10*V022*V05*V07*V08 + 
      4.10096368857404071e-10*V01*V03*V05*V07*V08 + 1.84618520403177604e-10*V01*V02*V06*V07*V08 - 
      3.14115442412135748e-11*V05*V06*V07*V08 + 1.71502659130912139e-11*V012*V072*V08 - 
      1.13296476403873147e-11*V04*V072*V08 - 9.03852837416208366e-11*V012*V022*V082 - 
      5.17576908594873142e-11*V013*V03*V082 + 1.067029732811515e-10*V02*V032*V082 + 
      6.18872150443019913e-11*V022*V04*V082 + 1.29771776509316575e-10*V01*V03*V04*V082 + 
      7.17550890769260581e-11*V01*V02*V05*V082 - 6.11719591211462514e-12*V052*V082 + 
      1.51072386032336263e-11*V012*V06*V082 - 9.84661374629752751e-12*V04*V06*V082 - 
      6.37649123886734803e-12*V03*V07*V082 - 7.38987198410308162e-13*V02*V083 - 
      1.27786651067381488e-11*V015*V022*V09 + 1.15571372904575366e-10*V01*V025*V09 - 
      2.70576865729729507e-12*V016*V03*V09 + 1.30515076365257969e-9*V012*V023*V03*V09 + 
      1.10840813246920019e-9*V013*V02*V032*V09 - 1.052782178063311e-9*V022*V033*V09 - 
      4.94831817675165216e-10*V01*V034*V09 + 7.21644868503580076e-10*V013*V022*V04*V09 + 
      2.79543369674906739e-10*V014*V03*V04*V09 - 1.19274516531780409e-9*V023*V03*V04*V09 - 
      3.77603580627585762e-9*V01*V02*V032*V04*V09 - 1.12556830809645511e-9*V01*V022*V042*V09 - 
      1.08974860368980038e-9*V012*V03*V042*V09 + 2.52782192073265841e-10*V03*V043*V09 + 
      1.5200374430611976e-10*V014*V02*V05*V09 - 1.52058710971210249e-10*V024*V05*V09 - 
      2.04194760603183097e-9*V01*V022*V03*V05*V09 - 9.25762037049638174e-10*V012*V032*V05*V09 - 
      1.19511823963564727e-9*V012*V02*V04*V05*V09 + 6.77567852847413353e-10*V032*V04*V05*V09 + 
      4.11985177098247078e-10*V02*V042*V05*V09 - 9.3940996437556709e-11*V013*V052*V09 + 
      3.74205335481882409e-10*V02*V03*V052*V09 + 2.28147777115509968e-10*V01*V04*V052*V09 + 
      9.69401138782525209e-12*V015*V06*V09 - 2.83735239320670168e-10*V01*V023*V06*V09 - 
      8.36251702327767415e-10*V012*V02*V03*V06*V09 + 1.61573427937811628e-10*V033*V06*V09 - 
      1.54995313015193545e-10*V013*V04*V06*V09 + 5.98704974196801246e-10*V02*V03*V04*V06*V09 + 
      1.85020446570367922e-10*V01*V042*V06*V09 + 1.61547985954117473e-10*V022*V05*V06*V09 + 
      3.24682722261078725e-10*V01*V03*V05*V06*V09 + 7.29227584242278138e-11*V01*V02*V062*V09 - 
      1.24293351437775697e-11*V05*V062*V09 - 1.62100266944318696e-10*V012*V022*V07*V09 - 
      9.27996976056798666e-11*V013*V03*V07*V09 + 1.93102209023206723e-10*V02*V032*V07*V09 + 
      1.14539949135674849e-10*V022*V04*V07*V09 + 2.34096073404997454e-10*V01*V03*V04*V07*V09 + 
      1.29676643912387054e-10*V01*V02*V05*V07*V09 - 1.10621114988217525e-11*V052*V07*V09 + 
      2.71705574881141094e-11*V012*V06*V07*V09 - 1.79236865374404376e-11*V04*V06*V07*V09 - 
      5.76296452638156642e-12*V03*V072*V09 - 3.24556712321388057e-11*V013*V02*V08*V09 + 
      6.54108211903389926e-11*V022*V03*V08*V09 + 6.43873857934932674e-11*V01*V032*V08*V09 + 
      8.1240227343306506e-11*V01*V02*V04*V08*V09 + 2.10050592745838378e-11*V012*V05*V08*V09 - 
      1.39778673365567756e-11*V04*V05*V08*V09 - 1.00987870674326629e-11*V03*V06*V08*V09 - 
      4.04003085847495002e-12*V02*V07*V08*V09 - 7.0384068199720649e-13*V01*V082*V09 - 
      1.00400339970225036e-12*V014*V092 + 3.22667309016817989e-12*V023*V092 + 
      2.03935153351722987e-11*V01*V02*V03*V092 + 6.00429697232133354e-12*V012*V04*V092 - 
      1.9912141812008445e-12*V042*V092 - 3.55247567981326924e-12*V03*V05*V092 - 
      1.59644359157180678e-12*V02*V06*V092 - 6.35162169965079895e-13*V01*V07*V092 - 
      6.33132775106889314e-13*V016*V02*V10 + 8.32899483082212424e-11*V012*V024*V10 + 
      2.97351775808750856e-10*V013*V022*V03*V10 + 5.66260599633643661e-11*V014*V032*V10 - 
      2.79007152620933182e-10*V023*V032*V10 - 5.58415483380781159e-10*V01*V02*V033*V10 + 
      7.58005868630162207e-11*V014*V02*V04*V10 - 6.89620683485173357e-11*V024*V04*V10 - 
      1.02905883280274499e-9*V01*V022*V03*V04*V10 - 4.75680433558513346e-10*V012*V032*V04*V10 - 
      3.05334986408896146e-10*V012*V02*V042*V10 + 1.74199026813605896e-10*V032*V042*V10 + 
      6.81549627138978716e-11*V02*V043*V10 + 5.87798026880567792e-12*V015*V05*V10 - 
      1.81091035793284139e-10*V01*V023*V05*V10 - 5.2412646595533704e-10*V012*V02*V03*V05*V10 + 
      1.02404028092258437e-10*V033*V05*V10 - 9.66442082337426395e-11*V013*V04*V05*V10 + 
      3.82175835350397204e-10*V02*V03*V04*V05*V10 + 1.1748726617374537e-10*V01*V042*V05*V10 + 
      5.17647797809666795e-11*V022*V052*V10 + 1.02688501499668206e-10*V01*V03*V052*V10 - 
      1.16069884063401726e-10*V012*V022*V06*V10 - 6.65089774063467926e-11*V013*V03*V06*V10 + 
      1.37837351862502029e-10*V02*V032*V06*V10 + 7.97638748698947631e-11*V022*V04*V06*V10 + 
      1.67704602811361538e-10*V01*V03*V04*V06*V10 + 9.26716539001144295e-11*V01*V02*V05*V06*V10 - 
      7.91976989664513997e-12*V052*V06*V10 + 9.76056744301488485e-12*V012*V062*V10 - 
      6.37073455247836032e-12*V04*V062*V10 - 2.63738555116070788e-11*V013*V02*V07*V10 + 
      5.35529032708496911e-11*V022*V03*V07*V10 + 5.25462817458546304e-11*V01*V032*V07*V10 + 
      6.64061577994341819e-11*V01*V02*V04*V07*V10 + 1.71314595452956681e-11*V012*V05*V07*V10 - 
      1.14333769345132069e-11*V04*V05*V07*V10 - 8.25685448490179709e-12*V03*V06*V07*V10 - 
      1.65329390033687367e-12*V02*V072*V10 - 1.82011142850124376e-12*V014*V08*V10 + 
      5.7067289308947108e-12*V023*V08*V10 + 3.69069606548844603e-11*V01*V02*V03*V08*V10 + 
      1.08920539323054365e-11*V012*V04*V08*V10 - 3.57896719559537757e-12*V042*V08*V10 - 
      6.42761433482527368e-12*V03*V05*V08*V10 - 2.86797474460883325e-12*V02*V06*V08*V10 - 
      1.15018902470406406e-12*V01*V07*V08*V10 + 5.69762325771199204e-12*V01*V022*V09*V10 + 
      5.32381535016997291e-12*V012*V03*V09*V10 - 3.67836276063556685e-12*V03*V04*V09*V10 - 
      2.04091113324051795e-12*V02*V05*V09*V10 - 9.11621428639660907e-13*V01*V06*V09*V10 + 
      1.0418565338820255e-14*V092*V10 + 7.6877729382681738e-13*V012*V02*V102 - 
      4.2148125428939307e-13*V032*V102 - 5.20204246617781007e-13*V02*V04*V102 - 
      2.89392542850321528e-13*V01*V05*V102 + 9.41138159148547301e-15*V08*V102 - 
      1.16527504620899874e-14*V017*V11 + 2.39815916563475053e-11*V013*V023*V11 + 
      2.79105569282221083e-11*V014*V02*V03*V11 - 3.22904798900808943e-11*V024*V03*V11 - 
      2.11721063857746594e-10*V01*V022*V032*V11 - 6.29985591972812124e-11*V012*V033*V11 + 
      2.66592734857453025e-12*V015*V04*V11 - 8.19913816076394164e-11*V01*V023*V04*V11 - 
      2.45071771235951194e-10*V012*V02*V03*V04*V11 + 4.85301005770072349e-11*V033*V04*V11 - 
      2.27283520397930333e-11*V013*V042*V11 + 8.92713896678584498e-11*V02*V03*V042*V11 + 
      1.84456576164992886e-11*V01*V043*V11 - 6.65548657619626093e-11*V012*V022*V05*V11 - 
      3.79128472919391166e-11*V013*V03*V05*V11 + 8.05161274173344189e-11*V02*V032*V05*V11 + 
      4.79406653732000083e-11*V022*V04*V05*V11 + 9.73872425588332163e-11*V01*V03*V04*V05*V11 + 
      2.69883135307704975e-11*V01*V02*V052*V11 - 1.54309000216690953e-12*V053*V11 - 
      1.7287583311934528e-11*V013*V02*V06*V11 + 3.49716412686530775e-11*V022*V03*V06*V11 + 
      3.45586697497600319e-11*V01*V032*V06*V11 + 4.35049265200639374e-11*V01*V02*V04*V06*V11 + 
      1.12723113498003417e-11*V012*V05*V06*V11 - 7.50857385543800848e-12*V04*V05*V06*V11 - 
      2.71416669302036425e-12*V03*V062*V11 - 1.35211118582378094e-12*V014*V07*V11 + 
      4.38224324222050243e-12*V023*V07*V11 + 2.76474890812399871e-11*V01*V02*V03*V07*V11 + 
      8.13516113690048536e-12*V012*V04*V07*V11 - 2.7043810468975504e-12*V042*V07*V11 - 
      4.82287299668780267e-12*V03*V05*V07*V11 - 2.16843509660284847e-12*V02*V06*V07*V11 - 
      4.31053509995438997e-13*V01*V072*V11 + 4.72472535150458627e-12*V01*V022*V08*V11 + 
      4.42216126381697544e-12*V012*V03*V08*V11 - 3.05382126155922135e-12*V03*V04*V08*V11 - 
      1.69353406177846534e-12*V02*V05*V08*V11 - 7.57178708588871928e-13*V01*V06*V08*V11 + 
      1.40785108312120479e-12*V012*V02*V09*V11 - 7.73555851049561324e-13*V032*V09*V11 - 
      9.6112432913581759e-13*V02*V04*V09*V11 - 5.30923806822417581e-13*V01*V05*V09*V11 + 1.73057581211014067e-14*V08*V09*V11 + 
      1.16684261308602601e-13*V013*V10*V11 - 4.46175926076727951e-13*V02*V03*V10*V11 - 
      2.75778029327522626e-13*V01*V04*V10*V11 + 1.41561613701348896e-14*V07*V10*V11 - 
      2.87269631484814765e-14*V022*V112 - 5.74017530166169687e-14*V01*V03*V112 + 
      4.66022949176908057e-15*V06*V112 + 3.13070562414817661e-12*V014*V022*V12 - 
      1.21799579150969147e-12*V025*V12 + 8.87551160195854038e-13*V015*V03*V12 - 
      3.18775481232743551e-11*V01*V023*V03*V12 - 4.50665226040214233e-11*V012*V02*V032*V12 + 
      4.63602556995200807e-12*V034*V12 - 2.85210152681613032e-11*V012*V022*V04*V12 - 
      1.64248370453559468e-11*V013*V03*V04*V12 + 3.48584345036547296e-11*V02*V032*V04*V12 + 
      9.98598002216247929e-12*V022*V042*V12 + 2.12395791975100846e-11*V01*V03*V042*V12 - 
      9.07646181176116889e-12*V013*V02*V05*V12 + 1.89316580882731494e-11*V022*V03*V05*V12 + 
      1.84607924790912189e-11*V01*V032*V05*V12 + 2.33956677329314359e-11*V01*V02*V04*V05*V12 + 
      3.0023223409846485e-12*V012*V052*V12 - 2.02530611708025931e-12*V04*V052*V12 - 
      8.16322726894157926e-13*V014*V06*V12 + 2.57466116908841119e-12*V023*V06*V12 + 
      1.67264551829486578e-11*V01*V02*V03*V06*V12 + 4.93860956886462368e-12*V012*V04*V06*V12 - 
      1.62559781945479911e-12*V042*V06*V12 - 2.923150128019417e-12*V03*V05*V06*V12 - 
      6.51093323138616902e-13*V02*V062*V12 + 3.26804943289264566e-12*V01*V022*V07*V12 + 
      3.0467969867703406e-12*V012*V03*V07*V12 - 2.11240040033415363e-12*V03*V04*V07*V12 - 
      1.17261617330729371e-12*V02*V05*V07*V12 - 5.23176903067724153e-13*V01*V06*V07*V12 + 
      1.07888896807477056e-12*V012*V02*V08*V12 - 5.92082274867088116e-13*V032*V08*V12 - 
      7.30297344320266281e-13*V02*V04*V08*V12 - 4.06524117723246949e-13*V01*V05*V08*V12 + 
      6.61080309535047683e-15*V082*V12 + 9.85531740325456897e-14*V013*V09*V12 - 
      3.77450186445678748e-13*V02*V03*V09*V12 - 2.33203077160212118e-13*V01*V04*V09*V12 + 1.19728703472553745e-14*V07*V09*V12 - 
      5.26077856664303583e-14*V022*V10*V12 - 1.05841802147032891e-13*V01*V03*V10*V12 + 
      8.5738722136240769e-15*V06*V10*V12 - 2.82029359172431111e-14*V01*V02*V11*V12 + 5.02921233142613493e-15*V05*V11*V12 - 
      1.60635046712624788e-15*V012*V122 + 1.10400147925909941e-15*V04*V122 + 
      1.83530819777917301e-13*V015*V02*V13 - 1.58576057258185731e-12*V01*V024*V13 - 
      9.78487635181340849e-12*V012*V022*V03*V13 - 2.74191935873732163e-12*V013*V032*V13 + 
      4.16971479849957847e-12*V02*V033*V13 - 3.63443074524917994e-12*V013*V02*V04*V13 + 
      7.51988250819285384e-12*V022*V03*V04*V13 + 7.50094311499404231e-12*V01*V032*V04*V13 + 
      4.69146186599332558e-12*V01*V02*V042*V13 - 3.95817220600381889e-13*V014*V05*V13 + 
      1.32927467538968383e-12*V023*V05*V13 + 8.32268801261682502e-12*V01*V02*V03*V05*V13 + 
      2.4419692647486601e-12*V012*V04*V05*V13 - 8.20891503892504953e-13*V042*V05*V13 - 
      7.306954501309534e-13*V03*V052*V13 + 1.82915516876284333e-12*V01*V022*V06*V13 + 
      1.7169515067241884e-12*V012*V03*V06*V13 - 1.18855749472952992e-12*V03*V04*V06*V13 - 
      6.58428479538001534e-13*V02*V05*V06*V13 - 1.47431211630936634e-13*V01*V062*V13 + 
      6.89873451151270801e-13*V012*V02*V07*V13 - 3.80208009195057129e-13*V032*V07*V13 - 
      4.7278303066790696e-13*V02*V04*V07*V13 - 2.6086033657266639e-13*V01*V05*V07*V13 + 
      7.01058025469803099e-14*V013*V08*V13 - 2.68157094752310663e-13*V02*V03*V08*V13 - 
      1.65824026644450188e-13*V01*V04*V08*V13 + 8.51224143817787461e-15*V07*V08*V13 - 
      4.16077104613113278e-14*V022*V09*V13 - 8.31099109588426592e-14*V01*V03*V09*V13 + 
      6.74806685323250018e-15*V06*V09*V13 - 2.41431235561626347e-14*V01*V02*V10*V13 + 4.30517715778522478e-15*V05*V10*V13 - 
      2.98233876046204982e-15*V012*V11*V13 + 2.0546943470689051e-15*V04*V11*V13 + 8.03021364910364086e-16*V03*V12*V13 + 
      9.19247023276731815e-17*V02*V132 + 3.88425015402999579e-15*V016*V14 - 
      6.45414303641273753e-13*V012*V023*V14 - 1.13117828612241918e-12*V013*V02*V03*V14 + 
      1.27956809362745091e-12*V022*V032*V14 + 8.184400418212819e-13*V01*V033*V14 - 
      1.47885486357413513e-13*V014*V04*V14 + 4.75293607733056244e-13*V023*V04*V14 + 
      3.1323206689741456e-12*V01*V02*V03*V04*V14 + 4.63082745184558011e-13*V012*V042*V14 - 
      1.02549076509573579e-13*V043*V14 + 8.54069429991588632e-13*V01*V022*V05*V14 + 
      7.91618722129729418e-13*V012*V03*V05*V14 - 5.55252743250623582e-13*V03*V04*V05*V14 - 
      1.54268046837207386e-13*V02*V052*V14 + 3.62568841291365059e-13*V012*V02*V06*V14 - 
      1.99907684423277587e-13*V032*V06*V14 - 2.45964209446922916e-13*V02*V04*V06*V14 - 
      1.37240790798272797e-13*V01*V05*V06*V14 + 4.1783496246552004e-14*V013*V07*V14 - 
      1.60883468635804432e-13*V02*V03*V07*V14 - 9.93228881761834839e-14*V01*V04*V07*V14 + 
      2.55169784912412626e-15*V072*V14 - 2.73847426617915356e-14*V022*V08*V14 - 
      5.51686627384737422e-14*V01*V03*V08*V14 + 4.46747815069143399e-15*V06*V08*V14 - 1.76953326208434678e-14*V01*V02*V09*V14 + 
      3.15532593186514953e-15*V05*V09*V14 - 2.38372010662769178e-15*V012*V10*V14 + 
      1.63781918949552886e-15*V04*V10*V14 + 6.95845763369166618e-16*V03*V11*V14 + 1.71191823532273526e-16*V02*V12*V14 + 
      3.87493022898067072e-17*V01*V13*V14 - 1.07911083762911233e-13*V013*V022*V15 - 
      4.23362156734084596e-14*V014*V03*V15 + 1.57976360800010349e-13*V023*V03*V15 + 
      4.84783546072895084e-13*V01*V02*V032*V15 + 2.97691652656416048e-13*V01*V022*V04*V15 + 
      2.81750654170691155e-13*V012*V03*V04*V15 - 9.86634376299344775e-14*V03*V042*V15 + 
      1.56854922626334215e-13*V012*V02*V05*V15 - 8.73762098676233302e-14*V032*V05*V15 - 
      1.08948115223871687e-13*V02*V04*V05*V15 - 2.99315659025737346e-14*V01*V052*V15 + 
      2.06122851098882268e-14*V013*V06*V15 - 7.91151427022368249e-14*V02*V03*V06*V15 - 
      4.89688576513780108e-14*V01*V04*V06*V15 - 1.5526503110635554e-14*V022*V07*V15 - 
      3.09642224213674957e-14*V01*V03*V07*V15 + 2.51646277396746904e-15*V06*V07*V15 - 1.10051342801842462e-14*V01*V02*V08*V15 + 
      1.96265605549587988e-15*V05*V08*V15 - 1.63650010264923478e-15*V012*V09*V15 + 
      1.12774157607100467e-15*V04*V09*V15 + 5.21113250099988471e-16*V03*V10*V15 + 1.39357196183763212e-16*V02*V11*V15 + 
      3.38963493882852479e-17*V01*V12*V15 - 8.83987720500501829e-20*V152 - 
      7.66998671719691198e-15*V014*V02*V16 + 6.44142841666682068e-15*V024*V16 + 
      8.80805793895757745e-14*V01*V022*V03*V16 + 4.01438895312181116e-14*V012*V032*V16 + 
      5.2287026575254386e-14*V012*V02*V04*V16 - 2.93601512194435959e-14*V032*V04*V16 - 
      1.79309004712099445e-14*V02*V042*V16 + 8.34738493246494506e-15*V013*V05*V16 - 
      3.26913593049608102e-14*V02*V03*V05*V16 - 2.01348936504653864e-14*V01*V04*V05*V16 - 
      7.11740808206424194e-15*V022*V06*V16 - 1.43918384241227764e-14*V01*V03*V06*V16 + 
      5.82802887230197417e-16*V062*V16 - 5.82167788837820886e-15*V01*V02*V07*V16 + 
      1.03857548499295498e-15*V05*V07*V16 - 9.59591371074207605e-16*V012*V08*V16 + 
      6.58902749314492699e-16*V04*V08*V16 + 3.370730703827716e-16*V03*V09*V16 + 9.80207295800078063e-17*V02*V10*V16 + 
      2.59188621619350082e-17*V01*V11*V16 - 1.66291256260869896e-19*V14*V16 - 1.89990496664510664e-16*V015*V17 + 
      4.86956197978733304e-15*V01*V023*V17 + 1.41433851396604892e-14*V012*V02*V03*V17 - 
      2.73162648117141933e-15*V033*V17 + 2.64350666053481643e-15*V013*V04*V17 - 
      1.02907079213416284e-14*V02*V03*V04*V17 - 3.19182275225112503e-15*V01*V042*V17 - 
      2.81216818292357462e-15*V022*V05*V17 - 5.57868684882707399e-15*V01*V03*V05*V17 - 
      2.55022002225303197e-15*V01*V02*V06*V17 + 4.55583332407079884e-16*V05*V06*V17 - 
      4.78337515329117704e-16*V012*V07*V17 + 3.30177520261485175e-16*V04*V07*V17 + 
      1.86502278342547543e-16*V03*V08*V17 + 6.00291886776867114e-17*V02*V09*V17 + 1.72613654871455534e-17*V01*V10*V17 - 
      1.38664714586950399e-19*V13*V17 + 1.15882475156915424e-15*V012*V022*V18 + 
      6.63559401313457614e-16*V013*V03*V18 - 1.37711696309173586e-15*V02*V032*V18 - 
      8.23668559016970901e-16*V022*V04*V18 - 1.68264145146248983e-15*V01*V03*V04*V18 - 
      9.40293795374838116e-16*V01*V02*V05*V18 + 8.41705171441197212e-17*V052*V18 - 
      1.99357485295257017e-16*V012*V06*V18 + 1.36894629564189941e-16*V04*V06*V18 + 
      8.83494081553293481e-17*V03*V07*V18 + 3.13880353012497346e-17*V02*V08*V18 + 9.99259205972608792e-18*V01*V09*V18 - 
      1.0208999924027615e-19*V12*V18 + 1.05550275924728147e-16*V013*V02*V19 - 
      2.14364791864165478e-16*V022*V03*V19 - 2.09312061062953955e-16*V01*V032*V19 - 
      2.67448482881812156e-16*V01*V02*V04*V19 - 6.93553271388734529e-17*V012*V05*V19 + 
      4.82485543922659681e-17*V04*V05*V19 + 3.49398029906350771e-17*V03*V06*V19 + 1.41782479920331556e-17*V02*V07*V19 + 
      4.98215762039735876e-18*V01*V08*V19 - 6.64130376146662509e-20*V11*V19 + 3.1665082777418444e-18*V014*V20 - 
      1.01648984547011437e-17*V023*V20 - 6.40481946427602086e-17*V01*V02*V03*V20 - 
      1.89900743028520249e-17*V012*V04*V20 + 6.55790918062027298e-18*V042*V20 + 
      1.16860936283651301e-17*V03*V05*V20 + 5.31774039008747801e-18*V02*V06*V20 + 2.13568501732262469e-18*V01*V07*V20 - 
      3.78983661526790449e-20*V10*V20 - 4.56756253555222396e-18*V01*V022*V21 - 
      4.24504780355999907e-18*V012*V03*V21 + 3.05408693112747148e-18*V03*V04*V21 + 1.7094981873439896e-18*V02*V05*V21 + 
      7.69634849490338413e-19*V01*V06*V21 - 1.89750678853887801e-20*V09*V21 - 5.96861679336260352e-19*V012*V02*V22 + 
      3.37245848397356718e-19*V032*V22 + 4.23042288989272819e-19*V02*V04*V22 + 2.34738599004732721e-19*V01*V05*V22 - 
      8.225270132817571e-21*V08*V22 - 2.30367665708732066e-20*V013*V23 + 9.08873057987742288e-20*V02*V03*V23 + 
      5.64547619310408531e-20*V01*V04*V23 - 3.09366062819588764e-21*V07*V23 + 5.71594254072700712e-21*V022*V24 + 
      1.13753964584449765e-20*V01*V03*V24 - 9.8115444576895747e-22*V06*V24 + 1.42545509624368692e-21*V01*V02*V25 - 
      2.66421094497812289e-22*V05*V25 + 7.9437126106459333e-23*V012*V26 - 5.70244159417206115e-23*V04*V26 - 
      1.04570214881099937e-23*V03*V27 - 1.17770910324011067e-24*V02*V28 - 1.26183118204297572e-25*V01*V29 + 
      7.35332856668400769e-29*V32) + 1.15163356207719503e-37*delta32*V32 + 
   9.21306849661756022e-37*delta30*eps*V32;
}
#endif


#ifdef p18 /* Uses: V00 - V34. */
double Vp(void)
{

   V012 = V01 * V01;
   V013 = V01 * V012;
   V014 = V01 * V013;
   V015 = V01 * V014;
   V016 = V01 * V015; 
   V017 = V01 * V016; 
   V018 = V01 * V017;
   V022 = V02 * V02;
   V023 = V02 * V022;
   V024 = V02 * V023;
   V025 = V02 * V024;
   V026 = V02 * V025;  
   V027 = V02 * V026; 
   V028 = V02 * V027; 
   V029 = V02 * V028;
   V032 = V03 * V03;
   V033 = V03 * V032;
   V034 = V03 * V033;
   V035 = V03 * V034;  
   V036 = V03 * V035;
   V042 = V04 * V04;
   V043 = V04 * V042;
   V044 = V04 * V043;   
   V045 = V04 * V044;
   V046 = V04 * V045;
   V052 = V05 * V05;
   V053 = V05 * V052;
   V054 = V05 * V053;
   V062 = V06 * V06;
   V063 = V06 * V062;
   V064 = V06 * V063;
   V072 = V07 * V07;
   V073 = V07 * V072;
   V074 = V07 * V073;
   V082 = V08 * V08;
   V083 = V08 * V082;
   V092 = V09 * V09;
   V093 = V09 * V092;
   V102 = V10 * V10;
   V103 = V10 * V102;
   V112 = V11 * V11;
   V122 = V12 * V12;
   V132 = V13 * V13;
   V142 = V14 * V14;
   V152 = V15 * V15;
   V162 = V16 * V16;
   delta4 = delta2 * delta2;
   delta6 = delta2 * delta4;
   delta8 = delta2 * delta6;
   delta10 = delta2 * delta8;
   delta12 = delta2 * delta10;
   delta14 = delta2 * delta12;
   delta16 = delta2 * delta14;
   delta18 = delta2 * delta16;
   delta20 = delta2 * delta18;
   delta22 = delta2 * delta20;
   delta24 = delta2 * delta22;
   delta26 = delta2 * delta24;
   delta28 = delta2 * delta26;
   delta30 = delta2 * delta28;
   delta32 = delta2 * delta30;
   delta34 = delta2 * delta32;

   return V00 + 0.166666666666666667*delta2*V02 + 0.0833333333333333333*eps*V02 + 
   eps2*(-0.0416666666666666667*V012 + 0.00416666666666666667*V04) + 
   0.00833333333333333333*delta4*V04 + 0.00833333333333333333*delta2*eps*V04 + 
   eps3*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 0.00014880952380952381*V06) + 
   delta2*eps2*(-0.00277777777777777778*V022 - 0.00833333333333333333*V01*V03 + 
      0.000297619047619047619*V06) + 0.000198412698412698413*delta6*V06 + 
   0.000297619047619047619*delta4*eps*V06 + 
   eps4*(0.00416666666666666667*V012*V02 - 0.000570436507936507937*V032 - 
      0.000595238095238095238*V02*V04 - 0.000446428571428571429*V01*V05 + 4.1335978835978836e-6*V08) + 
   delta2*eps3*(-0.000992063492063492063*V032 - 0.000793650793650793651*V02*V04 - 
      0.000595238095238095238*V01*V05 + 8.2671957671957672e-6*V08) + 
   delta4*eps2*(-0.000496031746031746032*V032 - 0.000396825396825396825*V02*V04 - 
      0.000297619047619047619*V01*V05 + 8.2671957671957672e-6*V08) + 2.75573192239858907e-6*delta8*V08 + 
   5.51146384479717813e-6*delta6*eps*V08 + eps5*
    (0.0001763668430335097*V023 + 0.00143849206349206349*V01*V02*V03 + 0.000446428571428571429*V012*V04 - 
      0.0000388558201058201058*V042 - 0.0000785383597883597884*V03*V05 - 0.0000330687830687830688*V02*V06 - 
      0.0000165343915343915344*V01*V07 + 9.39454064454064454e-8*V10) + 
   delta6*eps2*(-0.0000154320987654320988*V042 - 0.0000385802469135802469*V03*V05 - 
      0.0000110229276895943563*V02*V06 - 5.51146384479717813e-6*V01*V07 + 1.25260541927208594e-7*V10) + 
   delta2*eps4*(0.0000661375661375661376*V023 + 0.00119047619047619048*V01*V02*V03 + 
      0.000297619047619047619*V012*V04 - 0.0000644841269841269841*V042 - 0.00014880952380952381*V03*V05 - 
      0.0000496031746031746032*V02*V06 - 0.0000248015873015873016*V01*V07 + 1.87890812890812891e-7*V10) + 
   delta4*eps3*(-0.0000462962962962962963*V042 - 0.000115740740740740741*V03*V05 - 
      0.0000330687830687830688*V02*V06 - 0.0000165343915343915344*V01*V07 + 1.87890812890812891e-7*V10) + 
   2.50521083854417188e-8*delta10*V10 + 6.26302709636042969e-8*delta8*eps*V10 + 
   delta8*eps2*(-7.89141414141414141e-7*V052 - 9.01875901875901876e-7*V04*V06 - 
      7.51563251563251563e-7*V03*V07 - 1.67014055902944792e-7*V02*V08 - 6.26302709636042969e-8*V01*V09 + 
      1.20442828776162109e-9*V12) + eps6*(-0.000421626984126984127*V012*V022 - 
      0.00014880952380952381*V013*V03 + 0.000144675925925925926*V02*V032 + 
      0.0000793650793650793651*V022*V04 + 0.000188492063492063492*V01*V03*V04 + 0.000111607142857142857*V01*V02*V05 - 
      3.33506192881192881e-6*V052 + 0.0000248015873015873016*V012*V06 - 5.11063011063011063e-6*V04*V06 - 
      3.56992544492544493e-6*V03*V07 - 1.25260541927208594e-6*V02*V08 - 4.69727032227032227e-7*V01*V09 + 
      1.80664243164243164e-9*V12) + delta6*eps3*
    (-3.15656565656565657e-6*V052 - 3.6075036075036075e-6*V04*V06 - 3.00625300625300625e-6*V03*V07 - 
      6.68056223611779167e-7*V02*V08 - 2.50521083854417188e-7*V01*V09 + 2.40885657552324219e-9*V12) + 
   delta2*eps5*(0.00020667989417989418*V02*V032 + 0.0000727513227513227513*V022*V04 + 
      0.000243055555555555556*V01*V03*V04 + 0.000124007936507936508*V01*V02*V05 - 6.57617845117845118e-6*V052 + 
      0.0000248015873015873016*V012*V06 - 9.16907166907166907e-6*V04*V06 - 6.95196007696007696e-6*V03*V07 - 
      2.0041686708353375e-6*V02*V08 - 7.51563251563251563e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   delta4*eps4*(0.000082671957671957672*V02*V032 + 0.0000198412698412698413*V022*V04 + 
      0.0000925925925925925926*V01*V03*V04 + 0.0000496031746031746032*V01*V02*V05 - 6.1377665544332211e-6*V052 + 
      8.2671957671957672e-6*V012*V06 - 7.56573673240339907e-6*V04*V06 - 6.0751362834696168e-6*V03*V07 - 
      1.50312650312650313e-6*V02*V08 - 5.63672438672438672e-7*V01*V09 + 3.61328486328486328e-9*V12) + 
   1.60590438368216146e-10*delta12*V12 + 4.81771315104648438e-10*delta10*eps*V12 + 
   delta10*eps2*(-1.3627245770102913e-8*V062 - 3.17969067969067969e-8*V05*V07 - 
      1.41319585764030208e-8*V04*V08 - 8.83247411025188803e-9*V03*V09 - 1.60590438368216146e-9*V02*V10 - 
      4.81771315104648438e-10*V01*V11 + 8.0295219184108073e-12*V14) + 
   delta8*eps3*(-6.81362288505145648e-8*V062 - 1.58984533984533985e-7*V05*V07 - 
      7.06597928820151042e-8*V04*V08 - 4.41623705512594401e-8*V03*V09 - 8.0295219184108073e-9*V02*V10 - 
      2.40885657552324219e-9*V01*V11 + 2.00738047960270182e-11*V14) + 
   eps7*(-0.0000132275132275132275*V024 - 0.000203373015873015873*V01*V022*V03 - 
      0.0000777116402116402116*V012*V032 - 0.000124007936507936508*V012*V02*V04 + 
      0.0000224842672759339426*V032*V04 + 0.000013452982202982203*V02*V042 - 
      0.0000165343915343915344*V013*V05 + 0.0000264299743466410133*V02*V03*V05 + 0.0000173485850569183903*V01*V04*V05 + 
      5.71188071188071188e-6*V022*V06 + 0.0000124383718133718134*V01*V03*V06 - 1.95667978406073644e-7*V062 + 
      5.44883357383357383e-6*V01*V02*V07 - 3.61569371986038653e-7*V05*V07 + 9.39454064454064454e-7*V012*V08 - 
      2.24023661523661524e-7*V04*V08 - 1.20442828776162109e-7*V03*V09 - 3.61328486328486328e-8*V02*V10 - 
      1.08398545898545899e-8*V01*V11 + 3.01107071940405274e-11*V14) + 
   delta6*eps4*(6.76406926406926407e-6*V032*V04 + 1.90396023729357063e-6*V02*V042 + 
      7.01459034792368126e-6*V02*V03*V05 + 4.05844155844155844e-6*V01*V04*V05 + 6.51354818021484688e-7*V022*V06 + 
      2.70562770562770563e-6*V01*V03*V06 - 1.88303759732331161e-7*V062 + 1.00208433541766875e-6*V01*V02*V07 - 
      4.20586358086358086e-7*V05*V07 + 1.25260541927208594e-7*V012*V08 - 1.99453324453324453e-7*V04*V08 - 
      1.22048733159844271e-7*V03*V09 - 2.40885657552324219e-8*V02*V10 - 7.22656972656972657e-9*V01*V11 + 
      4.01476095920540365e-11*V14) + delta2*eps6*
    (-1.65343915343915344e-6*V024 - 0.000133928571428571429*V01*V022*V03 - 
      0.0000562169312169312169*V012*V032 - 0.0000744047619047619048*V012*V02*V04 + 
      0.0000395197009780343114*V032*V04 + 0.0000179623617123617124*V02*V042 - 
      8.2671957671957672e-6*V013*V05 + 0.0000417743907327240661*V02*V03*V05 + 0.0000256408329324995992*V01*V04*V05 + 
      6.68891293891293891e-6*V022*V06 + 0.0000185636123136123136*V01*V03*V06 - 3.70998324867372486e-7*V062 + 
      6.95196007696007696e-6*V01*V02*V07 - 7.19525459108792442e-7*V05*V07 + 1.12734487734487734e-6*V012*V08 - 
      4.17213958880625547e-7*V04*V08 - 2.37272372689039356e-7*V03*V09 - 6.02214143880810547e-8*V02*V10 - 
      1.80664243164243164e-8*V01*V11 + 6.02214143880810547e-11*V14) + 
   delta4*eps5*(0.0000263047138047138047*V032*V04 + 9.11896745230078563e-6*V02*V042 + 
      0.0000267431257014590348*V02*V03*V05 + 0.0000157828282828282828*V01*V04*V05 + 3.20666987333654e-6*V022*V06 + 
      0.0000109352453102453102*V01*V03*V06 - 3.36345202416630988e-7*V062 + 3.82044652877986211e-6*V01*V02*V07 - 
      7.00254606504606505e-7*V05*V07 + 5.63672438672438672e-7*V012*V08 - 3.67591513424846758e-7*V04*V08 - 
      2.18001520084853418e-7*V03*V09 - 4.81771315104648438e-8*V02*V10 - 1.44531394531394531e-8*V01*V11 + 
      6.02214143880810547e-11*V14) + 7.64716373181981648e-13*delta14*V14 + 
   2.67650730613693577e-12*delta12*eps*V14 + 
   delta12*eps2*(-3.28063324095070127e-10*V072 - 4.37417765460093502e-10*V06*V08 - 
      3.82740544777581815e-10*V05*V09 - 1.3917837991912066e-10*V04*V10 - 6.95891899595603299e-11*V03*V11 - 
      1.07060292245477431e-11*V02*V12 - 2.67650730613693577e-12*V01*V13 + 3.93604015608372907e-14*V16) + 
   delta10*eps3*(-1.96837994457042076e-9*V072 - 2.62450659276056101e-9*V06*V08 - 
      2.29644326866549089e-9*V05*V09 - 8.35070279514723959e-10*V04*V10 - 4.1753513975736198e-10*V03*V11 - 
      6.42361753472864584e-11*V02*V12 - 1.60590438368216146e-11*V01*V13 + 1.18081204682511872e-13*V16) + 
   delta8*eps4*(5.93542260208926876e-8*V043 + 5.93542260208926876e-7*V03*V04*V05 + 
      1.51757964257964258e-7*V02*V052 + 2.04408686551543694e-7*V032*V06 + 1.2498524403286308e-7*V02*V04*V06 + 
      1.22645211930926217e-7*V01*V05*V06 + 1.44531394531394531e-7*V02*V03*V07 + 8.47917514584181251e-8*V01*V04*V07 - 
      6.52972193150764579e-9*V072 + 1.09201498090386979e-8*V022*V08 + 4.23958757292090625e-8*V01*V03*V08 - 
      9.08483051340194197e-9*V06*V08 + 1.20442828776162109e-8*V01*V02*V09 - 7.72841484647040203e-9*V05*V09 + 
      1.20442828776162109e-9*V012*V10 - 2.9709231098119987e-9*V04*V10 - 1.46538775010997233e-9*V03*V11 - 
      2.40885657552324219e-10*V02*V12 - 6.02214143880810547e-11*V01*V13 + 2.9520301170627968e-13*V16) + 
   eps8*(0.0000427138447971781305*V012*V023 + 0.0000454695767195767196*V013*V02*V03 - 
      0.0000265865500240500241*V022*V032 - 0.0000157201980118646785*V01*V033 + 
      4.1335978835978836e-6*V014*V04 - 0.0000100208433541766875*V023*V04 - 
      0.000068329625621292288*V01*V02*V03*V04 - 0.0000103840989257655924*V012*V042 + 
      8.50711788211788212e-7*V043 - 0.0000202922077922077922*V01*V022*V05 - 
      0.0000166283369408369408*V012*V03*V05 + 4.77122221913888581e-6*V03*V04*V05 + 
      1.40881976819476819e-6*V02*V052 - 8.83086820586820587e-6*V012*V02*V06 + 
      1.726031766954386e-6*V032*V06 + 2.18586528110337634e-6*V02*V04*V06 + 1.33467860402384212e-6*V01*V05*V06 - 
      9.39454064454064454e-7*V013*V07 + 1.49830878997545664e-6*V02*V03*V07 + 9.8088639755306422e-7*V01*V04*V07 - 
      1.13969026729443396e-8*V072 + 2.66580127691238802e-7*V022*V08 + 5.46810442643775977e-7*V01*V03*V08 - 
      1.96493872089110184e-8*V06*V08 + 1.92708526041859375e-7*V01*V02*V09 - 1.41821430883930884e-8*V05*V09 + 
      2.70996364746364746e-8*V012*V10 - 7.34701255534588868e-9*V04*V10 - 3.22184566976233643e-9*V03*V11 - 
      8.43099801433134766e-10*V02*V12 - 2.10774950358283692e-10*V01*V13 + 4.4280451755941952e-13*V16) + 
   delta6*eps5*(3.56125356125356125e-7*V043 + 3.07900047483380817e-6*V03*V04*V05 + 
      7.79024216524216524e-7*V02*V052 + 1.07882362346648061e-6*V032*V06 + 7.57069209450161831e-7*V02*V04*V06 + 
      6.47294174079888366e-7*V01*V05*V06 + 7.41927825261158594e-7*V02*V03*V07 + 4.39857210690544024e-7*V01*V04*V07 - 
      1.45735822819156152e-8*V072 + 6.83044664526146008e-8*V022*V08 + 2.31410821688599466e-7*V01*V03*V08 - 
      2.17026506709046392e-8*V06*V08 + 6.18273187717632162e-8*V01*V02*V09 - 1.76649482205037761e-8*V05*V09 + 
      7.22656972656972657e-9*V012*V10 - 7.38716016493794272e-9*V04*V10 - 3.57313725369280925e-9*V03*V11 - 
      6.42361753472864584e-10*V02*V12 - 1.60590438368216146e-10*V01*V13 + 5.9040602341255936e-13*V16) + 
   delta2*eps7*(-0.0000311898749398749399*V022*V032 - 
      0.0000202922077922077922*V01*V033 - 6.91438191438191438e-6*V023*V04 - 
      0.0000756072631072631073*V01*V02*V03*V04 - 0.0000108976671476671477*V012*V042 + 
      1.41486599819933153e-6*V043 - 0.0000187139249639249639*V01*V022*V05 - 
      0.0000174362674362674363*V012*V03*V05 + 8.83134997718331052e-6*V03*V04*V05 + 
      2.36067944401277735e-6*V02*V052 - 7.89141414141414141e-6*V012*V02*V06 + 
      3.2333737690880548e-6*V032*V06 + 3.3093559879274165e-6*V02*V04*V06 + 2.16549323692180835e-6*V01*V05*V06 - 
      7.51563251563251563e-7*V013*V07 + 2.48834884251550918e-6*V02*V03*V07 + 1.55419426252759586e-6*V01*V04*V07 - 
      2.27636946386946387e-8*V072 + 3.52656602656602657e-7*V022*V08 + 8.77305564805564806e-7*V01*V03*V08 - 
      3.81287583668536049e-8*V06*V08 + 2.67383079883079883e-7*V01*V02*V09 - 2.83040647623980957e-8*V05*V09 + 
      3.61328486328486328e-8*V012*V10 - 1.39713681380348047e-8*V04*V10 - 6.3834699251365918e-9*V03*V11 - 
      1.44531394531394531e-9*V02*V12 - 3.61328486328486328e-10*V01*V13 + 8.8560903511883904e-13*V16) + 
   delta4*eps6*(-0.0000102087341670675004*V022*V032 - 7.13985088985088985e-6*V01*V033 - 
      9.01875901875901876e-7*V023*V04 - 0.0000239999198332531666*V01*V02*V03*V04 - 
      3.34445646945646946e-6*V012*V042 + 9.90714532381199048e-7*V043 - 
      6.12524050024050024e-6*V01*V022*V05 - 5.59914622414622415e-6*V012*V03*V05 + 
      7.18272853689520356e-6*V03*V04*V05 + 1.84751269820714265e-6*V02*V052 - 
      2.31732002565335899e-6*V012*V02*V06 + 2.5855634114562686e-6*V032*V06 + 
      2.17219215235088251e-6*V02*V04*V06 + 1.60770529074100503e-6*V01*V05*V06 - 1.87890812890812891e-7*V013*V07 + 
      1.8291250930139819e-6*V02*V03*V07 + 1.10662871079537746e-6*V01*V04*V07 - 2.25830303955303955e-8*V072 + 
      2.09088750755417422e-7*V022*V08 + 6.12813112813112813e-7*V01*V03*V08 - 3.60296119224690653e-8*V06*V08 + 
      1.69824388574388574e-7*V01*V02*V09 - 2.79427362760696094e-8*V05*V09 + 2.16797091797091797e-8*V012*V10 - 
      1.27669398502731836e-8*V04*V10 - 6.02214143880810547e-9*V03*V11 - 1.20442828776162109e-9*V02*V12 - 
      3.01107071940405274e-10*V01*V13 + 8.8560903511883904e-13*V16) + 2.81145725434552076e-15*delta16*V16 + 
   1.12458290173820831e-14*delta14*eps*V16 + 
   delta14*eps2*(-3.57367455441252861e-12*V082 - 8.04076774742818938e-12*V07*V09 - 
      4.38587331677901239e-12*V06*V10 - 3.07011132174530867e-12*V05*V11 - 9.44649637460094976e-13*V04*V12 - 
      3.93604015608372907e-13*V03*V13 - 5.24805354144497209e-14*V02*V14 - 1.12458290173820831e-14*V01*V15 + 
      1.47971434439237935e-16*V18) + delta12*eps3*
    (-2.50157218808877003e-11*V082 - 5.62853742319973257e-11*V07*V09 - 3.07011132174530867e-11*V06*V10 - 
      2.14907792522171607e-11*V05*V11 - 6.61254746222066484e-12*V04*V12 - 2.75522810925861035e-12*V03*V13 - 
      3.67363747901148046e-13*V02*V14 - 7.87208031216745814e-14*V01*V15 + 5.17900020537332772e-16*V18) + 
   delta10*eps4*(1.31523569023569024e-8*V04*V052 + 5.84549195660306771e-9*V042*V06 + 
      1.83715461493239271e-8*V03*V05*V06 + 2.06932250583044234e-9*V02*V062 + 1.25260541927208594e-8*V03*V04*V07 + 
      6.35938135938135938e-9*V02*V05*V07 + 2.62450659276056101e-9*V01*V06*V07 + 3.28063324095070127e-9*V032*V08 + 
      2.11061718998226935e-9*V02*V04*V08 + 1.96837994457042076e-9*V01*V05*V08 - 1.03457878350242703e-10*V082 + 
      1.76649482205037761e-9*V02*V03*V09 + 1.04383784939340495e-9*V01*V04*V09 - 2.25945573702732122e-10*V07*V09 + 
      1.12413306857751302e-10*V022*V10 + 4.1753513975736198e-10*V01*V03*V10 - 1.28213696627173129e-10*V06*V10 + 
      9.63542630209296876e-11*V01*V02*V11 - 8.8009857890032182e-11*V05*V11 + 8.0295219184108073e-12*V012*V12 - 
      2.84182099269245239e-11*V04*V12 - 1.17293996651295126e-11*V03*V13 - 1.65313686555516621e-12*V02*V14 - 
      3.54243614047535616e-13*V01*V15 + 1.55370006161199832e-15*V18) + 
   delta8*eps5*(8.54903198653198653e-8*V04*V052 + 4.25885842552509219e-8*V042*V06 + 
      1.20563271604938272e-7*V03*V05*V06 + 1.51413841890032366e-8*V02*V062 + 8.1419352252685586e-8*V03*V04*V07 + 
      4.10710046126712793e-8*V02*V05*V07 + 1.72233245149911817e-8*V01*V06*V07 + 2.18708882730046751e-8*V032*V08 + 
      1.55696253579851463e-8*V02*V04*V08 + 1.31225329638028051e-8*V01*V05*V08 - 3.06889302360175895e-10*V082 + 
      1.14086123924086887e-8*V02*V03*V09 + 6.78494602105713217e-9*V01*V04*V09 - 6.39241035920541056e-10*V07*V09 + 
      8.56482337963819445e-10*V022*V10 + 2.87055408583186361e-9*V01*V03*V10 - 3.8595685187655309e-10*V06*V10 + 
      6.22287948676837566e-10*V01*V02*V11 - 2.57121823196169601e-10*V05*V11 + 6.02214143880810547e-11*V012*V12 - 
      8.91513095352964634e-11*V04*V12 - 3.63099704398724007e-11*V03*V13 - 5.5104562185172207e-12*V02*V14 - 
      1.18081204682511872e-12*V01*V15 + 3.88425015402999579e-15*V18) + 
   eps9*(1.06888995777884667e-6*V025 + 0.0000263923961840628507*V01*V023*V03 + 
      0.0000299748476831810165*V012*V02*V032 - 1.21518211175949271e-6*V034 + 
      0.0000238245550745550746*V012*V022*V04 + 0.0000102212602212602213*V013*V03*V04 - 
      0.0000101287830702513242*V02*V032*V04 - 3.09484386865339246e-6*V022*V042 - 
      6.45033978367311701e-6*V01*V03*V042 + 6.32565736732403399e-6*V013*V02*V05 - 
      5.97243869813314258e-6*V022*V03*V05 - 5.42102848650467698e-6*V01*V032*V05 - 
      7.74114737408388202e-6*V01*V02*V04*V05 - 9.78856075582266058e-7*V012*V052 + 
      2.90447881593714927e-7*V04*V052 + 4.69727032227032227e-7*V014*V06 - 
      8.74346112441350537e-7*V023*V06 - 5.52347371543800115e-6*V01*V02*V03*V06 - 
      1.67601358077548554e-6*V012*V04*V06 + 2.3201418290704005e-7*V042*V06 + 
      4.20311060192012573e-7*V03*V05*V06 + 1.000249016122032e-7*V02*V062 - 
      1.21213662880329547e-6*V01*V022*V07 - 1.0095517908017908e-6*V012*V03*V07 + 
      3.08183088131004798e-7*V03*V04*V07 + 1.83444465128492906e-7*V02*V05*V07 + 8.64564434132886514e-8*V01*V06*V07 - 
      4.09505617838951172e-7*V012*V02*V08 + 8.67546827988296242e-8*V032*V08 + 
      1.14248626153388058e-7*V02*V04*V08 + 6.72587168122882409e-8*V01*V05*V08 - 5.58025064485634825e-10*V082 - 
      3.61328486328486328e-8*V013*V09 + 6.05727059720115276e-8*V02*V03*V09 + 3.94450264241930909e-8*V01*V04*V09 - 
      1.01977880393934316e-9*V07*V09 + 9.15365498698832032e-9*V022*V10 + 1.79760921948421948e-8*V01*V03*V10 - 
      7.27717595714794594e-10*V06*V10 + 5.32959517334517335e-9*V01*V02*V11 - 4.32620013655552871e-10*V05*V11 + 
      6.32324851074851075e-10*V012*V12 - 1.92177160620788072e-10*V04*V12 - 7.12915273270665428e-11*V03*V13 - 
      1.65313686555516621e-11*V02*V14 - 3.54243614047535616e-12*V01*V15 + 5.82637523104499369e-15*V18) + 
   delta6*eps6*(-3.02827683780064732e-7*V034 - 1.85757254209635162e-6*V02*V032*V04 - 
      1.58222876476844731e-7*V022*V042 - 1.08321462488129155e-6*V01*V03*V042 - 
      9.25161515439293217e-7*V022*V03*V05 - 1.03112826327112041e-6*V01*V032*V05 - 
      1.11454352525781097e-6*V01*V02*V04*V05 - 1.39369559012416155e-7*V012*V052 + 
      2.68161943509165731e-7*V04*V052 - 3.51463645114438765e-8*V023*V06 - 
      7.62712816284244856e-7*V01*V02*V03*V06 - 2.12598798908322718e-7*V012*V04*V06 + 
      1.55031715051556321e-7*V042*V06 + 3.8440189109831967e-7*V03*V05*V06 + 5.61607704464847322e-8*V02*V062 - 
      1.32165930777041888e-7*V01*V022*V07 - 1.24296999296999297e-7*V012*V03*V07 + 
      2.6128064322508767e-7*V03*V04*V07 + 1.32968882968882969e-7*V02*V05*V07 + 5.73479926158497587e-8*V01*V06*V07 - 
      3.77387530165307943e-8*V012*V02*V08 + 7.26576144069530313e-8*V032*V08 + 
      5.89825738635262445e-8*V02*V04*V08 + 4.44778160551970076e-8*V01*V05*V08 - 6.7521831725198257e-10*V082 - 
      2.40885657552324219e-9*V013*V09 + 3.86086178910252984e-8*V02*V03*V09 + 2.32454659537992871e-8*V01*V04*V09 - 
      1.33786004905285951e-9*V07*V09 + 3.45269442491664714e-9*V022*V10 + 1.03580832747499414e-8*V01*V03*V10 - 
      8.61655419311815204e-10*V06*V10 + 2.28841374674708008e-9*V01*V02*V11 - 5.54981662007805799e-10*V05*V11 + 
      2.40885657552324219e-10*V012*V12 - 2.07822920241220895e-10*V04*V12 - 8.32472493011708698e-11*V03*V13 - 
      1.37761405462930517e-11*V02*V14 - 2.9520301170627968e-12*V01*V15 + 7.76850030805999158e-15*V18) + 
   delta2*eps8*(4.1753513975736198e-8*V025 + 0.0000140291806958473625*V01*V023*V03 + 
      0.0000188517115600448934*V012*V02*V032 - 2.104308279903518e-6*V034 + 
      0.0000125886844636844637*V012*V022*V04 + 5.82461519961519962e-6*V013*V03*V04 - 
      0.0000153405163325798246*V02*V032*V04 - 3.46221514376276281e-6*V022*V042 - 
      9.37767864851198185e-6*V01*V03*V042 + 2.94362273528940196e-6*V013*V02*V05 - 
      7.97973888251666029e-6*V022*V03*V05 - 8.09444633849395754e-6*V01*V032*V05 - 
      9.9663114296050804e-6*V01*V02*V04*V05 - 1.24727152256914162e-6*V012*V052 + 
      5.53495019640852974e-7*V04*V052 + 1.87890812890812891e-7*V014*V06 - 
      8.40346822489679633e-7*V023*V06 - 7.21314895422038279e-6*V01*V02*V03*V06 - 
      2.10547829595448643e-6*V012*V04*V06 + 4.143130073189597e-7*V042*V06 + 
      8.11973933253695158e-7*V03*V05*V06 + 1.64565051717829496e-7*V02*V062 - 
      1.3248711165377832e-6*V01*V022*V07 - 1.25380984755984756e-6*V012*V03*V07 + 
      5.84147719564386231e-7*V03*V04*V07 + 3.1668434446212224e-7*V02*V05*V07 + 1.46458479791813125e-7*V01*V06*V07 - 
      4.40820753320753321e-7*V012*V02*V08 + 1.6699971747094763e-7*V032*V08 + 
      1.84426647720298514e-7*V02*V04*V08 + 1.14231420034991464e-7*V01*V05*V08 - 1.09940630202554417e-9*V082 - 
      3.61328486328486328e-8*V013*V09 + 1.03781570795459684e-7*V02*V03*V09 + 6.52800131966798633e-8*V01*V04*V09 - 
      2.03867199884356747e-9*V07*V09 + 1.30479731174175619e-8*V022*V10 + 3.01107071940405274e-8*V01*V03*V10 - 
      1.42836085807024182e-9*V06*V10 + 7.82878387045053712e-9*V01*V02*V11 - 8.64354418275986903e-10*V05*V11 + 
      9.03321215821215821e-10*V012*V12 - 3.70184576679674719e-10*V04*V12 - 1.41697445619014246e-10*V03*V13 - 
      2.89298951472154087e-11*V02*V14 - 6.19926324583187328e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   delta4*eps7*(-1.3248711165377832e-6*V034 - 8.6670659587326254e-6*V02*V032*V04 - 
      1.31581381581381581e-6*V022*V042 - 5.14897910731244065e-6*V01*V03*V042 - 
      4.27957459207459207e-6*V022*V03*V05 - 4.63174942341609008e-6*V01*V032*V05 - 
      5.20023957523957524e-6*V01*V02*V04*V05 - 6.59063159063159063e-7*V012*V052 + 
      5.00520248784137673e-7*V04*V052 - 3.03928875357446786e-7*V023*V06 - 
      3.68334817739579644e-6*V01*V02*V03*V06 - 1.04922909982433792e-6*V012*V04*V06 + 
      3.34278174059920092e-7*V042*V06 + 7.29246916002868384e-7*V03*V05*V06 + 1.25604664295140486e-7*V02*V062 - 
      6.11367798867798868e-7*V01*V022*V07 - 6.07995399662066329e-7*V012*V03*V07 + 
      5.08188442216219994e-7*V03*V04*V07 + 2.63408466533466533e-7*V02*V05*V07 + 1.17724262069500165e-7*V01*V06*V07 - 
      1.95117382617382617e-7*V012*V02*V08 + 1.4478948630734345e-7*V032*V08 + 
      1.36065984280269995e-7*V02*V04*V08 + 9.21731762505572029e-8*V01*V05*V08 - 1.06818506921603716e-9*V082 - 
      1.44531394531394531e-8*V013*V09 + 8.19011235677902345e-8*V02*V03*V09 + 5.02246595996595997e-8*V01*V04*V09 - 
      2.03276793860944188e-9*V07*V09 + 8.67188367188367188e-9*V022*V10 + 2.30045802962469629e-8*V01*V03*V10 - 
      1.37834503351543501e-9*V06*V10 + 5.41992729492729493e-9*V01*V02*V11 - 8.5845035804186131e-10*V05*V11 + 
      6.02214143880810547e-10*V012*V12 - 3.45977929719759785e-10*V04*V12 - 1.35793385384888653e-10*V03*V13 - 
      2.47970529833274931e-11*V02*V14 - 5.31365421071303424e-12*V01*V15 + 1.16527504620899874e-14*V18) + 
   8.22063524662432972e-18*delta18*V18 + 3.69928586098094837e-17*delta16*eps*V18 + 
   delta16*eps2*(-4.99609107113593639e-14*V092 - 7.26704155801590747e-14*V08*V10 - 
      6.54033740221431672e-14*V07*V11 - 3.01861726256045387e-14*V06*V12 - 1.76086006982693143e-14*V05*V13 - 
      4.69562685287181713e-15*V04*V14 - 1.67700959031136326e-15*V03*V15 - 1.97295245918983913e-16*V02*V16 - 
      3.69928586098094837e-17*V01*V17 + 4.40391173926303378e-19*V20) + 
   delta14*eps3*(-3.99687285690874911e-13*V092 - 5.81363324641272598e-13*V08*V10 - 
      5.23226992177145338e-13*V07*V11 - 2.4148938100483631e-13*V06*V12 - 1.40868805586154514e-13*V05*V13 - 
      3.75650148229745371e-14*V04*V14 - 1.34160767224909061e-14*V03*V15 - 1.57836196735187131e-15*V02*V16 - 
      2.9594286887847587e-16*V01*V17 + 1.76156469570521351e-18*V20) + 
   delta12*eps4*(4.14465028435616671e-10*V052*V06 + 1.9311337588648513e-10*V04*V062 + 
      5.61121884651296416e-10*V04*V05*V07 + 3.94728598510111115e-10*V03*V06*V07 + 6.75424490783967908e-11*V02*V072 + 
      9.9293173004138872e-11*V042*V08 + 3.00188662570652404e-10*V03*V05*V08 + 7.05638284744001105e-11*V02*V06*V08 + 
      4.28840946529503434e-11*V01*V07*V08 + 1.55867190180915671e-10*V03*V04*V09 + 7.8799523924796256e-11*V02*V05*V09 + 
      3.28940498758425929e-11*V01*V06*V09 - 1.87500359022631024e-12*V092 + 3.28940498758425929e-11*V032*V10 + 
      2.19068749258602978e-11*V02*V04*V10 + 1.97364299255055558e-11*V01*V05*V10 - 2.808497825656736e-12*V08*V10 + 
      1.43271861681447738e-11*V02*V03*V11 + 8.50184673714085479e-12*V01*V04*V11 - 2.47282462663132475e-12*V07*V11 + 
      7.87208031216745814e-13*V022*V12 + 2.83394891238028493e-12*V01*V03*V12 - 1.183475532645025e-12*V06*V12 + 
      5.5104562185172207e-13*V01*V02*V13 - 6.80520626986055263e-13*V05*V13 + 3.93604015608372907e-14*V012*V14 - 
      1.89344247508448862e-13*V04*V14 - 6.71543693296741495e-14*V03*V15 - 8.28640032859732435e-15*V02*V16 - 
      1.55370006161199832e-15*V01*V17 + 6.16547643496824729e-18*V20) + 
   delta10*eps5*(3.26045822369351781e-9*V052*V06 + 1.65543101467471215e-9*V04*V062 + 
      4.38766140359277614e-9*V04*V05*V07 + 3.10519830827954077e-9*V03*V06*V07 + 5.25866210681803586e-10*V02*V072 + 
      8.54383116547241456e-10*V042*V08 + 2.38274750915455345e-9*V03*V05*V08 + 6.08564288665958964e-10*V02*V06*V08 + 
      3.40392501307793351e-10*V01*V07*V08 + 1.21879483433132671e-9*V03*V04*V09 + 6.1351057912877085e-10*V02*V05*V09 + 
      2.58766525689961731e-10*V01*V06*V09 - 6.38324106265132578e-12*V092 + 2.64979846222065332e-10*V032*V10 + 
      1.91044143347286827e-10*V02*V04*V10 + 1.58987907733239199e-10*V01*V05*V10 - 1.00156931590772184e-11*V08*V10 + 
      1.11547378023412882e-10*V02*V03*V11 + 6.6479718236254184e-11*V01*V04*V11 - 8.52071309503185762e-12*V07*V11 + 
      7.08487228095071232e-12*V022*V12 + 2.34981597318198625e-11*V01*V03*V12 - 4.3121835424282719e-12*V06*V12 + 
      4.29028377013126468e-12*V01*V02*V13 - 2.42687949623794137e-12*V05*V13 + 3.54243614047535616e-13*V012*V14 - 
      7.18016588472958155e-13*V04*V14 - 2.5221731000168106e-13*V03*V15 - 3.31456013143892974e-14*V02*V16 - 
      6.21480024644799327e-15*V01*V17 + 1.84964293049047419e-17*V20) + 
   delta8*eps6*(-8.45508658008658009e-8*V032*V042 - 1.14340392118169896e-8*V02*V043 - 
      5.74110817166372722e-8*V033*V05 - 1.70707635985413763e-7*V02*V03*V04*V05 - 
      5.07305194805194805e-8*V01*V042*V05 - 2.09931850556850557e-8*V022*V052 - 
      4.97910654160654161e-8*V01*V03*V052 - 5.99346457481378116e-8*V02*V032*V06 - 
      1.17185137026406868e-8*V022*V04*V06 - 6.97283683394794506e-8*V01*V03*V04*V06 - 
      3.5960787448882687e-8*V01*V02*V05*V06 + 1.29533113516637482e-8*V052*V06 - 
      3.43835599291948498e-9*V012*V062 + 7.392378229602008e-9*V04*V062 - 
      1.99935095768429102e-8*V022*V03*V07 - 2.28153129938844225e-8*V01*V032*V07 - 
      2.43868051407733947e-8*V01*V02*V04*V07 - 6.24582097796383511e-9*V012*V05*V07 + 
      1.75019961580419097e-8*V04*V05*V07 + 1.2518744403859561e-8*V03*V06*V07 + 2.14039052230578841e-9*V02*V072 - 
      6.57656080936504217e-10*V023*V08 - 1.26407616486981566e-8*V01*V02*V03*V08 - 
      3.52151889850302549e-9*V012*V04*V08 + 3.86929241225589394e-9*V042*V08 + 
      9.72664871847229976e-9*V03*V05*V08 + 2.79046504017974087e-9*V02*V06*V08 + 1.42857640312640831e-9*V01*V07*V08 - 
      1.66612579807024251e-9*V01*V022*V09 - 1.58583057888613444e-9*V012*V03*V09 + 
      5.00664307853850338e-9*V03*V04*V09 + 2.53392425148280268e-9*V02*V05*V09 + 1.08879305089038983e-9*V01*V06*V09 - 
      1.6748072821287926e-11*V092 - 3.81402291124513347e-10*V012*V02*V10 + 
      1.12917963434906323e-9*V032*V10 + 9.01690570613695419e-10*V02*V04*V10 + 6.8620642935438298e-10*V01*V05*V10 - 
      2.760150625644289e-11*V08*V10 - 2.00738047960270182e-11*V013*V11 + 4.80787305065627506e-10*V02*V03*V11 + 
      2.88905347456545714e-10*V01*V04*V11 - 2.26228347113945505e-11*V07*V11 + 3.54243614047535616e-11*V022*V12 + 
      1.07453896261085804e-10*V01*V03*V12 - 1.21478628817236775e-11*V06*V12 + 1.97786017843207386e-11*V01*V02*V13 - 
      6.6713291145516521e-12*V05*V13 + 1.77121807023767808e-12*V012*V14 - 2.11096048371016838e-12*V04*V14 - 
      7.32828529060325873e-13*V03*V15 - 1.03580004107466554e-13*V02*V16 - 1.9421250770149979e-14*V01*V17 + 
      4.62410732622618547e-17*V20) + eps10*(-4.32775172358505692e-6*V012*V024 - 
      9.24422799422799423e-6*V013*V022*V03 - 1.23068482443482443e-6*V014*V032 + 
      4.22450354245989167e-6*V023*V032 + 7.39166243258505163e-6*V01*V02*V033 - 
      1.69101731601731602e-6*V014*V02*V04 + 1.21747740795359843e-6*V024*V04 + 
      0.0000161214859875574161*V01*V022*V03*V04 + 6.33712696584720394e-6*V012*V032*V04 + 
      4.84675707889993604e-6*V012*V02*V042 - 1.07324812418438411e-6*V032*V042 - 
      4.62417873132158846e-7*V02*V043 - 9.39454064454064454e-8*V015*V05 + 
      3.19858299769014055e-6*V01*V023*V05 + 7.76295326146516623e-6*V012*V02*V03*V05 - 
      6.14896486982300474e-7*V033*V05 + 1.39724005051386004e-6*V013*V04*V05 - 
      2.56161679617780808e-6*V02*V03*V04*V05 - 8.20972733175114127e-7*V01*V042*V05 - 
      3.79289523169731503e-7*V022*V052 - 6.95468437903953777e-7*V01*V03*V052 + 
      2.05559775872275872e-6*V012*V022*V06 + 9.52221004304337638e-7*V013*V03*V06 - 
      9.2266376058538757e-7*V02*V032*V06 - 5.93101783577974054e-7*V022*V04*V06 - 
      1.16940150577303355e-6*V01*V03*V04*V06 - 7.07132752333645191e-7*V01*V02*V05*V06 + 
      2.89604486589270086e-8*V052*V06 - 7.63370950312914599e-8*V012*V062 + 
      2.35668492554580323e-8*V04*V062 + 4.33594183594183594e-7*V013*V02*V07 - 
      4.0140583760375427e-7*V022*V03*V07 - 3.62902846161774733e-7*V01*V032*V07 - 
      5.19422603685996543e-7*V01*V02*V04*V07 - 1.32534428479368956e-7*V012*V05*V07 + 
      4.25063111758883818e-8*V04*V05*V07 + 3.06977183828184645e-8*V03*V06*V07 + 6.76143520976766775e-9*V02*V072 + 
      2.70996364746364746e-8*V014*V08 - 4.80241882358284475e-8*V023*V08 - 
      2.87815345479035955e-7*V01*V02*V03*V08 - 8.72350202707345564e-8*V012*V04*V08 + 
      1.34766641195601669e-8*V042*V08 + 2.39151691290706619e-8*V03*V05*V08 + 1.16898143469883277e-8*V02*V06*V08 + 
      4.92813313471090471e-9*V01*V07*V08 - 5.07365416219582886e-8*V01*V022*V09 - 
      4.2305543607626941e-8*V012*V03*V09 + 1.39815526419386714e-8*V03*V04*V09 + 8.39144081076270619e-9*V02*V05*V09 + 
      3.92546204816425405e-9*V01*V06*V09 - 2.56298084717075669e-11*V092 - 1.40014788452288452e-8*V012*V02*V10 + 
      3.21391736030508206e-9*V032*V10 + 4.35416007894999492e-9*V02*V04*V10 + 2.49794462727031588e-9*V01*V05*V10 - 
      4.62118489039601052e-11*V08*V10 - 1.05387475179141846e-9*V013*V11 + 1.88841366588507111e-9*V02*V03*V11 + 
      1.22273087448741044e-9*V01*V04*V11 - 3.49496505466431814e-11*V07*V11 + 2.47970529833274931e-10*V022*V12 + 
      4.71144006683222369e-10*V01*V03*V12 - 2.1239079842236017e-11*V06*V12 + 1.20885633293721529e-10*V01*V02*V13 - 
      1.07535465514320433e-11*V05*V13 + 1.23985264916637466e-11*V012*V14 - 4.17634576561305147e-12*V04*V14 - 
      1.34395055329437854e-12*V03*V15 - 2.79666011090159697e-13*V02*V16 - 5.24373770794049432e-14*V01*V17 + 
      6.9361609893392782e-17*V20) + delta6*eps7*
    (-5.30269627491849714e-7*V032*V042 - 1.06760523427190094e-7*V02*V043 - 
      3.44466490299823633e-7*V033*V05 - 1.06134220717554051e-6*V02*V03*V04*V05 - 
      3.18161776495109828e-7*V01*V042*V05 - 1.30511849261849262e-7*V022*V052 - 
      3.03130511463844797e-7*V01*V03*V052 - 3.78534604725080916e-7*V02*V032*V06 - 
      1.11853534472582092e-7*V022*V04*V06 - 4.46345064400619956e-7*V01*V03*V04*V06 - 
      2.27120762835048549e-7*V01*V02*V05*V06 + 3.26639377224889207e-8*V052*V06 - 
      2.2585898081929828e-8*V012*V062 + 2.10193091164924343e-8*V04*V062 - 
      1.24296999296999297e-7*V022*V03*V07 - 1.41067229360880155e-7*V01*V032*V07 - 
      1.51620315310791501e-7*V01*V02*V04*V07 - 4.0124668100858577e-8*V012*V05*V07 + 4.4787492448848658e-8*V04*V05*V07 + 
      3.24298782831501475e-8*V03*V06*V07 + 5.68358575623981786e-9*V02*V072 - 6.5918551368286818e-9*V023*V08 - 
      8.25205438300676396e-8*V01*V02*V03*V08 - 2.34003210193686384e-8*V012*V04*V08 + 
      1.12529063924436888e-8*V042*V08 + 2.54356286410311724e-8*V03*V05*V08 + 8.30444495178907462e-9*V02*V06*V08 + 
      3.92657491666076582e-9*V01*V07*V08 - 1.03580832747499414e-8*V01*V022*V09 - 
      1.05989689323022656e-8*V012*V03*V09 + 1.3470310226165346e-8*V03*V04*V09 + 6.88846387716213424e-9*V02*V05*V09 + 
      3.03283139855268707e-9*V01*V06*V09 - 3.40039836055713167e-11*V092 - 2.64974223307556641e-9*V012*V02*V10 + 
      3.11981788600213748e-9*V032*V10 + 2.79278917817666651e-9*V02*V04*V10 + 1.94147992156084282e-9*V01*V05*V10 - 
      5.8329550274963918e-11*V08*V10 - 1.60590438368216146e-10*V013*V11 + 1.39296461123803172e-9*V02*V03*V11 + 
      8.47035841589218496e-10*V01*V04*V11 - 4.62613453487800303e-11*V07*V11 + 1.18081204682511872e-10*V022*V12 + 
      3.24723312876907648e-10*V01*V03*V12 - 2.6147736236888857e-11*V06*V12 + 6.25830384817312922e-11*V01*V02*V13 - 
      1.39998733551651795e-11*V05*V13 + 5.9040602341255936e-12*V012*V14 - 4.73567778779337087e-12*V04*V14 - 
      1.62102706428185158e-12*V03*V15 - 2.48592009857919731e-13*V02*V16 - 4.66110018483599495e-14*V01*V17 + 
      9.24821465245237093e-17*V20) + delta2*eps9*
    (4.15642466733736575e-6*V023*V032 + 8.35529109338633148e-6*V01*V02*V033 + 
      6.79829796893288957e-7*V024*V04 + 0.0000154207702570797809*V01*V022*V03*V04 + 
      6.74263732299446585e-6*V012*V032*V04 + 4.56072256667494763e-6*V012*V02*V042 - 
      1.91435273280511376e-6*V032*V042 - 6.72419695237155555e-7*V02*V043 + 
      2.49385480040241945e-6*V01*V023*V05 + 7.25582012784393737e-6*V012*V02*V03*V05 - 
      1.13434203215949248e-6*V033*V05 + 1.24703063691158929e-6*V013*V04*V05 - 
      4.15228372817658532e-6*V02*V03*V04*V05 - 1.29452411198442944e-6*V01*V042*V05 - 
      5.49420037267259489e-7*V022*V052 - 1.13306877939814448e-6*V01*V03*V052 + 
      1.63031413031413031e-6*V012*V022*V06 + 8.24792491459158126e-7*V013*V03*V06 - 
      1.51755096571564826e-6*V02*V032*V06 - 7.77042071684928828e-7*V022*V04*V06 - 
      1.86239140232195788e-6*V01*V03*V04*V06 - 1.01627938309485929e-6*V01*V02*V05*V06 + 
      5.68838491377298567e-8*V052*V06 - 1.07641476689095737e-7*V012*V062 + 
      4.41557917412842716e-8*V04*V062 + 3.20377924544591211e-7*V013*V02*V07 - 
      5.77443068762513207e-7*V022*V03*V07 - 5.83046527987004177e-7*V01*V032*V07 - 
      7.28552935894205735e-7*V01*V02*V04*V07 - 1.86531529537481918e-7*V012*V05*V07 + 
      8.20730498018079717e-8*V04*V05*V07 + 6.00686679154524626e-8*V03*V06*V07 + 1.19181468478999992e-8*V02*V072 + 
      1.80664243164243164e-8*V014*V08 - 5.42489795135297781e-8*V023*V08 - 
      4.0979812185169328e-7*V01*V02*V03*V08 - 1.20546065486541677e-7*V012*V04*V08 + 
      2.49040458005988663e-8*V042*V08 + 4.6958392905278604e-8*V03*V05*V08 + 2.00429912245193913e-8*V02*V06*V08 + 
      8.62016691568998603e-9*V01*V07*V08 - 6.16667283333950001e-8*V01*V022*V09 - 
      5.79330006413339747e-8*V012*V03*V09 + 2.68752821857397021e-8*V03*V04*V09 + 1.4780224390110011e-8*V02*V05*V09 + 
      6.83399189285918978e-9*V01*V06*V09 - 5.12537905681840888e-11*V092 - 1.68619960286626953e-8*V012*V02*V10 + 
      6.27264228017029137e-9*V032*V10 + 7.31125081907061366e-9*V02*V04*V10 + 4.36078106078397862e-9*V01*V05*V10 - 
      9.16586854918693502e-11*V08*V10 - 1.20442828776162109e-9*V013*V11 + 3.30686413713374498e-9*V02*V03*V11 + 
      2.08501887168145338e-9*V01*V04*V11 - 6.98876483428242728e-11*V07*V11 + 3.71955794749912397e-10*V022*V12 + 
      8.121034852039754e-10*V01*V03*V12 - 4.19521212350405431e-11*V06*V12 + 1.85092288339837359e-10*V01*V02*V13 - 
      2.14954403524019967e-11*V05*V13 + 1.85977897374956198e-11*V012*V14 - 8.11342172173785521e-12*V04*V14 - 
      2.6762483561266671e-12*V03*V15 - 4.97184019715839461e-13*V02*V16 - 9.3222003696719899e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + delta4*eps8*
    (1.12355953129762654e-6*V023*V032 + 2.5791971476495286e-6*V01*V02*V033 + 
      3.77616945077262538e-8*V024*V04 + 4.13625909657655689e-6*V01*V022*V03*V04 + 
      1.98785727059536583e-6*V012*V032*V04 + 1.22404326273373892e-6*V012*V02*V042 - 
      1.42409880133094419e-6*V032*V042 - 3.91505723846993688e-7*V02*V043 + 
      6.74135718778575921e-7*V01*V023*V05 + 2.06180916746392937e-6*V012*V02*V03*V05 - 
      8.81354738001563398e-7*V033*V05 + 3.3207808505427553e-7*V013*V04*V05 - 
      2.91372423688891943e-6*V02*V03*V04*V05 - 8.88464306123036282e-7*V01*V042*V05 - 
      3.66935769134843209e-7*V022*V052 - 8.12937475883904455e-7*V01*V03*V052 + 
      4.23557281196170085e-7*V012*V022*V06 + 2.13183806933806934e-7*V013*V03*V06 - 
      1.05803289707059548e-6*V02*V032*V06 - 4.22574620656631239e-7*V022*V04*V06 - 
      1.26838342984176318e-6*V01*V03*V04*V06 - 6.5878786116881355e-7*V01*V02*V05*V06 + 
      5.45632582627067921e-8*V052*V06 - 6.76716636538065109e-8*V012*V062 + 
      3.90218908615850726e-8*V04*V062 + 7.34701255534588868e-8*V013*V02*V07 - 
      3.63268954125435607e-7*V022*V03*V07 - 3.97088535729408745e-7*V01*V032*V07 - 
      4.49314840435872182e-7*V01*V02*V04*V07 - 1.17990956904647381e-7*V012*V05*V07 + 
      7.65859343014163276e-8*V04*V05*V07 + 5.59869380444485487e-8*V03*V06*V07 + 1.02824269600355035e-8*V02*V072 + 
      3.61328486328486328e-9*V014*V08 - 2.64209506934374659e-8*V023*V08 - 
      2.52155665102093674e-7*V01*V02*V03*V08 - 7.26442318704223466e-8*V012*V04*V08 + 
      2.14728983840795232e-8*V042*V08 + 4.39814532769423059e-8*V03*V05*V08 + 1.64109258267755e-8*V02*V06*V08 + 
      7.31276900598796024e-9*V01*V07*V08 - 3.37239920573253907e-8*V01*V022*V09 - 
      3.40250991292657959e-8*V012*V03*V09 + 2.42509274116708757e-8*V03*V04*V09 + 1.27037664057680398e-8*V02*V05*V09 + 
      5.74203595255766124e-9*V01*V06*V09 - 5.12110638164897588e-11*V092 - 9.03321215821215821e-9*V012*V02*V10 + 
      5.67822993017028965e-9*V032*V10 + 5.76472441260022959e-9*V02*V04*V10 + 3.68295277404754529e-9*V01*V05*V10 - 
      9.01908088622321099e-11*V08*V10 - 6.02214143880810547e-10*V013*V11 + 2.72767582816602424e-9*V02*V03*V11 + 
      1.68501879081944441e-9*V01*V04*V11 - 6.98021948394356129e-11*V07*V11 + 2.65682710535651712e-10*V022*V12 + 
      6.5535068598794089e-10*V01*V03*V12 - 4.09621923386420413e-11*V06*V12 + 1.35793385384888653e-10*V01*V02*V13 - 
      2.14099868490133368e-11*V05*V13 + 1.32841355267825856e-11*V012*V14 - 7.69703010522583966e-12*V04*V14 - 
      2.59079485273800719e-12*V03*V15 - 4.35036017251359529e-13*V02*V16 - 8.15692532346299116e-14*V01*V17 + 
      1.38723219786785564e-16*V20) + 1.95729410633912612e-20*delta20*V20 + 
   9.78647053169563062e-20*delta18*eps*V20 + 
   delta18*eps2*(-3.73576270568999572e-16*V102 - 8.21867795251799059e-16*V09*V11 - 
      5.0576479707803019e-16*V08*V12 - 3.79323597808522643e-16*V07*V13 - 1.51729439123409057e-16*V06*V14 - 
      7.58647195617045285e-17*V05*V15 - 1.78505222498128302e-17*V04*V16 - 5.57828820306650945e-18*V03*V17 - 
      5.87188231901737837e-19*V02*V18 - 9.78647053169563062e-20*V01*V19 + 1.06374679692343811e-21*V22) + 
   delta16*eps3*(-3.36218643512099615e-15*V102 - 7.39681015726619153e-15*V09*V11 - 
      4.55188317370227171e-15*V08*V12 - 3.41391238027670378e-15*V07*V13 - 1.36556495211068151e-15*V06*V14 - 
      6.82782476055340757e-16*V05*V15 - 1.60654700248315472e-16*V04*V16 - 5.02045938275985851e-17*V03*V17 - 
      5.28469408711564053e-18*V02*V18 - 8.80782347852606755e-19*V01*V19 + 4.7868605861554715e-21*V22) + 
   delta14*eps4*(2.13459363566774952e-12*V063 + 1.7930586539609096e-11*V05*V06*V07 + 
      6.04327175964602865e-12*V04*V072 + 6.86735427232503256e-12*V052*V08 + 
      6.60875939349902034e-12*V04*V06*V08 + 6.54033740221431672e-12*V03*V07*V08 + 6.07011706610740506e-13*V02*V082 + 
      7.05048371958703343e-12*V04*V05*V09 + 4.98071848322474889e-12*V03*V06*V09 + 1.69279320998488198e-12*V02*V07*V09 + 
      5.4502811685119306e-13*V01*V08*V09 + 1.03773353448467159e-12*V042*V10 + 3.05215745436668114e-12*V03*V05*V10 + 
      7.38870695966594755e-13*V02*V06*V10 + 4.36022493480954448e-13*V01*V07*V10 - 1.85215182566314525e-14*V102 + 
      1.28190613083400608e-12*V03*V04*V11 + 6.463392256305913e-13*V02*V05*V11 + 2.71675553630440848e-13*V01*V06*V11 - 
      3.9838959969837207e-14*V09*V11 + 2.2639629469203404e-13*V032*V12 + 1.54600554702115794e-13*V02*V04*V12 + 
      1.35837776815220424e-13*V01*V05*V12 - 2.52150370543244262e-14*V08*V12 + 8.28640032859732435e-14*V02*V03*V13 + 
      4.93040819551540799e-14*V01*V04*V13 - 1.8596838492559939e-14*V07*V13 + 4.00509349215537344e-15*V022*V14 + 
      1.40868805586154514e-14*V01*V03*V14 - 7.6902868355706801e-15*V06*V14 + 2.36754295102780696e-15*V01*V02*V15 - 
      3.80321817802755597e-15*V05*V15 + 1.47971434439237935e-16*V012*V16 - 9.29401533454070648e-16*V04*V16 - 
      2.88896610095655016e-16*V03*V17 - 3.17081645226938432e-17*V02*V18 - 5.28469408711564053e-18*V01*V19 + 
      1.9147442344621886e-20*V22) + delta12*eps5*
    (2.10613238719217953e-11*V063 + 1.64612745870577951e-10*V05*V06*V07 + 5.52527703739065477e-11*V04*V072 + 
      6.34085711144678006e-11*V052*V08 + 6.53389768538752109e-11*V04*V06*V08 + 6.03891153471121911e-11*V03*V07*V08 + 
      6.02167012238729901e-12*V02*V082 + 6.44615654362243056e-11*V04*V05*V09 + 4.57257627418272085e-11*V03*V06*V09 + 
      1.54291047785080388e-11*V02*V07*V09 + 5.03242627892601592e-12*V01*V08*V09 + 1.03162921957593822e-11*V042*V10 + 
      2.84232162937897181e-11*V03*V05*V10 + 7.35516676785972028e-12*V02*V06*V10 + 4.0604594705413883e-12*V01*V07*V10 - 
      7.67994164653953858e-14*V102 + 1.17202846247680556e-11*V03*V04*V11 + 5.89111273361216028e-12*V02*V05*V11 + 
      2.49413251319057501e-12*V01*V06*V11 - 1.5942072417897397e-13*V09*V11 + 2.13818722764698816e-12*V032*V12 + 
      1.55808001607139976e-12*V02*V04*V12 + 1.2829123365881929e-12*V01*V05*V12 - 1.05441977990826965e-13*V08*V12 + 
      7.55270863283610293e-13*V02*V03*V13 + 4.50780177875694445e-13*V01*V04*V13 - 7.57798708621947274e-14*V07*V13 + 
      4.16161438725110068e-14*V022*V14 + 1.36760132089891674e-13*V01*V03*V14 - 3.29532384496182881e-14*V06*V14 + 
      2.15791675223888655e-14*V01*V02*V15 - 1.60364042073524112e-14*V05*V15 + 1.55370006161199832e-15*V012*V16 - 
      4.13580159257670028e-15*V04*V16 - 1.27625362203842719e-15*V03*V17 - 1.47971434439237935e-16*V02*V18 - 
      2.46619057398729892e-17*V01*V19 + 6.7016048206176601e-20*V22) + 
   delta10*eps6*(-2.95801289810004407e-10*V044 - 7.84358338143741194e-9*V03*V042*V05 - 
      4.09348176232707823e-9*V032*V052 - 3.92005983305002913e-9*V02*V04*V052 - 
      8.01299054975525564e-10*V01*V053 - 5.49887301462931715e-9*V032*V04*V06 - 
      1.23515189263710895e-9*V02*V042*V06 - 5.57736890117064409e-9*V02*V03*V05*V06 - 
      3.29932380877759029e-9*V01*V04*V05*V06 - 2.13153443195460002e-10*V022*V062 - 
      1.13590745155871206e-9*V01*V03*V062 + 1.11077632135397347e-10*V063 - 
      1.27190326186591359e-9*V033*V07 - 3.73339031719050393e-9*V02*V03*V04*V07 - 
      1.12051191163391599e-9*V01*V042*V07 - 9.11823062558356676e-10*V022*V05*V07 - 
      2.2213661141454481e-9*V01*V03*V05*V07 - 7.96766985881520584e-10*V01*V02*V06*V07 + 7.90818238274194341e-10*V05*V06*V07 - 
      7.07587561773680666e-11*V012*V072 + 2.66182291692605467e-10*V04*V072 - 
      1.0063142665720734e-9*V02*V032*V08 - 2.14750350915928258e-10*V022*V04*V08 - 
      1.16958121224642648e-9*V01*V03*V04*V08 - 6.03788559943244039e-10*V01*V02*V05*V08 + 
      3.07308867141893107e-10*V052*V08 - 1.15543395934255982e-10*V012*V06*V08 + 
      3.48020435329644263e-10*V04*V06*V08 + 2.95653173692384828e-10*V03*V07*V08 + 3.2678175994266238e-11*V02*V082 - 
      2.53284184043987966e-10*V022*V03*V09 - 2.92166637871586518e-10*V01*V032*V09 - 
      3.11115859765875328e-10*V01*V02*V04*V09 - 8.04807753628948774e-11*V012*V05*V09 + 
      3.13793240103475455e-10*V04*V05*V09 + 2.24240350892254344e-10*V03*V06*V09 + 7.61580611867156797e-11*V02*V07*V09 + 
      2.53822800065346792e-11*V01*V08*V09 - 7.30978886129835398e-12*V023*V10 - 
      1.29608179425328507e-10*V01*V02*V03*V10 - 3.60822424022704135e-11*V012*V04*V10 + 
      5.60804732543481649e-11*V042*V10 + 1.42000663750085985e-10*V03*V05*V10 + 4.03355333137918687e-11*V02*V06*V10 + 
      2.06774049390104097e-11*V01*V07*V10 - 2.53132042505487258e-13*V102 - 
      1.3815500947853889e-11*V01*V022*V11 - 1.32250949244413297e-11*V012*V03*V11 + 
      5.88245344526877608e-11*V03*V04*V11 + 2.96754985434489887e-11*V02*V05*V11 + 1.27296865619387611e-11*V01*V06*V11 - 
      5.05754031960445325e-13*V09*V11 - 2.63714690457609848e-12*V012*V02*V12 + 
      1.11352203701387527e-11*V032*V12 + 8.81730210584071817e-12*V02*V04*V12 + 6.74017282442450755e-12*V01*V05*V12 - 
      3.50568990092294541e-13*V08*V12 - 1.18081204682511872e-13*V013*V13 + 3.95761932360611793e-12*V02*V03*V13 + 
      2.37602171422117529e-12*V01*V04*V13 - 2.44874227567633878e-13*V07*V13 + 2.48384849849704798e-13*V022*V14 + 
      7.57584150042010379e-13*V01*V03*V14 - 1.12391703028323173e-13*V06*V14 + 1.1963490474412387e-13*V01*V02*V15 - 
      5.36951342721384656e-14*V05*V15 + 9.3222003696719899e-15*V012*V16 - 1.46935634398163269e-14*V04*V16 - 
      4.49463232109185227e-15*V03*V17 - 5.54892879147142256e-16*V02*V18 - 9.24821465245237093e-17*V01*V19 + 
      2.01048144618529803e-19*V22) + delta8*eps7*
    (-3.12288574815807931e-9*V044 - 6.13302756208529629e-8*V03*V042*V05 - 
      3.11053445414828857e-8*V032*V052 - 3.05407589414942356e-8*V02*V04*V052 - 
      6.13408242084712673e-9*V01*V053 - 4.34778369389713928e-8*V032*V04*V06 - 
      1.31957658023639972e-8*V02*V042*V06 - 4.3769553743682284e-8*V02*V03*V05*V06 - 
      2.60867021633828357e-8*V01*V04*V05*V06 - 2.31124277965236571e-9*V022*V062 - 
      9.11367606483152702e-9*V01*V03*V062 + 3.89361294085025683e-10*V063 - 
      9.73663876324940751e-9*V033*V07 - 2.90864370871373672e-8*V02*V03*V04*V07 - 
      8.76146794583613756e-9*V01*V042*V07 - 7.13092395077689195e-9*V022*V05*V07 - 
      1.71856509877829517e-8*V01*V03*V05*V07 - 6.252793391954612e-9*V01*V02*V06*V07 + 2.5282819527162001e-9*V05*V06*V07 - 
      5.70894510067401446e-10*V012*V072 + 8.58885837973415987e-10*V04*V072 - 
      8.03345795856689103e-9*V02*V032*V08 - 2.36162409365023744e-9*V022*V04*V08 - 
      9.43862429428878231e-9*V01*V03*V04*V08 - 4.82007477514013462e-9*V01*V02*V05*V08 + 
      9.90550771013638422e-10*V052*V08 - 9.52465488627175524e-10*V012*V06*V08 + 
      1.24013655702525207e-9*V04*V06*V08 + 9.70630955157051171e-10*V03*V07*V08 + 1.20233202577373189e-10*V02*V082 - 
      1.98081220854913665e-9*V022*V03*V09 - 2.30511380283789247e-9*V01*V032*V09 - 
      2.42386975726144727e-9*V01*V02*V04*V09 - 6.55688060858462352e-10*V012*V05*V09 + 
      1.03082561137740446e-9*V04*V05*V09 + 7.43326732405203706e-10*V03*V06*V09 + 2.56405271524897592e-10*V02*V07*V09 + 
      8.76982300491031469e-11*V01*V08*V09 - 8.45686342107132646e-11*V023*V10 - 1.06762277776516805e-9*V01*V02*V03*V10 - 
      3.02034852834339296e-10*V012*V04*V10 + 2.06123073726194409e-10*V042*V10 + 
      4.7748951503009169e-10*V03*V05*V10 + 1.50591515305042041e-10*V02*V06*V10 + 7.19068418752763738e-11*V01*V07*V10 - 
      6.67076525370678137e-13*V102 - 1.08044302284498363e-10*V01*V022*V11 - 
      1.12177144448386278e-10*V012*V03*V11 + 2.03127638655029436e-10*V03*V04*V11 + 
      1.03144968090215195e-10*V02*V05*V11 + 4.50206788567242398e-11*V01*V06*V11 - 1.29003346187058122e-12*V09*V11 - 
      2.30258349130898151e-11*V012*V02*V12 + 3.95028240664850572e-11*V032*V12 + 
      3.43243417611322668e-11*V02*V04*V12 + 2.42921004633035937e-11*V01*V05*V12 - 9.30432048801058198e-13*V08*V12 - 
      1.18081204682511872e-12*V013*V13 + 1.45685275777151709e-11*V02*V03*V13 + 8.81931944973023978e-12*V01*V04*V13 - 
      6.32855328667315743e-13*V07*V13 + 1.03165684091036688e-12*V022*V14 + 2.90075801502960086e-12*V01*V03*V14 - 
      3.05117097813708622e-13*V06*V14 + 4.73878518791659487e-13*V01*V02*V15 - 1.4295890209760875e-13*V05*V15 + 
      3.88425015402999579e-14*V012*V16 - 4.15429802188160502e-14*V04*V16 - 1.25775719273352245e-14*V03*V17 - 
      1.66467863744142677e-15*V02*V18 - 2.77446439573571128e-16*V01*V19 + 5.02620361546324507e-19*V22) + 
   eps11*(-9.01835117002665504e-8*V026 - 3.25916459348999032e-6*V01*V024*V03 - 
      7.35068548808628174e-6*V012*V022*V032 - 1.0854789500622834e-6*V013*V033 + 
      6.78100295225791258e-7*V02*V034 - 3.88445328921519398e-6*V012*V023*V04 - 
      4.99063464093225998e-6*V013*V02*V03*V04 + 2.84278006510562727e-6*V022*V032*V04 + 
      1.64707575731881287e-6*V01*V033*V04 - 2.84933320647606362e-7*V014*V042 + 
      5.87400058299529199e-7*V023*V042 + 3.58815504059799695e-6*V01*V02*V03*V042 + 
      3.5912954439740154e-7*V012*V043 - 2.81868399275952575e-8*V044 - 
      1.54110614180058625e-6*V013*V022*V05 - 4.60814262897596231e-7*V014*V03*V05 + 
      1.12000694579646299e-6*V023*V03*V05 + 3.00648528885136028e-6*V01*V02*V032*V05 + 
      2.15679602202006303e-6*V01*V022*V04*V05 + 1.75801937489685506e-6*V012*V03*V04*V05 - 
      3.02837308803974984e-7*V03*V042*V05 + 5.39000298734921751e-7*V012*V02*V052 - 
      1.30260107162109282e-7*V032*V052 - 1.81474604951678073e-7*V02*V04*V052 - 
      3.30907815972154207e-8*V01*V053 - 2.28841374674708008e-7*V014*V02*V06 + 
      1.2426335177657929e-7*V024*V06 + 1.53341242595954898e-6*V01*V022*V03*V06 + 
      6.11779025097477478e-7*V012*V032*V06 + 9.21724593289573448e-7*V012*V02*V04*V06 - 
      2.1732776138249265e-7*V032*V04*V06 - 1.45683102372722665e-7*V02*V042*V06 + 
      1.38048989425477521e-7*V013*V05*V06 - 2.61595716210939036e-7*V02*V03*V05*V06 - 
      1.66642922459441776e-7*V01*V04*V05*V06 - 3.13513920345541883e-8*V022*V062 - 
      5.92808427693683879e-8*V01*V03*V062 + 8.84509142307875836e-10*V063 - 
      1.08398545898545899e-8*V015*V07 + 2.24590985483015906e-7*V01*V023*V07 + 
      5.54011203192750812e-7*V012*V02*V03*V07 - 4.56228874516762589e-8*V033*V07 + 
      1.01933346911025482e-7*V013*V04*V07 - 1.91754429908024679e-7*V02*V03*V04*V07 - 
      6.13420781184067054e-8*V01*V042*V07 - 5.72043116871378037e-8*V022*V05*V07 - 
      1.03916952302356811e-7*V01*V03*V05*V07 - 5.3133259730785894e-8*V01*V02*V06*V07 + 4.73703555517935601e-9*V05*V06*V07 - 
      5.00584884186415077e-9*V012*V072 + 1.741265174578467e-9*V04*V072 + 
      1.12062015273820829e-7*V012*V022*V08 + 5.3898165877332544e-8*V013*V03*V08 - 
      5.36809105180029939e-8*V02*V032*V08 - 3.57374452845974788e-8*V022*V04*V08 - 
      6.77966188714758976e-8*V01*V03*V04*V08 - 4.12668507250089883e-8*V01*V02*V05*V08 + 
      1.84415328275492498e-9*V052*V08 - 8.89450891456902195e-9*V012*V06*V08 + 
      3.03796541544199087e-9*V04*V06*V08 + 1.95419862124377447e-9*V03*V07*V08 + 3.79246470634262349e-10*V02*V082 + 
      1.95719596761263428e-8*V013*V02*V09 - 1.87589213813852975e-8*V022*V03*V09 - 
      1.67786011778556713e-8*V01*V032*V09 - 2.41704845909809145e-8*V01*V02*V04*V09 - 
      6.17402338833098637e-9*V012*V05*V09 + 2.15772698503969466e-9*V04*V05*V09 + 1.55508035764887683e-9*V03*V06*V09 + 
      6.91653165373944804e-10*V02*V07*V09 + 2.50103168132130448e-10*V01*V08*V09 + 1.05387475179141846e-9*V014*V10 - 
      1.89829593813409562e-9*V023*V10 - 1.09471819705392301e-8*V01*V02*V03*V10 - 
      3.31517199332033599e-9*V012*V04*V10 + 5.66213951638936691e-10*V042*V10 + 
      9.90709445715168765e-10*V03*V05*V10 + 4.93857621869645393e-10*V02*V06*V10 + 2.04600194881280817e-10*V01*V07*V10 - 
      1.0592820988240287e-12*V102 - 1.62155014330259428e-9*V01*V022*V11 - 
      1.34701134241575418e-9*V012*V03*V11 + 4.83293552740012793e-10*V03*V04*V11 + 2.92311187466604348e-10*V02*V05*V11 + 
      1.35732624614622041e-10*V01*V06*V11 - 1.95010166215273807e-12*V09*V11 - 3.7815505799574427e-10*V012*V02*V12 + 
      9.37949305944393234e-11*V032*V12 + 1.29817854947928907e-10*V02*V04*V12 + 7.30666296474582508e-11*V01*V05*V12 - 
      1.49261560383255041e-12*V08*V12 - 2.47970529833274931e-11*V013*V13 + 4.77180131422584983e-11*V02*V03*V13 + 
      3.07298566685929087e-11*V01*V04*V13 - 9.64334462347839848e-13*V07*V13 + 5.53945861966731133e-12*V022*V14 + 
      1.02559741067008009e-11*V01*V03*V14 - 5.09835577360394305e-13*V06*V14 + 2.32278159210993748e-12*V01*V02*V15 - 
      2.25009062494166185e-13*V05*V15 + 2.09749508317619773e-13*V012*V16 - 7.75740245047704874e-14*V04*V16 - 
      2.20569919460989047e-14*V03*V17 - 4.16169659360356692e-15*V02*V18 - 6.9361609893392782e-16*V01*V19 + 
      7.53930542319486761e-19*V22) + delta6*eps8*
    (1.16714836456899949e-7*V02*V034 + 3.3167660895835499e-7*V022*V032*V04 + 
      2.55740273101384212e-7*V01*V033*V04 + 1.0639753805538638e-8*V023*V042 + 
      4.0211845767401323e-7*V01*V02*V03*V042 + 3.92643621810288477e-8*V012*V043 - 
      1.44647796358943781e-8*V044 + 1.06435773874045479e-7*V023*V03*V05 + 
      3.97805457329266853e-7*V01*V02*V032*V05 + 1.99005965375012994e-7*V01*V022*V04*V05 + 
      2.09450079241745908e-7*V012*V03*V04*V05 - 2.23205463736282545e-7*V03*V042*V05 + 
      5.46638381459810031e-8*V012*V02*V052 - 1.08785983451243074e-7*V032*V052 - 
      1.12518714013131224e-7*V02*V04*V052 - 2.20587498467400428e-8*V01*V053 + 
      1.74482785814355479e-9*V024*V06 + 1.40126628221866317e-7*V01*V022*V03*V06 + 
      6.90710946167295374e-8*V012*V032*V06 + 8.25320145756653693e-8*V012*V02*V04*V06 - 
      1.60306931018687944e-7*V032*V04*V06 - 6.23141806988030663e-8*V02*V042*V06 + 
      1.17976618472650219e-8*V013*V05*V06 - 1.63158892000544402e-7*V02*V03*V05*V06 - 
      9.83588207974490265e-8*V01*V04*V05*V06 - 1.11381689475890119e-8*V022*V062 - 
      3.48030855806882884e-8*V01*V03*V062 + 9.53886585144753617e-10*V063 + 
      1.52051105534350684e-8*V01*V023*V07 + 4.88653762463286273e-8*V012*V02*V03*V07 - 
      3.50760218509401516e-8*V033*V07 + 8.00084505441648299e-9*V013*V04*V07 - 
      1.0966831245289851e-7*V02*V03*V04*V07 - 3.33776917471737993e-8*V01*V042*V07 - 
      2.72838431539411932e-8*V022*V05*V07 - 6.36466502471469273e-8*V01*V03*V05*V07 - 
      2.43659066418494264e-8*V01*V02*V06*V07 + 5.73454430680343706e-9*V05*V06*V07 - 
      2.24285876770250149e-9*V012*V072 + 1.97943651812315506e-9*V04*V072 + 
      7.29348240922314996e-9*V012*V022*V08 + 3.81402291124513347e-9*V013*V03*V08 - 
      3.10448607244177324e-8*V02*V032*V08 - 1.1607382420290917e-8*V022*V04*V08 - 
      3.68885683428167088e-8*V01*V03*V04*V08 - 1.90217012623058375e-8*V01*V02*V05*V08 + 
      2.25567676854889474e-9*V052*V08 - 3.85231495904931946e-9*V012*V06*V08 + 
      3.10327793500338834e-9*V04*V06*V08 + 2.26552478541084656e-9*V03*V07*V08 + 3.14616699492002765e-10*V02*V082 + 
      1.00369023980135091e-9*V013*V02*V09 - 7.92456084758190786e-9*V022*V03*V09 - 
      9.03546132401563463e-9*V01*V032*V09 - 9.76593414783968783e-9*V01*V02*V04*V09 - 
      2.6475492964171769e-9*V012*V05*V09 + 2.41967965015243137e-9*V04*V05*V09 + 1.75967541052281089e-9*V03*V06*V09 + 
      6.25456165059616089e-10*V02*V07*V09 + 2.19248139960954814e-10*V01*V08*V09 + 4.01476095920540365e-11*V014*V10 - 
      4.41323816738797546e-10*V023*V10 - 4.45295468686769652e-9*V01*V02*V03*V10 - 
      1.27550192715147586e-9*V012*V04*V10 + 5.34938290003461784e-10*V042*V10 + 
      1.1361175216718043e-9*V03*V05*V10 + 4.00148693505997441e-10*V02*V06*V10 + 1.80018298529104411e-10*V01*V07*V10 - 
      1.37352914624220985e-12*V102 - 4.69963194636397251e-10*V01*V022*V11 - 
      4.90627405455836828e-10*V012*V03*V11 + 5.02893349542243018e-10*V03*V04*V11 + 
      2.59112630875115109e-10*V02*V05*V11 + 1.15332635287803027e-10*V01*V06*V11 - 2.59545595292284319e-12*V09*V11 - 
      1.05092272167435566e-10*V012*V02*V12 + 9.92078181483731716e-11*V032*V12 + 
      9.54439427562594958e-11*V02*V04*V12 + 6.26440027127202582e-11*V01*V05*V12 - 1.92513302396022541e-12*V08*V12 - 
      5.9040602341255936e-12*V013*V13 + 3.87855325380408513e-11*V02*V03*V13 + 2.3732250541102737e-11*V01*V04*V13 - 
      1.28109968651631223e-12*V07*V13 + 3.08841045580429443e-12*V022*V14 + 7.94458631504268473e-12*V01*V03*V14 - 
      6.42639939769610351e-13*V06*V14 + 1.37243505442393185e-12*V01*V02*V15 - 2.95332486711414013e-13*V05*V15 + 
      1.16527504620899874e-13*V012*V16 - 9.08914536043019015e-14*V04*V16 - 2.71897510782099705e-14*V03*V17 - 
      3.88425015402999579e-15*V02*V18 - 6.47375025671665965e-16*V01*V19 + 1.00524072309264901e-18*V22) + 
   delta2*eps10*(-1.05683802773749864e-9*V026 - 1.43624287969526065e-6*V01*V024*V03 - 
      4.03239837763647287e-6*V012*V022*V032 - 6.39695952195952196e-7*V013*V033 + 
      1.03731386283469617e-6*V02*V034 - 1.80719302743112267e-6*V012*V023*V04 - 
      2.58256954685526114e-6*V013*V02*V03*V04 + 3.76126895224117446e-6*V022*V032*V04 + 
      2.41349362443112443e-6*V01*V033*V04 - 1.39266322302036588e-7*V014*V042 + 
      5.67501373552960855e-7*V023*V042 + 4.64213503648027458e-6*V01*V02*V03*V042 + 
      4.56605646337789195e-7*V012*V043 - 4.8511255774108832e-8*V044 - 
      6.58099616432949766e-7*V013*V022*V05 - 2.11015836015836016e-7*V014*V03*V05 + 
      1.29053917496377814e-6*V023*V03*V05 + 3.9946842867229772e-6*V01*V02*V032*V05 + 
      2.44500548319992764e-6*V01*V022*V04*V05 + 2.24826843130414559e-6*V012*V03*V04*V05 - 
      5.60125414233724224e-7*V03*V042*V05 + 6.19076139909473243e-7*V012*V02*V052 - 
      2.49438911785360782e-7*V032*V052 - 3.07119530720429413e-7*V02*V04*V052 - 
      5.691691187504096e-8*V01*V053 - 8.67188367188367188e-8*V014*V02*V06 + 
      1.01721424886107426e-7*V024*V06 + 1.76647646885742124e-6*V01*V022*V03*V06 + 
      7.76630845455250217e-7*V012*V032*V06 + 1.04599434956577814e-6*V012*V02*V04*V06 - 
      4.0652457348302353e-7*V032*V04*V06 - 2.31405524903132279e-7*V02*V042*V06 + 
      1.52463415112224636e-7*V013*V05*V06 - 4.49494829929295382e-7*V02*V03*V05*V06 - 
      2.8006164438601997e-7*V01*V04*V05*V06 - 4.55565553349458578e-8*V022*V062 - 
      1.00457618621134027e-7*V01*V03*V062 + 1.71256554412201539e-9*V063 - 
      3.61328486328486328e-9*V015*V07 + 2.13711461231302501e-7*V01*V023*V07 + 
      6.20745133393942918e-7*V012*V02*V03*V07 - 8.67051308647217844e-8*V033*V07 + 
      1.10772990237275952e-7*V013*V04*V07 - 3.23151314667712894e-7*V02*V03*V04*V07 - 
      1.01333081107021933e-7*V01*V042*V07 - 8.70315157488360103e-8*V022*V05*V07 - 
      1.77061130153304523e-7*V01*V03*V05*V07 - 8.07420722001137501e-8*V01*V02*V06*V07 + 9.36414228087805413e-9*V05*V06*V07 - 
      7.52927932914510879e-9*V012*V072 + 3.39053821003755583e-9*V04*V072 + 
      1.08217881655381655e-7*V012*V022*V08 + 5.69694580111246778e-8*V013*V03*V08 - 
      9.20055009399080361e-8*V02*V032*V08 - 5.09313924784279593e-8*V022*V04*V08 - 
      1.13208170487071631e-7*V01*V03*V04*V08 - 6.28664755448281359e-8*V01*V02*V05*V08 + 
      3.65860240983193125e-9*V052*V08 - 1.33508092355693896e-8*V012*V06*V08 + 
      5.81472070492569043e-9*V04*V06*V08 + 3.86604911270109038e-9*V03*V07*V08 + 6.69355072471856466e-10*V02*V082 + 
      1.80664243164243164e-8*V013*V02*V09 - 2.83619245526925265e-8*V022*V03*V09 - 
      2.81638855036964281e-8*V01*V032*V09 - 3.58774136840050706e-8*V01*V02*V04*V09 - 
      9.23462495591347132e-9*V012*V05*V09 + 4.20004124525269606e-9*V04*V05*V09 + 3.06443310291299597e-9*V03*V06*V09 + 
      1.23744774342815094e-9*V02*V07*V09 + 4.45845885430025007e-10*V01*V08*V09 + 9.03321215821215821e-10*V014*V10 - 
      2.36809044533523214e-9*V023*V10 - 1.64647371186236732e-8*V01*V02*V03*V10 - 
      4.8689519595069315e-9*V012*V04*V10 + 1.06738757717012689e-9*V042*V10 + 
      1.95993066468536445e-9*V03*V05*V10 + 8.68331150576541423e-10*V02*V06*V10 + 3.64912169506311622e-10*V01*V07*V10 - 
      2.10980781986575818e-12*V102 - 2.1210336391096195e-9*V01*V022*V11 - 
      1.96605205796382267e-9*V012*V03*V11 + 9.3749562552640253e-10*V03*V04*V11 + 5.22594784223503694e-10*V02*V05*V11 + 
      2.40847369943663066e-10*V01*V06*V11 - 3.90006460108568935e-12*V09*V11 - 4.91513014490955667e-10*V012*V02*V12 + 
      1.84496333387633329e-10*V032*V12 + 2.23917921136611244e-10*V02*V04*V12 + 1.29959796546414746e-10*V01*V05*V12 - 
      2.97043406422117702e-12*V08*V12 - 3.09963162291593664e-11*V013*V13 + 8.4929129617865858e-11*V02*V03*V13 + 
      5.3556817973796388e-11*V01*V04*V13 - 1.92853020147589291e-12*V07*V13 + 8.62458904200820265e-12*V022*V14 + 
      1.80431188155001364e-11*V01*V03*V14 - 1.01084835794234905e-12*V06*V14 + 3.67061639555834602e-12*V01*V02*V15 - 
      4.49879401768545584e-13*V05*V15 + 3.26277012938519646e-13*V012*V16 - 1.51596734582999264e-13*V04*V16 - 
      4.39752606724110238e-14*V03*V17 - 7.49105386848642045e-15*V02*V18 - 1.24850897808107008e-15*V01*V19 + 
      1.50786108463897352e-18*V22) + delta4*eps9*
    (5.77265272205748396e-7*V02*V034 + 1.82975598402185704e-6*V022*V032*V04 + 
      1.29435893324782214e-6*V01*V033*V04 + 1.71045640622360199e-7*V023*V042 + 
      2.22836898184120406e-6*V01*V02*V03*V042 + 2.17760634427301094e-7*V012*V043 - 
      3.60906857706966639e-8*V044 + 5.88336453498490536e-7*V023*V03*V05 + 
      2.02834900255535176e-6*V01*V02*V032*V05 + 1.09785359041311422e-6*V01*V022*V04*V05 + 
      1.10349719724719725e-6*V012*V03*V04*V05 - 4.68083420578654783e-7*V03*V042*V05 + 
      2.91282378335949765e-7*V012*V02*V052 - 2.17885800504264557e-7*V032*V052 - 
      2.43074095879106772e-7*V02*V04*V052 - 4.63433304017454344e-8*V01*V053 + 
      2.92978136893480809e-8*V024*V06 + 7.90223105451280054e-7*V01*V022*V03*V06 + 
      3.71694599125154681e-7*V012*V032*V06 + 4.64519313725662932e-7*V012*V02*V04*V06 - 
      3.39387086707542668e-7*V032*V04*V06 - 1.61809756133596781e-7*V02*V042*V06 + 
      6.75684269434269434e-8*V013*V05*V06 - 3.55806643708089008e-7*V02*V03*V05*V06 - 
      2.17671871098866897e-7*V01*V04*V05*V06 - 3.00604608299908642e-8*V022*V062 - 
      7.77819282174149121e-8*V01*V03*V062 + 1.60833310225194172e-9*V063 + 
      8.40480647854986479e-8*V01*V023*V07 + 2.70296649264903233e-7*V012*V02*V03*V07 - 
      7.32294648124869102e-8*V033*V07 + 4.66974053283577093e-8*V013*V04*V07 - 
      2.46677484412856339e-7*V02*V03*V04*V07 - 7.61219370190736515e-8*V01*V042*V07 - 
      6.29359832025273202e-8*V022*V05*V07 - 1.38998120525801042e-7*V01*V03*V05*V07 - 
      5.7467395205441813e-8*V01*V02*V06*V07 + 9.13001277706507386e-9*V05*V06*V07 - 
      5.30907153538845104e-9*V012*V072 + 3.22444623072974743e-9*V04*V072 + 
      4.26367613867613868e-8*V012*V022*V08 + 2.3125023125023125e-8*V013*V03*V08 - 
      7.06136849830438377e-8*V02*V032*V08 - 3.23479074354424494e-8*V022*V04*V08 - 
      8.51545756400059232e-8*V01*V03*V04*V08 - 4.4997879418105842e-8*V01*V02*V05*V08 + 
      3.58588104686483122e-9*V052*V08 - 9.33831149945373413e-9*V012*V06*V08 + 
      5.35219682347953734e-9*V04*V06*V08 + 3.70330815615235731e-9*V03*V07*V08 + 5.74573573165675699e-10*V02*V082 + 
      6.62435558268891602e-9*V013*V02*V09 - 1.95347640966513516e-8*V022*V03*V09 - 
      2.10785071604399335e-8*V01*V032*V09 - 2.43510434044981197e-8*V01*V02*V04*V09 - 
      6.44571558874780163e-9*V012*V05*V09 + 3.98584660105880436e-9*V04*V05*V09 + 2.91333022299243766e-9*V03*V06*V09 + 
      1.09040704931153581e-9*V02*V07*V09 + 3.89198166147944597e-10*V01*V08*V09 + 3.01107071940405274e-10*V014*V10 - 
      1.34500115047889713e-9*V023*V10 - 1.12181361634267797e-8*V01*V02*V03*V10 - 
      3.25870387436680621e-9*V012*V04*V10 + 9.5573417761393829e-10*V042*V10 + 
      1.87501133817503019e-9*V03*V05*V10 + 7.39981468201118634e-10*V02*V06*V10 + 3.1894243886195272e-10*V01*V07*V10 - 
      2.09271123396052009e-12*V102 - 1.28944675513302964e-9*V01*V022*V11 - 
      1.29121797320326732e-9*V012*V03*V11 + 8.658560693855349e-10*V03*V04*V11 + 4.59043272703367589e-10*V02*V05*V11 + 
      2.08292359616979377e-10*V01*V06*V11 - 3.89895481532739506e-12*V09*V11 - 2.9520301170627968e-10*V012*V02*V12 + 
      1.71398086975365036e-10*V032*V12 + 1.84287767650791223e-10*V02*V04*V12 + 1.129495553361591e-10*V01*V05*V12 - 
      2.94167211665205015e-12*V08*V12 - 1.77121807023767808e-11*V013*V13 + 7.22146841136743384e-11*V02*V03*V13 + 
      4.47838505759042395e-11*V01*V04*V13 - 1.92742041571759863e-12*V07*V13 + 6.47582185679880898e-12*V022*V14 + 
      1.51042951489610416e-11*V01*V03*V14 - 9.94035103704190637e-13*V06*V14 + 2.80831286136368696e-12*V01*V02*V15 - 
      4.48769616010251299e-13*V05*V15 + 2.44707759703889735e-13*V012*V16 - 1.45326445048636557e-13*V04*V16 - 
      4.28654749141167393e-14*V03*V17 - 6.65871454976570707e-15*V02*V18 - 1.10978575829428451e-15*V01*V19 + 
      1.50786108463897352e-18*V22) + 3.86817017063068404e-23*delta22*V22 + 
   2.12749359384687622e-22*delta20*eps*V22 + 
   delta20*eps2*(-3.41091377476043088e-18*V112 - 5.24755965347758597e-18*V10*V12 - 
      4.81026301568778714e-18*V09*V13 - 2.56547360836681981e-18*V08*V14 - 1.64923303395009845e-18*V07*V15 - 
      5.82082247276505334e-19*V06*V16 - 2.54660983183471084e-19*V05*V17 - 5.36128385649412808e-20*V04*V18 - 
      1.48924551569281335e-20*V03*V19 - 1.41832906256458415e-21*V02*V20 - 2.12749359384687622e-22*V01*V21 + 
      2.12749359384687622e-24*V24) + delta18*eps3*
    (-3.41091377476043088e-17*V112 - 5.24755965347758597e-17*V10*V12 - 4.81026301568778714e-17*V09*V13 - 
      2.56547360836681981e-17*V08*V14 - 1.64923303395009845e-17*V07*V15 - 5.82082247276505334e-18*V06*V16 - 
      2.54660983183471084e-18*V05*V17 - 5.36128385649412808e-19*V04*V18 - 1.48924551569281335e-19*V03*V19 - 
      1.41832906256458415e-20*V02*V20 - 2.12749359384687622e-21*V01*V21 + 1.06374679692343811e-23*V24) + 
   delta16*eps4*(1.95275788151827456e-13*V06*V072 + 1.10155572803594975e-13*V062*V08 + 
      3.00424289464349933e-13*V05*V07*V08 + 5.69431659769029285e-14*V04*V082 + 2.27821752843798699e-13*V05*V06*V09 + 
      1.53157480903394083e-13*V04*V07*V09 + 8.34511915178749814e-14*V03*V08*V09 + 1.07059094381484351e-14*V02*V092 + 
      7.06059151375409192e-14*V052*V10 + 6.95537485590207015e-14*V04*V06*V10 + 6.7243728702419923e-14*V03*V07*V10 + 
      1.28135148350630137e-14*V02*V08*V10 + 5.60364405853499358e-15*V01*V09*V10 + 5.84783108903868319e-14*V04*V05*V11 + 
      4.14221368806906726e-14*V03*V06*V11 + 1.40150087190306787e-14*V02*V07*V11 + 4.55188317370227171e-15*V01*V08*V11 - 
      2.06888162885766611e-16*V112 + 7.37226568917269889e-15*V042*V12 + 2.1242121477277268e-14*V03*V05*V12 + 
      5.25463004964227156e-15*V02*V06*V12 + 3.03458878246818114e-15*V01*V07*V12 - 3.25473640412121701e-16*V10*V12 + 
      7.4972193449213887e-15*V03*V04*V13 + 3.77327157820056734e-15*V02*V05*V13 + 1.5931591107957951e-15*V01*V06*V13 - 
      2.93082453741548745e-16*V09*V13 + 1.13797079342556793e-15*V032*V14 + 7.91999487189063994e-16*V02*V04*V14 + 
      6.82782476055340757e-16*V01*V05*V14 - 1.60525348637809582e-16*V08*V14 + 3.59359197923863556e-16*V02*V03*V15 + 
      2.14206266997753963e-16*V01*V04*V15 - 1.01840139846418579e-16*V07*V15 + 1.55017693222058789e-17*V022*V16 + 
      5.35515667494384907e-17*V01*V03*V16 - 3.70592364099375063e-17*V06*V16 + 7.9270411306734608e-18*V01*V02*V17 - 
      1.60739587242709963e-17*V05*V17 + 4.40391173926303378e-19*V012*V18 - 3.50142895675318888e-18*V04*V18 - 
      9.68541458598790399e-19*V03*V19 - 9.57372117231094299e-20*V02*V20 - 1.43605817584664145e-20*V01*V21 + 
      4.7868605861554715e-23*V24) + delta14*eps5*
    (2.05039577559418829e-12*V06*V072 + 1.23173958680383473e-12*V062*V08 + 
      3.16697271810335554e-12*V05*V07*V08 + 6.37501651281648877e-13*V04*V082 + 2.39212840485988634e-12*V05*V06*V09 + 
      1.60336737820740681e-12*V04*V07*V09 + 8.79714643917598762e-13*V03*V08*V09 + 1.11817276353994767e-13*V02*V092 + 
      7.48422700457933743e-13*V052*V10 + 7.8015382937856978e-13*V04*V06*V10 + 7.12783524245651184e-13*V03*V07*V10 + 
      1.44021970804301276e-13*V02*V08*V10 + 5.9398627020470932e-14*V01*V09*V10 + 6.12194817133737146e-13*V04*V05*V11 + 
      4.34932437247252062e-13*V03*V06*V11 + 1.46378979954320422e-13*V02*V07*V11 + 4.79844351227781143e-14*V01*V08*V11 - 
      9.47746755987005437e-16*V112 + 8.32191347286274146e-14*V042*V12 + 2.27025173288400802e-13*V03*V05*V12 + 
      5.93661394970222595e-14*V02*V06*V12 + 3.24321676126286859e-14*V01*V07*V12 - 1.54428184088054673e-15*V10*V12 + 
      7.8486515017145788e-14*V03*V04*V13 + 3.94097253723170367e-14*V02*V05*V13 + 1.67281706633558485e-14*V01*V06*V13 - 
      1.35237108783908073e-15*V09*V13 + 1.23280169287769859e-14*V032*V14 + 9.06336779704970386e-15*V02*V04*V14 + 
      7.39681015726619153e-15*V01*V05*V14 - 7.71841059888646073e-16*V08*V14 + 3.75330717831590825e-15*V02*V03*V15 + 
      2.2424718576327368e-15*V01*V04*V15 - 4.79926812879478648e-16*V07*V15 + 1.82732977767820815e-16*V022*V16 + 
      5.95761180087503209e-16*V01*V03*V16 - 1.82773825644822675e-16*V06*V16 + 8.2793540698145035e-17*V01*V02*V17 - 
      7.82900622586899674e-17*V05*V17 + 5.28469408711564053e-18*V012*V18 - 1.78913701268146903e-17*V04*V18 - 
      4.9208926825678247e-18*V03*V19 - 5.10598462523250293e-19*V02*V20 - 7.65897693784875439e-20*V01*V21 + 
      1.9147442344621886e-22*V24) + delta12*eps6*
    (-1.81710194045720362e-10*V042*V052 - 1.29792995746943115e-10*V03*V053 - 
      4.18662090202051216e-11*V043*V06 - 5.14805050014601672e-10*V03*V04*V05*V06 - 
      1.29420107732156236e-10*V02*V052*V06 - 9.01865811069624174e-11*V032*V062 - 
      4.40269978275238859e-11*V02*V04*V062 - 5.41119486641774504e-11*V01*V05*V062 - 
      1.7305732766259082e-10*V03*V042*V07 - 1.82550878953343448e-10*V032*V05*V07 - 
      1.71981279391348682e-10*V02*V04*V05*V07 - 5.3904957766173305e-11*V01*V052*V07 - 
      1.23257245459196415e-10*V02*V03*V06*V07 - 7.35435785735145245e-11*V01*V04*V06*V07 - 
      9.95785605773606822e-12*V022*V072 - 2.49971695512631185e-11*V01*V03*V072 + 
      1.15250268045761243e-11*V06*V072 - 9.3124342549990002e-11*V032*V04*V08 - 
      2.23761745508195875e-11*V02*V042*V08 - 9.46468041976648278e-11*V02*V03*V05*V08 - 
      5.58746055299940012e-11*V01*V04*V05*V08 - 7.76241046146929228e-12*V022*V06*V08 - 
      3.85115190357462705e-11*V01*V03*V06*V08 + 7.53554676494466446e-12*V062*V08 - 
      1.35209720282378325e-11*V01*V02*V07*V08 + 1.79154934532962937e-11*V05*V07*V08 - 
      9.82119292914208671e-13*V012*V082 + 3.92859226055028743e-12*V04*V082 - 
      1.63718061254146838e-11*V033*V09 - 4.77725776087079673e-11*V02*V03*V04*V09 - 
      1.44214439718825684e-11*V01*V042*V09 - 1.16174987340254129e-11*V022*V05*V09 - 
      2.86854167432348997e-11*V01*V03*V05*V09 - 1.02714371215997013e-11*V01*V02*V06*V09 + 1.35496295737393273e-11*V05*V06*V09 - 
      1.84187443018241419e-12*V012*V07*V09 + 9.10052682992914154e-12*V04*V07*V09 + 
      5.05222430881163618e-12*V03*V08*V09 + 6.46063149296892166e-13*V02*V092 - 
      1.04307530326792808e-11*V02*V032*V10 - 2.36513594902759535e-12*V022*V04*V10 - 
      1.21170650938357241e-11*V01*V03*V04*V10 - 6.25845181960756846e-12*V01*V02*V05*V10 + 
      4.29758799138050964e-12*V052*V10 - 1.19770545225693172e-12*V012*V06*V10 + 
      4.84506694116438835e-12*V04*V06*V10 + 4.12322028399698023e-12*V03*V07*V10 + 9.06863113883747762e-13*V02*V08*V10 + 
      3.51171525289348256e-13*V01*V09*V10 - 2.11227249709552962e-12*V022*V03*V11 - 
      2.44960790856780832e-12*V01*V032*V11 - 2.60577696047498003e-12*V01*V02*V04*V11 - 
      6.77191269711172409e-13*V012*V05*V11 + 3.52815936324254369e-12*V04*V05*V11 + 
      2.52016808708015893e-12*V03*V06*V11 + 8.52167490935571267e-13*V02*V07*V11 + 2.83833873160198232e-13*V01*V08*V11 - 
      3.51413879689133865e-15*V112 - 5.41772745293529826e-14*V023*V12 - 
      9.0682813881742576e-13*V01*V02*V03*V12 - 2.52291295718900679e-13*V012*V04*V12 + 
      5.289041628784641e-13*V042*V12 + 1.34433281283334658e-12*V03*V05*V12 + 3.79763754107156185e-13*V02*V06*V12 + 
      1.94742738674907059e-13*V01*V07*V12 - 5.94631364944065399e-15*V10*V12 - 8.12412498882896009e-14*V01*V022*V13 - 
      7.79957430929223155e-14*V012*V03*V13 + 4.66023701813509939e-13*V03*V04*V13 + 
      2.34608709303411746e-13*V02*V05*V13 + 1.0055768755904512e-13*V01*V06*V13 - 5.05191543929168149e-15*V09*V13 - 
      1.32927671937915412e-14*V012*V02*V14 + 7.5919621661387341e-14*V032*V14 + 
      5.98495128495237701e-14*V02*V04*V14 + 4.58452496751368932e-14*V01*V05*V14 - 3.0134525591120312e-15*V08*V14 - 
      5.17900020537332772e-16*V013*V15 + 2.31657501249873611e-14*V02*V03*V15 + 1.3901916265566404e-14*V01*V04*V15 - 
      1.83240640289184556e-15*V07*V15 + 1.26762195502947164e-15*V022*V16 + 3.87685158230803389e-15*V01*V03*V16 - 
      7.33048341698442132e-16*V06*V16 + 5.36396449842237514e-16*V01*V02*V17 - 3.09533723454688484e-16*V05*V17 + 
      3.69928586098094837e-17*V012*V18 - 7.45754584438333215e-17*V04*V18 - 2.03728786546776867e-17*V03*V19 - 
      2.23386827353922003e-18*V02*V20 - 3.35080241030883005e-19*V01*V21 + 6.7016048206176601e-22*V24) + 
   delta10*eps7*(-1.70557610707464509e-9*V042*V052 - 1.19217270167562565e-9*V03*V053 - 
      5.01323905320006685e-10*V043*V06 - 4.86215725920891613e-9*V03*V04*V05*V06 - 
      1.21733642787349358e-9*V02*V052*V06 - 8.59173938356269183e-10*V032*V062 - 
      5.31289659696870534e-10*V02*V04*V062 - 5.1550436301376151e-10*V01*V05*V062 - 
      1.6243581972139477e-9*V03*V042*V07 - 1.68494184567353601e-9*V032*V05*V07 - 
      1.61287383824424957e-9*V02*V04*V05*V07 - 5.00033949543139184e-10*V01*V052*V07 - 
      1.15936802654618436e-9*V02*V03*V06*V07 - 6.94593894172702304e-10*V01*V04*V06*V07 - 
      9.39246312560111764e-11*V022*V072 - 2.33856304153575109e-10*V01*V03*V072 + 
      4.44102205900675288e-11*V06*V072 - 8.89988989578240483e-10*V032*V04*V08 - 
      2.7239765423050433e-10*V02*V042*V08 - 8.9868083163720132e-10*V02*V03*V05*V08 - 
      5.3399339374694429e-10*V01*V04*V05*V08 - 9.55675284983031473e-11*V022*V06*V08 - 
      3.723987620360497e-10*V01*V03*V06*V08 + 3.1674494679726012e-11*V062*V08 - 
      1.28382975948171617e-10*V01*V02*V07*V08 + 6.94986314416835163e-11*V05*V07*V08 - 
      9.71432467093597043e-12*V012*V082 + 1.67162671835187365e-11*V04*V082 - 
      1.52649797958091841e-10*V033*V09 - 4.48020510623402657e-10*V02*V03*V04*V09 - 
      1.35363183101162308e-10*V01*V042*V09 - 1.09578736465346372e-10*V022*V05*V09 - 
      2.69805352535325616e-10*V01*V03*V05*V09 - 9.66140022121820299e-11*V01*V02*V06*V09 + 5.29256680159109844e-11*V05*V06*V09 - 
      1.79602794741199031e-11*V012*V07*V09 + 3.57673098659722354e-11*V04*V07*V09 + 2.0127259476718193e-11*V03*V08*V09 + 
      2.61853949669536431e-12*V02*V092 - 1.00756215900251097e-10*V02*V032*V10 - 
      2.97018917149718008e-11*V022*V04*V10 - 1.18149015058534227e-10*V01*V03*V04*V10 - 
      6.04537295401506583e-11*V01*V02*V05*V10 + 1.69961237638805225e-11*V052*V10 - 
      1.19030688053496982e-11*V012*V06*V10 + 2.08588297254544514e-11*V04*V06*V10 + 
      1.65213712420960515e-11*V03*V07*V10 + 3.99657392471796277e-12*V02*V08*V10 + 1.46042761310808322e-12*V01*V09*V10 - 
      1.99234066300629768e-11*V022*V03*V11 - 2.35260967386419907e-11*V01*V032*V11 - 
      2.44374823976401449e-11*V01*V02*V04*V11 - 6.69245203681785332e-12*V012*V05*V11 + 
      1.42250735474288297e-11*V04*V05*V11 + 1.02303454542559249e-11*V03*V06*V11 + 3.49571416005116678e-12*V02*V07*V11 + 
      1.18753241613923411e-12*V01*V08*V11 - 1.07722042660262976e-14*V112 - 7.15353102653051873e-13*V023*V12 - 
      9.02525129503932721e-12*V01*V02*V03*V12 - 2.54954781538806962e-12*V012*V04*V12 + 
      2.35514294482179882e-12*V042*V12 + 5.54943436053908996e-12*V03*V05*V12 + 1.71018478591264041e-12*V02*V06*V12 + 
      8.23411708842879362e-13*V01*V07*V12 - 1.88276916619772124e-14*V10*V12 - 7.6628487038703757e-13*V01*V022*V13 - 
      8.02123551808220998e-13*V012*V03*V13 + 1.96948746143338698e-12*V03*V04*V13 + 
      9.95921739493290921e-13*V02*V05*V13 + 4.32416922861785017e-13*V01*V06*V13 - 1.55700618665683636e-14*V09*V13 - 
      1.39833005545079848e-13*V012*V02*V14 + 3.29532384496182881e-13*V032*V14 + 
      2.80820188278785753e-13*V02*V04*V14 + 2.01241150837363591e-13*V01*V05*V14 - 9.65495738769839211e-15*V08*V14 - 
      6.21480024644799327e-15*V013*V15 + 1.03543011248856745e-13*V02*V03*V15 + 6.25179310505780275e-14*V01*V04*V15 - 
      5.74558068332762718e-15*V07*V15 + 6.30358310711153603e-15*V022*V16 + 1.7985927856089371e-14*V01*V03*V16 - 
      2.40764535427438304e-15*V06*V16 + 2.55250724407685438e-15*V01*V02*V17 - 1.00124656661956089e-15*V05*V17 + 
      1.84964293049047419e-16*V012*V18 - 2.54660983183471084e-16*V04*V18 - 6.9026529652361899e-17*V03*V19 - 
      8.04192578474119211e-18*V02*V20 - 1.20628886771117882e-18*V01*V21 + 2.01048144618529803e-21*V24) + 
   delta8*eps8*(1.12851894189429203e-8*V034*V04 + 
      3.22772161542391857e-8*V02*V032*V042 + 1.32727772394750297e-9*V022*V043 + 
      1.28988759163051102e-8*V01*V03*V043 + 2.32560932622207132e-8*V02*V033*V05 + 
      3.15213839859809359e-8*V022*V03*V04*V05 + 3.88793049954736852e-8*V01*V032*V04*V05 + 
      1.93663296925435114e-8*V01*V02*V042*V05 + 2.50509275733948937e-9*V023*V052 + 
      2.01676793537496152e-8*V01*V02*V03*V052 + 5.42296366876198809e-9*V012*V04*V052 - 
      7.79716800769014296e-9*V042*V052 - 5.26980793180764275e-9*V03*V053 + 
      1.12944672278822606e-8*V022*V032*V06 + 8.727044463213931e-9*V01*V033*V06 + 
      8.90219825015965694e-10*V023*V04*V06 + 2.72517925412416542e-8*V01*V02*V03*V04*V06 + 
      3.97332007927635067e-9*V012*V042*V06 - 2.82619430165753763e-9*V043*V06 + 
      6.77668033672935634e-9*V01*V022*V05*V06 + 7.21389005435262827e-9*V012*V03*V05*V06 - 
      2.24289006366088539e-8*V03*V04*V05*V06 - 5.65439409962507944e-9*V02*V052*V06 + 
      1.39900924433487459e-9*V012*V02*V062 - 4.00160730277563195e-9*V032*V062 - 
      3.03640156876773161e-9*V02*V04*V062 - 2.43622427282075352e-9*V01*V05*V062 + 
      2.38580262603760892e-9*V023*V03*V07 + 9.24041655785742309e-9*V01*V02*V032*V07 + 
      4.5030548551401337e-9*V01*V022*V04*V07 + 4.91510203033701322e-9*V012*V03*V04*V07 - 
      7.54012879201343963e-9*V03*V042*V07 + 2.57138691939695675e-9*V012*V02*V05*V07 - 
      7.59338696663967903e-9*V032*V05*V07 - 7.5484574628484751e-9*V02*V04*V05*V07 - 
      2.29457182461032637e-9*V01*V052*V07 + 2.82523339489181381e-10*V013*V06*V07 - 
      5.4663977239129376e-9*V02*V03*V06*V07 - 3.30056967893175719e-9*V01*V04*V06*V07 - 
      4.51109044388735651e-10*V022*V072 - 1.09454741335667439e-9*V01*V03*V072 + 
      1.26631398443508704e-10*V06*V072 + 3.65989257687912458e-11*V024*V08 + 
      2.43314756620078749e-9*V01*V022*V03*V08 + 1.21284391647629535e-9*V012*V032*V08 + 
      1.42878257665839365e-9*V012*V02*V04*V08 - 4.21187584438707663e-9*V032*V04*V08 - 
      1.57900113818356684e-9*V02*V042*V08 + 2.09303621061842869e-10*V013*V05*V08 - 
      4.27845468704313461e-9*V02*V03*V05*V08 - 2.56344641051699639e-9*V01*V04*V05*V08 - 
      5.6232564871173011e-10*V022*V06*V08 - 1.80530156382735475e-9*V01*V03*V06*V08 + 
      9.74318743872451483e-11*V062*V08 - 6.28867334096473348e-10*V01*V02*V07*V08 + 
      1.99076135566589245e-10*V05*V07*V08 - 4.90493244688611919e-11*V012*V082 + 
      5.22622857692870916e-11*V04*V082 + 1.98816885503134077e-10*V01*V023*V09 + 
      6.53734098066692215e-10*V012*V02*V03*V09 - 7.14665652030552913e-10*V033*V09 + 
      1.07959958566867997e-10*V013*V04*V09 - 2.16039515045621509e-9*V02*V03*V04*V09 - 
      6.56907690744922031e-10*V01*V042*V09 - 5.34141365181383528e-10*V022*V05*V09 - 
      1.28674492004969786e-9*V01*V03*V05*V09 - 4.75848265203103142e-10*V01*V02*V06*V09 + 1.53293911446729409e-10*V05*V06*V09 - 
      8.93781990681032949e-11*V012*V07*V09 + 1.04748497532374607e-10*V04*V07*V09 + 
      5.96375848728657949e-11*V03*V08*V09 + 8.00285623282956963e-12*V02*V092 + 
      7.68511840475348101e-11*V012*V022*V10 + 4.10332186271728755e-11*V013*V03*V10 - 
      4.99307533109571225e-10*V02*V032*V10 - 1.79761814709409732e-10*V022*V04*V10 - 
      5.90560875518700023e-10*V01*V03*V04*V10 - 3.03615680992265154e-10*V01*V02*V05*V10 + 
      4.95593811626264585e-11*V052*V10 - 6.1010472062228291e-11*V012*V06*V10 + 
      6.60909927939994441e-11*V04*V06*V10 + 4.90642617367695468e-11*V03*V07*V10 + 1.30867700317987669e-11*V02*V08*V10 + 
      4.56632279958408988e-12*V01*V09*V10 + 8.75768934728629718e-12*V013*V02*V11 - 
      1.01397055520901697e-10*V022*V03*V11 - 1.18628329061350954e-10*V01*V032*V11 - 
      1.24778071200457163e-10*V01*V02*V04*V11 - 3.4528579333517025e-11*V012*V05*V11 + 
      4.27939492219946726e-11*V04*V05*V11 + 3.09900829324836135e-11*V03*V06*V11 + 1.08063045332860666e-11*V02*V07*V11 + 
      3.74521866042146181e-12*V01*V08*V11 - 2.71163685054242072e-14*V112 + 2.9520301170627968e-13*V014*V12 - 
      4.5881009438459709e-12*V023*V12 - 4.77907041094267739e-11*V01*V02*V03*V12 - 
      1.3647553369765354e-11*V012*V04*V12 + 7.75800666716767563e-12*V042*V12 + 
      1.69422051777957712e-11*V03*V05*V12 + 5.72886205574953589e-12*V02*V06*V12 + 2.60664012717587559e-12*V01*V07*V12 - 
      4.85079215546758719e-14*V10*V12 - 4.17427416553090214e-12*V01*V022*V13 - 
      4.44746642636434518e-12*V012*V03*V13 + 6.23590467228488958e-12*V03*V04*V13 + 
      3.18383353458829799e-12*V02*V05*V13 + 1.40300965206493938e-12*V01*V06*V13 - 3.92968703471378353e-14*V09*V13 - 
      8.00155531730179133e-13*V012*V02*V14 + 1.06004577715517818e-12*V032*V14 + 
      9.83467477094655061e-13*V02*V04*V14 + 6.59268229714719714e-13*V01*V05*V14 - 2.50933103808588833e-14*V08*V14 - 
      3.88425015402999579e-14*V013*V15 + 3.49335894805300891e-13*V02*V03*V15 + 2.12560965571965293e-13*V01*V04*V15 - 
      1.46526903520153798e-14*V07*V15 + 2.35521199815787046e-14*V022*V16 + 6.23329667575289801e-14*V01*V03*V16 - 
      6.38931003597687713e-15*V06*V16 + 9.24821465245237093e-15*V01*V02*V17 - 2.61613898184861906e-15*V05*V17 + 
      6.9361609893392782e-16*V012*V18 - 7.01658024718669012e-16*V04*V18 - 1.8848263557987169e-16*V03*V19 - 
      2.34556168721618103e-17*V02*V20 - 3.51834253082427155e-18*V01*V21 + 5.02620361546324507e-21*V24) + 
   eps12*(4.38492191964414187e-7*V012*V025 + 1.56443190297356964e-6*V013*V023*V03 + 
      6.26423152464819131e-7*V014*V02*V032 - 6.15952990446624706e-7*V024*V032 - 
      2.13342389991695547e-6*V01*V022*V033 - 4.02632490461111493e-7*V012*V034 + 
      4.3106488418988419e-7*V014*V022*V04 - 1.43889032777921667e-7*V025*V04 + 
      9.17774355274355274e-8*V015*V03*V04 - 3.11017509368203813e-6*V01*V023*V03*V04 - 
      3.63782652349120603e-6*V012*V02*V032*V04 + 1.63667367473803243e-7*V034*V04 - 
      1.39086131227128251e-6*V012*V022*V042 - 6.47181474004390671e-7*V013*V03*V042 + 
      6.94893262950216634e-7*V02*V032*V042 + 1.51283642180000723e-7*V022*V043 + 
      2.90338231387046747e-7*V01*V03*V043 + 4.81771315104648438e-8*V015*V02*V05 - 
      4.63494115837865838e-7*V01*V024*V05 - 2.22791129909185465e-6*V012*V022*V03*V05 - 
      5.21445756440796123e-7*V013*V032*V05 + 3.96565639823316158e-7*V02*V033*V05 - 
      7.97474910818164786e-7*V013*V02*V04*V05 + 8.3079202034726953e-7*V022*V03*V04*V05 + 
      7.30771143336125926e-7*V01*V032*V04*V05 + 5.27975212689593233e-7*V01*V02*V042*V05 - 
      3.96192383729586111e-8*V014*V052 + 8.21761150132950242e-8*V023*V052 + 
      4.45765187284624921e-7*V01*V02*V03*V052 + 1.3232200882651688e-7*V012*V04*V052 - 
      2.37469976794500349e-8*V042*V052 - 1.36096627499663723e-8*V03*V053 + 
      1.80664243164243164e-9*V016*V06 - 3.92472994469522247e-7*V012*V023*V06 - 
      5.43036567342122898e-7*V013*V02*V03*V06 + 2.9825624725585578e-7*V022*V032*V06 + 
      1.71632696794454206e-7*V01*V033*V06 - 6.66349950204116871e-8*V014*V04*V06 + 
      1.29177689090543121e-7*V023*V04*V06 + 7.4981900942536933e-7*V01*V02*V03*V04*V06 + 
      1.1252040651039834e-7*V012*V042*V06 - 1.29392157703847877e-8*V043*V06 + 
      2.26994879836485229e-7*V01*V022*V05*V06 + 1.8517650554189128e-7*V012*V03*V05*V06 - 
      6.81809509230165907e-8*V03*V04*V05*V06 - 2.05992629199890677e-8*V02*V052*V06 + 
      4.8446145797846895e-8*V012*V02*V062 - 1.22055305562127859e-8*V032*V062 - 
      1.68156090978436291e-8*V02*V04*V062 - 9.37819813764003117e-9*V01*V05*V062 - 
      1.2330334595959596e-7*V013*V022*V07 - 3.92944728882228882e-8*V014*V03*V07 + 
      8.66334246474497019e-8*V023*V03*V07 + 2.31846393732372082e-7*V01*V02*V032*V07 + 
      1.6665107427975075e-7*V01*V022*V04*V07 + 1.36708868964792167e-7*V012*V03*V04*V07 - 
      2.50571343461910233e-8*V03*V042*V07 + 8.40820834182762287e-8*V012*V02*V05*V07 - 
      2.14821947819303148e-8*V032*V05*V07 - 3.02261663079119173e-8*V02*V04*V05*V07 - 
      8.22752243934466367e-9*V01*V052*V07 + 1.09705030084640262e-8*V013*V06*V07 - 
      2.17543301382968463e-8*V02*V03*V06*V07 - 1.38315040954813512e-8*V01*V04*V06*V07 - 
      2.39937340072932961e-9*V022*V072 - 4.31306178988452739e-9*V01*V03*V072 + 
      2.14767307517493529e-10*V06*V072 - 1.5356460668960669e-8*V014*V02*V08 + 
      7.81750055533643043e-9*V024*V08 + 9.19141145218555349e-8*V01*V022*V03*V08 + 
      3.68678479028521823e-8*V012*V032*V08 + 5.52415504398901925e-8*V012*V02*V04*V08 - 
      1.39583195853626023e-8*V032*V04*V08 - 9.5986425764438334e-9*V02*V042*V08 + 
      8.45095936083720086e-9*V013*V05*V08 - 1.6922158316131765e-8*V02*V03*V05*V08 - 
      1.07323878817334722e-8*V01*V04*V05*V08 - 4.15583968693321596e-9*V022*V06*V08 - 
      7.63161126818879759e-9*V01*V03*V06*V08 + 1.88392481149618117e-10*V062*V08 - 
      3.44611396259379405e-9*V01*V02*V07*V08 + 3.34163144371482397e-10*V05*V07*V08 - 
      2.87881903030246724e-10*V012*V082 + 1.07955611905981345e-10*V04*V082 - 
      6.32324851074851075e-10*V015*V09 + 1.08012321958230183e-8*V01*V023*V09 + 
      2.67003744013037314e-8*V012*V02*V03*V09 - 2.32715627508698703e-9*V033*V09 + 
      4.97490875478007831e-9*V013*V04*V09 - 9.88389262871376166e-9*V02*V03*V04*V09 - 
      3.15013205391853196e-9*V01*V042*V09 - 2.97133665297839776e-9*V022*V05*V09 - 
      5.32644539790241181e-9*V01*V03*V05*V09 - 2.74320110204596492e-9*V01*V02*V06*V09 + 2.65885815201741545e-10*V05*V06*V09 - 
      5.17205072695488891e-10*V012*V07*V09 + 1.95841700939319757e-10*V04*V07*V09 + 1.096083942566415e-10*V03*V08*V09 + 
      1.95715989957548972e-11*V02*V092 + 4.40590494971622423e-9*V012*V022*V10 + 
      2.16310006827776436e-9*V013*V03*V10 - 2.25902809958179182e-9*V02*V032*V10 - 
      1.54286144998219302e-9*V022*V04*V10 - 2.84471333483214826e-9*V01*V03*V04*V10 - 
      1.74167770044125429e-9*V01*V02*V05*V10 + 8.46077491142124186e-11*V052*V10 - 
      3.74968030744362659e-10*V012*V06*V10 + 1.40534807154727983e-10*V04*V06*V10 + 
      8.96631141416310435e-11*V03*V07*V10 + 3.53068698438173758e-11*V02*V08*V10 + 1.14933982587741202e-11*V01*V09*V10 + 
      6.56088693517206589e-10*V013*V02*V11 - 6.63592935339787407e-10*V022*V03*V11 - 
      5.86501686136304238e-10*V01*V032*V11 - 8.50965315512898983e-10*V01*V02*V04*V11 - 
      2.17109607466627468e-10*V012*V05*V11 + 8.25656605053924563e-11*V04*V05*V11 + 
      5.93973291009376551e-11*V03*V06*V11 + 2.66550932927223941e-11*V02*V07*V11 + 9.56771272405064299e-12*V01*V08*V11 - 
      4.07749009133190344e-14*V112 + 3.09963162291593664e-11*V014*V12 - 
      5.82036759080676063e-11*V023*V12 - 3.25941413725211455e-10*V01*V02*V03*V12 - 
      9.86366484114377131e-11*V012*V04*V12 + 1.84687031573766897e-11*V042*V12 + 
      3.1993273768693732e-11*V03*V05*V12 + 1.61905904420380971e-11*V02*V06*V12 + 6.62190665544894663e-12*V01*V07*V12 - 
      7.51070723847808455e-14*V10*V12 - 4.17471438054835888e-11*V01*V022*V13 - 
      3.44956371929249896e-11*V012*V03*V13 + 1.34089170629807992e-11*V03*V04*V13 + 
      8.16679779260448407e-12*V02*V05*V13 + 3.76684869312443917e-12*V01*V06*V13 - 5.91460018310722003e-14*V09*V13 - 
      8.42882283424509087e-12*V012*V02*V14 + 2.25096920533364482e-12*V032*V14 + 
      3.16777246847520571e-12*V02*V04*V14 + 1.75706830181942595e-12*V01*V05*V14 - 3.93062525938867e-14*V08*V14 - 
      4.8941551940777947e-13*V013*V15 + 1.01138475439219129e-12*V02*V03*V15 + 6.48114882843862155e-13*V01*V04*V15 - 
      2.21797318383885171e-14*V07*V15 + 1.05207689886298172e-13*V022*V16 + 1.90772171850787508e-13*V01*V03*V16 - 
      1.03716716845807155e-14*V06*V16 + 3.87037783205131723e-14*V01*V02*V17 - 4.05901125373965282e-15*V05*V17 + 
      3.12127244520267519e-15*V012*V18 - 1.25755614458890392e-15*V04*V18 - 3.20420480485781873e-16*V03*V19 - 
      5.52882397700956958e-17*V02*V20 - 8.29323596551435437e-18*V01*V21 + 7.53930542319486761e-21*V24) + 
   delta6*eps9*(7.65183075086203004e-8*V034*V04 + 
      2.36200532725392669e-7*V02*V032*V042 + 2.10474956623416007e-8*V022*V043 + 
      9.48188609885232979e-8*V01*V03*V043 + 1.57752553415679777e-7*V02*V033*V05 + 
      2.30720518966025502e-7*V022*V03*V04*V05 + 2.68114688535634692e-7*V01*V032*V04*V05 + 
      1.41720319635235602e-7*V01*V02*V042*V05 + 1.84747491222164425e-8*V023*V052 + 
      1.39170980163627222e-7*V01*V02*V03*V052 + 3.83673161377993311e-8*V012*V04*V052 - 
      2.2023741600738457e-8*V042*V052 - 1.42734771738816095e-8*V03*V053 + 
      8.35556661619725734e-8*V022*V032*V06 + 6.10311140773325647e-8*V01*V033*V06 + 
      1.45381579205108617e-8*V023*V04*V06 + 2.02131518633813996e-7*V01*V02*V03*V04*V06 + 
      2.94928838394835905e-8*V012*V042*V06 - 9.41028310842586455e-9*V043*V06 + 
      5.01333996971835441e-8*V01*V022*V05*V06 + 5.18720048632708141e-8*V012*V03*V05*V06 - 
      6.38881832797249232e-8*V03*V04*V05*V06 - 1.63995054407892911e-8*V02*V052*V06 + 
      1.04752648131110627e-8*V012*V02*V062 - 1.14954440383213866e-8*V032*V062 - 
      1.0373940513735223e-8*V02*V04*V062 - 7.1995374382365363e-9*V01*V05*V062 + 
      1.75949991640156595e-8*V023*V03*V07 + 6.49355534538774501e-8*V01*V02*V032*V07 + 
      3.29600741380036431e-8*V01*V022*V04*V07 + 3.5490127012847212e-8*V012*V03*V04*V07 - 
      2.19073568194984549e-8*V03*V042*V07 + 1.86392868465697597e-8*V012*V02*V05*V07 - 
      2.1179389152059458e-8*V032*V05*V07 - 2.23122299449632283e-8*V02*V04*V05*V07 - 
      6.59696094049781919e-9*V01*V052*V07 + 2.17904805955303932e-9*V013*V06*V07 - 
      1.62855136239927535e-8*V02*V03*V06*V07 - 9.93213689609712688e-9*V01*V04*V06*V07 - 
      1.39055312077097546e-9*V022*V072 - 3.23282820827403963e-9*V01*V03*V072 + 
      2.70691673066425051e-10*V06*V072 + 6.3274781919956039e-10*V024*V08 + 
      1.84578803786903694e-8*V01*V022*V03*V08 + 9.01661706319217472e-9*V012*V032*V08 + 
      1.08198370142036497e-8*V012*V02*V04*V08 - 1.23996749144077e-8*V032*V04*V08 - 
      5.5206283010412297e-9*V02*V042*V08 + 1.63325049124276223e-9*V013*V05*V08 - 
      1.28086576834036954e-8*V02*V03*V05*V08 - 7.75394468687961361e-9*V01*V04*V05*V08 - 
      2.01580544695901625e-9*V022*V06*V08 - 5.50766241918738492e-9*V01*V03*V06*V08 + 
      2.20755502650434519e-10*V062*V08 - 1.97947906813119159e-9*V01*V02*V07*V08 + 4.2591718923221259e-10*V05*V07*V08 - 
      1.583082256110483e-10*V012*V082 + 1.20675045280608754e-10*V04*V082 + 
      1.46624993033463829e-9*V01*V023*V09 + 4.95485603591345888e-9*V012*V02*V03*V09 - 
      2.10097487807609381e-9*V033*V09 + 8.58787732912382772e-10*V013*V04*V09 - 
      6.70950969054189387e-9*V02*V03*V04*V09 - 2.05870427299032854e-9*V01*V042*V09 - 
      1.68483925214565814e-9*V022*V05*V09 - 3.89132664126299495e-9*V01*V03*V05*V09 - 
      1.52386038876203899e-9*V01*V02*V06*V09 + 3.32066820728828843e-10*V05*V06*V09 - 
      2.85511375988624393e-10*V012*V07*V09 + 2.30855487854577695e-10*V04*V07*V09 + 
      1.32285455360861002e-10*V03*V08*V09 + 1.86224886360941026e-11*V02*V092 + 
      6.04575767974460785e-10*V012*V022*V10 + 3.40073869485634192e-10*V013*V03*V10 - 
      1.57213310981915158e-9*V02*V032*V10 - 6.71181261929988321e-10*V022*V04*V10 - 
      1.87883873030537691e-9*V01*V03*V04*V10 - 9.79242152784242622e-10*V01*V02*V05*V10 + 
      1.07336839085989354e-10*V052*V10 - 2.00661102814361779e-10*V012*V06*V10 + 
      1.54495629503149789e-10*V04*V06*V10 + 1.08715403184487502e-10*V03*V07*V10 + 3.19419553321709642e-11*V02*V08*V10 + 
      1.07962929205513937e-11*V01*V09*V10 + 7.75399910748494626e-11*V013*V02*V11 - 
      3.40440197433494265e-10*V022*V03*V11 - 3.83107217992122246e-10*V01*V032*V11 - 
      4.21791587392818139e-10*V01*V02*V04*V11 - 1.14751107550456822e-10*V012*V05*V11 + 
      9.62065320400714134e-11*V04*V05*V11 + 7.0053450335113439e-11*V03*V06*V11 + 2.5310464537020169e-11*V02*V07*V11 + 
      8.92101281804860605e-12*V01*V08*V11 - 5.43372820460500498e-14*V112 + 2.9520301170627968e-12*V014*V12 - 
      1.849485094293739e-11*V023*V12 - 1.63911361271335963e-10*V01*V02*V03*V12 - 
      4.73197850193238992e-11*V012*V04*V12 + 1.88537309952640217e-11*V042*V12 + 
      3.82877627980636899e-11*V03*V05*V12 + 1.42638050703933002e-11*V02*V06*V12 + 6.20117454352671344e-12*V01*V07*V12 - 
      9.861716111939824e-14*V10*V12 - 1.52801222059334661e-11*V01*V022*V13 - 
      1.59005664305371908e-11*V012*V03*V13 + 1.46902340825414441e-11*V03*V04*V13 + 
      7.63906846126070317e-12*V02*V05*V13 + 3.41839908555666496e-12*V01*V06*V13 - 7.88028307646789415e-14*V09*V13 - 
      3.00382011911653008e-12*V012*V02*V14 + 2.51465121876614934e-12*V032*V14 + 
      2.55827813001998466e-12*V02*V04*V14 + 1.60913386023879783e-12*V01*V05*V14 - 5.13051632836443249e-14*V08*V14 - 
      1.55370006161199832e-13*V013*V15 + 8.81293201614361267e-13*V02*V03*V15 + 5.4133499646664708e-13*V01*V04*V15 - 
      2.95144707744340306e-14*V07*V15 + 6.57733026082412621e-14*V022*V16 + 1.60419531361438826e-13*V01*V03*V16 - 
      1.32723943151368635e-14*V06*V16 + 2.52476260011949726e-14*V01*V02*V17 - 5.35350999490221159e-15*V05*V17 + 
      1.9421250770149979e-15*V012*V18 - 1.50866527721744764e-15*V04*V18 - 4.01091048513966957e-16*V03*V19 - 
      5.36128385649412808e-17*V02*V20 - 8.04192578474119211e-18*V01*V21 + 1.00524072309264901e-20*V24) + 
   delta2*eps11*(-5.19942132872027052e-7*V024*V032 - 
      2.12909656114021193e-6*V01*V022*V033 - 4.30973118225102352e-7*V012*V034 - 
      6.80612866459427306e-8*V025*V04 - 2.60643787429501715e-6*V01*V023*V03*V04 - 
      3.48396023619237905e-6*V012*V02*V032*V04 + 2.92634394072278254e-7*V034*V04 - 
      1.17616437060881505e-6*V012*V022*V042 - 5.9607155961322628e-7*V013*V03*V042 + 
      1.1082481523457393e-6*V02*V032*V042 + 1.95584655809718057e-7*V022*V043 + 
      4.54467079326658575e-7*V01*V03*V043 - 3.11965279723216231e-7*V01*V024*V05 - 
      1.86285023214586707e-6*V012*V022*V03*V05 - 4.72547688569513966e-7*V013*V032*V05 + 
      6.54479977676270082e-7*V02*V033*V05 - 6.53448229093070363e-7*V013*V02*V04*V05 + 
      1.19518228764965654e-6*V022*V03*V04*V05 + 1.16986246668154153e-6*V01*V032*V04*V05 + 
      7.49205341404634316e-7*V01*V02*V042*V05 - 3.07473335747145271e-8*V014*V052 + 
      1.0472435081384564e-7*V023*V052 + 6.53677756463315131e-7*V01*V02*V03*V052 + 
      1.8926780842484624e-7*V012*V04*V052 - 4.49111369355517819e-8*V042*V052 - 
      2.66308862018481758e-8*V03*V053 - 2.7752321899147296e-7*V012*V023*V06 - 
      4.30835469277929595e-7*V013*V02*V03*V06 + 4.35860386828621345e-7*V022*V032*V06 + 
      2.74950060854005765e-7*V01*V033*V06 - 5.11709961114723019e-8*V014*V04*V06 + 
      1.49373083789906074e-7*V023*V04*V06 + 1.07553785650458347e-6*V01*V02*V03*V04*V06 + 
      1.58959003141207273e-7*V012*V042*V06 - 2.34589188319894784e-8*V043*V06 + 
      2.91743367359030291e-7*V01*V022*V05*V06 + 2.64325940625106125e-7*V012*V03*V05*V06 - 
      1.30477649586021645e-7*V03*V04*V05*V06 - 3.63982154243717568e-8*V02*V052*V06 + 
      6.21909667103265376e-8*V012*V02*V062 - 2.35866641208131788e-8*V032*V062 - 
      2.83830922891645865e-8*V02*V04*V062 - 1.64809807039780169e-8*V01*V05*V062 - 
      8.3627470780248558e-8*V013*V022*V07 - 2.86653932487265821e-8*V014*V03*V07 + 
      1.09769440570337318e-7*V023*V03*V07 + 3.35492824806258513e-7*V01*V02*V032*V07 + 
      2.09044847038933562e-7*V01*V022*V04*V07 + 1.92355750008498608e-7*V012*V03*V04*V07 - 
      4.72618338936615608e-8*V03*V042*V07 + 1.07650164092011664e-7*V012*V02*V05*V07 - 
      4.18304532027872241e-8*V032*V05*V07 - 5.2495110872022949e-8*V02*V04*V05*V07 - 
      1.45549356985976133e-8*V01*V052*V07 + 1.36847681855268223e-8*V013*V06*V07 - 
      3.83220680268478737e-8*V02*V03*V06*V07 - 2.39667134245575088e-8*V01*V04*V06*V07 - 
      3.78370234356419949e-9*V022*V072 - 7.57514185448521646e-9*V01*V03*V072 + 
      4.26147160475657499e-10*V06*V072 - 9.63542630209296876e-9*V014*V02*V08 + 
      7.72535223236800164e-9*V024*V08 + 1.17120217666946775e-7*V01*V022*V03*V08 + 
      5.1466665825082803e-8*V012*V032*V08 + 6.95025549042676727e-8*V012*V02*V04*V08 - 
      2.66734083953653464e-8*V032*V04*V08 - 1.59763800882102491e-8*V02*V042*V08 + 
      1.04776967236360716e-8*V013*V05*V08 - 2.9909484601287233e-8*V02*V03*V05*V08 - 
      1.86295937434687129e-8*V01*V04*V05*V08 - 6.38461798617259437e-9*V022*V06*V08 - 
      1.33424917612395601e-8*V01*V03*V06*V08 + 3.69473760663051925e-10*V062*V08 - 
      5.46385122184290841e-9*V01*V02*V07*V08 + 6.65193360464561812e-10*V05*V07*V08 - 
      4.51929472006984006e-10*V012*V082 + 2.09622080250661849e-10*V04*V082 - 
      3.61328486328486328e-10*V015*V09 + 1.16554442820539537e-8*V01*V023*V09 + 
      3.32813562272012319e-8*V012*V02*V03*V09 - 4.49623559158400142e-9*V033*V09 + 
      6.05996959616532446e-9*V013*V04*V09 - 1.71008894358145883e-8*V02*V03*V04*V09 - 
      5.36744415768178965e-9*V01*V042*V09 - 4.68188403056017865e-9*V022*V05*V09 - 
      9.32814612085776875e-9*V01*V03*V05*V09 - 4.32938137442453789e-9*V01*V02*V06*V09 + 5.27480366322598665e-10*V05*V06*V09 - 
      8.11379645939557258e-10*V012*V07*V09 + 3.83426984261945439e-10*V04*V07*V09 + 2.1768055216367305e-10*V03*V08*V09 + 
      3.5427496549520743e-11*V02*V092 + 4.80738104563676459e-9*V012*V022*V10 + 
      2.57712229219582161e-9*V013*V03*V10 - 3.97089667710882205e-9*V02*V032*V10 - 
      2.32086891334837589e-9*V022*V04*V10 - 4.89421578838019756e-9*V01*V03*V04*V10 - 
      2.7556254125600797e-9*V01*V02*V05*V10 + 1.68525837843121799e-10*V052*V10 - 
      5.86367513038126459e-10*V012*V06*V10 + 2.72167713347360047e-10*V04*V06*V10 + 
      1.78212007585668558e-10*V03*V07*V10 + 6.34254219220624266e-11*V02*V08*V10 + 2.07887313037605561e-11*V01*V09*V10 + 
      6.93727077509757248e-10*V013*V02*V11 - 1.04023300630045484e-9*V022*V03*V11 - 
      1.01343227212338563e-9*V01*V032*V11 - 1.31535377883894447e-9*V01*V02*V04*V11 - 
      3.38479662243844452e-10*V012*V05*V11 + 1.61601702895817855e-10*V04*V05*V11 + 
      1.17549811516796611e-10*V03*V06*V11 + 4.82422574380474134e-11*V02*V07*V11 + 1.72881408123471871e-11*V01*V08*V11 - 
      8.15490478960957494e-14*V112 + 3.09963162291593664e-11*V014*V12 - 
      7.7737976854129163e-11*V023*V12 - 5.09456252588209318e-10*V01*V02*V03*V12 - 
      1.51223846568212385e-10*V012*V04*V12 + 3.5268177555702946e-11*V042*V12 + 
      6.35409685554323088e-11*V03*V05*V12 + 2.89625228485092606e-11*V02*V06*V12 + 1.19713052157937093e-11*V01*V07*V12 - 
      1.49876201115561999e-13*V10*V12 - 5.76407185857435255e-11*V01*V022*V13 - 
      5.26657709884619069e-11*V012*V03*V13 + 2.61749907254696341e-11*V03*V04*V13 + 
      1.47714796482632382e-11*V02*V05*V13 + 6.77909855989667958e-12*V01*V06*V13 - 1.18290495801059762e-13*V09*V13 - 
      1.15828339593174474e-11*V012*V02*V14 + 4.4488998996354753e-12*V032*V14 + 
      5.57193834952672406e-12*V02*V04*V14 + 3.16827187206643814e-12*V01*V05*V14 - 7.8365081937796196e-14*V08*V14 - 
      6.52554025877039293e-13*V013*V15 + 1.82291559014488683e-12*V02*V03*V15 + 1.14846179197084033e-12*V01*V04*V15 - 
      4.43579558156923953e-14*V07*V15 + 1.68539463826292008e-13*V022*V16 + 3.40815206372174774e-13*V01*V03*V16 - 
      2.06130641714486236e-14*V06*V16 + 6.27028953436270749e-14*V01*V02*V17 - 8.11651464639466667e-15*V05*V17 + 
      4.9940359123242803e-15*V012*V18 - 2.46806702333707186e-15*V04*V18 - 6.39333099886924773e-16*V03*V19 - 
      1.00524072309264901e-16*V02*V20 - 1.50786108463897352e-17*V01*V21 + 1.50786108463897352e-20*V24) + 
   delta4*eps10*(-1.17745291769762669e-7*V024*V032 - 
      5.79433243123719314e-7*V01*V022*V033 - 1.24555091072948216e-7*V012*V034 - 
      1.48202033122668043e-9*V025*V04 - 5.98870803897258924e-7*V01*V023*V03*V04 - 
      9.19068255377779187e-7*V012*V02*V032*V04 + 2.14311482438524922e-7*V034*V04 - 
      2.78216052025575835e-7*V012*V022*V042 - 1.52528798362131695e-7*V013*V03*V042 + 
      7.28419279216334149e-7*V02*V032*V042 + 9.77137892841674354e-8*V022*V043 + 
      2.94835574485628952e-7*V01*V03*V043 - 7.06471750618576015e-8*V01*V024*V05 - 
      4.70752516883469264e-7*V012*V022*V03*V05 - 1.22944598391026962e-7*V013*V032*V05 + 
      4.53829576895904121e-7*V02*V033*V05 - 1.57814517933565553e-7*V013*V02*V04*V05 + 
      7.3417265658745584e-7*V022*V03*V04*V05 + 7.89349551944867849e-7*V01*V032*V04*V05 + 
      4.54844988100998839e-7*V01*V02*V042*V05 - 7.17495137137994281e-9*V014*V052 + 
      6.06452340719542971e-8*V023*V052 + 4.1961331835354361e-7*V01*V02*V03*V052 + 
      1.18468274871461146e-7*V012*V04*V052 - 4.026399605523601e-8*V042*V052 - 
      2.49344252732416599e-8*V03*V053 - 6.40105840171977738e-8*V012*V023*V06 - 
      1.01929045381426334e-7*V013*V02*V03*V06 + 2.68121481016361191e-7*V022*V032*V06 + 
      1.83131423420507804e-7*V01*V033*V06 - 1.15108932073217788e-8*V014*V04*V06 + 
      6.94660406346006512e-8*V023*V04*V06 + 6.53241508264072845e-7*V01*V02*V03*V04*V06 + 
      9.57025503606288698e-8*V012*V042*V06 - 1.94107261144450045e-8*V043*V06 + 
      1.67111827140421912e-7*V01*V022*V05*V06 + 1.63286817054226796e-7*V012*V03*V05*V06 - 
      1.17292675685637981e-7*V03*V04*V05*V06 - 3.1097029829286499e-8*V02*V052*V06 + 
      3.52784186586804856e-8*V012*V02*V062 - 2.12175240295383638e-8*V032*V062 - 
      2.22496709765014992e-8*V02*V04*V062 - 1.3892605532982901e-8*V01*V05*V062 - 
      1.7584653001319668e-8*V013*V022*V07 - 6.08236285319618653e-9*V014*V03*V07 + 
      6.00239001444391008e-8*V023*V03*V07 + 2.05120027408751926e-7*V01*V02*V032*V07 + 
      1.13262007082035093e-7*V01*V022*V04*V07 + 1.1481891901160303e-7*V012*V03*V04*V07 - 
      4.13685034628376481e-8*V03*V042*V07 + 6.13554156716213205e-8*V012*V02*V05*V07 - 
      3.81989797524358541e-8*V032*V05*V07 - 4.35034561212444647e-8*V02*V04*V05*V07 - 
      1.24465574767207969e-8*V01*V052*V07 + 7.51825841670807435e-9*V013*V06*V07 - 
      3.18774024187369472e-8*V02*V03*V06*V07 - 1.9667871997796414e-8*V01*V04*V06*V07 - 
      2.88384332637313435e-9*V022*V072 - 6.2963852833022967e-9*V01*V03*V072 + 
      4.1939913591699306e-10*V06*V072 - 1.80664243164243164e-9*V014*V02*V08 + 
      3.19339934526286845e-9*V024*V08 + 6.40864146422619812e-8*V01*V022*V03*V08 + 
      3.00955337592388246e-8*V012*V032*V08 + 3.77117630268890773e-8*V012*V02*V04*V08 - 
      2.34923487086251406e-8*V032*V04*V08 - 1.21932300356941412e-8*V02*V042*V08 + 
      5.71217827651651181e-9*V013*V05*V08 - 2.5025281349342178e-8*V02*V03*V05*V08 - 
      1.53470257143579543e-8*V01*V04*V05*V08 - 4.61685998131022047e-9*V022*V06*V08 - 
      1.09728674070220722e-8*V01*V03*V06*V08 + 3.55652899273829005e-10*V062*V08 - 
      4.15881740242510684e-9*V01*V02*V07*V08 + 6.57949166107055085e-10*V05*V07*V08 - 
      3.39306748576642572e-10*V012*V082 + 1.98294607994327916e-10*V04*V082 - 
      6.02214143880810547e-11*V015*V09 + 5.56862526910962952e-9*V01*V023*V09 + 
      1.77171569817169724e-8*V012*V02*V03*V09 - 3.97927241519096207e-9*V033*V09 + 
      3.15622625744591197e-9*V013*V04*V09 - 1.37407137803524885e-8*V02*V03*V04*V09 - 
      4.2604639747773317e-9*V01*V042*V09 - 3.55753189027397834e-9*V022*V05*V09 - 
      7.70861279121372267e-9*V01*V03*V05*V09 - 3.26262256487220193e-9*V01*V02*V06*V09 + 5.18422609402698898e-10*V05*V06*V09 - 
      6.09370338393160972e-10*V012*V07*V09 + 3.68525742913893642e-10*V04*V07*V09 + 
      2.10984752273151009e-10*V03*V08*V09 + 3.17026393750257638e-11*V02*V092 + 
      2.31409640876552641e-9*V012*V022*V10 + 1.29948365753104315e-9*V013*V03*V10 - 
      3.22012106269394711e-9*V02*V032*V10 - 1.61126775629484608e-9*V022*V04*V10 - 
      3.90065748563062876e-9*V01*V03*V04*V10 - 2.08963724511459505e-9*V01*V02*V05*V10 + 
      1.66708646337348923e-10*V052*V10 - 4.36754705462371277e-10*V012*V06*V10 + 
      2.56156280440564972e-10*V04*V06*V10 + 1.72991833207666797e-10*V03*V07*V10 + 5.59156137952565482e-11*V02*V08*V10 + 
      1.85371567607405689e-11*V01*V09*V10 + 3.18819252642782055e-10*V013*V02*V11 - 
      7.60905183923706026e-10*V022*V03*V11 - 8.04406011184446243e-10*V01*V032*V11 - 
      9.51332212403664011e-10*V01*V02*V04*V11 - 2.51421963541570156e-10*V012*V05*V11 + 
      1.55046124435856297e-10*V04*V05*V11 + 1.13147716831517197e-10*V03*V06*V11 + 4.31537972541215944e-11*V02*V07*V11 + 
      1.53827773885756874e-11*V01*V08*V11 - 8.15425138313956472e-14*V112 + 1.32841355267825856e-11*V014*V12 - 
      4.86248930710779778e-11*V023*V12 - 3.70489767763205647e-10*V01*V02*V03*V12 - 
      1.0830510193769752e-10*V012*V04*V12 + 3.23502918471370033e-11*V042*V12 + 
      6.15313315114544086e-11*V03*V05*V12 + 2.53281964472471377e-11*V02*V06*V12 + 1.06661509229663684e-11*V01*V07*V12 - 
      1.4921036621479354e-13*V10*V12 - 3.77044162451691691e-11*V01*V022*V13 - 
      3.72150007257613897e-11*V012*V03*V13 + 2.45643216615985292e-11*V03*V04*V13 + 
      1.31821739602392982e-11*V02*V05*V13 + 5.98357638370737909e-12*V01*V06*V13 - 1.18277427671659557e-13*V09*V13 - 
      7.51602404804804186e-12*V012*V02*V14 + 4.20331355953960259e-12*V032*V14 + 
      4.72524580166540459e-12*V02*V04*V14 + 2.80845158458347374e-12*V01*V05*V14 - 7.78802878450727144e-14*V08*V14 - 
      4.07846266173149558e-13*V013*V15 + 1.58477406284423828e-12*V02*V03*V15 + 9.84657414046603933e-13*V01*V04*V15 - 
      4.43448876862921908e-14*V07*V15 + 1.31287655206213858e-13*V022*V16 + 2.92872461613861683e-13*V01*V03*V16 - 
      2.03625581832539355e-14*V06*V16 + 4.95241894638824463e-14*V01*V02*V17 - 8.10344651699446223e-15*V05*V17 + 
      3.88425015402999579e-15*V012*V18 - 2.3840288988865264e-15*V04*V18 - 6.26264970486720336e-16*V03*V19 - 
      9.04716650783384113e-17*V02*V20 - 1.35707497617507617e-17*V01*V21 + 1.50786108463897352e-20*V24) + 
   6.4469502843844734e-26*delta24*V24 + 3.86817017063068404e-25*delta22*eps*V24 + 
   delta22*eps2*(-1.85682880046129965e-20*V122 - 4.02312906766614924e-20*V11*V13 - 
      2.68208604511076616e-20*V10*V14 - 2.10735332115845913e-20*V09*V15 - 9.91695680545157236e-21*V08*V16 - 
      5.57828820306650945e-21*V07*V17 - 1.76156469570521351e-21*V06*V18 - 6.85052937218694143e-22*V05*V19 - 
      1.30486273755941742e-22*V04*V20 - 3.26215684389854354e-23*V03*V21 - 2.83665812512916829e-24*V02*V22 - 
      3.86817017063068404e-25*V01*V23 + 3.581639046880263e-27*V26) + 
   delta20*eps3*(-2.04251168050742961e-19*V122 - 4.42544197443276416e-19*V11*V13 - 
      2.95029464962184278e-19*V10*V14 - 2.31808865327430504e-19*V09*V15 - 1.09086524859967296e-19*V08*V16 - 
      6.1361170233731604e-20*V07*V17 - 1.93772116527573486e-20*V06*V18 - 7.53558230940563557e-21*V05*V19 - 
      1.43534901131535916e-21*V04*V20 - 3.58837252828839789e-22*V03*V21 - 3.12032393764208512e-23*V02*V22 - 
      4.25498718769375244e-24*V01*V23 + 1.96990147578414465e-26*V26) + 
   delta18*eps4*(3.30176453396809709e-15*V072*V08 + 1.9052198711412549e-15*V06*V082 + 
      4.99426568163241577e-15*V06*V07*V09 + 3.85205862296277994e-15*V05*V08*V09 + 9.77496079135291902e-16*V04*V092 + 
      1.16561970017120193e-15*V062*V10 + 3.11705043416568606e-15*V05*V07*V10 + 1.2063126956394299e-15*V04*V08*V10 + 
      8.65847342823801684e-16*V03*V09*V10 + 6.80933335986972465e-17*V02*V102 + 1.90690144207783147e-15*V05*V06*V11 + 
      1.27963123086801849e-15*V04*V07*V11 + 7.00374295084141807e-16*V03*V08*V11 + 1.78666912011260665e-16*V02*V09*V11 + 
      4.72280368812982737e-17*V01*V10*V11 + 4.95894387253631874e-16*V052*V12 + 4.97254203795415384e-16*V04*V06*V12 + 
      4.72280368812982737e-16*V03*V07*V12 + 9.17573287979509317e-17*V02*V08*V12 + 3.93566974010818947e-17*V01*V09*V12 - 
      1.4057404994796687e-18*V122 + 3.4451610061831267e-16*V04*V05*V13 + 2.4447454385613224e-16*V03*V06*V13 + 
      8.24616516975049223e-17*V02*V07*V13 + 2.6937472887851608e-17*V01*V08*V13 - 2.991109002482224e-18*V11*V13 + 
      3.79960143891801628e-17*V042*V14 + 1.07749891551406432e-16*V03*V05*V14 + 2.70991624009839705e-17*V02*V06*V14 + 
      1.53928416502009188e-17*V01*V07*V14 - 2.03780233210046255e-18*V10*V14 + 3.28110572017440638e-17*V03*V04*V15 + 
      1.64923303395009845e-17*V02*V05*V15 + 6.98498696731806401e-18*V01*V06*V15 - 1.57822438943280254e-18*V09*V15 + 
      4.36561685457379e-18*V032*V16 + 3.08401471364043177e-18*V02*V04*V16 + 2.619370112744274e-18*V01*V05*V16 - 
      7.61557606853427812e-19*V08*V16 + 1.21267134849271945e-18*V02*V03*V17 + 7.2377332062670729e-19*V01*V04*V17 - 
      4.23828636298205446e-19*V07*V17 + 4.72303577834006521e-20*V022*V18 + 1.60838515694823842e-19*V01*V03*V18 - 
      1.3767011045783136e-19*V06*V18 + 2.12749359384687622e-20*V01*V02*V19 - 5.31660649102334368e-20*V05*V19 + 
      1.06374679692343811e-21*V012*V20 - 1.04459935457881622e-20*V04*V20 - 2.60263382980601191e-21*V03*V21 - 
      2.34024295323156384e-22*V02*V22 - 3.19124039077031433e-23*V01*V23 + 9.84950737892072324e-26*V26) + 
   delta16*eps5*(3.91494937599074369e-14*V072*V08 + 2.38059997491145151e-14*V06*V082 + 
      5.90467869651332489e-14*V06*V07*V09 + 4.56744093865586764e-14*V05*V08*V09 + 1.15308333779477952e-14*V04*V092 + 
      1.45811602942764586e-14*V062*V10 + 3.71015586399999022e-14*V05*V07*V10 + 1.51019979579681752e-14*V04*V08*V10 + 
      1.03059885111110839e-14*V03*V09*V10 + 8.54602572137778286e-16*V02*V102 + 2.2545136841232695e-14*V05*V06*V11 + 
      1.50949091493134774e-14*V04*V07*V11 + 8.30443807028339571e-15*V03*V08*V11 + 2.10380288893259433e-15*V02*V09*V11 + 
      5.62144827878786397e-16*V01*V10*V11 + 5.93420283413512809e-15*V052*V12 + 6.24345874560816188e-15*V04*V06*V12 + 
      5.65162174679536008e-15*V03*V07*V12 + 1.15366349562739614e-15*V02*V08*V12 + 4.7096847889961334e-16*V01*V09*V12 - 
      7.4883685401212359e-18*V122 + 4.06401400173824391e-15*V04*V05*V13 + 2.8904021591323968e-15*V03*V06*V13 + 
      9.7098594873812046e-16*V02*V07*V13 + 3.19401464241669066e-16*V01*V08*V13 - 1.54868604273257256e-17*V11*V13 + 
      4.80337674442322357e-16*V042*V14 + 1.29973306683884008e-15*V03*V05*V14 + 3.42781767840608697e-16*V02*V06*V14 + 
      1.85676152405548583e-16*V01*V07*V14 - 1.09149240792333788e-17*V10*V14 + 3.8704895254649942e-16*V03*V04*V15 + 
      1.94197189747624092e-16*V02*V05*V15 + 8.25829188323541943e-17*V01*V06*V15 - 8.26678058267486846e-18*V09*V15 + 
      5.33575393336796556e-17*V032*V16 + 3.95203209992995727e-17*V02*V04*V16 + 3.20145236002077934e-17*V01*V05*V16 - 
      4.14491066914811507e-18*V08*V16 + 1.42792051285017715e-17*V02*V03*V17 + 8.53784454146689896e-18*V01*V04*V17 - 
      2.2701207643783708e-18*V07*V17 + 6.22930124278365357e-19*V022*V18 + 2.01718305100591569e-18*V01*V03*V18 - 
      7.68578335713122504e-19*V06*V18 + 2.50512370675469675e-19*V01*V02*V19 - 2.93865371384084395e-19*V05*V19 + 
      1.43605817584664145e-20*V012*V20 - 6.02825309816512377e-20*V04*V20 - 1.49509612307589226e-20*V03*V21 - 
      1.40414577193893831e-21*V02*V22 - 1.9147442344621886e-22*V01*V23 + 4.43227832051432546e-25*V26) + 
   delta14*eps6*(-1.54203318660389367e-12*V054 - 1.20222768349253792e-11*V04*V052*V06 - 
      2.20810148842809719e-12*V042*V062 - 8.49950385609556685e-12*V03*V05*V062 - 
      5.19154254600674884e-13*V02*V063 - 8.03458254146862924e-12*V042*V05*V07 - 
      8.72037364191043845e-12*V03*V052*V07 - 1.14497874618336945e-11*V03*V04*V06*V07 - 
      5.72782625570846122e-12*V02*V05*V06*V07 - 1.21421483658508098e-12*V01*V062*V07 - 
      2.04958885084975925e-12*V032*V072 - 1.89411468817236972e-12*V02*V04*V072 - 
      1.21671837233061723e-12*V01*V05*V072 - 7.53220636853102185e-13*V043*V08 - 
      8.7898649136415848e-12*V03*V04*V05*V08 - 2.21582514890753923e-12*V02*V052*V08 - 
      3.07934896700958681e-12*V032*V06*V08 - 1.58993354704801313e-12*V02*V04*V06*V08 - 
      1.84760938020575209e-12*V01*V05*V06*V08 - 2.11030966562622784e-12*V02*V03*V07*V08 - 
      1.25569498766308354e-12*V01*V04*V07*V08 + 2.52902464207594821e-13*V072*V08 - 
      7.05860041184046148e-14*V022*V082 - 3.2938676181467125e-13*V01*V03*V082 + 
      1.65322644154544154e-13*V06*V082 - 2.2318284837412859e-12*V03*V042*V09 - 
      2.36584127953175572e-12*V032*V05*V09 - 2.20980046953443135e-12*V02*V04*V05*V09 - 
      7.00410678164405918e-13*V01*V052*V09 - 1.5910628488079059e-12*V02*V03*V06*V09 - 
      9.54148955152807872e-13*V01*V04*V06*V09 - 2.55178500255161524e-13*V022*V07*V09 - 
      6.50858439786300493e-13*V01*V03*V07*V09 + 3.8183588904119501e-13*V06*V07*V09 - 1.75859138802185653e-13*V01*V02*V08*V09 + 
      2.96791441398816354e-13*V05*V08*V09 - 1.20920740210491967e-14*V012*V092 + 
      7.51242092489750279e-14*V04*V092 - 9.72977199189485451e-13*V032*V04*V10 - 
      2.45301962166125281e-13*V02*V042*V10 - 9.89880319917499004e-13*V02*V03*V05*V10 - 
      5.8378631951369127e-13*V01*V04*V05*V10 - 8.53406564866380643e-14*V022*V06*V10 - 
      4.02592159254841163e-13*V01*V03*V06*V10 + 1.01860733210772983e-13*V062*V10 - 
      1.41411474273928429e-13*V01*V02*V07*V10 + 2.42414016797913357e-13*V05*V07*V10 - 
      2.05587945175887093e-14*V012*V08*V10 + 1.06087349072260034e-13*V04*V08*V10 + 
      6.81155107853280148e-14*V03*V09*V10 + 6.10328012679467652e-15*V02*V102 - 
      1.38073789602302242e-13*V033*V11 - 4.0178190355171479e-13*V02*V03*V04*V11 - 
      1.21736099113161049e-13*V01*V042*V11 - 9.74317910065162182e-14*V022*V05*V11 - 
      2.4234761532458389e-13*V01*V03*V05*V11 - 8.67852462986130488e-14*V01*V02*V06*V11 + 1.47517807276666873e-13*V05*V06*V11 - 
      1.56321251096880647e-14*V012*V07*V11 + 9.89245613535953171e-14*V04*V07*V11 + 
      5.49103892488515527e-14*V03*V08*V11 + 1.39755139279545053e-14*V02*V09*V11 + 3.80029519523811889e-15*V01*V10*V11 - 
      7.36486711745073699e-14*V02*V032*V12 - 1.74606292638300763e-14*V022*V04*V12 - 
      8.55307773599781761e-14*V01*V03*V04*V12 - 4.4189202704704422e-14*V01*V02*V05*V12 + 
      3.94736305220268869e-14*V052*V12 - 8.45492335115312311e-15*V012*V06*V12 + 
      4.4391093491512922e-14*V04*V06*V12 + 3.7804669162617643e-14*V03*V07*V12 + 8.28983170499228742e-15*V02*V08*V12 + 
      3.20307292991376506e-15*V01*V09*V12 - 3.2885668253304498e-17*V122 - 1.2491255257245669e-14*V022*V03*V13 - 
      1.45258624807851906e-14*V01*V032*V13 - 1.5453150136604415e-14*V01*V02*V04*V13 - 
      4.02482301674727183e-15*V012*V05*V13 + 2.71021119581024799e-14*V04*V05*V13 + 
      1.93550835918877473e-14*V03*V06*V13 + 6.52510369708493555e-15*V02*V07*V13 + 2.17272708614309219e-15*V01*V08*V13 - 
      6.59474565261144479e-17*V11*V13 - 2.87957108924612235e-16*V023*V14 - 4.61600412862594148e-15*V01*V02*V03*V14 - 
      1.28347603729081856e-15*V012*V04*V14 + 3.49836247258676175e-15*V042*V14 + 
      8.9090194133122693e-15*V03*V05*V14 + 2.5090229770134993e-15*V02*V06*V14 + 1.28626433039491428e-15*V01*V07*V14 - 
      4.82088307689125368e-17*V10*V14 - 3.56893007349876257e-16*V01*V022*V15 - 
      3.43152802723375592e-16*V012*V03*V15 + 2.65553069586017059e-15*V03*V04*V15 + 
      1.33496733924397574e-15*V02*V05*V15 + 5.71968568230076054e-16*V01*V06*V15 - 3.56303053376302519e-17*V09*V15 - 
      5.10853761754511918e-17*V012*V02*V16 + 3.79444864943371915e-16*V032*V16 + 
      2.98429483390964099e-16*V02*V04*V16 + 2.28782576606636451e-16*V01*V05*V16 - 1.86185474371915526e-17*V08*V16 - 
      1.76156469570521351e-18*V013*V17 + 1.01462296984151374e-16*V02*V03*V17 + 6.08748251981782081e-17*V01*V04*V17 - 
      1.00166653385498626e-17*V07*V17 + 4.92472217103674908e-18*V022*V18 + 1.50805255906241974e-17*V01*V03*V18 - 
      3.54738281838028141e-18*V06*V18 + 1.85730190742832294e-18*V01*V02*V19 - 1.34095921220168608e-18*V05*V19 + 
      1.14884654067731316e-19*V012*V20 - 2.88488131325636416e-19*V04*V20 - 7.11646607141780096e-20*V03*V21 - 
      7.02072885969469153e-21*V02*V22 - 9.57372117231094299e-22*V01*V23 + 1.77291132820573018e-24*V26) + 
   delta12*eps7*(-1.66065112403496242e-11*V054 - 1.32286910338566607e-10*V04*V052*V06 - 
      2.9624444362982876e-11*V042*V062 - 9.40202849236138478e-11*V03*V05*V062 - 
      6.99935888436239844e-12*V02*V063 - 8.81082588939342752e-11*V042*V05*V07 - 
      9.41948082625692053e-11*V03*V052*V07 - 1.25987533655777721e-10*V03*V04*V06*V07 - 
      6.28954061798325235e-11*V02*V05*V06*V07 - 1.34314692748019783e-11*V01*V062*V07 - 
      2.22227074615757362e-11*V032*V072 - 2.07868960496107846e-11*V02*V04*V072 - 
      1.32336899509046145e-11*V01*V05*V072 - 1.0160231656237466e-11*V043*V08 - 
      9.74169938630722944e-11*V03*V04*V05*V08 - 2.44607475427185688e-11*V02*V052*V08 - 
      3.43735457862127048e-11*V032*V06*V08 - 2.15689127816977362e-11*V02*V04*V06*V08 - 
      2.06241274717276229e-11*V01*V05*V06*V08 - 2.32959500406843512e-11*V02*V03*V07*V08 - 
      1.39167134090103278e-11*V01*V04*V07*V08 + 1.14358065959054919e-12*V072*V08 - 
      9.72492181709934615e-13*V022*V082 - 3.72143225233535432e-12*V01*V03*V082 + 
      8.06832513790939047e-13*V06*V082 - 2.44745163594261876e-11*V03*V042*V09 - 
      2.57321749045367505e-11*V032*V05*V09 - 2.42513787245459154e-11*V02*V04*V05*V09 - 
      7.64803272769843236e-12*V01*V052*V09 - 1.74709461610645899e-11*V02*V03*V06*V09 - 
      1.04989611379814768e-11*V01*V04*V06*V09 - 2.81955869038106904e-12*V022*V07*V09 - 
      7.15964568449305329e-12*V01*V03*V07*V09 + 1.73526454756329624e-12*V06*V07*V09 - 1.94132917005702927e-12*V01*V02*V08*V09 + 
      1.35608337396241624e-12*V05*V08*V09 - 1.37908629566892789e-13*V012*V092 + 
      3.46474443578993563e-13*V04*V092 - 1.09131825067883835e-11*V032*V04*V10 - 
      3.37043773226947542e-12*V02*V042*V10 - 1.10387250589529224e-11*V02*V03*V05*V10 - 
      6.54790950407303009e-12*V01*V04*V05*V10 - 1.18352037247364295e-12*V022*V06*V10 - 
      4.56141900382685922e-12*V01*V03*V06*V10 + 5.0179374673263931e-13*V062*V10 - 
      1.57696072270756034e-12*V01*V02*V07*V10 + 1.11318188386107411e-12*V05*V07*V10 - 
      2.37735166353798372e-13*V012*V08*V10 + 5.27507721727871024e-13*V04*V08*V10 + 
      3.19132526809428339e-13*V03*V09*V10 + 3.11787899621623516e-14*V02*V102 - 
      1.51881168562532466e-12*V033*V11 - 4.40934158628107553e-12*V02*V03*V04*V11 - 
      1.33497361960506478e-12*V01*V042*V11 - 1.07655877269095363e-12*V022*V05*V11 - 
      2.68644112176895661e-12*V01*V03*V05*V11 - 9.52960699694432174e-13*V01*V02*V06*V11 + 6.84129584149527379e-13*V05*V06*V11 - 
      1.79020773765738028e-13*V012*V07*V11 + 4.60774808337594117e-13*V04*V07*V11 + 
      2.58509306778680506e-13*V03*V08*V11 + 6.66112563825561374e-14*V02*V09*V11 + 1.84889018457526946e-14*V01*V10*V11 - 
      8.35290526774251518e-13*V02*V032*V12 - 2.47605533628324811e-13*V022*V04*V12 - 
      9.78324647684366881e-13*V01*V03*V04*V12 - 5.01174316064550911e-13*V01*V02*V05*V12 + 
      1.85755303096988537e-13*V052*V12 - 9.84544380311962849e-14*V012*V06*V12 + 
      2.24702992214237174e-13*V04*V06*V12 + 1.79638835024222621e-13*V03*V07*V12 + 4.27110664190148531e-14*V02*V08*V12 + 
      1.56521585564102695e-14*V01*V09*V12 - 1.21283886108971637e-16*V122 - 
      1.38020355473199184e-13*V022*V03*V13 - 1.64470249379212965e-13*V01*V032*V13 - 
      1.69590061010810597e-13*V01*V02*V04*V13 - 4.6788567569687035e-14*V012*V05*V13 + 
      1.2987681548843124e-13*V04*V05*V13 + 9.32407235128521577e-14*V03*V06*V13 + 3.16695058366000516e-14*V02*V07*V13 + 
      1.07086075255241517e-14*V01*V08*V13 - 2.36726161901129699e-16*V11*V13 - 4.28788334463925038e-15*V023*V14 - 
      5.38763992793265321e-14*V01*V02*V03*V14 - 1.52040648886316978e-14*V012*V04*V14 + 
      1.83220005303319117e-14*V042*V14 + 4.36973912871109959e-14*V03*V05*V14 + 1.32520690923386879e-14*V02*V06*V14 + 
      6.42266317854633338e-15*V01*V07*V14 - 1.7866191433540021e-16*V10*V14 - 3.94343872780569097e-15*V01*V022*V15 - 
      4.14813254544663678e-15*V012*V03*V15 + 1.32933569350157555e-14*V03*V04*V15 + 
      6.70424078518043637e-15*V02*V05*V15 + 2.90109792042610258e-15*V01*V06*V15 - 1.29107459341060207e-16*V09*V15 - 
      6.28878596366761223e-16*V012*V02*V16 + 1.9498542612414436e-15*V032*V16 + 
      1.63958782899303425e-15*V02*V04*V16 + 1.18553176371345238e-15*V01*V05*V16 - 7.00374295084141807e-17*V08*V16 - 
      2.46619057398729892e-17*V013*V17 + 5.33805162644932019e-16*V02*V03*V17 + 3.2177532159368341e-16*V01*V04*V17 - 
      3.70192182554372465e-17*V07*V17 + 2.85220301165487614e-17*V022*V18 + 8.2215287939337454e-17*V01*V03*V18 - 
      1.36918254221765874e-17*V06*V18 + 1.03204714237511965e-17*V01*V02*V19 - 5.11287770447656681e-18*V05*V19 + 
      6.7016048206176601e-19*V012*V20 - 1.1553566710744846e-18*V04*V20 - 2.832544970847731e-19*V03*V21 - 
      2.94870612107177044e-20*V02*V22 - 4.02096289237059606e-21*V01*V23 + 6.20518964872005564e-24*V26) + 
   delta10*eps8*(1.03644223710013184e-9*V032*V043 + 7.69281785172546935e-11*V02*V044 + 
      2.23576403065925483e-9*V033*V04*V05 + 3.0758151273048265e-9*V02*V03*V042*V05 + 
      6.21865342260079102e-10*V01*V043*V05 + 1.72425317004195095e-9*V02*V032*V052 + 
      7.44933924140365489e-10*V022*V04*V052 + 1.95196621320524829e-9*V01*V03*V04*V052 + 
      3.37044154365490795e-10*V01*V02*V053 - 8.86044777363391133e-11*V054 + 
      3.8244802639047179e-10*V034*V06 + 2.19627954448125206e-9*V02*V032*V04*V06 + 
      1.57554740974366134e-10*V022*V042*V06 + 1.3106433671735816e-9*V01*V03*V042*V06 + 
      1.07889346598353593e-9*V022*V03*V05*V06 + 1.32380166356476179e-9*V01*V032*V05*V06 + 
      1.31776772668875124e-9*V01*V02*V04*V05*V06 + 1.85737232406228952e-10*V012*V052*V06 - 
      7.31437823120934984e-10*V04*V052*V06 + 1.78028801454292508e-11*V023*V062 + 
      4.63481031146693903e-10*V01*V02*V03*V062 + 1.3454676832729077e-10*V012*V04*V062 - 
      1.95663925615815219e-10*V042*V062 - 5.235117843415e-10*V03*V05*V062 - 
      4.66936333251060897e-11*V02*V063 + 5.34990721215064754e-10*V02*V033*V07 + 
      7.09460880133681418e-10*V022*V03*V04*V07 + 9.00830856579603447e-10*V01*V032*V04*V07 + 
      4.39402161043546643e-10*V01*V02*V042*V07 + 1.12101974959691146e-10*V023*V05*V07 + 
      9.34561339650519572e-10*V01*V02*V03*V05*V07 + 2.53549200883068641e-10*V012*V04*V05*V07 - 
      4.89345958036449584e-10*V042*V05*V07 - 5.0936164839679545e-10*V03*V052*V07 + 
      1.5412763799764799e-10*V01*V022*V06*V07 + 1.6931956922865567e-10*V012*V03*V06*V07 - 
      7.04068186757063522e-10*V03*V04*V06*V07 - 3.53228899935868542e-10*V02*V05*V06*V07 - 
      7.6362931160826196e-11*V01*V062*V07 + 3.02631670953244222e-11*V012*V02*V072 - 
      1.21809194119213621e-10*V032*V072 - 1.17419159346054373e-10*V02*V04*V072 - 
      7.34560746088200637e-11*V01*V05*V072 + 1.9730626157021439e-10*V022*V032*V08 + 
      1.52448556807254477e-10*V01*V033*V08 + 1.77815628638582902e-11*V023*V04*V08 + 
      4.7487650391059968e-10*V01*V02*V03*V04*V08 + 6.90528428335295722e-11*V012*V042*V08 - 
      6.78083241517972135e-11*V043*V08 + 1.18383756942128634e-10*V01*V022*V05*V08 + 
      1.26591387143792804e-10*V012*V03*V05*V08 - 5.48630925336919625e-10*V03*V04*V05*V08 - 
      1.38327168512975287e-10*V02*V052*V08 + 4.8745308936170531e-11*V012*V02*V06*V08 - 
      1.95031783256437153e-10*V032*V06*V08 - 1.4543219266699888e-10*V02*V04*V06*V08 - 
      1.18210669118258031e-10*V01*V05*V06*V08 + 5.01746472277715964e-12*V013*V07*V08 - 
      1.33112230181405307e-10*V02*V03*V07*V08 - 8.00030249249020578e-11*V01*V04*V07*V08 + 
      3.92990368802391292e-12*V072*V08 - 6.70541348750019e-12*V022*V082 - 
      2.17404810478333747e-11*V01*V03*V082 + 2.97203456063187927e-12*V06*V082 + 
      3.1139437488803096e-11*V023*V03*V09 + 1.22754882439275202e-10*V01*V02*V032*V09 + 
      5.91217400111401182e-11*V01*V022*V04*V09 + 6.56508562462427927e-11*V012*V03*V04*V09 - 
      1.38854417015004065e-10*V03*V042*V09 + 3.43776854632476121e-11*V012*V02*V05*V09 - 
      1.42941449688980166e-10*V032*V05*V09 - 1.38448103897304411e-10*V02*V04*V05*V09 - 
      4.30276258233606887e-11*V01*V052*V09 + 3.81396372267135777e-12*V013*V06*V09 - 
      1.00202658874331531e-10*V02*V03*V06*V09 - 6.05375329378461776e-11*V01*V04*V06*V09 - 
      1.64118652809714842e-11*V022*V07*V09 - 4.08646481491317894e-11*V01*V03*V07*V09 + 
      6.01397796505936062e-12*V06*V07*V09 - 1.14357032716647961e-11*V01*V02*V08*V09 + 4.72038477027008684e-12*V05*V08*V09 - 
      8.2482864742720661e-13*V012*V092 + 1.22588102727520073e-12*V04*V092 + 
      4.41628966719152241e-13*V024*V10 + 2.58472555773542445e-11*V01*V022*V03*V10 + 
      1.29549237470610211e-11*V012*V032*V10 + 1.51456161720281988e-11*V012*V02*V04*V10 - 
      6.3325802769482879e-11*V032*V04*V10 - 2.32112737609917358e-11*V02*V042*V10 + 
      2.24854925583291979e-12*V013*V05*V10 - 6.42691019807710967e-11*V02*V03*V05*V10 - 
      3.83706426821222986e-11*V01*V04*V05*V10 - 8.24636658227674083e-12*V022*V06*V10 - 
      2.69448662011830399e-11*V01*V03*V06*V10 + 1.86934827302314237e-12*V062*V10 - 
      9.3636809477959793e-12*V01*V02*V07*V10 + 3.88547034161994706e-12*V05*V07*V10 - 
      1.44871320788164355e-12*V012*V08*V10 + 1.99004986634628615e-12*V04*V08*V10 + 
      1.14387030318298649e-12*V03*V09*V10 + 1.21953854967834181e-13*V02*V102 + 
      1.69851477211653251e-12*V01*V023*V11 + 5.6508811098000575e-12*V012*V02*V03*V11 - 
      8.77872595288240884e-12*V033*V11 + 9.38064908627548888e-13*V013*V04*V11 - 
      2.59682468869140614e-11*V02*V03*V04*V11 - 7.89296648013855657e-12*V01*V042*V11 - 
      6.39681333144350255e-12*V022*V05*V11 - 1.57396968193959993e-11*V01*V03*V05*V11 - 
      5.69289266622793113e-12*V01*V02*V06*V11 + 2.42670699692985867e-12*V05*V06*V11 - 
      1.08447647752873986e-12*V012*V07*V11 + 1.64742693740948427e-12*V04*V07*V11 + 
      9.33604454491042186e-13*V03*V08*V11 + 2.46029316174515537e-13*V02*V09*V11 + 6.96299380888316339e-14*V01*V10*V11 + 
      5.48801388429393628e-13*V012*V022*V12 + 2.96756711767891678e-13*V013*V03*V12 - 
      5.06091900069081585e-12*V02*V032*V12 - 1.78082799284098192e-12*V022*V04*V12 - 
      5.96983353673383486e-12*V01*V03*V04*V12 - 3.06467337152966668e-12*V01*V02*V05*V12 + 
      6.64541833429161692e-13*V052*V12 - 6.12971667164543145e-13*V012*V06*V12 + 
      8.64904687778891982e-13*V04*V06*V12 + 6.515886536102613e-13*V03*V07*V12 + 1.6855302949908041e-13*V02*V08*V12 + 
      5.90505816400706376e-14*V01*V09*V12 - 3.74596196056266142e-16*V122 + 
      5.33437021153452755e-14*V013*V02*V13 - 8.53556778292250779e-13*V022*V03*V13 - 
      1.01555261646222982e-12*V01*V032*V13 - 1.04979567258204347e-12*V01*V02*V04*V13 - 
      2.945001473926933e-13*V012*V05*V13 + 4.78694801337721704e-13*V04*V05*V13 + 3.45583666266237063e-13*V03*V06*V13 + 
      1.1908242444271215e-13*V02*V07*V13 + 4.09234391918326829e-14*V01*V08*V13 - 7.16541842251606127e-16*V11*V13 + 
      1.55370006161199832e-15*V014*V14 - 3.25948187528654673e-14*V023*V14 - 
      3.46142178011987339e-13*V01*V02*V03*V14 - 9.8667352484083855e-14*V012*V04*V14 + 
      7.33058474524930906e-14*V042*V14 + 1.6352256203831978e-13*V03*V05*V14 + 5.36870923463537244e-14*V02*V06*V14 + 
      2.46884977078012e-14*V01*V07*V14 - 5.53761160863980495e-16*V10*V14 - 2.58210153096470196e-14*V01*V022*V15 - 
      2.7874118962491446e-14*V012*V03*V15 + 5.13986819450477708e-14*V03*V04*V15 + 2.60977111694806816e-14*V02*V05*V15 + 
      1.14235555772248634e-14*V01*V06*V15 - 3.92931397871210248e-16*V09*V15 - 4.3281644573477096e-15*V012*V02*V16 + 
      7.66455841729221167e-15*V032*V16 + 6.93053164128995936e-15*V02*V04*V16 + 4.72235285289644036e-15*V01*V05*V16 - 
      2.19634375428030821e-16*V08*V16 - 1.84964293049047419e-16*V013*V17 + 2.18324881846082131e-15*V02*V03*V17 + 
      1.32375459700696516e-15*V01*V04*V17 - 1.14226173525499769e-16*V07*V17 + 1.27732587880972601e-16*V022*V18 + 
      3.44998616165397142e-16*V01*V03*V18 - 4.39182970314357737e-17*V06*V18 + 4.49007522981383226e-17*V01*V02*V19 - 
      1.61950982095046374e-17*V05*V19 + 3.01572216927794704e-18*V012*V20 - 3.8427002041421663e-18*V04*V20 - 
      9.35544032958225349e-19*V03*V21 - 1.03204714237511965e-19*V02*V22 - 1.40733701232970862e-20*V01*V23 + 
      1.86155689461601669e-23*V26) + delta8*eps9*
    (9.45532553415107021e-9*V032*V043 + 1.26121885620031857e-9*V02*V044 + 
      1.9236691918831295e-8*V033*V04*V05 + 2.80143356086422153e-8*V02*V03*V042*V05 + 
      5.67319532049064213e-9*V01*V043*V05 + 1.48129746610753902e-8*V02*V032*V052 + 
      6.81024771582047124e-9*V022*V04*V052 + 1.69721695215116268e-8*V01*V03*V04*V052 + 
      2.92333949172506964e-9*V01*V02*V053 - 3.01794207563108192e-10*V054 + 
      3.32166487416964801e-9*V034*V06 + 2.01536861179702234e-8*V02*V032*V04*V06 + 
      2.63380560248332698e-9*V022*V042*V06 + 1.20713226448484733e-8*V01*V03*V042*V06 + 
      9.90150503351099135e-9*V022*V03*V05*V06 + 1.16365122459848362e-8*V01*V032*V05*V06 + 
      1.20922116707821341e-8*V01*V02*V04*V05*V06 + 1.66451337448793449e-9*V012*V052*V06 - 
      2.60533004952591578e-9*V04*V052*V06 + 3.04152605911516103e-10*V023*V062 + 
      4.29268672053267617e-9*V01*V02*V03*V062 + 1.24788195969702198e-9*V012*V04*V062 - 
      8.06569167406602239e-10*V042*V062 - 1.87772943073893864e-9*V03*V05*V062 - 
      1.96002792948003781e-10*V02*V063 + 4.64022141543661848e-9*V02*V033*V07 + 
      6.48595020554330594e-9*V022*V03*V04*V07 + 7.91967443622623238e-9*V01*V032*V04*V07 + 
      4.00204794409174504e-9*V01*V02*V042*V07 + 1.03563623669674131e-9*V023*V05*V07 + 
      8.20429847684633615e-9*V01*V02*V03*V05*V07 + 2.27371485633562394e-9*V012*V04*V05*V07 - 
      1.76603097599484093e-9*V042*V05*V07 - 1.7725841772712883e-9*V03*V052*V07 + 
      1.41450071907299876e-9*V01*V022*V06*V07 + 1.53932493269909523e-9*V012*V03*V06*V07 - 
      2.55804468490423388e-9*V03*V04*V06*V07 - 1.29848555321289188e-9*V02*V05*V06*V07 - 
      2.84730444412418445e-10*V01*V062*V07 + 2.75556597736724661e-10*V012*V02*V072 - 
      4.32782883923761649e-10*V032*V072 - 4.37045606733090645e-10*V02*V04*V072 - 
      2.66544802682082887e-10*V01*V05*V072 + 1.83748806362752038e-9*V022*V032*V08 + 
      1.36783610224156033e-9*V01*V033*V08 + 3.09244777418661657e-10*V023*V04*V08 + 
      4.4295562598826887e-9*V01*V02*V03*V04*V08 + 6.4469062655569227e-10*V012*V042*V08 - 
      2.84375948424868838e-10*V043*V08 + 1.10249283817651223e-9*V01*V022*V05*V08 + 
      1.16187002620730595e-9*V012*V03*V05*V08 - 2.00379019114445587e-9*V03*V04*V05*V08 - 
      5.11059549984255632e-10*V02*V052*V08 + 4.57908455110747334e-10*V012*V02*V06*V08 - 
      7.17308210461874218e-10*V032*V06*V08 - 6.20926322796909474e-10*V02*V04*V06*V08 - 
      4.43164997112489852e-10*V01*V05*V06*V08 + 4.87383378374813935e-11*V013*V07*V08 - 
      5.00958232930441006e-10*V02*V03*V07*V08 - 3.03361359199640337e-10*V01*V04*V07*V08 + 
      1.05185172877049743e-11*V072*V08 - 2.96368428745279302e-11*V022*V082 - 
      8.34852942360073705e-11*V01*V03*V082 + 8.42135875274038724e-12*V06*V082 + 
      2.87676732415761474e-10*V023*V03*V09 + 1.10333888951482431e-9*V01*V02*V032*V09 + 
      5.40495850461942162e-10*V01*V022*V04*V09 + 6.04535618391916272e-10*V012*V03*V04*V09 - 
      5.20240032580919634e-10*V03*V042*V09 + 3.16809430634511105e-10*V012*V02*V05*V09 - 
      5.17637658963436757e-10*V032*V05*V09 - 5.24562163091996322e-10*V02*V04*V05*V09 - 
      1.59044648426037593e-10*V01*V052*V09 + 3.71995253799096194e-11*V013*V06*V09 - 
      3.81897553570740288e-10*V02*V03*V06*V09 - 2.3236488317619325e-10*V01*V04*V06*V09 - 
      6.40105065788137506e-11*V022*V07*V09 - 1.53992753440856139e-10*V01*V03*V07*V09 + 
      1.62711915862272012e-11*V06*V07*V09 - 4.53052324091337561e-11*V01*V02*V08*V09 + 1.27970839761365963e-11*V05*V08*V09 - 
      3.29435978864654287e-12*V012*V092 + 3.40283698966436004e-12*V04*V092 + 
      8.1607890220289046e-12*V024*V10 + 2.46944717864024914e-10*V01*V022*V03*V10 + 
      1.23282523912579785e-10*V012*V032*V10 + 1.44532282360001167e-10*V012*V02*V04*V10 - 
      2.40824437360646892e-10*V032*V04*V10 - 1.02282749004364433e-10*V02*V042*V10 + 
      2.23117494323917926e-11*V013*V05*V10 - 2.46940637439620681e-10*V02*V03*V05*V10 - 
      1.48568020885695002e-10*V01*V04*V05*V10 - 3.69865033114333662e-11*V022*V06*V10 - 
      1.05079828554496227e-10*V01*V03*V06*V10 + 5.3573388311976452e-12*V062*V10 - 
      3.7225474562396066e-11*V01*V02*V07*V10 + 1.05331784243999658e-11*V05*V07*V10 - 
      5.88727892826532548e-12*V012*V08*V10 + 5.79164320309262717e-12*V04*V08*V10 + 
      3.19802563074875501e-12*V03*V09*V10 + 3.7107362635932425e-13*V02*V102 + 
      1.56914581317688077e-11*V01*V023*V11 + 5.45080893329476388e-11*V012*V02*V03*V11 - 
      3.35412399372212098e-11*V033*V11 + 9.46750831829132155e-12*V013*V04*V11 - 
      1.03379823418576005e-10*V02*V03*V04*V11 - 3.16140969679431848e-11*V01*V042*V11 - 
      2.57464068793074689e-11*V022*V05*V11 - 6.13166742838945541e-11*V01*V03*V05*V11 - 
      2.314427988088199e-11*V01*V02*V06*V11 + 6.70145101878702692e-12*V05*V06*V11 - 
      4.39712531127282944e-12*V012*V07*V11 + 4.60832450404364041e-12*V04*V07*V11 + 
      2.63025586772588469e-12*V03*V08*V11 + 7.18500274567017961e-13*V02*V09*V11 + 2.0643658012849413e-13*V01*V10*V11 + 
      5.43484281551877011e-12*V012*V022*V12 + 3.12397292388119128e-12*V013*V03*V12 - 
      2.04535364896567126e-11*V02*V032*V12 - 8.33434307335563745e-12*V022*V04*V12 - 
      2.43186859976911768e-11*V01*V03*V04*V12 - 1.25867461562704572e-11*V01*V02*V05*V12 + 
      1.83811761205944291e-12*V052*V12 - 2.55921528243809983e-12*V012*V06*V12 + 
      2.56527370540687419e-12*V04*V06*V12 + 1.83501369778612031e-12*V03*V07*V12 + 5.16770641723490209e-13*V02*V08*V12 + 
      1.7500680491185295e-13*V01*V09*V12 - 9.51467811463379367e-16*V122 + 
      5.92995523515246024e-13*V013*V02*V13 - 3.63570130250712084e-12*V022*V03*V13 - 
      4.20778969543138954e-12*V01*V032*V13 - 4.48928068754629983e-12*V01*V02*V04*V13 - 
      1.24654835657475017e-12*V012*V05*V13 + 1.37299761393899378e-12*V04*V05*V13 + 
      9.96161857994013652e-13*V03*V06*V13 + 3.52057919143315269e-13*V02*V07*V13 + 1.22784748364545112e-13*V01*V08*V13 - 
      1.79621550299223666e-15*V11*V13 + 1.9421250770149979e-14*V014*V14 - 1.63228933456972691e-13*V023*V14 - 
      1.50547987041411165e-12*V01*V02*V03*V14 - 4.33112388603649435e-13*V012*V04*V14 + 
      2.26134324491859549e-13*V042*V14 + 4.72403651941420687e-13*V03*V05*V14 + 1.68587357962076689e-13*V02*V06*V14 + 
      7.409507624095008e-14*V01*V07*V14 - 1.40971547280422602e-15*V10*V14 - 1.1822917611695111e-13*V01*V022*V15 - 
      1.26164144288755244e-13*V012*V03*V15 + 1.54348581062465391e-13*V03*V04*V15 + 
      7.93638556122369489e-14*V02*V05*V15 + 3.51664367400224497e-14*V01*V06*V15 - 9.87189392041246962e-16*V09*V15 - 
      2.0346072235395216e-14*V012*V02*V16 + 2.32222334842838003e-14*V032*V16 + 
      2.27093261593378277e-14*V02*V04*V16 + 1.45999822301012219e-14*V01*V05*V16 - 5.63749049917588494e-16*V08*V16 - 
      9.24821465245237093e-16*V013*V17 + 6.96548051042948046e-15*V02*V03*V17 + 4.25303946730858563e-15*V01*V04*V17 - 
      2.89206080632549967e-16*V07*V17 + 4.45522688474662043e-16*V022*V18 + 1.12194917104370556e-15*V01*V03*V18 - 
      1.14825296996462988e-16*V06*V18 + 1.53299210271628975e-16*V01*V02*V19 - 4.18163386794490446e-17*V05*V19 + 
      1.05550275924728147e-17*V012*V20 - 1.03975398791882996e-17*V04*V20 - 2.51142640652646812e-18*V03*V21 - 
      2.94870612107177044e-19*V02*V22 - 4.02096289237059606e-20*V01*V23 + 4.65389223654004173e-23*V26) + 
   eps13*(7.83069566138349207e-9*V027 + 3.89470526809316492e-7*V01*V025*V03 + 
      1.4560094596883618e-6*V012*V023*V032 + 6.43388385203861394e-7*V013*V02*V033 - 
      2.25963672458806971e-7*V022*V034 - 7.40421868182868416e-8*V01*V035 + 
      5.75913158068416005e-7*V012*V024*V04 + 1.47733453165000784e-6*V013*V022*V03*V04 + 
      2.2660888081274986e-7*V014*V032*V04 - 6.34316323392156272e-7*V023*V032*V04 - 
      1.09169531821405071e-6*V01*V02*V033*V04 + 1.68546834283441426e-7*V014*V02*V042 - 
      9.93094869534334209e-8*V024*V042 - 1.19255469126537345e-6*V01*V022*V03*V042 - 
      4.7194417974956753e-7*V012*V032*V042 - 2.36977895033304697e-7*V012*V02*V043 + 
      6.15396422160911125e-8*V032*V043 + 2.08755249185163841e-8*V02*V044 + 
      3.0365453335856775e-7*V013*V023*V05 + 2.72437377162079543e-7*V014*V02*V03*V05 - 
      1.87735168274331277e-7*V024*V03*V05 - 9.9695598435458963e-7*V01*V022*V032*V05 - 
      2.57829614588594222e-7*V012*V033*V05 + 2.32669736017950304e-8*V015*V04*V05 - 
      4.78481933545874632e-7*V01*V023*V04*V05 - 1.15909676568249893e-6*V012*V02*V03*V04*V05 + 
      1.04774569359265628e-7*V033*V04*V05 - 1.06365326721047134e-7*V013*V042*V05 + 
      2.22867743488102149e-7*V02*V03*V042*V05 + 4.68070079918040045e-8*V01*V043*V05 - 
      1.77712107617533329e-7*V012*V022*V052 - 8.62823368941701691e-8*V013*V03*V052 + 
      9.55102875060511121e-8*V02*V032*V052 + 6.68835757659441601e-8*V022*V04*V052 + 
      1.18262788679119731e-7*V01*V03*V04*V052 + 2.4114996135405519e-8*V01*V02*V053 - 
      5.87971432306545918e-10*V054 + 6.7598537650620984e-8*V014*V022*V06 - 
      1.67841748918624113e-8*V025*V06 + 1.55672356193189527e-8*V015*V03*V06 - 
      3.39250098452824682e-7*V01*V023*V03*V06 - 4.02710445142131358e-7*V012*V02*V032*V06 + 
      1.85997849341130047e-8*V034*V06 - 3.03600293319488289e-7*V012*V022*V04*V06 - 
      1.4652365639961199e-7*V013*V03*V04*V06 + 1.59493451267026331e-7*V02*V032*V04*V06 + 
      5.38775891387696344e-8*V022*V042*V06 + 9.95998783780060399e-8*V01*V03*V042*V06 - 
      9.0371657699760816e-8*V013*V02*V05*V06 + 9.61234477073195602e-8*V022*V03*V05*V06 + 
      8.35480469489877804e-8*V01*V032*V05*V06 + 1.21508776031097569e-7*V01*V02*V04*V05*V06 + 
      1.52399636306011813e-8*V012*V052*V06 - 5.89896157218003488e-9*V04*V052*V06 - 
      3.96868820344981643e-9*V014*V062 + 7.7188754804050435e-9*V023*V062 + 
      4.31138384904303964e-8*V01*V02*V03*V062 + 1.29330943052344899e-8*V012*V04*V062 - 
      2.43809977936439083e-9*V042*V062 - 4.2243022736965277e-9*V03*V05*V062 - 
      7.07716085533879318e-10*V02*V063 + 6.41358063233063233e-9*V015*V02*V07 - 
      3.72903536990352272e-8*V01*V024*V07 - 1.82159404246676656e-7*V012*V022*V03*V07 - 
      4.37857125942516349e-8*V013*V032*V07 + 3.33510664947870221e-8*V02*V033*V07 - 
      6.66512522719849401e-8*V013*V02*V04*V07 + 7.0436522298911306e-8*V022*V03*V04*V07 + 
      6.1629967050080088e-8*V01*V032*V04*V07 + 4.47039502924786497e-8*V01*V02*V042*V07 - 
      6.89687013435262735e-9*V014*V05*V07 + 1.40319220319051179e-8*V023*V05*V07 + 
      7.55002763583002605e-8*V01*V02*V03*V05*V07 + 2.25165618306410122e-8*V012*V04*V05*V07 - 
      4.3390872573251391e-9*V042*V05*V07 - 3.71581570466195363e-9*V03*V052*V07 + 
      1.93279029537411271e-8*V01*V022*V06*V07 + 1.57967461763094828e-8*V012*V03*V06*V07 - 
      6.22175490190489495e-9*V03*V04*V06*V07 - 3.78129113979179746e-9*V02*V05*V06*V07 - 
      8.58084901628134437e-10*V01*V062*V07 + 3.60138821890595882e-9*V012*V02*V072 - 
      9.78266741482981504e-10*V032*V072 - 1.38948128968561484e-9*V02*V04*V072 - 
      7.52394819580870262e-10*V01*V05*V072 + 2.10774950358283692e-10*V016*V08 - 
      2.45112683534232709e-8*V012*V023*V08 - 3.51761800156262108e-8*V013*V02*V03*V08 + 
      1.96330626303350956e-8*V022*V032*V08 + 1.1216843817911246e-8*V01*V033*V08 - 
      4.47633195393757952e-9*V014*V04*V08 + 8.78358434831316382e-9*V023*V04*V08 + 
      4.92151309619481556e-8*V01*V02*V03*V04*V08 + 7.3841526455329652e-9*V012*V042*V08 - 
      9.28787617588229207e-10*V043*V08 + 1.49915135042101125e-8*V01*V022*V05*V08 + 
      1.22042032643364276e-8*V012*V03*V05*V08 - 4.83269600788884407e-9*V03*V04*V05*V08 - 
      1.47011713658956168e-9*V02*V052*V08 + 6.3955703261807191e-9*V012*V02*V06*V08 - 
      1.72787802715219131e-9*V032*V06*V08 - 2.42668113764751516e-9*V02*V04*V06*V08 - 
      1.33087411285108721e-9*V01*V05*V06*V08 + 7.34425621745087177e-10*V013*V07*V08 - 
      1.55259713298449543e-9*V02*V03*V07*V08 - 9.82807179230375702e-10*V01*V04*V07*V08 + 
      1.66409833207679984e-11*V072*V08 - 1.50941041769118968e-10*V022*V082 - 
      2.70912027194210816e-10*V01*V03*V082 + 1.46477147933849181e-11*V06*V082 - 
      6.3675289625044527e-9*V013*V022*V09 - 2.10996352617063401e-9*V014*V03*V09 + 
      4.57593414678611544e-9*V023*V03*V09 + 1.21308679000675984e-8*V01*V02*V032*V09 + 
      8.77025813340971257e-9*V01*V022*V04*V09 + 7.1834582491458546e-9*V012*V03*V04*V09 - 
      1.4153130144278294e-9*V03*V042*V09 + 4.43374919694538825e-9*V012*V02*V05*V09 - 
      1.2085493846929004e-9*V032*V05*V09 - 1.71860988325774967e-9*V02*V04*V05*V09 - 
      4.64537966320880956e-10*V01*V052*V09 + 5.85119928881510634e-10*V013*V06*V09 - 
      1.23485121005822109e-9*V02*V03*V06*V09 - 7.82527221124742941e-10*V01*V04*V06*V09 - 
      2.74866492876620447e-10*V022*V07*V09 - 4.87679733209617839e-10*V01*V03*V07*V09 + 
      2.64872102510882816e-11*V06*V07*V09 - 1.96132737209951713e-10*V01*V02*V08*V09 + 2.05915231695656882e-11*V05*V08*V09 - 
      1.47194794595128582e-11*V012*V092 + 6.04604398570575428e-12*V04*V092 - 
      6.81918957041506061e-10*V014*V02*V10 + 3.48265568096190404e-10*V024*V10 + 
      3.9527475182641169e-9*V01*V022*V03*V10 + 1.58723639999545373e-9*V012*V032*V10 + 
      2.37547505225306883e-9*V012*V02*V04*V10 - 6.43522757525397723e-10*V032*V04*V10 - 
      4.50952228298101522e-10*V02*V042*V10 + 3.68274912836089829e-10*V013*V05*V10 - 
      7.85069953286181082e-10*V02*V03*V05*V10 - 4.96120765508822204e-10*V01*V04*V05*V10 - 
      1.96309128408017937e-10*V022*V06*V10 - 3.52688219460775253e-10*V01*V03*V06*V10 + 
      9.5316233966908681e-12*V062*V10 - 1.60333731470374093e-10*V01*V02*V07*V10 + 1.68369529618378081e-11*V05*V07*V10 - 
      2.67557676759354174e-11*V012*V08*V10 + 1.0935460066826233e-11*V04*V08*V10 + 5.52161429611184481e-12*V03*V09*V10 + 
      8.9919967036980298e-13*V02*V102 - 2.47970529833274931e-11*V015*V11 + 
      3.89954577624368677e-10*V01*V023*V11 + 9.61437921518691765e-10*V012*V02*V03*V11 - 
      8.91464542226039259e-11*V033*V11 + 1.80678947825540564e-10*V013*V04*V11 - 
      3.82417051477253683e-10*V02*V03*V04*V11 - 1.21402737967798751e-10*V01*V042*V11 - 
      1.1579794533571919e-10*V022*V05*V11 - 2.04845647122264229e-10*V01*V03*V05*V11 - 
      1.06250624924977204e-10*V01*V02*V06*V11 + 1.11490964617701429e-11*V05*V06*V11 - 
      2.0020992866254189e-11*V012*V07*V11 + 8.22649391242126872e-12*V04*V07*V11 + 4.59415296211132609e-12*V03*V08*V11 + 
      1.65438981434644094e-12*V02*V09*V11 + 4.82472259286606351e-13*V01*V10*V11 + 
      1.34548483210522039e-10*V012*V022*V12 + 6.68595979013183176e-11*V013*V03*V12 - 
      7.38062556142881292e-11*V02*V032*V12 - 5.13963980381249043e-11*V022*V04*V12 - 
      9.27015141760798796e-11*V01*V03*V04*V12 - 5.70547794500081007e-11*V01*V02*V05*V12 + 
      2.99860569026803575e-12*V052*V12 - 1.2273583111709115e-11*V012*V06*V12 + 
      5.01003651777715458e-12*V04*V06*V12 + 3.17860203949389117e-12*V03*V07*V12 + 1.2659976078683143e-12*V02*V08*V12 + 
      4.08194929348678229e-13*V01*V09*V12 - 1.4504663090396124e-15*V122 + 
      1.74558201922108011e-11*V013*V02*V13 - 1.87565584625415959e-11*V022*V03*V13 - 
      1.63891079936603135e-11*V01*V032*V13 - 2.39430034807101478e-11*V01*V02*V04*V13 - 
      6.09778721055783964e-12*V012*V05*V13 + 2.51300746588976029e-12*V04*V05*V13 + 
      1.80512891105252166e-12*V03*V06*V13 + 8.16578853091849905e-13*V02*V07*V13 + 2.91207984024564874e-13*V01*V08*V13 - 
      2.69675342393643147e-15*V11*V13 + 7.34123279111669205e-13*V014*V14 - 1.4520930099637216e-12*V023*V14 - 
      7.94578858294750353e-12*V01*V02*V03*V14 - 2.40313008101044368e-12*V012*V04*V14 + 
      4.89671735163281324e-13*V042*V14 + 8.42069244727671752e-13*V03*V05*V14 + 4.31272395984100651e-13*V02*V06*V14 + 
      1.74658263583684653e-13*V01*V07*V14 - 2.15457447914380396e-15*V10*V14 - 8.9781667846007617e-13*V01*V022*V15 - 
      7.37730082826125629e-13*V012*V03*V15 + 3.09546490011871761e-13*V03*V04*V15 + 
      1.89703701486212331e-13*V02*V05*V15 + 8.69839823895684655e-14*V01*V06*V15 - 1.48321425750994692e-15*V09*V15 - 
      1.5980914919437697e-13*V012*V02*V16 + 4.57771546685545971e-14*V032*V16 + 
      6.52843535205289976e-14*V02*V04*V16 + 3.57966221493292314e-14*V01*V05*V16 - 8.70649042677774238e-16*V08*V16 - 
      8.32339318720713384e-15*V013*V17 + 1.84343556902537708e-14*V02*V03*V17 + 1.17610148879670657e-14*V01*V04*V17 - 
      4.36239290396901429e-16*V07*V17 + 1.7370559695040975e-15*V022*V18 + 3.09639273730613213e-15*V01*V03*V18 - 
      1.8281307790162915e-16*V06*V18 + 5.69217559451212504e-16*V01*V02*V19 - 6.42876573435826361e-17*V05*V19 + 
      4.14661798275717718e-17*V012*V20 - 1.80792544048212925e-17*V04*V20 - 4.17426210264222503e-18*V03*V21 - 
      6.63458877241148349e-19*V02*V22 - 9.04716650783384113e-20*V01*V23 + 6.9808383548100626e-23*V26) + 
   delta6*eps10*(-2.74769340381696435e-8*V022*V034 - 1.07639452439872608e-8*V01*V035 - 
      4.89821079515290533e-8*V023*V032*V04 - 1.22930855987967722e-7*V01*V02*V033*V04 - 
      6.21784885258793341e-10*V024*V042 - 9.20991292139751524e-8*V01*V022*V03*V042 - 
      4.92875941492888272e-8*V012*V032*V042 - 1.87580428009933145e-8*V012*V02*V043 + 
      3.8824614260066828e-8*V032*V043 + 7.35917308458240036e-9*V02*V044 - 
      1.14557399132108646e-8*V024*V03*V05 - 9.39409530971155621e-8*V01*V022*V032*V05 - 
      2.85950056049067876e-8*V012*V033*V05 - 2.9389264770917432e-8*V01*V023*V04*V05 - 
      1.01809884577158153e-7*V012*V02*V03*V04*V05 + 7.44574559481591069e-8*V033*V04*V05 - 
      8.71032191546508384e-9*V013*V042*V05 + 1.17074384057691148e-7*V02*V03*V042*V05 + 
      2.38540431258448046e-8*V01*V043*V05 - 1.30756378568003218e-8*V012*V022*V052 - 
      7.29685615792836459e-9*V013*V03*V052 + 5.81283378552467414e-8*V02*V032*V052 + 
      2.89942622476878869e-8*V022*V04*V052 + 6.76905840804596579e-8*V01*V03*V04*V052 + 
      1.18056790875543742e-8*V01*V02*V053 - 7.06794045525907851e-10*V054 - 
      8.08275217575974916e-11*V025*V06 - 2.12515129940433395e-8*V01*V023*V03*V06 - 
      3.38762155989046745e-8*V012*V02*V032*V06 + 1.30392731897766477e-8*V034*V06 - 
      1.95949349048088544e-8*V012*V022*V04*V06 - 1.13983674421738536e-8*V013*V03*V04*V06 + 
      8.48076389399461026e-8*V02*V032*V04*V06 + 1.56786788592745625e-8*V022*V042*V06 + 
      5.10787322326783384e-8*V01*V03*V042*V06 - 5.92992564086557239e-9*V013*V02*V05*V06 + 
      4.24257291634024247e-8*V022*V03*V05*V06 + 4.70787089119660635e-8*V01*V032*V05*V06 + 
      5.20706209726761905e-8*V01*V02*V04*V05*V06 + 6.94713693255276068e-9*V012*V052*V06 - 
      6.40105790975212439e-9*V04*V052*V06 - 2.24298059751685646e-10*V014*V062 + 
      1.84866682635380758e-9*V023*V062 + 1.85948157653287073e-8*V01*V02*V03*V062 + 
      5.42265501444226541e-9*V012*V04*V062 - 2.22130745594143576e-9*V042*V062 - 
      4.63736991429361019e-9*V03*V05*V062 - 5.54580846146333209e-10*V02*V063 - 
      1.63653427331583779e-9*V01*V024*V07 - 1.17421299435771891e-8*V012*V022*V03*V07 - 
      3.20093405070451445e-9*V013*V032*V07 + 1.87592204069923935e-8*V02*V033*V07 - 
      4.00733871205393148e-9*V013*V02*V04*V07 + 2.82652039123999253e-8*V022*V03*V04*V07 + 
      3.2547018463495343e-8*V01*V032*V04*V07 + 1.75210095995387451e-8*V01*V02*V042*V07 - 
      3.83623342355446308e-10*V014*V05*V07 + 4.60317291956745984e-9*V023*V05*V07 + 
      3.41071335553664913e-8*V01*V02*V03*V05*V07 + 9.62912321222397202e-9*V012*V04*V05*V07 - 
      4.42951313977359782e-9*V042*V05*V07 - 4.25973443487603526e-9*V03*V052*V07 + 
      6.34079407561570895e-9*V01*V022*V06*V07 + 6.61773317046439941e-9*V012*V03*V06*V07 - 
      6.44617457894883118e-9*V03*V04*V06*V07 - 3.34149468111654351e-9*V02*V05*V06*V07 - 
      7.42741450773490953e-10*V01*V062*V07 + 1.21142067789604728e-9*V012*V02*V072 - 
      1.06680612584732195e-9*V032*V072 - 1.14702018027081605e-9*V02*V04*V072 - 
      6.77478100005880002e-10*V01*V05*V072 - 1.14891137851247821e-9*V012*V023*V08 - 
      1.92910950964172253e-9*V013*V02*V03*V08 + 8.11039841871320418e-9*V022*V032*V08 + 
      5.76365642877216439e-9*V01*V033*V08 - 2.22498727108904513e-10*V014*V04*V08 + 
      1.91415314893434211e-9*V023*V04*V08 + 1.96330381410626959e-8*V01*V02*V03*V04*V08 + 
      2.86591172869538992e-9*V012*V042*V08 - 8.01282368730101966e-10*V043*V08 + 
      4.97306318106403491e-9*V01*V022*V05*V08 + 5.05041475517903175e-9*V012*V03*V05*V08 - 
      5.05492119438749656e-9*V03*V04*V05*V08 - 1.31604917227658524e-9*V02*V052*V08 + 
      2.08191788365372175e-9*V012*V02*V06*V08 - 1.82019520578530927e-9*V032*V06*V08 - 
      1.79627438518836763e-9*V02*V04*V06*V08 - 1.15840113098896455e-9*V01*V05*V06*V08 + 
      2.25606373851185909e-10*V013*V07*V08 - 1.32165695838759844e-9*V02*V03*V07*V08 - 
      8.07434980281941008e-10*V01*V04*V07*V08 + 2.17051692867928172e-11*V072*V08 - 
      8.98487444929676867e-11*V022*V082 - 2.24134068354309549e-10*V01*V03*V082 + 
      1.81331803232160107e-11*V06*V082 - 2.52693778020575406e-10*V013*V022*V09 - 
      9.09225276055341415e-11*V014*V03*V09 + 1.3370593591798383e-9*V023*V03*V09 + 
      4.85068722880645286e-9*V01*V02*V032*V09 + 2.51833886420762107e-9*V01*V022*V04*V09 + 
      2.70947346742516175e-9*V012*V03*V04*V09 - 1.36161805484418992e-9*V03*V042*V09 + 
      1.43096367560202802e-9*V012*V02*V05*V09 - 1.29851267719888812e-9*V032*V05*V09 - 
      1.40116539159537664e-9*V02*V04*V05*V09 - 4.11291740294556219e-10*V01*V052*V09 + 
      1.74891630887711094e-10*V013*V06*V09 - 1.02452104590438096e-9*V02*V03*V06*V09 - 
      6.28379847623859237e-10*V01*V04*V06*V09 - 1.78484697920670409e-10*V022*V07*V09 - 
      4.08092701013585716e-10*V01*V03*V07*V09 + 3.3953132833433193e-11*V06*V07*V09 - 1.27888002532006643e-10*V01*V02*V08*V09 + 
      2.6678956657570525e-11*V05*V08*V09 - 9.36810066023675533e-12*V012*V092 + 
      7.3042193898542391e-12*V04*V092 - 2.1254616842852137e-11*V014*V02*V10 + 
      5.34565056721994546e-11*V024*V10 + 1.16830609307205209e-9*V01*V022*V03*V10 + 
      5.7084323796536825e-10*V012*V032*V10 + 6.85449851410095157e-10*V012*V02*V04*V10 - 
      6.33606321810949201e-10*V032*V04*V10 - 3.07470334617415872e-10*V02*V042*V10 + 
      1.06936736097720667e-10*V013*V05*V10 - 6.62203685910129601e-10*V02*V03*V05*V10 - 
      4.02223295614672744e-10*V01*V04*V05*V10 - 1.13976288763887216e-10*V022*V06*V10 - 
      2.86328062844170295e-10*V01*V03*V06*V10 + 1.16480856420793068e-11*V062*V10 - 
      1.04988399583446367e-10*V01*V02*V07*V10 + 2.19163995634344966e-11*V05*V07*V10 - 
      1.69271171359636885e-11*V012*V08*V10 + 1.28132665874286097e-11*V04*V08*V10 + 
      6.86706159496541213e-12*V03*V09*V10 + 8.64949181561006468e-13*V02*V102 - 
      5.9040602341255936e-13*V015*V11 + 7.9301443030414151e-11*V01*V023*V11 + 
      2.6594713548899463e-10*V012*V02*V03*V11 - 8.87299917031129082e-11*V033*V11 + 
      4.73697993641643616e-11*V013*V04*V11 - 2.90710931892431905e-10*V02*V03*V04*V11 - 
      8.95415287043420387e-11*V01*V042*V11 - 7.38304027027456823e-11*V022*V05*V11 - 
      1.6709053987121586e-10*V01*V03*V05*V11 - 6.70736015883760654e-11*V01*V02*V06*V11 + 1.41806766887971536e-11*V05*V06*V11 - 
      1.26383881868897513e-11*V012*V07*V11 + 9.92787536971747346e-12*V04*V07*V11 + 
      5.68022819682475523e-12*V03*V08*V11 + 1.63246143178152037e-12*V02*V09*V11 + 4.7344232554941086e-13*V01*V10*V11 + 
      2.78562884046415178e-11*V012*V022*V12 + 1.62444520441739797e-11*V013*V03*V12 - 
      5.77149632529734132e-11*V02*V032*V12 - 2.6944414439909714e-11*V022*V04*V12 - 
      6.92962743396114235e-11*V01*V03*V04*V12 - 3.64699830497891316e-11*V01*V02*V05*V12 + 
      3.87536377323733394e-12*V052*V12 - 7.53905826800908323e-12*V012*V06*V12 + 
      5.76198889094579598e-12*V04*V06*V12 + 3.95150326642972839e-12*V03*V07*V12 + 1.21099716344026668e-12*V02*V08*V12 + 
      4.00943552284233181e-13*V01*V09*V12 - 1.91905668480552483e-15*V122 + 
      3.26277012938519646e-12*V013*V02*V13 - 1.10242787871679341e-11*V022*V03*V13 - 
      1.21615132465506972e-11*V01*V032*V13 - 1.36914823893645027e-11*V01*V02*V04*V13 - 
      3.70892250064880374e-12*V012*V05*V13 + 3.00593384548658181e-12*V04*V05*V13 + 
      2.18822945116350435e-12*V03*V06*V13 + 8.0426113589143413e-13*V02*V07*V13 + 2.83733661829447263e-13*V01*V08*V13 - 
      3.5950044222355905e-15*V11*V13 + 1.16527504620899874e-13*V014*V14 - 5.70142157529630388e-13*V023*V14 - 
      4.61744861167641976e-12*V01*V02*V03*V14 - 1.3414535353382164e-12*V012*V04*V14 + 
      5.26901714422590449e-13*V042*V14 + 1.03479343769192604e-12*V03*V05*V14 + 4.02694965934368117e-13*V02*V06*V14 + 
      1.70833668881899522e-13*V01*V07*V14 - 2.84703099736483097e-15*V10*V14 - 3.89072390428671245e-13*V01*V022*V15 - 
      4.00077765865089566e-13*V012*V03*V15 + 3.51758725996098794e-13*V03*V04*V15 + 
      1.84741598720858294e-13*V02*V05*V15 + 8.28519403972961318e-14*V01*V06*V15 - 1.97695220033361111e-15*V09*V15 - 
      6.79743776955249263e-14*V012*V02*V16 + 5.30733593768815591e-14*V032*V16 + 
      5.64663818975602804e-14*V02*V04*V16 + 3.43795678100096272e-14*V01*V05*V16 - 1.14444869229479259e-15*V08*V16 - 
      3.23687512835832983e-15*V013*V17 + 1.69279186966391785e-14*V02*V03*V17 + 1.04222688009763788e-14*V01*V04*V17 - 
      5.80985577516217115e-16*V07*V17 + 1.18497776438161466e-15*V022*V18 + 2.76682456624020715e-15*V01*V03*V18 - 
      2.36325392394261166e-16*V06*V18 + 4.01091048513966957e-16*V01*V02*V19 - 8.50500667784587243e-17*V05*V19 + 
      2.81467402465941724e-17*V012*V20 - 2.20750862791145724e-17*V04*V20 - 5.28421540105702499e-18*V03*V21 - 
      6.63458877241148349e-19*V02*V22 - 9.04716650783384113e-20*V01*V23 + 9.30778447308008347e-23*V26) + 
   delta2*eps12*(2.67650730613693577e-11*V027 + 1.45976708476708477e-7*V01*V025*V03 + 
      7.0347310654023617e-7*V012*V023*V032 + 3.42178076553076553e-7*V013*V02*V033 - 
      3.084430776406004e-7*V022*V034 - 1.08118735615307161e-7*V01*V035 + 
      2.37633701175367842e-7*V012*V024*V04 + 6.93810915165081832e-7*V013*V022*V03*V04 + 
      1.13156037635204302e-7*V014*V032*V04 - 7.43688622196506832e-7*V023*V032*V04 - 
      1.44359805672247316e-6*V01*V02*V033*V04 + 7.64811962728629395e-8*V014*V02*V042 - 
      8.46192910475220622e-8*V024*V042 - 1.38524165905300651e-6*V01*V022*V03*V042 - 
      6.05303266276509741e-7*V012*V032*V042 - 2.74664734491634001e-7*V012*V02*V043 + 
      1.11694089518080728e-7*V032*V043 + 3.25142589196534057e-8*V02*V044 + 
      1.18629495076254336e-7*V013*V023*V05 + 1.16106886940220274e-7*V014*V02*V03*V05 - 
      1.89987803884635766e-7*V024*V03*V05 - 1.18823842681875478e-6*V01*V022*V032*V05 - 
      3.31736914716460702e-7*V012*V033*V05 + 9.63542630209296876e-9*V015*V04*V05 - 
      4.83504726572034514e-7*V01*V023*V04*V05 - 1.34919420843425862e-6*V012*V02*V03*V04*V05 + 
      1.95378476733736308e-7*V033*V04*V05 - 1.21287286511449093e-7*V013*V042*V05 + 
      3.72522518500135835e-7*V02*V03*V042*V05 + 7.73089389403570869e-8*V01*V043*V05 - 
      1.8487438634533931e-7*V012*V022*V052 - 9.78097825560769072e-8*V013*V03*V052 + 
      1.65316922135894928e-7*V02*V032*V052 + 1.01740062258203634e-7*V022*V04*V052 + 
      2.00321126014137137e-7*V01*V03*V04*V052 + 3.76852254599081583e-8*V01*V02*V053 - 
      1.16437164809287144e-9*V054 + 2.40283443408443408e-8*V014*V022*V06 - 
      1.2002167247946115e-8*V025*V06 + 5.90169861003194337e-9*V015*V03*V06 - 
      3.48537536633261034e-7*V01*V023*V03*V06 - 4.65194063466705857e-7*V012*V02*V032*V06 + 
      3.48391497335826987e-8*V034*V06 - 3.12553644628662136e-7*V012*V022*V04*V06 - 
      1.64529391194015377e-7*V013*V03*V04*V06 + 2.69770771364478109e-7*V02*V032*V04*V06 + 
      7.7090098636797543e-8*V022*V042*V06 + 1.65806390843634817e-7*V01*V03*V042*V06 - 
      9.2022791402022261e-8*V013*V02*V05*V06 + 1.48557661675356213e-7*V022*V03*V05*V06 + 
      1.41952602899461084e-7*V01*V032*V05*V06 + 1.85640328809827055e-7*V01*V02*V04*V05*V06 + 
      2.34643216241922976e-8*V012*V052*V06 - 1.14432768100795188e-8*V04*V052*V06 - 
      3.87938929240866683e-9*V014*V062 + 1.00510417097837275e-8*V023*V062 + 
      6.64465440764529479e-8*V01*V02*V03*V062 + 1.96674517835845123e-8*V012*V04*V062 - 
      4.58348028122747872e-9*V042*V062 - 8.278219783333639e-9*V03*V05*V062 - 
      1.24683518334632837e-9*V02*V063 + 2.04752808919475586e-9*V015*V02*V07 - 
      3.13823433674672781e-8*V01*V024*V07 - 1.84926089044246724e-7*V012*V022*V03*V07 - 
      4.810012569626832e-8*V013*V032*V07 + 5.73194526254322907e-8*V02*V033*V07 - 
      6.68356487246543269e-8*V013*V02*V04*V07 + 1.0676507036741326e-7*V022*V03*V04*V07 + 
      1.03432916432419505e-7*V01*V032*V04*V07 + 6.71412123632643145e-8*V01*V02*V042*V07 - 
      6.69646946126287863e-9*V014*V05*V07 + 1.90859584989206258e-8*V023*V05*V07 + 
      1.16939449769792707e-7*V01*V02*V03*V05*V07 + 3.4238071677382654e-8*V012*V04*V05*V07 - 
      8.30823257228058229e-9*V042*V05*V07 - 7.33675818986803955e-9*V03*V052*V07 + 
      2.65804099641751113e-8*V01*V022*V06*V07 + 2.40101095250355247e-8*V012*V03*V06*V07 - 
      1.20455061030964279e-8*V03*V04*V06*V07 - 6.79398788954425902e-9*V02*V05*V06*V07 - 
      1.53869034002724677e-9*V01*V062*V07 + 4.96562880025493872e-9*V012*V02*V072 - 
      1.92466642630860559e-9*V032*V072 - 2.45920200644826241e-9*V02*V04*V072 - 
      1.35724029323924052e-9*V01*V05*V072 + 6.02214143880810547e-11*V016*V08 - 
      2.13611851300781039e-8*V012*V023*V08 - 3.42695272229585955e-8*V013*V02*V03*V08 + 
      3.02792194681157412e-8*V022*V032*V08 + 1.88389345300225058e-8*V01*V033*V08 - 
      4.26361709807379742e-9*V014*V04*V08 + 1.12167139606465727e-8*V023*V04*V08 + 
      7.47344361790665714e-8*V01*V02*V03*V04*V08 + 1.10687472366313311e-8*V012*V042*V08 - 
      1.72772347997289948e-9*V043*V08 + 2.06640487907188666e-8*V01*V022*V05*V08 + 
      1.85082141198720689e-8*V012*V03*V05*V08 - 9.37950419429437389e-9*V03*V04*V05*V08 - 
      2.65050454855617483e-9*V02*V052*V08 + 8.80299398332571031e-9*V012*V02*V06*V08 - 
      3.38269656824215663e-9*V032*V06*V08 - 4.22589433929602085e-9*V02*V04*V06*V08 - 
      2.38981532068142626e-9*V01*V05*V06*V08 + 9.90515159221750045e-10*V013*V07*V08 - 
      2.79267731905870259e-9*V02*V03*V07*V08 - 1.74370892281823102e-9*V01*V04*V07*V08 + 
      3.31867925608791034e-11*V072*V08 - 2.41409229250683865e-10*V022*V082 - 
      4.84349766673563639e-10*V01*V03*V082 + 2.89712894379706975e-11*V06*V082 - 
      5.41549924975170073e-9*V013*V022*V09 - 1.93062769655906911e-9*V014*V03*V09 + 
      6.18950644102830038e-9*V023*V03*V09 + 1.85179574839370135e-8*V01*V02*V032*V09 + 
      1.17828203493836249e-8*V01*V022*V04*V09 + 1.07257156401284082e-8*V012*V03*V04*V09 - 
      2.70359820304872567e-9*V03*V042*V09 + 6.07914170003273737e-9*V012*V02*V05*V09 - 
      2.37460104972733882e-9*V032*V05*V09 - 3.04046225768207461e-9*V02*V04*V05*V09 - 
      8.36430987272470724e-10*V01*V052*V09 + 7.86772810235201405e-10*V013*V06*V09 - 
      2.21263297880806407e-9*V02*V03*V06*V09 - 1.38398602015655266e-9*V01*V04*V06*V09 - 
      4.4520846148331938e-10*V022*V07*V09 - 8.72931442629041828e-10*V01*V03*V07*V09 + 
      5.26721248135003586e-11*V06*V07*V09 - 3.19721355448360149e-10*V01*V02*V08*V09 + 4.10606581135547258e-11*V05*V08*V09 - 
      2.38199168900336927e-11*V012*V092 + 1.18839211140883258e-11*V04*V092 - 
      5.49077601773680205e-10*V014*V02*V10 + 3.86984390179204898e-10*V024*V10 + 
      5.38127123739438841e-9*V01*V022*V03*V10 + 2.35425271167935375e-9*V012*V032*V10 + 
      3.1997553842434887e-9*V012*V02*V04*V10 - 1.24450308167573351e-9*V032*V04*V10 - 
      7.73375929443341844e-10*V02*V042*V10 + 4.92008163903447967e-10*V013*V05*V10 - 
      1.41186771676983161e-9*V02*V03*V05*V10 - 8.79027095323632989e-10*V01*V04*V05*V10 - 
      3.12777136181320367e-10*V022*V06*V10 - 6.28829694329919415e-10*V01*V03*V06*V10 + 
      1.88137017465615999e-11*V062*V10 - 2.61467955813591311e-10*V01*V02*V07*V10 + 
      3.36011857984340028e-11*V05*V07*V10 - 4.32819850759256635e-11*V012*V08*V10 + 
      2.13961039994227219e-11*V04*V08*V10 + 1.09996421190625787e-11*V03*V09*V10 + 1.63674936427126164e-12*V02*V102 - 
      1.85977897374956198e-11*V015*V11 + 4.59321643964406406e-10*V01*V023*V11 + 
      1.28685984453044567e-9*V012*V02*V03*V11 - 1.73965530086105601e-10*V033*V11 + 
      2.37428674915237523e-10*V013*V04*V11 - 6.74434524894710797e-10*V02*V03*V04*V11 - 
      2.11500334074548793e-10*V01*V042*V11 - 1.87388333343387057e-10*V022*V05*V11 - 
      3.65495445156227141e-10*V01*V03*V05*V11 - 1.72407649831470694e-10*V01*V02*V06*V11 + 2.21675458077228265e-11*V05*V06*V11 - 
      3.23547309901701805e-11*V012*V07*V11 + 1.61689362500497414e-11*V04*V07*V11 + 
      9.14425764956572053e-12*V03*V08*V11 + 3.02273164582402388e-12*V02*V09*V11 + 8.81698213101695296e-13*V01*V10*V11 + 
      1.59805819837102087e-10*V012*V022*V12 + 8.63507651742408364e-11*V013*V03*V12 - 
      1.32009755806277339e-10*V02*V032*V12 - 8.03257382924611658e-11*V022*V04*V12 - 
      1.62859423095692768e-10*V01*V03*V04*V12 - 9.27706260841776561e-11*V01*V02*V05*V12 + 
      5.98372199130302705e-12*V052*V12 - 1.97702321500602692e-11*V012*V06*V12 + 
      9.77437966473708316e-12*V04*V06*V12 + 6.3322572941193529e-12*V03*V07*V12 + 2.30242322547588044e-12*V02*V08*V12 + 
      7.46025996387384221e-13*V01*V09*V12 - 2.89767620050883711e-15*V122 + 
      2.02563645532664281e-11*V013*V02*V13 - 3.02249688860715764e-11*V022*V03*V13 - 
      2.89074219856099494e-11*V01*V032*V13 - 3.81567556720352671e-11*V01*V02*V04*V13 - 
      9.79910305465500131e-12*V012*V05*V13 + 4.93805918318293845e-12*V04*V05*V13 + 
      3.58232318765102169e-12*V03*V06*V13 + 1.49168263991744812e-12*V02*V07*V13 + 5.31637941831333841e-13*V01*V08*V13 - 
      5.39349176926201655e-15*V11*V13 + 8.15692532346299116e-13*V014*V14 - 2.0394039642059269e-12*V023*V14 - 
      1.27822904068819101e-11*V01*V02*V03*V14 - 3.80462302587238088e-12*V012*V04*V14 + 
      9.43493087903362422e-13*V042*V14 + 1.6761637137509049e-12*V03*V05*V14 + 7.81357932304635833e-13*V02*V06*V14 + 
      3.18991229225688745e-13*V01*V07*V14 - 4.30350651164704879e-15*V10*V14 - 1.2922900262457796e-12*V01*V022*V15 - 
      1.16469240868589424e-12*V012*V03*V15 + 6.0699923045643279e-13*V03*V04*V15 + 3.46354183280487579e-13*V02*V05*V15 + 
      1.58266004160357444e-13*V01*V06*V15 - 2.96641343640904745e-15*V09*V15 - 2.29170759087769752e-13*V012*V02*V16 + 
      9.0756148202973631e-14*V032*V16 + 1.1655806393888189e-13*V02*V04*V16 + 6.52324830992174169e-14*V01*V05*V16 - 
      1.73765241233313247e-15*V08*V16 - 1.16527504620899874e-14*V013*V17 + 3.35629772626173653e-14*V02*V03*V17 + 
      2.11142771959826184e-14*V01*V04*V17 - 8.72463502182956469e-16*V07*V17 + 2.84623858336452642e-15*V022*V18 + 
      5.59838663504758089e-15*V01*V03*V18 - 3.6390719416676987e-16*V06*V18 + 9.40905316814719477e-16*V01*V02*V19 - 
      1.28560236076318882e-16*V05*V19 + 6.78537488087538085e-17*V012*V20 - 3.55955740047107016e-17*V04*V20 - 
      8.33344559443806033e-18*V03*V21 - 1.21634127494210531e-18*V02*V22 - 1.65864719310287087e-19*V01*V23 + 
      1.39616767096201252e-22*V26) + delta4*eps11*
    (-1.52806918959560572e-7*V022*V034 - 5.68856203558000944e-8*V01*V035 - 
      3.15876669022093859e-7*V023*V032*V04 - 6.958119979804348e-7*V01*V02*V033*V04 - 
      2.12135350797297057e-8*V024*V042 - 5.88091694777424625e-7*V01*V022*V03*V042 - 
      2.84453623063372519e-7*V012*V032*V042 - 1.17619271009793886e-7*V012*V02*V043 + 
      8.86966561558005104e-8*V032*V043 + 2.14460056215349951e-8*V02*V044 - 
      7.48091926548262786e-8*V024*V03*V05 - 5.39058962601990924e-7*V01*V022*V032*V05 - 
      1.58909001373938738e-7*V012*V033*V05 - 1.89526001413256315e-7*V01*V023*V04*V05 - 
      5.98055205770687797e-7*V012*V02*V03*V04*V05 + 1.61506258237866329e-7*V033*V04*V05 - 
      5.25955727480781947e-8*V013*V042*V05 + 2.7817888422773766e-7*V02*V03*V042*V05 + 
      5.71626170411310686e-8*V01*V043*V05 - 7.79750415933013972e-8*V012*V022*V052 - 
      4.30718512656148822e-8*V013*V03*V052 + 1.29951972063580657e-7*V02*V032*V052 + 
      7.14529200788832413e-8*V022*V04*V052 + 1.54251296369004045e-7*V01*V03*V04*V052 + 
      2.7666147109001462e-8*V01*V02*V053 - 1.13709972354473621e-9*V054 - 
      2.88534984820906597e-9*V025*V06 - 1.37982768361308666e-7*V01*V023*V03*V06 - 
      2.02380681221523114e-7*V012*V02*V032*V06 + 2.86427995168255253e-8*V034*V06 - 
      1.2455520353123839e-7*V012*V022*V04*V06 - 6.98371886039661483e-8*V013*V03*V04*V06 + 
      2.02138696129166647e-7*V02*V032*V04*V06 + 4.76440170839494897e-8*V022*V042*V06 + 
      1.22766511580894927e-7*V01*V03*V042*V06 - 3.73179340947003568e-8*V013*V02*V05*V06 + 
      1.04883064752468015e-7*V022*V03*V05*V06 + 1.08613935887695355e-7*V01*V032*V05*V06 + 
      1.29739082094093604e-7*V01*V02*V04*V05*V06 + 1.67949996998712611e-8*V012*V052*V06 - 
      1.07734910420858212e-8*V04*V052*V06 - 1.49676361306846834e-9*V014*V062 + 
      5.84866874828278493e-9*V023*V062 + 4.6490749479958687e-8*V01*V02*V03*V062 + 
      1.36335308620654137e-8*V012*V04*V062 - 4.07075243007609874e-9*V042*V062 - 
      7.81909983324219675e-9*V03*V05*V062 - 1.05468946841692334e-9*V02*V063 - 
      1.06870275221180398e-8*V01*V024*V07 - 7.26839521385117401e-8*V012*V022*V03*V07 - 
      1.97934519015381916e-8*V013*V032*V07 + 4.36427528289873252e-8*V02*V033*V07 - 
      2.5795429568918131e-8*V013*V02*V04*V07 + 7.24637097784827881e-8*V022*V03*V04*V07 + 
      7.71187361798493556e-8*V01*V032*V04*V07 + 4.5233620195199384e-8*V01*V02*V042*V07 - 
      2.55167860404399464e-9*V014*V05*V07 + 1.21804939863605216e-8*V023*V05*V07 + 
      8.29641982955464781e-8*V01*V02*V03*V05*V07 + 2.38538285080762939e-8*V012*V04*V05*V07 - 
      7.64283130640170456e-9*V042*V05*V07 - 7.0292409799740354e-9*V03*V052*V07 + 
      1.69392668103744883e-8*V01*V022*V06*V07 + 1.6595678076758996e-8*V012*V03*V06*V07 - 
      1.11310141599262844e-8*V03*V04*V06*V07 - 5.96678959169407956e-9*V02*V05*V06*V07 - 
      1.34126360695585486e-9*V01*V062*V07 + 3.18336816442698659e-9*V012*V02*V072 - 
      1.80743274343053554e-9*V032*V072 - 2.10266307800613464e-9*V02*V04*V072 - 
      1.19842672976589113e-9*V01*V05*V072 - 7.53560510796738621e-9*V012*V023*V08 - 
      1.27980626820787885e-8*V013*V02*V03*V08 + 2.07894937321814828e-8*V022*V032*V08 + 
      1.3921933471288758e-8*V01*V033*V08 - 1.54652640647038406e-9*V014*V04*V08 + 
      6.26249873969185865e-9*V023*V04*V08 + 5.07187641611914184e-8*V01*V02*V03*V04*V08 + 
      7.44622710619452884e-9*V012*V042*V08 - 1.50432993014089171e-9*V043*V08 + 
      1.32561219817359938e-8*V01*V022*V05*V08 + 1.27619496246252961e-8*V012*V03*V05*V08 - 
      8.70482219950651634e-9*V03*V04*V05*V08 - 2.34132189036775429e-9*V02*V052*V08 + 
      5.60267195480498943e-9*V012*V02*V06*V08 - 3.14457965704656587e-9*V032*V06*V08 - 
      3.49886763160363477e-9*V02*V04*V06*V08 - 2.08946769759537164e-9*V01*V05*V06*V08 + 
      6.17035147718537668e-10*V013*V07*V08 - 2.4147989327076599e-9*V02*V03*V07*V08 - 
      1.49030395092540559e-9*V01*V04*V07*V08 + 3.29892849746113782e-11*V072*V08 - 
      1.85769012528000428e-10*V022*V082 - 4.15060292854459985e-10*V01*V03*V082 + 
      2.8347059314050546e-11*V06*V082 - 1.82258339427457075e-9*V013*V022*V09 - 
      6.67749212479604636e-10*V014*V03*V09 + 3.77339507269355975e-9*V023*V03*V09 + 
      1.25618347953540254e-8*V01*V02*V032*V09 + 7.14196990737920524e-9*V01*V022*V04*V09 + 
      7.14037566314455689e-9*V012*V03*V04*V09 - 2.43543286477891104e-9*V03*V042*V09 + 
      3.85955520133643137e-9*V012*V02*V05*V09 - 2.22293375126654135e-9*V032*V05*V09 - 
      2.59506546555557269e-9*V02*V04*V05*V09 - 7.3581687943856921e-10*V01*V052*V09 + 
      4.8665825669129732e-10*V013*V06*V09 - 1.89847107157496911e-9*V02*V03*V06*V09 - 
      1.17490485564995988e-9*V01*V04*V06*V09 - 3.51426447562011315e-10*V022*V07*V09 - 
      7.50335709632982461e-10*V01*V03*V07*V09 + 5.20763182348270563e-11*V06*V07*V09 - 2.5303234703178275e-10*V01*V02*V08*V09 + 
      4.07778441576321774e-11*V05*V08*V09 - 1.8695582881471011e-11*V012*V092 + 
      1.15072965190096386e-11*V04*V092 - 1.71217746789642214e-10*V014*V02*V10 + 
      1.92113878170659558e-10*V024*V10 + 3.29879529180663194e-9*V01*V022*V03*V10 + 
      1.54202785290627957e-9*V012*V032*V10 + 1.94591185098659104e-9*V012*V02*V04*V10 - 
      1.13024061335515152e-9*V032*V04*V10 - 6.21893994910565973e-10*V02*V042*V10 + 
      3.01718378928932375e-10*V013*V05*V10 - 1.21968969858732122e-9*V02*V03*V05*V10 - 
      7.49404778180590171e-10*V01*V04*V05*V10 - 2.38893190799719848e-10*V022*V06*V10 - 
      5.35874668934533298e-10*V01*V03*V06*V10 + 1.83359842204111559e-11*V062*V10 - 
      2.0718693649376069e-10*V01*V02*V07*V10 + 3.34199798567538781e-11*V05*V07*V10 - 
      3.3924902962824983e-11*V012*V08*V10 + 2.05328632884404755e-11*V04*V08*V10 + 1.07581102072366036e-11*V03*V09*V10 + 
      1.47070404889579494e-12*V02*V102 - 5.31365421071303424e-12*V015*V11 + 
      2.48358769884384882e-10*V01*V023*V11 + 7.71874861251565881e-10*V012*V02*V03*V11 - 
      1.58559391707317819e-10*V033*V11 + 1.40032212088693673e-10*V013*V04*V11 - 
      5.61357991571373525e-10*V02*V03*V04*V11 - 1.7433030741664228e-10*V01*V042*V11 - 
      1.47512793895455299e-10*V022*V05*V11 - 3.12222269925821467e-10*V01*V03*V05*V11 - 
      1.35159910425839623e-10*V01*V02*V06*V11 + 2.18922952159847789e-11*V05*V06*V11 - 
      2.5333763872467914e-11*V012*V07*V11 + 1.56536001965007288e-11*V04*V07*V11 + 8.92813645643280211e-12*V03*V08*V11 + 
      2.73641576630246169e-12*V02*V09*V11 + 7.97100635634540666e-13*V01*V10*V11 + 
      8.70369827014528024e-11*V012*V022*V12 + 4.96329484681952862e-11*V013*V03*V12 - 
      1.1096220648949361e-10*V02*V032*V12 - 5.91343175830674534e-11*V022*V04*V12 - 
      1.34862071672957394e-10*V01*V03*V04*V12 - 7.31229327782623809e-11*V01*V02*V05*V12 + 
      5.9457389675347873e-12*V052*V12 - 1.53633191449469276e-11*V012*V06*V12 + 
      9.3275632375441689e-12*V04*V06*V12 + 6.19310925351062037e-12*V03*V07*V12 + 2.06544449972002528e-12*V02*V08*V12 + 
      6.74624177338058683e-13*V01*V09*V12 - 2.89121865360783184e-15*V122 + 
      1.06816879235824884e-11*V013*V02*V13 - 2.30842065612378769e-11*V022*V03*V13 - 
      2.38773642772143671e-11*V01*V032*V13 - 2.88804264470394409e-11*V01*V02*V04*V13 - 
      7.59812044951786155e-12*V012*V05*V13 + 4.77430004109124123e-12*V04*V05*V13 + 
      3.47710866212780649e-12*V03*V06*V13 + 1.34988740448089142e-12*V02*V07*V13 + 4.7964793038172923e-13*V01*V08*V13 - 
      5.39335103556078358e-15*V11*V13 + 4.07846266173149558e-13*V014*V14 - 1.36409933028385478e-12*V023*V14 - 
      9.72954723225390703e-12*V01*V02*V03*V14 - 2.85819773119901505e-12*V012*V04*V14 + 
      8.79942667404491114e-13*V042*V14 + 1.63558710494722192e-12*V03*V05*V14 + 6.95851218173700222e-13*V02*V06*V14 + 
      2.88122330608983782e-13*V01*V07*V14 - 4.29233219484547072e-15*V10*V14 - 8.92212260380690033e-13*V01*V022*V15 - 
      8.66576209364092061e-13*V012*V03*V15 + 5.76254546085077975e-13*V03*V04*V15 + 
      3.12876249383043852e-13*V02*V05*V15 + 1.418321277710942e-13*V01*V06*V15 - 2.96627270270781448e-15*V09*V15 - 
      1.5731213123821483e-13*V012*V02*V16 + 8.6747750819641693e-14*V032*V16 + 
      1.01055643603636294e-13*V02*V04*V16 + 5.86680601292778003e-14*V01*V05*V16 - 1.73047164276784065e-15*V08*V16 - 
      7.76850030805999158e-15*V013*V17 + 2.96757113864180916e-14*V02*V03*V17 + 1.84515955686548097e-14*V01*V04*V17 - 
      8.72322768481723498e-16*V07*V17 + 2.28069015255260208e-15*V022*V18 + 4.90597682498136425e-15*V01*V03*V18 - 
      3.60579847373333201e-16*V06*V18 + 7.61972468104227953e-16*V01*V02*V19 - 1.28419502375085912e-16*V05*V19 + 
      5.42829990470030468e-17*V012*V20 - 3.45802808743871261e-17*V04*V20 - 8.19271189320508947e-18*V03*V21 - 
      1.10576479540191392e-18*V02*V22 - 1.50786108463897352e-19*V01*V23 + 1.39616767096201252e-22*V26) + 
   9.18368986379554615e-29*delta26*V26 + 5.969398411467105e-28*delta24*eps*V26 + 
   delta24*eps2*(-1.19394855996739947e-22*V132 - 1.91031769594783915e-22*V12*V14 - 
      1.77386643195156492e-22*V11*V15 - 1.04345084232444995e-22*V10*V16 - 7.17372454098059343e-23*V09*V17 - 
      3.02051559620235513e-23*V08*V18 - 1.51025779810117756e-23*V07*V19 - 4.31502228028907875e-24*V06*V20 - 
      1.51025779810117756e-24*V05*V21 - 2.6265353010455262e-25*V04*V22 - 5.969398411467105e-26*V03*V23 - 
      4.775518729173684e-27*V02*V24 - 5.969398411467105e-28*V01*V25 + 5.1460331133337112e-30*V28) + 
   delta22*eps3*(-1.43273827196087936e-21*V132 - 2.29238123513740697e-21*V12*V14 - 
      2.1286397183418779e-21*V11*V15 - 1.25214101078933994e-21*V10*V16 - 8.60846944917671212e-22*V09*V17 - 
      3.62461871544282615e-22*V08*V18 - 1.81230935772141308e-22*V07*V19 - 5.17802673634689451e-23*V06*V20 - 
      1.81230935772141308e-23*V05*V21 - 3.15184236125463144e-24*V04*V22 - 7.163278093760526e-25*V03*V23 - 
      5.7306224750084208e-26*V02*V24 - 7.163278093760526e-27*V01*V25 + 3.08761986800022672e-29*V28) + 
   delta20*eps4*(1.10298597358411377e-17*V083 + 8.50874893907744908e-17*V07*V08*V09 + 
      3.21177283144453053e-17*V06*V092 + 3.45184474005755605e-17*V072*V10 + 
      4.05285146835004812e-17*V06*V08*V10 + 4.02715219673381539e-17*V05*V09*V10 + 6.42551185378679264e-18*V04*V102 + 
      4.20450261570920361e-17*V06*V07*V11 + 3.2487950494659351e-17*V05*V08*V11 + 1.64373559050359812e-17*V04*V09*V11 + 
      7.32209490315239162e-18*V03*V10*V11 + 7.50401030447294793e-19*V02*V112 + 
      8.37583361314851212e-18*V062*V12 + 2.20591261494802398e-17*V05*V07*V12 + 8.6735229906141829e-18*V04*V08*V12 + 
      6.12753504152228884e-18*V03*V09*V12 + 9.81159102388680945e-19*V02*V10*V12 + 3.34229184083033937e-19*V01*V11*V12 + 
      1.1319814734601702e-17*V05*V06*V13 + 7.58647195617045285e-18*V04*V07*V13 + 4.16512185828966039e-18*V03*V08*V13 + 
      1.05825786345131317e-18*V02*V09*V13 + 2.81619034736630447e-19*V01*V10*V13 - 1.06595727433889424e-20*V132 + 
      2.53457131262967402e-18*V052*V14 + 2.57722253056508207e-18*V04*V06*V14 + 2.41387744059968954e-18*V03*V07*V14 + 
      4.76053124119404531e-19*V02*V08*V14 + 2.01156453383307462e-19*V01*V09*V14 - 1.73647878561658578e-20*V12*V14 + 
      1.51729439123409057e-18*V04*V05*V15 + 1.07807759377159067e-18*V03*V06*V15 + 3.62831267469021658e-19*V02*V07*V15 + 
      1.19003481665418868e-19*V01*V08*V15 - 1.58849738981262639e-20*V11*V15 + 1.48754352081773585e-19*V042*V16 + 
      4.16512185828966039e-19*V03*V05*V16 + 1.06136400409832961e-19*V02*V06*V16 + 5.95017408327094341e-20*V01*V07*V16 - 
      9.54131450221477037e-21*V10*V16 + 1.11565764061330189e-19*V03*V04*V17 + 5.60254163003636384e-20*V02*V05*V17 + 
      2.37811233920203824e-20*V01*V06*V17 - 6.48217749523006422e-21*V09*V17 + 1.32117352177891013e-20*V032*V18 + 
      9.44607155668013042e-21*V02*V04*V18 + 7.9270411306734608e-21*V01*V05*V18 - 2.79458102960641896e-21*V08*V18 + 
      3.27634013452418938e-21*V02*V03*V19 + 1.95729410633912612e-21*V01*V04*V19 - 1.38505742663858994e-21*V07*V19 + 
      1.163029831302959e-22*V022*V20 + 3.91458821267825225e-22*V01*V03*V20 - 4.06216197466413874e-22*V06*V20 + 
      4.68048590646312769e-23*V01*V02*V21 - 1.4136012990227022e-22*V05*V21 + 2.12749359384687622e-24*V012*V22 - 
      2.52935349490684173e-23*V04*V22 - 5.73241329453186093e-24*V03*V23 - 4.72776354188194716e-25*V02*V24 - 
      5.90970442735243395e-26*V01*V25 + 1.6981909274001247e-28*V28) + 
   delta18*eps5*(1.52317110637806187e-16*V083 + 1.12120493832635136e-15*V07*V08*V09 + 
      4.22288650060299385e-16*V06*V092 + 4.56136626364748478e-16*V072*V10 + 
      5.60091452293578975e-16*V06*V08*V10 + 5.32159397425539891e-16*V05*V09*V10 + 8.89111523954218982e-17*V04*V102 + 
      5.52814232806210104e-16*V06*V07*V11 + 4.28096430997334157e-16*V05*V08*V11 + 2.15740296253597253e-16*V04*V09*V11 + 
      9.67562540773708892e-17*V03*V10*V11 + 9.8348013838925757e-18*V02*V112 + 
      1.15962448868508278e-16*V062*V12 + 2.92589798232689292e-16*V05*V07*V12 + 1.20147745912201742e-16*V04*V08*V12 + 
      8.12749439535248034e-17*V03*V09*V12 + 1.36140534804836448e-17*V02*V10*V12 + 4.43317876110135291e-18*V01*V11*V12 + 
      1.4883460114013349e-16*V05*V06*V13 + 9.95724444247371937e-17*V04*V07*V13 + 5.48841578201710458e-17*V03*V08*V13 + 
      1.38695916952331196e-17*V02*V09*V13 + 3.72139438759118805e-18*V01*V10*V13 - 6.13928349535236805e-20*V132 + 
      3.37942841683956536e-17*V052*V14 + 3.58270230657427606e-17*V04*V06*V14 + 3.21850325413291939e-17*V03*V07*V14 + 
      6.62404371072965862e-18*V02*V08*V14 + 2.68208604511076616e-18*V01*V09*V14 - 1.02870607926791138e-19*V12*V14 + 
      1.99144888849474387e-17*V04*V05*V15 + 1.41747239181079514e-17*V03*V06*V15 + 4.75528858122278385e-18*V02*V07*V15 + 
      1.56811879486202988e-18*V01*V08*V15 - 9.1930627835889852e-20*V11*V15 + 2.08256092914483019e-18*V042*V16 + 
      5.59688249707673115e-18*V03*V05*V16 + 1.48652232389268935e-18*V02*V06*V16 + 7.99554642439533021e-19*V01*V07*V16 - 
      5.70350230414544345e-20*V10*V16 + 1.46430065330495873e-18*V03*V04*V17 + 7.34272501512341624e-19*V02*V05*V17 + 
      3.12677733487675398e-19*V01*V06*V17 - 3.80494349653610676e-20*V09*V17 + 1.79826396019907213e-19*V032*V18 + 
      1.34032096412353202e-19*V02*V04*V18 + 1.07895837611944328e-19*V01*V05*V18 - 1.69994617754268547e-20*V08*V18 + 
      4.29399123691427851e-20*V02*V03*V19 + 2.56894851457010304e-20*V01*V04*V19 - 8.31623456524413426e-21*V07*V19 + 
      1.69726711153561903e-21*V022*V20 + 5.46411271353006043e-21*V01*V03*V20 - 2.53334958075771814e-21*V06*V20 + 
      6.13427319559182644e-22*V01*V02*V21 - 8.7443926510058181e-22*V05*V21 + 3.19124039077031433e-23*V012*V22 - 
      1.62713861899770348e-22*V04*V22 - 3.67386625233742977e-23*V03*V23 - 3.15184236125463144e-24*V02*V24 - 
      3.9398029515682893e-25*V01*V25 + 8.49095463700062349e-28*V28) + 
   delta16*eps6*(-1.9971583877377173e-13*V052*V062 - 5.15012279872686278e-14*V04*V063 - 
      1.38552891798664746e-13*V053*V07 - 5.35296957748947698e-13*V04*V05*V06*V07 - 
      1.90205560736925457e-13*V03*V062*V07 - 8.90955092929180725e-14*V042*V072 - 
      1.9633954345872527e-13*V03*V05*V072 - 6.35520307987724906e-14*V02*V06*V072 - 
      9.19777263033969904e-15*V01*V073 - 2.06722420226566058e-13*V04*V052*V08 - 
      7.93140422857561947e-14*V042*V06*V08 - 2.92044310053531097e-13*V03*V05*V06*V08 - 
      2.8054165341348957e-14*V02*V062*V08 - 1.96878495453872436e-13*V03*V04*V07*V08 - 
      9.88055510639503979e-14*V02*V05*V07*V08 - 4.17206157219330139e-14*V01*V06*V07*V08 - 
      2.64742324327273891e-14*V032*V082 - 1.43533312602985843e-14*V02*V04*V082 - 
      1.58845394596364335e-14*V01*V05*V082 + 1.1820275926538449e-15*V083 - 
      1.03944760841737751e-13*V042*V05*V09 - 1.13602057536292194e-13*V03*V052*V09 - 
      1.48693599374707694e-13*V03*V04*V06*V09 - 7.41440359319012391e-14*V02*V05*V06*V09 - 
      1.58504633947437881e-14*V01*V062*V09 - 5.34751684544834494e-14*V032*V07*V09 - 
      4.88875816832892394e-14*V02*V04*V07*V09 - 3.18195745542241038e-14*V01*V05*V07*V09 - 
      2.74459864066528883e-14*V02*V03*V08*V09 - 1.6406541287822703e-14*V01*V04*V08*V09 + 8.17560521363213863e-15*V07*V08*V09 - 
      1.643382958440418e-15*V022*V092 - 4.26733622425923663e-15*V01*V03*V092 + 
      3.08192679142743045e-15*V06*V092 - 8.23776276145120962e-15*V043*V10 - 
      9.24961930882277239e-14*V03*V04*V05*V10 - 2.33503285680618882e-14*V02*V052*V10 - 
      3.24037911030739563e-14*V032*V06*V10 - 1.74238643178067204e-14*V02*V04*V06*V10 - 
      1.94422746618443738e-14*V01*V05*V06*V10 - 2.22384081600589411e-14*V02*V03*V07*V10 - 
      1.32137418697468177e-14*V01*V04*V07*V10 + 3.34029474072375626e-15*V072*V10 - 
      1.55351438944380804e-15*V022*V08*V10 - 6.93994367294913794e-15*V01*V03*V08*V10 + 
      4.36673324974551584e-15*V06*V08*V10 - 1.85320068000491176e-15*V01*V02*V09*V10 + 3.91504901715321151e-15*V05*V09*V10 - 
      1.08465183908934031e-16*V012*V102 + 6.99478132891690773e-16*V04*V102 - 
      1.88990474257705002e-14*V03*V042*V11 - 2.0079848750027906e-14*V032*V05*V11 - 
      1.8666167551801346e-14*V02*V04*V05*V11 - 5.9528162369059927e-15*V01*V052*V11 - 
      1.34807338058002253e-14*V02*V03*V06*V11 - 8.11055996589314694e-15*V01*V04*V06*V11 - 
      2.15133769104927447e-15*V022*V07*V11 - 5.5380535084000978e-15*V01*V03*V07*V11 + 
      4.05344001817784992e-15*V06*V07*V11 - 1.49705380399924845e-15*V01*V02*V08*V11 + 3.15077698022744369e-15*V05*V08*V11 - 
      2.06810074200447004e-16*V012*V09*V11 + 1.59121692189397229e-15*V04*V09*V11 + 
      7.21666268378127112e-16*V03*V10*V11 + 7.36581415510666222e-17*V02*V112 - 
      6.9185418610290725e-15*V032*V04*V12 - 1.80834826436122564e-15*V02*V042*V12 - 
      7.0425748922771522e-15*V02*V03*V05*V12 - 4.1511251166174435e-15*V01*V04*V05*V12 - 
      6.30237871364720846e-16*V022*V06*V12 - 2.86359817679713366e-15*V01*V03*V06*V12 + 
      9.12710887385849357e-16*V062*V12 - 1.0060821274681646e-15*V01*V02*V07*V12 + 2.17298619641462655e-15*V05*V07*V12 - 
      1.46306960814815552e-16*V012*V08*V12 + 9.49799932113489445e-16*V04*V08*V12 + 
      6.09073484754213193e-16*V03*V09*V12 + 1.09033397228799142e-16*V02*V10*V12 + 3.38185036744886271e-17*V01*V11*V12 - 
      8.23403845626556504e-16*V033*V13 - 2.39309840407709564e-15*V02*V03*V04*V13 - 
      7.26886439452711547e-16*V01*V042*V13 - 5.79206301436343127e-16*V022*V05*V13 - 
      1.44677819056731709e-15*V01*V03*V05*V13 - 5.18489761761547126e-16*V01*V02*V06*V13 + 1.10659043311581401e-15*V05*V06*V13 - 
      9.35939746766680868e-17*V012*V07*V13 + 7.41243447021940299e-16*V04*V07*V13 + 
      4.11428398053562672e-16*V03*V08*V13 + 1.04354074922474458e-16*V02*V09*V13 + 2.83871112421247911e-17*V01*V10*V13 - 
      2.94467426655281363e-19*V132 - 3.77787547433765198e-16*V02*V032*V14 - 
      9.26777057356701142e-17*V022*V04*V14 - 4.38655479552699342e-16*V01*V03*V04*V14 - 
      2.26672528460259119e-16*V01*V02*V05*V14 + 2.55854974493514799e-16*V052*V14 - 
      4.33570429464430293e-17*V012*V06*V14 + 2.8735149788757784e-16*V04*V06*V14 + 2.44740351616357412e-16*V03*V07*V14 + 
      5.35741052876326988e-17*V02*V08*V14 + 2.06622661355679947e-17*V01*V09*V14 - 5.08721755295465973e-19*V12*V14 - 
      5.51625048986993454e-17*V022*V03*V15 - 6.42358395777375031e-17*V01*V032*V15 - 
      6.83742401164884467e-17*V01*V02*V04*V15 - 1.78262688228429759e-17*V012*V05*V15 + 
      1.50982944171200065e-16*V04*V05*V15 + 1.07814907755634392e-16*V03*V06*V15 + 3.6269383138285915e-17*V02*V07*V15 + 
      1.20757812882905002e-17*V01*V08*V15 - 4.43179318750542553e-19*V11*V15 - 1.15395252530254566e-18*V023*V16 - 
      1.78862641421894578e-17*V01*V02*V03*V16 - 4.9706760326638416e-18*V012*V04*V16 + 
      1.71110905763354099e-17*V042*V16 + 4.3613320824757824e-17*V03*V05*V16 + 1.22621922769833635e-17*V02*V06*V16 + 
      6.28244603275794854e-18*V01*V07*V16 - 2.8474503199052279e-19*V10*V16 - 1.21681996100072085e-18*V01*V022*V17 - 
      1.17086609937362833e-18*V012*V03*V17 + 1.14032592883395642e-17*V03*V04*V17 + 
      5.72673938731115986e-18*V02*V05*V17 + 2.45317031319295603e-18*V01*V06*V17 - 1.86187158637677321e-19*V09*V17 - 
      1.54775158952360245e-19*V012*V02*V18 + 1.45049853861487712e-18*V032*V18 + 
      1.1394855688643869e-18*V02*V04*V18 + 8.73649925579235103e-19*V01*V05*V18 - 8.64577938312806382e-20*V08*V18 - 
      4.7868605861554715e-21*V013*V19 + 3.45239022941501839e-19*V02*V03*V19 + 2.071115013609934e-19*V01*V04*V19 - 
      4.16838046931090252e-20*V07*V19 + 1.50626546444358836e-20*V022*V20 + 4.61453360505387452e-20*V01*V03*V20 - 
      1.32340232459151162e-20*V06*V20 + 5.1219408271863545e-21*V01*V02*V21 - 4.52579939307717773e-21*V05*V21 + 
      2.8721163516932829e-22*V012*V22 - 8.79364018790042171e-22*V04*V22 - 1.97679613094938916e-22*V03*V23 - 
      1.77291132820573018e-23*V02*V24 - 2.21613916025716273e-24*V01*V25 + 3.82092958665028057e-27*V28) + 
   delta14*eps7*(-2.51986024216111903e-12*V052*V062 - 
      7.66374204694040638e-13*V04*V063 - 1.71500114887796047e-12*V053*V07 - 
      6.73187355701465464e-12*V04*V05*V06*V07 - 2.39986689729630384e-12*V03*V062*V07 - 
      1.11856831327609723e-12*V042*V072 - 2.43566320925706709e-12*V03*V05*V072 - 
      7.98583082493023281e-13*V02*V06*V072 - 1.14618397393463942e-13*V01*V073 - 
      2.61143204268681004e-12*V04*V052*V08 - 1.18471866425539801e-12*V042*V06*V08 - 
      3.70632780010077628e-12*V03*V05*V06*V08 - 4.20522991215922173e-13*V02*V062*V08 - 
      2.48707813589220004e-12*V03*V04*V07*V08 - 1.24518743296266383e-12*V02*V05*V07*V08 - 
      5.29475400014396611e-13*V01*V06*V07*V08 - 3.38500229532863735e-13*V032*V082 - 
      2.1618555087787909e-13*V02*V04*V082 - 2.03100137719718241e-13*V01*V05*V082 + 
      6.55112010707955772e-15*V083 - 1.3049963654887801e-12*V042*V05*V09 - 
      1.41243945340161121e-12*V03*V052*V09 - 1.86996487694851518e-12*V03*V04*V06*V09 - 
      9.31680262908527161e-13*V02*V05*V06*V09 - 1.9998890810802532e-13*V01*V062*V09 - 
      6.67000771126056506e-13*V032*V07*V09 - 6.14853248028864449e-13*V02*V04*V07*V09 - 
      3.97810724009440211e-13*V01*V05*V07*V09 - 3.45885398045184397e-13*V02*V03*V08*V09 - 
      2.07256511324350003e-13*V01*V04*V08*V09 + 4.25003916946786307e-14*V07*V08*V09 - 
      2.082221806665971e-14*V022*V092 - 5.38830472713085848e-14*V01*V03*V092 + 
      1.60812251786407803e-14*V06*V092 - 1.24056419875980856e-13*V043*V10 - 
      1.17736463407971587e-12*V03*V04*V05*V10 - 2.96119791245740176e-13*V02*V052*V10 - 
      4.15039194364330216e-13*V032*V06*V10 - 2.63587490168626055e-13*V02*V04*V06*V10 - 
      2.49023516618598129e-13*V01*V05*V06*V10 - 2.82018848805466834e-13*V02*V03*V07*V10 - 
      1.68194947725673695e-13*V01*V04*V07*V10 + 1.74383716386006097e-14*V072*V10 - 
      2.38053768189902368e-14*V022*V08*V10 - 8.98202690897743747e-14*V01*V03*V08*V10 + 
      2.43846652416793024e-14*V06*V08*V10 - 2.35015707337889029e-14*V01*V02*V09*V10 + 2.06057236803017738e-14*V05*V09*V10 - 
      1.43370826246798331e-15*V012*V102 + 3.96428932547644154e-15*V04*V102 - 
      2.37272066452505473e-13*V03*V042*V11 - 2.51631536127520512e-13*V032*V05*V11 - 
      2.34762149247384608e-13*V02*V04*V05*V11 - 7.48492153453347417e-14*V01*V052*V11 - 
      1.69396411437914029e-13*V02*V03*V06*V11 - 1.01998084197191737e-13*V01*V04*V06*V11 - 
      2.72581763781727113e-14*V022*V07*V11 - 7.01033093976778396e-14*V01*V03*V07*V11 + 
      2.13218354709983197e-14*V06*V07*V11 - 1.8866476257010058e-14*V01*V02*V08*V11 + 1.66463961920891562e-14*V05*V08*V11 - 
      2.70549182705722968e-15*V012*V09*V11 + 8.46519127348510629e-15*V04*V09*V11 + 
      3.88883527020090202e-15*V03*V10*V11 + 4.02081764258068888e-16*V02*V112 - 
      8.9119744245507192e-14*V032*V04*V12 - 2.77615388249572503e-14*V02*V042*V12 - 
      9.02401843369926548e-14*V02*V03*V05*V12 - 5.34718465473043152e-14*V01*V04*V05*V12 - 
      9.75373498117561726e-15*V022*V06*V12 - 3.72237934749807608e-14*V01*V03*V06*V12 + 
      5.17221526231414158e-15*V062*V12 - 1.2891454905284665e-14*V01*V02*V07*V12 + 1.15738056510318501e-14*V05*V07*V12 - 
      1.9385984662704339e-15*V012*V08*V12 + 5.42172521751850093e-15*V04*V08*V12 + 3.29486197473159965e-15*V03*V09*V12 + 
      6.35760112757530432e-16*V02*V10*V12 + 1.88437848864205698e-16*V01*V11*V12 - 1.04411003105223144e-14*V033*V13 - 
      3.00977114419723856e-14*V02*V03*V04*V13 - 9.12584870971174895e-15*V01*V042*V13 - 
      7.33873979412342228e-15*V022*V05*V13 - 1.84758419748958044e-14*V01*V03*V05*V13 - 
      6.5152465937659242e-15*V01*V02*V06*V13 + 5.95861129736542136e-15*V05*V06*V13 - 
      1.23197707636072354e-15*V012*V07*V13 + 4.0041533527362525e-15*V04*V07*V13 + 2.2415825653105088e-15*V03*V08*V13 + 
      5.73795659728471751e-16*V02*V09*V13 + 1.58694949853917996e-16*V01*V10*V13 - 1.2092933945033283e-18*V132 - 
      4.9215054007228526e-15*V02*V032*V14 - 1.46814009844390231e-15*V022*V04*V14 - 
      5.7597988081150496e-15*V01*V03*V04*V14 - 2.95290324043371156e-15*V01*V02*V05*V14 + 
      1.39952415958247218e-15*V052*V14 - 5.79171836040122807e-16*V012*V06*V14 + 
      1.6750370091965098e-15*V04*V06*V14 + 1.34875401993507653e-15*V03*V07*V14 + 3.16627754139116627e-16*V02*V08*V14 + 
      1.16364635315865469e-16*V01*V09*V14 - 2.14611734546070503e-18*V12*V14 - 6.98927599440325931e-16*V022*V03*V15 - 
      8.37876759046778033e-16*V01*V032*V15 - 8.59934612627782446e-16*V01*V02*V04*V15 - 
      2.38362680259728934e-16*V012*V05*V15 + 8.3968746884450111e-16*V04*V05*V15 + 6.02108557224745365e-16*V03*V06*V15 + 
      2.03680279692837158e-16*V02*V07*V15 + 6.86493250381728478e-17*V01*V08*V15 - 1.82727523647880226e-18*V11*V15 - 
      1.9167866283122816e-17*V023*V16 - 2.3955748066203334e-16*V01*V02*V03*V16 - 
      6.75521765918260138e-17*V012*V04*V16 + 1.03124890677870831e-16*V042*V16 + 
      2.48128726852923635e-16*V03*V05*V16 + 7.43882390075747964e-17*V02*V06*V16 + 3.62386621307907661e-17*V01*V07*V16 - 
      1.21120144382787979e-18*V10*V16 - 1.54175205758895426e-17*V01*V022*V17 - 
      1.62676670159907543e-17*V012*V03*V17 + 6.60274019331159576e-17*V03*V04*V17 + 3.323932166218544e-17*V02*V05*V17 + 
      1.43510080372941035e-17*V01*V06*V17 - 7.77120222492417712e-19*V09*V17 - 2.182808427286895e-18*V012*V02*V18 + 
      8.61634905507984869e-18*V032*V18 + 7.17646139076428287e-18*V02*V04*V18 + 5.2234222716128505e-18*V01*V05*V18 - 
      3.7401337379828084e-19*V08*V18 - 7.65897693784875439e-20*V013*V19 + 2.09026245595455589e-18*V02*V03*V19 + 
      1.25862521011981197e-18*V01*V04*V19 - 1.77698902426060336e-19*V07*V19 + 9.95667001920338071e-20*V022*V20 + 
      2.89126379403790478e-19*V01*V03*V20 - 5.87492159558001676e-20*V06*V20 + 3.25506519858572062e-20*V01*V02*V21 - 
      1.98920651024682927e-20*V05*V21 + 1.9147442344621886e-21*V012*V22 - 4.04223782830906482e-21*V04*V22 - 
      9.04184777384922394e-22*V03*V23 - 8.50997437538750488e-23*V02*V24 - 1.06374679692343811e-23*V01*V25 + 
      1.52837183466011223e-26*V28) + delta12*eps8*
    (1.69722051530330397e-12*V045 + 9.90045300593593985e-11*V03*V043*V05 + 
      1.65145212109441825e-10*V032*V04*V052 + 7.29432517380202435e-11*V02*V042*V052 + 
      5.64335642606010761e-11*V02*V03*V053 + 3.24106070216067245e-11*V01*V04*V053 + 
      1.05663509164113951e-10*V032*V042*V06 + 1.17532365180228153e-11*V02*V043*V06 + 
      7.57945446961099518e-11*V033*V05*V06 + 2.10162034740904921e-10*V02*V03*V04*V05*V06 + 
      6.33981054984683709e-11*V01*V042*V05*V06 + 2.56238332842952961e-11*V022*V052*V06 + 
      6.63802309875038209e-11*V01*V03*V052*V06 + 3.74575065295956479e-11*V02*V032*V062 + 
      6.06698639197789842e-12*V022*V04*V062 + 4.45126951642857669e-11*V01*V03*V04*V062 + 
      2.24745039177573887e-11*V01*V02*V05*V062 - 1.63160233770679799e-11*V052*V062 + 
      1.52221561580565904e-12*V012*V063 - 5.78540684073728724e-12*V04*V063 + 
      5.14454079708043246e-11*V033*V04*V07 + 6.94697635600192795e-11*V02*V03*V042*V07 + 
      1.41435042941941998e-11*V01*V043*V07 + 7.92724339032897677e-11*V02*V032*V05*V07 + 
      3.34782410990087043e-11*V022*V04*V05*V07 + 9.03276914070541286e-11*V01*V03*V04*V05*V07 + 
      2.33776470874305423e-11*V01*V02*V052*V07 - 1.08185146013897752e-11*V053*V07 + 
      2.4403650746947901e-11*V022*V03*V06*V07 + 3.07358913088136596e-11*V01*V032*V06*V07 + 
      3.00231478201292744e-11*V01*V02*V04*V06*V07 + 8.68957492519746369e-12*V012*V05*V06*V07 - 
      4.37093686329841425e-11*V04*V05*V06*V07 - 1.566181267711276e-11*V03*V062*V07 + 
      1.25464861823383465e-12*V023*V072 + 1.08474889550181841e-11*V01*V02*V03*V072 + 
      2.96769747346639897e-12*V012*V04*V072 - 7.28858817233331817e-12*V042*V072 - 
      1.55159626435125332e-11*V03*V05*V072 - 5.24660148877228691e-12*V02*V06*V072 - 
      7.44212283487397049e-13*V01*V073 + 6.67609532142999851e-12*V034*V08 + 
      3.84582775897924735e-11*V02*V032*V04*V08 + 3.05603303904589489e-12*V022*V042*V08 + 
      2.28990069525048949e-11*V01*V03*V042*V08 + 1.89494560578382592e-11*V022*V03*V05*V08 + 
      2.31650689866383551e-11*V01*V032*V05*V08 + 2.30749665538754841e-11*V01*V02*V04*V05*V08 + 
      3.25981262240335248e-12*V012*V052*V08 - 1.70529257356118519e-11*V04*V052*V08 + 
      6.94763678262057234e-13*V023*V06*V08 + 1.62296042957806157e-11*V01*V02*V03*V06*V08 + 
      4.69918606764911534e-12*V012*V04*V06*V08 - 9.01512332233048342e-12*V042*V06*V08 - 
      2.43390798066278307e-11*V03*V05*V06*V08 - 3.22453879873185615e-12*V02*V062*V08 + 
      2.70706515111975132e-12*V01*V022*V07*V08 + 2.98045856840657767e-12*V012*V03*V07*V08 - 
      1.63678310962694555e-11*V03*V04*V07*V08 - 8.22054068494952146e-12*V02*V05*V07*V08 - 
      3.5306585954940383e-12*V01*V06*V07*V08 + 4.27227659317861358e-13*V012*V02*V082 - 
      2.25523495409310078e-12*V032*V082 - 1.67159794752105173e-12*V02*V04*V082 - 
      1.36330647299124867e-12*V01*V05*V082 + 2.80098426526990846e-14*V083 + 
      7.09060617403523279e-12*V02*V033*V09 + 9.29951141639130675e-12*V022*V03*V04*V09 + 
      1.19842625250196528e-11*V01*V032*V04*V09 + 5.78914696333493996e-12*V01*V02*V042*V09 + 
      1.46375672127280709e-12*V023*V05*V09 + 1.2430913178878777e-11*V01*V02*V03*V05*V09 + 
      3.3886904571058416e-12*V012*V04*V05*V09 - 8.57100355790489362e-12*V042*V05*V09 - 
      9.08705561862994056e-12*V03*V052*V09 + 2.03363756224565842e-12*V01*V022*V06*V09 + 
      2.26814706342825295e-12*V012*V03*V06*V09 - 1.23340808419557285e-11*V03*V04*V06*V09 - 
      6.1692665648056855e-12*V02*V05*V06*V09 - 1.33583675497378195e-12*V01*V062*V09 + 
      8.11760639874362548e-13*V012*V02*V07*V09 - 4.33464495272616129e-12*V032*V07*V09 - 
      4.09110037577523526e-12*V02*V04*V07*V09 - 2.60926157468941e-12*V01*V05*V07*V09 + 
      6.79697068800438898e-14*V013*V08*V09 - 2.31898587308895023e-12*V02*V03*V08*V09 - 
      1.39572328551556802e-12*V01*V04*V08*V09 + 1.71686331083175458e-13*V07*V08*V09 - 
      1.41825665686594023e-13*V022*V092 - 3.61035387268690237e-13*V01*V03*V092 + 
      6.53857258245341292e-14*V06*V092 + 2.10846776290424879e-12*V022*V032*V10 + 
      1.62762786071965243e-12*V01*V033*V10 + 2.0882306763634111e-13*V023*V04*V10 + 
      5.06712184364963239e-12*V01*V02*V03*V04*V10 + 7.35486409901654912e-13*V012*V042*V10 - 
      9.59305627506322286e-13*V043*V10 + 1.26508065774254928e-12*V01*V022*V05*V10 + 
      1.35509493219951251e-12*V012*V03*V05*V10 - 7.86276590867499058e-12*V03*V04*V05*V10 - 
      1.98258060474281681e-12*V02*V052*V10 + 5.19864378696037504e-13*V012*V02*V06*V10 - 
      2.78858403478309586e-12*V032*V06*V10 - 2.05469609340393125e-12*V02*V04*V06*V10 - 
      1.68557798488720377e-12*V01*V05*V06*V10 + 5.40740308239601506e-14*V013*V07*V10 - 
      1.90247352254040442e-12*V02*V03*V07*V10 - 1.14020824033674051e-12*V01*V04*V07*V10 + 
      7.06450656808127573e-14*V072*V10 - 1.88915965409151507e-13*V022*V08*V10 - 
      6.17169857042578985e-13*V01*V03*V08*V10 + 1.05241906443131414e-13*V06*V08*V10 - 1.62114839717559375e-13*V01*V02*V09*V10 + 
      8.43512198400368814e-14*V05*V09*V10 - 1.01879759579391264e-14*V012*V102 + 
      1.74429213223327529e-14*V04*V102 + 2.66137585685964925e-13*V023*V03*V11 + 
      1.05906854914023571e-12*V01*V02*V032*V11 + 5.07246077257707641e-13*V01*V022*V04*V11 + 
      5.68284293963893289e-13*V012*V03*V04*V11 - 1.59526465971872016e-12*V03*V042*V11 + 
      2.9770002966244182e-13*V012*V02*V05*V11 - 1.66744937872337325e-12*V032*V05*V11 - 
      1.58652933824338137e-12*V02*V04*V05*V11 - 5.007211389248975e-13*V01*V052*V11 + 
      3.32257525080438846e-14*V013*V06*V11 - 1.1479929179126796e-12*V02*V03*V06*V11 - 
      6.93777815562933079e-13*V01*V04*V06*V11 - 1.87092052579593526e-13*V022*V07*V11 - 
      4.74251271528799159e-13*V01*V03*V07*V11 + 8.74934122198606157e-14*V06*V07*V11 - 1.30363122113054841e-13*V01*V02*V08*V11 + 
      6.8574529490516731e-14*V05*V08*V11 - 1.90080765250655044e-14*V012*V09*V11 + 3.53027384466007188e-14*V04*V09*V11 + 
      1.64052489611799716e-14*V03*V10*V11 + 1.73546694453885326e-15*V02*V112 + 
      3.48280913281984102e-15*V024*V12 + 1.85950769278642338e-13*V01*V022*V03*V12 + 
      9.34645124364953167e-14*V012*V032*V12 + 1.08783666218579755e-13*V012*V02*V04*V12 - 
      6.13856704112766429e-13*V032*V04*V12 - 2.21778759541654563e-13*V02*V042*V12 + 
      1.6280968105939485e-14*V013*V05*V12 - 6.22704221012906932e-13*V02*V03*V05*V12 - 
      3.70956271646512361e-13*V01*V04*V05*V12 - 7.86666000003416018e-14*V022*V06*V12 - 
      2.60023262126741606e-13*V01*V03*V06*V12 + 2.27134927216431786e-14*V062*V12 - 
      9.02421222515664391e-14*V01*V02*V07*V12 + 4.79014585663032558e-14*V05*V07*V12 - 
      1.38882189976287973e-14*V012*V08*V12 + 2.40467287854516429e-14*V04*V08*V12 + 
      1.39260898601988465e-14*V03*V09*V12 + 2.9018707451200084e-15*V02*V10*V12 + 8.28596396924692205e-16*V01*V11*V12 + 
      1.02360609879217279e-14*V01*V023*V13 + 3.42738835019884867e-14*V012*V02*V03*V13 - 
      7.19332390498911321e-14*V033*V13 + 5.70923117878059699e-15*V013*V04*V13 - 
      2.09676282115613157e-13*V02*V03*V04*V13 - 6.37217418137510935e-14*V01*V042*V13 - 
      5.1525422695415292e-14*V022*V05*V13 - 1.28648176024020543e-13*V01*V03*V05*V13 - 
      4.58399896599754662e-14*V01*V02*V06*V13 + 2.51117911730858733e-14*V05*V06*V13 - 
      8.82037675447656105e-15*V012*V07*V13 + 1.69741932779255435e-14*V04*V07*V13 + 
      9.58338797132798474e-15*V03*V08*V13 + 2.49469101004387013e-15*V02*V09*V13 + 7.01380077351058344e-16*V01*V10*V13 - 
      4.27353345192435548e-18*V132 + 2.83817431889704983e-15*V012*V022*V14 + 
      1.54753458517703007e-15*V013*V03*V14 - 3.52847386806752976e-14*V02*V032*V14 - 
      1.22374878213716136e-14*V022*V04*V14 - 4.15516029503519116e-14*V01*V03*V04*V14 - 
      2.13136767458152763e-14*V01*V02*V05*V14 + 5.95542265348387808e-15*V052*V14 - 
      4.25021139007428497e-15*V012*V06*V14 + 7.60517821823443363e-15*V04*V06*V14 + 
      5.80084922444112894e-15*V03*V07*V14 + 1.46578502492623655e-15*V02*V08*V14 + 5.160537622557416e-16*V01*V09*V14 - 
      7.73886903353060472e-18*V12*V14 + 2.40453580963761644e-16*V013*V02*V15 - 
      5.09043477455507611e-15*V022*V03*V15 - 6.12709857802884349e-15*V01*V032*V15 - 
      6.25968312779994327e-15*V01*V02*V04*V15 - 1.77277552319798963e-15*V012*V05*V15 + 
      3.67333501324724325e-15*V04*V05*V15 + 2.64593878461763225e-15*V03*V06*V15 + 9.04658570208272093e-16*V02*V07*V15 + 
      3.08960363931146751e-16*V01*V08*V15 - 6.47264097833335275e-18*V11*V15 + 6.16547643496824729e-18*V014*V16 - 
      1.68403882914543334e-16*V023*V16 - 1.81046088097259627e-15*V01*V02*V03*V16 - 
      5.15451700909533787e-16*V012*V04*V16 + 4.86090927718546833e-16*V042*V16 + 
      1.10218688305046193e-15*V03*V05*V16 + 3.54020465499464205e-16*V02*V06*V16 + 1.64312925482935176e-16*V01*V07*V16 - 
      4.39498432485673238e-18*V10*V16 - 1.17948244842870818e-16*V01*V022*V17 - 
      1.28469764411240544e-16*V012*V03*V17 + 3.01963143875664068e-16*V03*V04*V17 + 
      1.52772017359073719e-16*V02*V05*V17 + 6.65625729466481393e-17*V01*V06*V17 - 2.77491205584608323e-18*V09*V17 - 
      1.75582046300182694e-17*V012*V02*V18 + 4.00700121566097593e-17*V032*V18 + 
      3.5554247441650226e-17*V02*V04*V18 + 2.45368091165547928e-17*V01*V05*V18 - 1.3760805856134416e-18*V08*V18 - 
      6.7016048206176601e-19*V013*V19 + 1.00524072309264901e-17*V02*V03*V19 + 6.08058944057375693e-18*V01*V04*V19 - 
      6.44825579181706125e-19*V07*V19 + 5.19746684976791861e-19*V022*V20 + 1.42520795851802238e-18*V01*V03*V20 - 
      2.21277062873357184e-19*V06*V20 + 1.65306252241902282e-19*V01*V02*V21 - 7.41520163022046649e-20*V05*V21 + 
      1.00524072309264901e-20*V012*V22 - 1.57611817077489413e-20*V04*V22 - 3.50593215152683144e-21*V03*V23 - 
      3.47490620328323116e-22*V02*V24 - 4.34363275410403895e-23*V01*V25 + 5.3493014213103928e-26*V28) + 
   delta10*eps9*(2.94346529368315861e-11*V045 + 1.07985655286172715e-9*V03*V043*V05 + 
      1.71897339904773307e-9*V032*V04*V052 + 7.96266008412303666e-10*V02*V042*V052 + 
      5.8607426055896506e-10*V02*V03*V053 + 3.39463604350525028e-10*V01*V04*V053 + 
      1.15932748685713087e-9*V032*V042*V06 + 2.06411599190622904e-10*V02*V043*V06 + 
      7.94747422420482385e-10*V033*V05*V06 + 2.30172081336221789e-9*V02*V03*V04*V05*V06 + 
      6.95596492114278522e-10*V01*V042*V05*V06 + 2.81347387631380162e-10*V022*V052*V06 + 
      7.01468961792346197e-10*V01*V03*V052*V06 + 4.12513514218773564e-10*V02*V032*V062 + 
      1.08095995688749874e-10*V022*V04*V062 + 4.91928317844827125e-10*V01*V03*V04*V062 + 
      2.47508108531264139e-10*V01*V02*V05*V062 - 6.99871235822987974e-11*V052*V062 + 
      1.69186310382554962e-11*V012*V063 - 2.82711509161556807e-11*V04*V063 + 
      5.38831118016706393e-10*V033*V04*V07 + 7.58348579440289206e-10*V02*V03*V042*V07 + 
      1.54265221837389593e-10*V01*V043*V07 + 8.28508293443252896e-10*V02*V032*V05*V07 + 
      3.67630249386954262e-10*V022*V04*V05*V07 + 9.535216764415262e-10*V01*V03*V04*V05*V07 + 
      2.45930292969252426e-10*V01*V02*V052*V07 - 4.50648873161857779e-11*V053*V07 + 
      2.67949892982266821e-10*V022*V03*V06*V07 + 3.27459639717265832e-10*V01*V032*V06*V07 + 
      3.28817259051745412e-10*V01*V02*V04*V06*V07 + 9.4048614407050179e-11*V012*V05*V06*V07 - 
      1.89215565149637133e-10*V04*V05*V06*V07 - 6.81763445170203853e-11*V03*V062*V07 + 
      1.39444848287510596e-11*V023*V072 + 1.15182666174941962e-10*V01*V02*V03*V072 + 
      3.21017537411587722e-11*V012*V04*V072 - 3.18406426463850054e-11*V042*V072 - 
      6.56634174168191508e-11*V03*V05*V072 - 2.32359443397106751e-11*V02*V06*V072 - 
      3.24855532859376506e-12*V01*V073 + 7.09335127901937342e-11*V034*V08 + 
      4.255771685715893e-10*V02*V032*V04*V08 + 5.51372149754177856e-11*V022*V042*V08 + 
      2.54174166457058009e-10*V01*V03*V042*V08 + 2.09757140803781025e-10*V022*V03*V05*V08 + 
      2.48540229250877708e-10*V01*V032*V05*V08 + 2.5534630114295358e-10*V01*V02*V04*V05*V08 + 
      3.55537576199033233e-11*V012*V052*V08 - 7.41718453423337579e-11*V04*V052*V08 + 
      1.27541569802581361e-11*V023*V06*V08 + 1.8086421825184335e-10*V01*V02*V03*V06*V08 + 
      5.24600512141898831e-11*V012*V04*V06*V08 - 4.4634629696567675e-11*V042*V06*V08 - 
      1.06465580947736599e-10*V03*V05*V06*V08 - 1.61793688506655506e-11*V02*V062*V08 + 
      2.9965305829111575e-11*V01*V022*V07*V08 + 3.28863762865051076e-11*V012*V03*V07*V08 - 
      7.22184165366019031e-11*V03*V04*V07*V08 - 3.65672326448746265e-11*V02*V05*V07*V08 - 
      1.58851445341324774e-11*V01*V06*V07*V08 + 4.81429545930922416e-12*V012*V02*V082 - 
      1.00567311914564964e-11*V032*V082 - 8.49608394495698954e-12*V02*V04*V082 - 
      6.1646152851312787e-12*V01*V05*V082 + 9.4887905784810694e-14*V083 + 
      7.50950919461509207e-11*V02*V033*V09 + 1.02119513718598406e-10*V022*V03*V04*V09 + 
      1.28440672102984811e-10*V01*V032*V04*V09 + 6.31957149533574338e-11*V01*V02*V042*V09 + 
      1.62685656335429029e-11*V023*V05*V09 + 1.32923002168697043e-10*V01*V02*V03*V05*V09 + 
      3.69364418100398072e-11*V012*V04*V05*V09 - 3.79694474739357151e-11*V042*V05*V09 - 
      3.9034308676048156e-11*V03*V052*V09 + 2.23291577485222351e-11*V01*V022*V06*V09 + 
      2.50290819078244188e-11*V012*V03*V06*V09 - 5.49219470293534729e-11*V03*V04*V06*V09 - 
      2.76958345878698167e-11*V02*V05*V06*V09 - 6.06184731941184335e-12*V01*V062*V09 + 
      8.94597365597926538e-12*V012*V02*V07*V09 - 1.89037760065707799e-11*V032*V07*V09 - 
      1.85289155193646286e-11*V02*V04*V07*V09 - 1.15536048336506895e-11*V01*V05*V07*V09 + 
      7.95055001224887219e-13*V013*V08*V09 - 1.05951063776393714e-11*V02*V03*V08*V09 - 
      6.41284233545450153e-12*V01*V04*V08*V09 + 5.55883324588347876e-13*V07*V08*V09 - 
      6.65118998787311756e-13*V022*V092 - 1.64515184248772008e-12*V01*V03*V092 + 
      2.13608060848841071e-13*V06*V092 + 2.37158096442747268e-11*V022*V032*V10 + 
      1.78646809595064318e-11*V01*V033*V10 + 3.93339699765279626e-12*V023*V04*V10 + 
      5.70557438613053632e-11*V01*V02*V03*V04*V10 + 8.29135109407503231e-12*V012*V042*V10 - 
      4.86945810336921357e-12*V043*V10 + 1.42294857865648361e-11*V01*V022*V05*V10 + 
      1.51736511538758572e-11*V012*V03*V05*V10 - 3.53050072330784785e-11*V03*V04*V05*V10 - 
      8.97064762190009636e-12*V02*V052*V10 + 5.88941853542087871e-12*V012*V02*V06*V10 - 
      1.25932366524160681e-11*V032*V06*V10 - 1.05676700348517258e-11*V02*V04*V06*V10 - 
      7.71623126310894452e-12*V01*V05*V06*V10 + 6.36406082595999729e-13*V013*V07*V10 - 
      8.72294959529437055e-12*V02*V03*V07*V10 - 5.25867723896048924e-12*V01*V04*V07*V10 + 
      2.28898431203407425e-13*V072*V10 - 9.97338905526024202e-13*V022*V08*V10 - 
      2.8782774654125242e-12*V01*V03*V08*V10 + 3.60135174475426985e-13*V06*V08*V10 - 7.71781383693338668e-13*V01*V02*V09*V10 + 
      2.76443023372544839e-13*V05*V09*V10 - 4.96460571321507087e-14*V012*V102 + 
      6.10495166679236661e-14*V04*V102 + 2.9579210242805278e-12*V023*V03*V11 + 
      1.16146626148653275e-11*V01*V02*V032*V11 + 5.57015529374173124e-12*V01*V022*V04*V11 + 
      6.37387447085132202e-12*V012*V03*V04*V11 - 7.35191647879915301e-12*V03*V042*V11 + 
      3.33627493944288791e-12*V012*V02*V05*V11 - 7.47447845867108231e-12*V032*V05*V11 - 
      7.3704400826648317e-12*V02*V04*V05*V11 - 2.27772842501028492e-12*V01*V052*V11 + 
      3.92839496530436844e-13*V013*V06*V11 - 5.35591512045307342e-12*V02*V03*V06*V11 - 
      3.2534226911779279e-12*V01*V04*V06*V11 - 8.87941756531218918e-13*V022*V07*V11 - 
      2.18868978399247471e-12*V01*V03*V07*V11 + 2.88103562668946431e-13*V06*V07*V11 - 6.25646721041756942e-13*V01*V02*V08*V11 + 
      2.26356906084163136e-13*V05*V08*V11 - 9.17518543701169467e-14*V012*V09*V11 + 
      1.18720485286494369e-13*V04*V09*V11 + 5.55963333795981137e-14*V03*V10*V11 + 6.08766127182957582e-15*V02*V112 + 
      6.97126310184236409e-14*V024*V12 + 2.14508023030128266e-12*V01*V022*V03*V12 + 
      1.08549131494993563e-12*V012*V032*V12 + 1.25421574306927669e-12*V012*V02*V04*V12 - 
      2.87395694078467199e-12*V032*V04*V12 - 1.18073000878447294e-12*V02*V042*V12 + 
      1.96419748265218422e-13*V013*V05*V12 - 2.93488217411979218e-12*V02*V03*V05*V12 - 
      1.75892385028531593e-12*V01*V04*V05*V12 - 4.24427157495073098e-13*V022*V06*V12 - 
      1.24049252083159444e-12*V01*V03*V06*V12 + 7.90915954466652055e-14*V062*V12 - 
      4.35830349941432114e-13*V01*V02*V07*V12 + 1.58221233806604946e-13*V05*V07*V12 - 
      6.83918592447986524e-14*V012*V08*V12 + 8.47838077594851237e-14*V04*V08*V12 + 
      4.71921138034589144e-14*V03*V09*V12 + 1.06064692652075795e-14*V02*V10*V12 + 2.94712436112520976e-15*V01*V11*V12 + 
      1.13766193241558761e-13*V01*V023*V13 + 4.018188964103246e-13*V012*V02*V03*V13 - 
      3.39446113184688056e-13*V033*V13 + 6.98943070573740386e-14*V013*V04*V13 - 
      1.02076494598224435e-12*V02*V03*V04*V13 - 3.115083629311985e-13*V01*V042*V13 - 
      2.52986278945218013e-13*V022*V05*V13 - 6.15808787097615085e-13*V01*V03*V05*V13 - 
      2.26529352821879131e-13*V01*V02*V06*V13 + 8.4727092316375805e-14*V05*V06*V13 - 
      4.35519694409946241e-14*V012*V07*V13 + 5.78301316721366918e-14*V04*V07*V13 + 
      3.28743702409754702e-14*V03*V08*V13 + 8.79555959489167708e-15*V02*V09*V13 + 2.50710033784371886e-15*V01*V10*V13 - 
      1.28605817626567052e-17*V132 + 3.39150527734733347e-14*V012*V022*V14 + 
      1.97689836410821881e-14*V013*V03*V14 - 1.74504919696047553e-13*V02*V032*V14 - 
      6.88531028421720269e-14*V022*V04*V14 - 2.06827059977782492e-13*V01*V03*V04*V14 - 
      1.06625347370051632e-13*V01*V02*V05*V14 + 2.01573940483405383e-14*V052*V14 - 
      2.15718046925592802e-14*V012*V06*V14 + 2.74241246925085559e-14*V04*V06*V14 + 1.9914991776080897e-14*V03*V07*V14 + 
      5.42456758466606654e-15*V02*V08*V14 + 1.84487798792354805e-15*V01*V09*V14 - 2.36008514869398616e-17*V12*V14 + 
      3.21837869905342508e-15*V013*V02*V15 - 2.63042546300521179e-14*V022*V03*V15 - 
      3.10484279082444893e-14*V01*V032*V15 - 3.24148583247491478e-14*V01*V02*V04*V15 - 
      9.13844236549065366e-15*V012*V05*V15 + 1.28653803882824346e-14*V04*V05*V15 + 
      9.30702659603714739e-15*V03*V06*V15 + 3.24213499459520527e-15*V02*V07*V15 + 1.12131899680374015e-15*V01*V08*V15 - 
      1.94978857487673357e-17*V11*V15 + 9.24821465245237093e-17*V014*V16 - 1.00713504338861027e-15*V023*V16 - 
      9.5489022575438441e-15*V01*V02*V03*V16 - 2.74127804866401263e-15*V012*V04*V16 + 
      1.82135143557975467e-15*V042*V16 + 3.8926459245492656e-15*V03*V05*V16 + 1.34458139769482602e-15*V02*V06*V16 + 
      5.97447399597582336e-16*V01*V07*V16 - 1.34599721373616975e-17*V10*V16 - 6.48500895281529732e-16*V01*V022*V17 - 
      7.04231440969786193e-16*V012*V03*V17 + 1.10490698998487486e-15*V03*V04*V17 + 
      5.64120095437823358e-16*V02*V05*V17 + 2.48213369185554833e-16*V01*V06*V17 - 8.39360579453806537e-18*V09*V17 - 
      9.91837513451413694e-17*V012*V02*V18 + 1.48092063326009053e-16*V032*V18 + 
      1.40635411028935136e-16*V02*V04*V18 + 9.20552542974503644e-17*V01*V05*V18 - 4.25846563971969208e-18*V08*V18 - 
      4.02096289237059606e-18*V013*V19 + 3.88268644623851834e-17*V02*V03*V19 + 2.36131045854463253e-17*V01*V04*V19 - 
      1.97123450811280778e-18*V07*V19 + 2.17400060380836893e-18*V022*V20 + 5.6072327534107962e-18*V01*V03*V20 - 
      6.98636983815406448e-19*V06*V20 + 6.77532247364445436e-19*V01*V02*V21 - 2.31689371103909438e-19*V05*V21 + 
      4.22201103698912586e-20*V012*V22 - 5.14534325671867014e-20*V04*V22 - 1.1374112626103862e-20*V03*V23 - 
      1.19139641255425068e-21*V02*V24 - 1.48924551569281335e-22*V01*V25 + 1.60479042639311784e-25*V28) + 
   delta8*eps10*(-3.48353822487445235e-10*V036 - 5.63618331860497148e-9*V02*V034*V04 - 
      7.52142487857241595e-9*V022*V032*V042 - 6.31557116084406533e-9*V01*V033*V042 - 
      1.18235613578975095e-10*V023*V043 - 6.20497920477853972e-9*V01*V02*V03*V043 - 
      4.68244180888229736e-10*V012*V044 + 2.04522364126337295e-10*V045 - 
      5.69957259001663313e-9*V022*V033*V05 - 2.91870821835366133e-9*V01*V034*V05 - 
      4.75996246502304676e-9*V023*V03*V04*V05 - 1.94477609941236912e-8*V01*V02*V032*V04*V05 - 
      4.51285492714344957e-9*V01*V022*V042*V05 - 5.29793573792971798e-9*V012*V03*V042*V05 + 
      5.59571374853810928e-9*V03*V043*V05 - 2.76558300226923378e-10*V024*V052 - 
      4.94975404004256773e-9*V01*V022*V03*V052 - 2.375237797497436e-9*V012*V032*V052 - 
      2.73842679842908882e-9*V012*V02*V04*V052 + 8.44899434558817426e-9*V032*V04*V052 + 
      4.17434942425085623e-9*V02*V042*V052 - 1.38131989351095415e-10*V013*V053 + 
      2.90352382085443044e-9*V02*V03*V053 + 1.70184735404769042e-9*V01*V04*V053 - 
      1.73954584163477662e-9*V023*V032*V06 - 4.40434437955229898e-9*V01*V02*V033*V06 - 
      5.87254203673968461e-11*V024*V04*V06 - 6.49781876600089265e-9*V01*V022*V03*V04*V06 - 
      3.5490267205211955e-9*V012*V032*V04*V06 - 1.97199129312179211e-9*V012*V02*V042*V06 + 
      6.04178321890165732e-9*V032*V042*V06 + 1.45494291493694489e-9*V02*V043*V06 - 
      1.04372750498086597e-9*V01*V023*V05*V06 - 3.67813736079536552e-9*V012*V02*V03*V05*V06 + 
      3.94832555048672289e-9*V033*V05*V06 - 6.34555710698009723e-10*V013*V04*V05*V06 + 
      1.21278448455036406e-8*V02*V03*V04*V05*V06 + 3.68117797660595973e-9*V01*V042*V05*V06 + 
      1.50086149642047213e-9*V022*V052*V06 + 3.55613591527038345e-9*V01*V03*V052*V06 - 
      3.44719728612722945e-10*V012*V022*V062 - 2.08773784678927438e-10*V013*V03*V062 + 
      2.18499743603896193e-9*V02*V032*V062 + 7.73560057249388023e-10*V022*V04*V062 + 
      2.61697161424435874e-9*V01*V03*V04*V062 + 1.33089573649811817e-9*V01*V02*V05*V062 - 
      2.15515965268820468e-10*V052*V062 + 9.16959769356950817e-11*V012*V063 - 
      9.67413716629006364e-11*V04*V063 - 2.63388857358974646e-10*V024*V03*V07 - 
      2.27137749955722174e-9*V01*V022*V032*V07 - 7.11282704434497315e-10*V012*V033*V07 - 
      6.79994637860435252e-10*V01*V023*V04*V07 - 2.48766852904853134e-9*V012*V02*V03*V04*V07 + 
      2.70257970473577217e-9*V033*V04*V07 - 2.15513291631896969e-10*V013*V042*V07 + 
      4.03779812962716808e-9*V02*V03*V042*V07 + 8.24512636044631884e-10*V01*V043*V07 - 
      6.39821675829280626e-10*V012*V022*V05*V07 - 3.68508356270347032e-10*V013*V03*V05*V07 + 
      4.1867374435375795e-9*V02*V032*V05*V07 + 1.98341983515254212e-9*V022*V04*V05*V07 + 
      4.87810293002306012e-9*V01*V03*V04*V05*V07 + 1.26645435615914452e-9*V01*V02*V052*V07 - 
      1.34822783062642816e-10*V053*V07 - 1.47932961866283733e-10*V013*V02*V06*V07 + 
      1.45131577655238092e-9*V022*V03*V06*V07 + 1.69420034313961507e-9*V01*V032*V06*V07 + 
      1.78593788867828818e-9*V01*V02*V04*V06*V07 + 4.97484348880810243e-10*V012*V05*V06*V07 - 
      5.91527317494421009e-10*V04*V05*V06*V07 - 2.14111837640765805e-10*V03*V062*V07 - 
      4.98460273337877888e-12*V014*V072 + 7.75456826903812862e-11*V023*V072 + 
      6.04883423727214372e-10*V01*V02*V03*V072 + 1.71199337557789747e-10*V012*V04*V072 - 
      1.01035142618061238e-10*V042*V072 - 2.00437065382737022e-10*V03*V05*V072 - 
      7.51436497578171893e-11*V02*V06*V072 - 1.034089196038987e-11*V01*V073 - 
      1.90317570721649182e-12*V025*V08 - 3.82821435828408598e-10*V01*V023*V03*V08 - 
      6.21948995444348751e-10*V012*V02*V032*V08 + 3.62822522193854791e-10*V034*V08 - 
      3.51341006389575525e-10*V012*V022*V04*V08 - 2.10733814299509583e-10*V013*V03*V04*V08 + 
      2.29129168331781158e-9*V02*V032*V04*V08 + 4.00038718360123285e-10*V022*V042*V08 + 
      1.37391448269021764e-9*V01*V03*V042*V08 - 1.09914167977695533e-10*V013*V02*V05*V08 + 
      1.14273217810063096e-9*V022*V03*V05*V08 + 1.29747898633794244e-9*V01*V032*V05*V08 + 
      1.39521690195051682e-9*V01*V02*V04*V05*V08 + 1.89817244764465933e-10*V012*V052*V08 - 
      2.32345054050319718e-10*V04*V052*V08 - 8.4691450501297832e-12*V014*V06*V08 + 
      9.40480899945783424e-11*V023*V06*V08 + 9.92961990520016034e-10*V01*V02*V03*V06*V08 + 
      2.88801564071787016e-10*V012*V04*V06*V08 - 1.55454334755832098e-10*V042*V06*V08 - 
      3.35167087204343158e-10*V03*V05*V06*V08 - 5.74591434619374414e-11*V02*V062*V08 + 
      1.68078190530655331e-10*V01*V022*V07*V08 + 1.7922784297330001e-10*V012*V03*V07*V08 - 
      2.30627741795751109e-10*V03*V04*V07*V08 - 1.1847375577040188e-10*V02*V05*V07*V08 - 
      5.20635310606352351e-11*V01*V06*V07*V08 + 2.73302791010986286e-11*V012*V02*V082 - 
      3.23689884485910393e-11*V032*V082 - 3.0687952430678249e-11*V02*V04*V082 - 
      2.02660877457561619e-11*V01*V05*V082 + 2.5478272581313858e-13*V083 - 
      2.19490714465812205e-11*V01*V024*V09 - 1.63453537653180961e-10*V012*V022*V03*V09 - 
      4.5621590851981985e-11*V013*V032*V09 + 3.9451350045098616e-10*V02*V033*V09 - 
      5.63016510897856419e-11*V013*V02*V04*V09 + 5.67847963196590586e-10*V022*V03*V04*V09 + 
      6.83497674924997587e-10*V01*V032*V04*V09 + 3.52039989815995021e-10*V01*V02*V042*V09 - 
      5.54652425566178494e-12*V014*V05*V09 + 9.18275435053114489e-11*V023*V05*V09 + 
      7.11472707603287305e-10*V01*V02*V03*V05*V09 + 2.00808560272265483e-10*V012*V04*V05*V09 - 
      1.22379251573796394e-10*V042*V05*V09 - 1.2104186629599732e-10*V03*V052*V09 + 
      1.26423950179252656e-10*V01*V022*V06*V09 + 1.3777207229766087e-10*V012*V03*V06*V09 - 
      1.77770794499627443e-10*V03*V04*V06*V09 - 9.09454281396483529e-11*V02*V05*V06*V09 - 
      2.01178788126795057e-11*V01*V062*V09 + 4.98127842058461555e-11*V012*V02*V07*V09 - 
      5.97734920434934253e-11*V032*V07*V09 - 6.17065865165672288e-11*V02*V04*V07*V09 - 
      3.73422990754700221e-11*V01*V05*V07*V09 + 4.6326605235350596e-12*V013*V08*V09 - 
      3.54902394595375172e-11*V02*V03*V08*V09 - 2.16182468692036307e-11*V01*V04*V08*V09 + 1.44416410754209022e-12*V07*V08*V09 - 
      2.31982052822957649e-12*V022*V092 - 5.50043602650990372e-12*V01*V03*V092 + 
      5.60756891947137004e-13*V06*V092 - 1.25177421440102926e-11*V012*V023*V10 - 
      2.16603545160845274e-11*V013*V02*V03*V10 + 1.33909625510296353e-10*V022*V032*V10 + 
      9.76607742790705792e-11*V01*V033*V10 - 2.52831391454603897e-12*V014*V04*V10 + 
      2.97886436303311412e-11*V023*V04*V10 + 3.23010487473487697e-10*V01*V02*V03*V04*V10 + 
      4.70550540341506635e-11*V012*V042*V10 - 1.75022677593823745e-11*V043*V10 + 
      8.14695838240757881e-11*V01*V022*V05*V10 + 8.48788142856757976e-11*V012*V03*V05*V10 - 
      1.14552171393243433e-10*V03*V04*V05*V10 - 2.95108352868355473e-11*V02*V052*V10 + 
      3.39326742656223317e-11*V012*V02*V06*V10 - 4.10807357303802357e-11*V032*V06*V10 - 
      3.87061693537785587e-11*V02*V04*V06*V10 - 2.57011365522157467e-11*V01*V05*V06*V10 + 
      3.73548841761136647e-12*V013*V07*V10 - 2.92217665576245852e-11*V02*V03*V07*V10 - 
      1.77384521140662386e-11*V01*V04*V07*V10 + 5.93962491830135727e-13*V072*V10 - 
      3.78246057178661458e-12*V022*V08*V10 - 9.79616287622452431e-12*V01*V03*V08*V10 + 
      9.76297712086681666e-13*V06*V08*V10 - 2.72121658140061301e-12*V01*V02*V09*V10 + 7.25084909932484695e-13*V05*V09*V10 - 
      1.78323033133655411e-13*V012*V102 + 1.69575297984627578e-13*V04*V102 - 
      2.29222549089823485e-12*V013*V022*V11 - 8.44435983486121085e-13*V014*V03*V11 + 
      1.74364153827111444e-11*V023*V03*V11 + 6.5728760123736834e-11*V01*V02*V032*V11 + 
      3.281694442754688e-11*V01*V022*V04*V11 + 3.66814218986499327e-11*V012*V03*V04*V11 - 
      2.47814438354677427e-11*V03*V042*V11 + 1.92631247960223483e-11*V012*V02*V05*V11 - 
      2.4270321576788209e-11*V032*V05*V11 - 2.51925693621858727e-11*V02*V04*V05*V11 - 
      7.5569455661131593e-12*V01*V052*V11 + 2.35164218730202385e-12*V013*V06*V11 - 
      1.83757610573746442e-11*V02*V03*V06*V11 - 1.12271506506756399e-11*V01*V04*V06*V11 - 
      3.13110455057833352e-12*V022*V07*V11 - 7.39832471867915497e-12*V01*V03*V07*V11 + 
      7.60245426486413122e-13*V06*V07*V11 - 2.22886744666734419e-12*V01*V02*V08*V11 + 5.97517127561872589e-13*V05*V08*V11 - 
      3.27626045988909981e-13*V012*V09*V11 + 3.21185006823789825e-13*V04*V09*V11 + 
      1.50808308443720851e-13*V03*V10*V11 + 1.72946818913936683e-14*V02*V112 - 
      1.63138506469259823e-13*V014*V02*V12 + 5.58419531667944093e-13*V024*V12 + 
      1.28764372320438753e-11*V01*V022*V03*V12 + 6.45396832557506403e-12*V012*V032*V12 + 
      7.54254792767127526e-12*V012*V02*V04*V12 - 9.75145473881211404e-12*V032*V04*V12 - 
      4.50376637938931664e-12*V02*V042*V12 + 1.20158353693452675e-12*V013*V05*V12 - 
      1.00839260572710666e-11*V02*V03*V05*V12 - 6.08782612914198772e-12*V01*V04*V05*V12 - 
      1.6484320757807942e-12*V022*V06*V12 - 4.31836552247896612e-12*V01*V03*V06*V12 + 
      2.17717556668614242e-13*V062*V12 - 1.55274369081896802e-12*V01*V02*V07*V12 + 
      4.16717345659387109e-13*V05*V07*V12 - 2.47998588843422056e-13*V012*V08*V12 + 
      2.36849734453498605e-13*V04*V08*V12 + 1.27868089741642656e-13*V03*V09*V12 + 3.09373294846011127e-14*V02*V10*V12 + 
      8.44356355298828722e-15*V01*V11*V12 - 3.88425015402999579e-15*V015*V13 + 
      7.1809920585718673e-13*V01*V023*V13 + 2.48945291657643411e-12*V012*V02*V03*V13 - 
      1.16160373954814387e-12*V033*V13 + 4.43525878302310805e-13*V013*V04*V13 - 
      3.66707114608416697e-12*V02*V03*V04*V13 - 1.12477065389886273e-12*V01*V042*V13 - 
      9.21441289700999496e-13*V022*V05*V13 - 2.15189828220726337e-12*V01*V03*V05*V13 - 
      8.31430815663206351e-13*V01*V02*V06*V13 + 2.27749640225126443e-13*V05*V06*V13 - 
      1.58376245559656605e-13*V012*V07*V13 + 1.57655305342467814e-13*V04*V07*V13 + 
      8.99693016116435438e-14*V03*V08*V13 + 2.50465583102290494e-14*V02*V09*V13 + 7.20849329211898222e-15*V01*V10*V13 - 
      3.21803883195180805e-17*V132 + 2.18045156860869549e-13*V012*V022*V14 + 
      1.30270351594444097e-13*V013*V03*V14 - 6.30326478088255669e-13*V02*V032*V14 - 
      2.80122041894993088e-13*V022*V04*V14 - 7.52745557853500325e-13*V01*V03*V04*V14 - 
      3.92273981607649023e-13*V01*V02*V05*V14 + 5.40803287586297931e-14*V052*V14 - 
      8.04948184417643853e-14*V012*V06*V14 + 7.80891139128618399e-14*V04*V06*V14 + 
      5.43740781719425874e-14*V03*V07*V14 + 1.597202818528769e-14*V02*V08*V14 + 5.29724316851910525e-15*V01*V09*V14 - 
      5.95245198917411751e-17*V12*V14 + 2.21957151658856902e-14*V013*V02*V15 - 
      1.00947915306144865e-13*V022*V03*V15 - 1.14771751173946253e-13*V01*V032*V15 - 
      1.24857632920951728e-13*V01*V02*V04*V15 - 3.4513834462590702e-14*V012*V05*V15 + 
      3.58028429140039697e-14*V04*V05*V15 + 2.59899778457856372e-14*V03*V06*V15 + 9.32107114925971582e-15*V02*V07*V15 + 
      3.25854476754579703e-15*V01*V08*V15 - 4.88025821976709744e-17*V11*V15 + 6.9361609893392782e-16*V014*V16 - 
      4.38463664730278108e-15*V023*V16 - 3.70702621454876177e-14*V01*V02*V03*V16 - 
      1.07299394782909356e-14*V012*V04*V16 + 5.38104465524185602e-15*V042*V16 + 
      1.08618951941430341e-14*V03*V05*V16 + 4.04737615083692379e-15*V02*V06*V16 + 1.73388722735808211e-15*V01*V07*V16 - 
      3.40357899883500811e-17*V10*V16 - 2.66841149944943681e-15*V01*V022*V17 - 
      2.82321857080570476e-15*V012*V03*V17 + 3.20146552388739126e-15*V03*V04*V17 + 
      1.65932740599216357e-15*V02*V05*V17 + 7.37439568257151854e-16*V01*V06*V17 - 2.10418823120977985e-17*V09*V17 - 
      4.14661798275717718e-16*V012*V02*V18 + 4.31147746134437162e-16*V032*V18 + 
      4.40295436714580268e-16*V02*V04*V18 + 2.73892913617438614e-16*V01*V05*V18 - 1.08451911250036055e-17*V08*V18 - 
      1.75917126541213578e-17*V013*V19 + 1.19137779698530452e-16*V02*V03*V19 + 7.29134604483201418e-17*V01*V04*V19 - 
      4.96989816781859134e-18*V07*V19 + 7.22432999662583758e-18*V022*V20 + 1.74509789528883869e-17*V01*V03*V20 - 
      1.80799724339092158e-18*V06*V20 + 2.21655579441929108e-18*V01*V02*V21 - 5.93510876925951522e-19*V05*V21 + 
      1.40733701232970862e-19*V012*V22 - 1.37382898822662032e-19*V04*V22 - 3.01572216927794704e-20*V03*V23 - 
      3.35080241030883005e-21*V02*V24 - 4.18850301288603756e-22*V01*V25 + 4.0119760659827946e-25*V28) + 
   eps14*(-4.44285396439000936e-8*V012*V026 - 2.38124362318310731e-7*V013*V024*V03 - 
      1.91046128236108395e-7*V014*V022*V032 + 8.47814123243652694e-8*V025*V032 - 
      1.35979953688287022e-8*V015*V033 + 4.85554468215240858e-7*V01*V023*V033 + 
      2.73534843558599589e-7*V012*V02*V034 - 5.66691941869923714e-9*V036 - 
      8.77483361362329616e-8*V014*V023*V04 + 1.66609565924847593e-8*V026*V04 - 
      5.61693735056830295e-8*V015*V02*V03*V04 + 5.31943375712827938e-7*V01*V024*V03*V04 + 
      1.23637235775819508e-6*V012*V022*V032*V04 + 
      1.92166939849085624e-7*V013*V033*V04 - 1.23357570532137392e-7*V02*V034*V04 - 
      1.71415954526073574e-9*V016*V042 + 3.15099921017591905e-7*V012*V023*V042 + 
      4.38158827637666048e-7*V013*V02*V03*V042 - 2.6288958283670669e-7*V022*V032*V042 - 
      1.49320092000854684e-7*V01*V033*V042 + 1.81036536333863598e-8*V014*V043 - 
      3.84541066603365207e-8*V023*V043 - 2.18275281392033712e-7*V01*V02*V03*V043 - 
      1.62557222292894705e-8*V012*V044 + 1.23616495716322489e-9*V045 - 
      1.47743203298758854e-8*V015*V022*V05 + 6.3486237399161944e-8*V01*V025*V05 - 
      2.61963152588152588e-9*V016*V03*V05 + 5.04749092373161098e-7*V012*V023*V03*V05 + 
      3.52991140766754484e-7*V013*V02*V032*V05 - 1.49577749258686372e-7*V022*V033*V05 - 
      6.20592452742179181e-8*V01*V034*V05 + 2.69761723133219301e-7*V013*V022*V04*V05 + 
      8.77107272725415816e-8*V014*V03*V04*V05 - 2.09818162328113677e-7*V023*V03*V04*V05 - 
      5.48198735129195742e-7*V01*V02*V032*V04*V05 - 1.98662769889577042e-7*V01*V022*V042*V05 - 
      1.6042882424496805e-7*V012*V03*V042*V05 + 2.15636899144237912e-8*V03*V043*V05 + 
      2.67278282813924154e-8*V014*V02*V052 - 1.55886771333317162e-8*V024*V052 - 
      1.67299596589608388e-7*V01*V022*V03*V052 - 
      6.60736192207424135e-8*V012*V032*V052 - 
      9.87358270157971727e-8*V012*V02*V04*V052 + 2.75385910139636236e-8*V032*V04*V052 + 
      1.95974610187973338e-8*V02*V042*V052 - 5.0322316333669934e-9*V013*V053 + 
      1.11939649437148335e-8*V02*V03*V053 + 6.96824490892339008e-9*V01*V04*V053 - 
      1.11409616617949951e-9*V016*V02*V06 + 6.65795095057685511e-8*V012*V024*V06 + 
      1.83568097555524123e-7*V013*V022*V03*V06 + 2.97925711255105513e-8*V014*V032*V06 - 
      7.51309637948993831e-8*V023*V032*V06 - 1.2851692907095802e-7*V01*V02*V033*V06 + 
      4.49398509403761505e-8*V014*V02*V04*V06 - 2.45969778812155529e-8*V024*V04*V06 - 
      2.81476680443194741e-7*V01*V022*V03*V04*V06 - 1.11990144232753333e-7*V012*V032*V04*V06 - 
      8.39195240244391173e-8*V012*V02*V042*V06 + 2.30850772817083477e-8*V032*V042*V06 + 
      1.07019465801876516e-8*V02*V043*V06 + 3.34093899905641269e-9*V015*V05*V06 - 
      5.68612789544256521e-8*V01*V023*V05*V06 - 1.37946216092929594e-7*V012*V02*V03*V05*V06 + 
      1.30513790433038994e-8*V033*V05*V06 - 2.5648829174374078e-8*V013*V04*V05*V06 + 
      5.61239769146853626e-8*V02*V03*V04*V05*V06 + 1.76001840353159858e-8*V01*V042*V05*V06 + 
      8.48834586634070483e-9*V022*V052*V06 + 1.47938814807311634e-8*V01*V03*V052*V06 - 
      1.80369720913617452e-8*V012*V022*V062 - 8.88476205467893865e-9*V013*V03*V062 + 
      1.00226471812315941e-8*V02*V032*V062 + 6.94477230572795859e-9*V022*V04*V062 + 
      1.24772222583550127e-8*V01*V03*V04*V062 + 7.65341039943219654e-9*V01*V02*V05*V062 - 
      4.00421842173653072e-10*V052*V062 + 5.42508390784734171e-10*V012*V063 - 
      2.22402533455576898e-10*V04*V063 - 3.01107071940405274e-11*V017*V07 + 
      2.77283134599238124e-8*V013*V023*V07 + 2.64719083561724785e-8*V014*V02*V03*V07 - 
      1.63832980432584913e-8*V024*V03*V07 - 8.67821980500707419e-8*V01*V022*V032*V07 - 
      2.26562275544794585e-8*V012*V033*V07 + 2.42602052206102159e-9*V015*V04*V07 - 
      4.17244583788554264e-8*V01*V023*V04*V07 - 1.01754981256123818e-7*V012*V02*V03*V04*V07 + 
      9.61933163483392822e-9*V033*V04*V07 - 9.46603145239704213e-9*V013*V042*V07 + 
      2.06181050369082218e-8*V02*V03*V042*V07 + 4.32428629621820677e-9*V01*V043*V07 - 
      3.12950296226941361e-8*V012*V022*V05*V07 - 1.54385614355878046e-8*V013*V03*V05*V07 + 
      1.76198113679567036e-8*V02*V032*V05*V07 + 1.24514430520378678e-8*V022*V04*V05*V07 + 
      2.18382321119836989e-8*V01*V03*V04*V05*V07 + 6.7076755062824439e-9*V01*V02*V052*V07 - 
      2.34661747410824179e-10*V053*V07 - 8.10809190164792969e-9*V013*V02*V06*V07 + 
      8.93730376339007827e-9*V022*V03*V06*V07 + 7.72142743457785924e-9*V01*V032*V06*V07 + 
      1.12813037607382006e-8*V01*V02*V04*V06*V07 + 2.83745875649115152e-9*V012*V05*V06*V07 - 
      1.18025293159619893e-9*V04*V05*V06*V07 - 4.22181735978734033e-10*V03*V062*V07 - 
      3.18691793748441956e-10*V014*V072 + 6.57786841443475241e-10*V023*V072 + 
      3.50638547974525262e-9*V01*V02*V03*V072 + 1.04890139026294974e-9*V012*V04*V072 - 
      2.17336706555266237e-10*V042*V072 - 3.70918013728160585e-10*V03*V05*V072 - 
      1.90194226432363861e-10*V02*V06*V072 - 2.51314251998090779e-11*V01*V073 + 
      5.16310067474283161e-9*V014*V022*V08 - 1.18730700632077167e-9*V025*V08 + 
      1.25136556662291956e-9*V015*V03*V08 - 2.29279375669576944e-8*V01*V023*V03*V08 - 
      2.73729662872491818e-8*V012*V02*V032*V08 + 1.32330997386533185e-9*V034*V08 - 
      2.05293337471624539e-8*V012*V022*V04*V08 - 1.00946782145188957e-8*V013*V03*V04*V08 + 
      1.14433490804597708e-8*V02*V032*V04*V08 + 3.9580363656136679e-9*V022*V042*V08 + 
      7.12851884157794588e-9*V01*V03*V042*V08 - 6.24094168156796559e-9*V013*V02*V05*V08 + 
      6.94356978258042249e-9*V022*V03*V05*V08 + 5.97551640081225015e-9*V01*V032*V05*V08 + 
      8.74380863198565107e-9*V01*V02*V04*V05*V08 + 1.09674986486655438e-9*V012*V052*V08 - 
      4.581985947432085e-10*V04*V052*V08 - 5.64122782334582771e-10*V014*V06*V08 + 
      1.14077085538480067e-9*V023*V06*V08 + 6.2033225723360664e-9*V01*V02*V03*V06*V08 + 
      1.86052874460750999e-9*V012*V04*V06*V08 - 3.81590377099588795e-10*V042*V06*V08 - 
      6.55281918259906118e-10*V03*V05*V06*V08 - 1.66926781546952041e-10*V02*V062*V08 + 
      1.4005434568201366e-9*V01*V022*V07*V08 + 1.13979684147809739e-9*V012*V03*V07*V08 - 
      4.83322804309876299e-10*V03*V04*V07*V08 - 2.95582748451497857e-10*V02*V05*V07*V08 - 
      1.33409947208532761e-10*V01*V06*V07*V08 + 2.31526965969625083e-10*V012*V02*V082 - 
      6.69929031241200044e-11*V032*V082 - 9.55031661992683771e-11*V02*V04*V082 - 
      5.17126889322778945e-11*V01*V05*V082 + 4.13107977656135402e-13*V083 + 
      4.2464953233948332e-10*V015*V02*V09 - 2.02019027419996013e-9*V01*V024*V09 - 
      9.89520180800151304e-9*V012*V022*V03*V09 - 2.41562895063108654e-9*V013*V032*V09 + 
      1.90018113274307923e-9*V02*V033*V09 - 3.66727316596148449e-9*V013*V02*V04*V09 + 
      4.05192218156296103e-9*V022*V03*V04*V09 + 3.51340513992207514e-9*V01*V032*V04*V09 + 
      2.56351206321914891e-9*V01*V02*V042*V09 - 3.89765451634726026e-10*V014*V05*V09 + 
      8.1311449232293595e-10*V023*V05*V09 + 4.32302295795212964e-9*V01*V02*V03*V05*V09 + 
      1.29182440988578419e-9*V012*V04*V05*V09 - 2.68529095864056996e-10*V042*V05*V09 - 
      2.29028113383650342e-10*V03*V052*V09 + 1.1142292397210049e-9*V01*V022*V06*V09 + 
      9.07931717762568069e-10*V012*V03*V06*V09 - 3.84555435601096485e-10*V03*V04*V06*V09 - 
      2.35077579863707066e-10*V02*V05*V06*V09 - 5.31194531671469679e-11*V01*V062*V09 + 
      4.15842572147764832e-10*V012*V02*V07*V09 - 1.20677033057322425e-10*V032*V07*V09 - 
      1.7307782150521251e-10*V02*V04*V07*V09 - 9.30875921523964184e-11*V01*V05*V07*V09 + 
      4.27915270305025167e-11*V013*V08*V09 - 9.64922137274363018e-11*V02*V03*V08*V09 - 
      6.0897977955022888e-11*V01*V04*V08*V09 + 2.23672006049290896e-12*V07*V08*V09 - 
      8.61435126001093185e-12*V022*V092 - 1.5101570440934915e-11*V01*V03*V092 + 
      8.90312494831359498e-13*V06*V092 + 1.23985264916637466e-11*V016*V10 - 
      1.08597003336772874e-9*V012*V023*V10 - 1.59037792603074527e-9*V013*V02*V03*V10 + 
      9.21839305565832322e-10*V022*V032*V10 + 5.2290045243083601e-10*V01*V033*V10 - 
      2.07045792763975322e-10*V014*V04*V10 + 4.223102586584077e-10*V023*V04*V10 + 
      2.30531604195516552e-9*V01*V02*V03*V04*V10 + 3.45866196153316002e-10*V012*V042*V10 - 
      4.730140076757285e-11*V043*V10 + 7.06111048292429286e-10*V01*V022*V05*V10 + 
      5.72957043956577621e-10*V012*V03*V05*V10 - 2.43995573875325085e-10*V03*V04*V05*V10 - 
      7.46676721210225473e-11*V02*V052*V10 + 3.01169854286320233e-10*V012*V02*V06*V10 - 
      8.71561659032362657e-11*V032*V06*V10 - 1.24184781432973377e-10*V02*V04*V06*V10 - 
      6.72932958419904147e-11*V01*V05*V06*V10 + 3.49217470015431594e-11*V013*V07*V10 - 
      7.88821815003766501e-11*V02*V03*V07*V10 - 4.97562731181520737e-11*V01*V04*V07*V10 + 
      9.14063254057000579e-13*V072*V10 - 1.55453703275504475e-11*V022*V08*V10 - 
      2.74200591514209273e-11*V01*V03*V08*V10 + 1.61275026622152242e-12*V06*V08*V10 - 9.98822615803830342e-12*V01*V02*V09*V10 + 
      1.13079968870586721e-12*V05*V09*V10 - 6.80460290457835636e-13*V012*V102 + 
      3.01293286387371767e-13*V04*V102 - 2.40416310658712261e-10*V013*V022*V11 - 
      8.17459866166382764e-11*V014*V03*V11 + 1.80452585440968922e-10*V023*V03*V11 + 
      4.7330571674483787e-10*V01*V02*V032*V11 + 3.44422568062248563e-10*V01*V022*V04*V11 + 
      2.81012315314083125e-10*V012*V03*V04*V11 - 5.95582892105503442e-11*V03*V042*V11 + 
      1.74071537746559336e-10*V012*V02*V05*V11 - 5.06728075205236914e-11*V032*V05*V11 - 
      7.27687542032896293e-11*V02*V04*V05*V11 - 1.95355626099852823e-11*V01*V052*V11 + 
      2.31618530300907583e-11*V013*V06*V11 - 5.2207755670901011e-11*V02*V03*V06*V11 - 
      3.297199918412495e-11*V01*V04*V06*V11 - 1.1719434646825447e-11*V022*V07*V11 - 
      2.05337843265451811e-11*V01*V03*V07*V11 + 1.2105816634917136e-12*V06*V07*V11 - 8.31119230639439751e-12*V01*V02*V08*V11 + 
      9.40616387175285778e-13*V05*V08*V11 - 1.24684884587326264e-12*V012*V09*V11 + 
      5.53411506155556774e-13*V04*V09*V11 + 2.5217127119503702e-13*V03*V10*V11 + 3.80558411977371771e-14*V02*V112 - 
      2.25674933949142755e-11*V014*V02*V12 + 1.18826980712085631e-11*V024*V12 + 
      1.31282476206008484e-10*V01*V022*V03*V12 + 5.26689431260876981e-11*V012*V032*V12 + 
      7.88924869784827072e-11*V012*V02*V04*V12 - 2.28704609621203231e-11*V032*V04*V12 - 
      1.62613938571251225e-11*V02*V042*V12 + 1.2343499614481655e-11*V013*V05*V12 - 
      2.8057126377794321e-11*V02*V03*V05*V12 - 1.76754020392417743e-11*V01*V04*V05*V12 - 
      7.11446422836924071e-12*V022*V06*V12 - 1.25639885755102269e-11*V01*V03*V06*V12 + 
      3.69165227756859453e-13*V062*V12 - 5.7461886803326097e-12*V01*V02*V07*V12 + 6.50304802067189682e-13*V05*V07*V12 - 
      9.58157148441811182e-13*V012*V08*V12 + 4.23974042778759694e-13*V04*V08*V12 + 
      2.13299545045710937e-13*V03*V09*V12 + 7.01010201669626122e-14*V02*V10*V12 + 1.86645558392741721e-14*V01*V11*V12 - 
      7.34123279111669205e-13*V015*V13 + 1.11917223375579105e-11*V01*V023*V13 + 
      2.74773798021158917e-11*V012*V02*V03*V13 - 2.71184870502481249e-12*V033*V13 + 
      5.19683538733058212e-12*V013*V04*V13 - 1.17379576815014896e-11*V02*V03*V04*V13 - 
      3.7125710821677119e-12*V01*V042*V13 - 3.57769544470418032e-12*V022*V05*V13 - 
      6.25241942029032562e-12*V01*V03*V05*V13 - 3.26429884921483961e-12*V01*V02*V06*V13 + 3.69055431492914755e-13*V05*V06*V13 - 
      6.14606188580291793e-13*V012*V07*V13 + 2.72738495171039016e-13*V04*V07*V13 + 
      1.52048984007312621e-13*V03*V08*V13 + 5.51653449031946066e-14*V02*V09*V13 + 1.59933365724365125e-14*V01*V10*V13 - 
      4.82840505109887935e-17*V132 + 3.34634624519940854e-12*V012*V022*V14 + 
      1.67527709143313718e-12*V013*V03*V14 - 1.96009308477979693e-12*V02*V032*V14 - 
      1.38589788154165138e-12*V022*V04*V14 - 2.45614126959940437e-12*V01*V03*V04*V14 - 
      1.5188247425853835e-12*V01*V02*V05*V14 + 8.59482153995903017e-14*V052*V14 - 
      3.26537068713583715e-13*V012*V06*V14 + 1.44221830492316582e-13*V04*V06*V14 + 
      9.11392462040902418e-14*V03*V07*V14 + 3.66389488900220047e-14*V02*V08*V14 + 1.17260332723494438e-14*V01*V09*V14 - 
      9.00758329931411365e-17*V12*V14 + 3.84540765248969583e-13*V013*V02*V15 - 
      4.39666189529948373e-13*V022*V03*V15 - 3.80178623655181342e-13*V01*V032*V15 - 
      5.58897255567581823e-13*V01*V02*V04*V15 - 1.42081226422276558e-13*V012*V05*V15 + 
      6.31543037165354444e-14*V04*V05*V15 + 4.53093106098236628e-14*V03*V06*V15 + 2.06422463096400032e-14*V02*V07*V15 + 
      7.32019980438718352e-15*V01*V08*V15 - 7.32308093599298073e-17*V11*V15 + 1.45659380776124842e-14*V014*V16 - 
      3.04692484132274287e-14*V023*V16 - 1.63637306916058396e-13*V01*V02*V03*V16 - 
      4.94650813093645986e-14*V012*V04*V16 + 1.08989807582861954e-14*V042*V16 + 
      1.86396459507237516e-14*V03*V05*V16 + 9.64001727668496181e-15*V02*V06*V16 + 3.8737051788447539e-15*V01*V07*V16 - 
      5.16507406747715027e-17*V10*V16 - 1.6556767067661321e-14*V01*V022*V17 - 
      1.35313945874416845e-14*V012*V03*V17 + 6.10374627756433287e-15*V03*V04*V17 + 
      3.76127654327226431e-15*V02*V05*V17 + 1.71578004959984158e-15*V01*V06*V17 - 3.15897595315700434e-17*V09*V17 - 
      2.63498724540660623e-15*V012*V02*V18 + 8.06592590700502911e-16*V032*V18 + 
      1.16286246847357638e-15*V02*V04*V18 + 6.31725940714921152e-16*V01*V05*V18 - 1.66021090089434833e-17*V08*V18 - 
      1.24398539482715316e-16*V013*V19 + 2.94460138811914213e-16*V02*V03*V19 + 1.87125560603696614e-16*V01*V04*V19 - 
      7.48178331515123269e-18*V07*V19 + 2.53588726412172258e-17*V022*V20 + 4.45623212546971308e-17*V01*V03*V20 - 
      2.83988482374650272e-18*V06*V20 + 7.49155648884796678e-18*V01*V02*V21 - 9.06880710673375232e-19*V05*V21 + 
      4.97594157930861262e-19*V012*V22 - 2.33439234584848493e-19*V04*V22 - 4.9284718784959042e-20*V03*V23 - 
      7.2600718890024651e-21*V02*V24 - 9.07508986125308138e-22*V01*V25 + 6.0179640989741919e-25*V28) + 
   delta6*eps11*(-2.49661808097621507e-9*V036 - 4.26038561333340795e-8*V02*V034*V04 - 
      6.35525387519264992e-8*V022*V032*V042 - 4.83292346032964941e-8*V01*V033*V042 - 
      3.48009271425128996e-9*V023*V043 - 5.21007542194428255e-8*V01*V02*V03*V043 - 
      3.88562403920447723e-9*V012*V044 + 7.74456172615070677e-10*V045 - 
      4.33178344404360152e-8*V022*V033*V05 - 2.14585667164907926e-8*V01*V034*V05 - 
      4.05750607908712866e-8*V023*V03*V04*V05 - 1.49701349905328914e-7*V01*V02*V032*V04*V05 - 
      3.81315232511558995e-8*V01*V022*V042*V05 - 4.14542305333481087e-8*V012*V03*V042*V05 + 
      1.74757770810771918e-8*V03*V043*V05 - 2.39083324048852658e-9*V024*V052 - 
      3.83066196167295525e-8*V01*V022*V03*V052 - 
      1.80376103167323091e-8*V012*V032*V052 - 
      2.15672748820465144e-8*V012*V02*V04*V052 + 2.50208225944889591e-8*V032*V04*V052 + 
      1.33552205247362602e-8*V02*V042*V052 - 1.0931822218562792e-9*V013*V053 + 
      8.75985166357305396e-9*V02*V03*V053 + 5.20810599820024563e-9*V01*V04*V053 - 
      1.48779795339320709e-8*V023*V032*V06 - 3.43121584273838304e-8*V01*V02*V033*V06 - 
      1.78831917683038053e-9*V024*V04*V06 - 5.51184596961167823e-8*V01*V022*V03*V04*V06 - 
      2.80922928946639527e-8*V012*V032*V04*V06 - 1.64962882079455804e-8*V012*V02*V042*V06 + 
      1.8942406412571866e-8*V032*V042*V06 + 5.66450426445252467e-9*V02*V043*V06 - 
      8.92678772035924254e-9*V01*V023*V05*V06 - 2.93794851767513907e-8*V012*V02*V03*V05*V06 + 
      1.18176763577933914e-8*V033*V05*V06 - 5.18481639171417276e-9*V013*V04*V05*V06 + 
      3.89480165738484644e-8*V02*V03*V04*V05*V06 + 1.18938744327780421e-8*V01*V042*V05*V06 + 
      4.93394369258030515e-9*V022*V052*V06 + 1.09980585927146159e-8*V01*V03*V052*V06 - 
      2.90935693102773385e-9*V012*V022*V062 - 1.72637399528795707e-9*V013*V03*V062 + 
      7.0439280037250256e-9*V02*V032*V062 + 3.09503195995822463e-9*V022*V04*V062 + 
      8.48663599829213159e-9*V01*V03*V04*V062 + 4.41494802311360294e-9*V01*V02*V05*V062 - 
      4.84192342238050314e-10*V052*V062 + 3.06606269118169895e-10*V012*V063 - 
      2.3609905663751539e-10*V04*V063 - 2.2769840385605015e-9*V024*V03*V07 - 
      1.79177086843174721e-8*V01*V022*V032*V07 - 5.54028518810008891e-9*V012*V033*V07 - 
      5.79643725583875523e-9*V01*V023*V04*V07 - 2.00156143389004272e-8*V012*V02*V03*V04*V07 + 
      8.24612384933782233e-9*V033*V04*V07 - 1.77952711019574461e-9*V013*V042*V07 + 
      1.32850691831887295e-8*V02*V03*V042*V07 + 2.72810098339074092e-9*V01*V043*V07 - 
      5.17986347072184624e-9*V012*V022*V05*V07 - 3.00001458976562176e-9*V013*V03*V05*V07 + 
      1.30002531630843894e-8*V02*V032*V05*V07 + 6.67320638621514296e-9*V022*V04*V05*V07 + 
      1.5359262313915318e-8*V01*V03*V04*V05*V07 + 4.05369906224963899e-9*V01*V02*V052*V07 - 
      2.95320892275880125e-10*V053*V07 - 1.25602716004587036e-9*V013*V02*V06*V07 + 
      4.89987598832738015e-9*V022*V03*V06*V07 + 5.39008937563491906e-9*V01*V032*V06*V07 + 
      6.05928022089994357e-9*V01*V02*V04*V06*V07 + 1.63292218138416486e-9*V012*V05*V06*V07 - 
      1.35522339946117897e-9*V04*V05*V06*V07 - 4.9177054136235004e-10*V03*V062*V07 - 
      4.42819314702863444e-11*V014*V072 + 2.73300107347243502e-10*V023*V072 + 
      1.98787540226761154e-9*V01*V02*V03*V072 + 5.70839279729497001e-10*V012*V04*V072 - 
      2.36194080412229453e-10*V042*V072 - 4.48932968279637233e-10*V03*V05*V072 - 
      1.80111790128789343e-10*V02*V06*V072 - 2.44145584190784027e-11*V01*V073 - 
      6.1591651792682389e-11*V025*V08 - 3.3205120028876497e-9*V01*V023*V03*V08 - 
      5.12971004917428142e-9*V012*V02*V032*V08 + 1.12654005149410709e-9*V034*V08 - 
      2.99579217556008662e-9*V012*V022*V04*V08 - 1.77931999951134116e-9*V013*V03*V04*V08 + 
      7.57072442063727112e-9*V02*V032*V04*V08 + 1.63909310102557311e-9*V022*V042*V08 + 
      4.56593896082372445e-9*V01*V03*V042*V08 - 9.42611166537989541e-10*V013*V02*V05*V08 + 
      3.86025914024896609e-9*V022*V03*V05*V08 + 4.15757927376058933e-9*V01*V032*V05*V08 + 
      4.73780983192891003e-9*V01*V02*V04*V05*V08 + 6.27676099485222348e-10*V012*V052*V08 - 
      5.31670146918461443e-10*V04*V052*V08 - 7.66171425620634154e-11*V014*V06*V08 + 
      3.95636370021983198e-10*V023*V06*V08 + 3.38492848473740677e-9*V01*V02*V03*V06*V08 + 
      9.88657452675484232e-10*V012*V04*V06*V08 - 3.87119861701422049e-10*V042*V06*V08 - 
      7.695276814491008e-10*V03*V05*V06*V08 - 1.46948279806190887e-10*V02*V062*V08 + 
      5.9700727167391108e-10*V01*V022*V07*V08 + 6.08501502443267155e-10*V012*V03*V07*V08 - 
      5.39598172457962928e-10*V03*V04*V07*V08 - 2.83515124264387506e-10*V02*V05*V07*V08 - 
      1.25932010249151538e-10*V01*V06*V07*V08 + 9.79822849116433203e-11*V012*V02*V082 - 
      7.60321202835209672e-11*V032*V082 - 8.00438662894526186e-11*V02*V04*V082 - 
      4.90581509132273981e-11*V01*V05*V082 + 5.30370390189967646e-13*V083 - 
      1.89748669880041792e-10*V01*V024*V09 - 1.38492783871933339e-9*V012*V022*V03*V09 - 
      3.92619956245540495e-10*V013*V032*V09 + 1.28926976485616982e-9*V02*V033*V09 - 
      4.94435450321130617e-10*V013*V02*V04*V09 + 2.00577754615659779e-9*V022*V03*V04*V09 + 
      2.26381328315603608e-9*V01*V032*V04*V09 + 1.24854198374475265e-9*V01*V02*V042*V09 - 
      5.06266999599834683e-11*V014*V05*V09 + 3.30997431172136471e-10*V023*V05*V09 + 
      2.39176482559352055e-9*V01*V02*V03*V05*V09 + 6.84796104831609499e-10*V012*V04*V05*V09 - 
      2.8964693312899592e-10*V042*V05*V09 - 2.7452581036405451e-10*V03*V052*V09 + 
      4.58543497875720728e-10*V01*V022*V06*V09 + 4.74776799562345758e-10*V012*V03*V06*V09 - 
      4.21594857816365011e-10*V03*V04*V06*V09 - 2.20749527071950243e-10*V02*V05*V06*V09 - 
      4.92822244041278936e-11*V01*V062*V09 + 1.76500396127192128e-10*V012*V02*V07*V09 - 
      1.38689184975927788e-10*V032*V07*V09 - 1.52857352811459595e-10*V02*V04*V07*V09 - 
      8.93272283859778263e-11*V01*V05*V07*V09 + 1.70090809796901564e-11*V013*V08*V09 - 
      8.79396612859014719e-11*V02*V03*V08*V09 - 5.39460898133261518e-11*V01*V04*V08*V09 + 2.94106739734106171e-12*V07*V08*V09 - 
      6.08730636079525797e-12*V022*V092 - 1.3637441496554828e-11*V01*V03*V092 + 
      1.15356416762231491e-12*V06*V092 - 1.10290212716417116e-10*V012*V023*V10 - 
      1.96961668981946391e-10*V013*V02*V03*V10 + 4.73736502833791189e-10*V022*V032*V10 + 
      3.30526268265465486e-10*V01*V033*V10 - 2.40308568958011191e-11*V014*V04*V10 + 
      1.306858449197228e-10*V023*V04*V10 + 1.14855445011369218e-9*V01*V02*V03*V04*V10 + 
      1.68032962650687216e-10*V012*V042*V10 - 4.50591365188107947e-11*V043*V10 + 
      2.95281792295839512e-10*V01*V022*V05*V10 + 2.96087417912995843e-10*V012*V03*V05*V10 - 
      2.70958150839110306e-10*V03*V04*V05*V10 - 7.13538949593980984e-11*V02*V052*V10 + 
      1.23973004586497602e-10*V012*V02*V06*V10 - 9.75850911950480834e-11*V032*V06*V10 - 
      1.02290832413024991e-10*V02*V04*V06*V10 - 6.29210003101351228e-11*V01*V05*V06*V10 + 
      1.37901305728218524e-11*V013*V07*V10 - 7.22394463607154801e-11*V02*V03*V07*V10 - 
      4.42014311579501796e-11*V01*V04*V07*V10 + 1.20693083515099705e-12*V072*V10 - 
      1.04548365252086475e-11*V022*V08*V10 - 2.45525098402197856e-11*V01*V03*V08*V10 + 
      2.04868873712807041e-12*V06*V08*V10 - 7.16738347520472014e-12*V01*V02*V09*V10 + 1.48553413763209583e-12*V05*V09*V10 - 
      4.76362356925007745e-13*V012*V102 + 3.64596047658544612e-13*V04*V102 - 
      2.2225852014699815e-11*V013*V022*V11 - 8.46041473549786817e-12*V014*V03*V11 + 
      6.68071543587624776e-11*V023*V03*V11 + 2.35400430463378888e-10*V01*V02*V032*V11 + 
      1.25999768576681367e-10*V01*V022*V04*V11 + 1.33242160559910272e-10*V012*V03*V04*V11 - 
      6.1093208918199871e-11*V03*V042*V11 + 7.08712637913533671e-11*V012*V02*V05*V11 - 
      5.73967385086297412e-11*V032*V05*V11 - 6.35821678907591332e-11*V02*V04*V05*V11 - 
      1.84336694398277715e-11*V01*V052*V11 + 8.89175146688824675e-12*V013*V06*V11 - 
      4.64625183219576854e-11*V02*V03*V06*V11 - 2.85686697464344414e-11*V01*V04*V06*V11 - 
      8.26546389412233474e-12*V022*V07*V11 - 1.84599259550681866e-11*V01*V03*V07*V11 + 
      1.56758121391240015e-12*V06*V07*V11 - 5.91926806409766088e-12*V01*V02*V08*V11 + 1.22978944900088456e-12*V05*V08*V11 - 
      8.73047668890433673e-13*V012*V09*V11 + 6.79875661187316609e-13*V04*V09*V11 + 
      3.18472665746274171e-13*V03*V10*V11 + 3.86507060780704276e-14*V02*V112 - 
      1.76086006982693143e-12*V014*V02*V12 + 2.65284831789715095e-12*V024*V12 + 
      4.94243888968296153e-11*V01*V022*V03*V12 + 2.4059427713600762e-11*V012*V032*V12 + 
      2.90634455322732559e-11*V012*V02*V04*V12 - 2.40332415562754902e-11*V032*V04*V12 - 
      1.24004736709692699e-11*V02*V042*V12 + 4.62159797731715339e-12*V013*V05*V12 - 
      2.53817340430362582e-11*V02*V03*V05*V12 - 1.54582452810502205e-11*V01*V04*V05*V12 - 
      4.65443001013582812e-12*V022*V06*V12 - 1.10195143774801306e-11*V01*V03*V06*V12 + 
      4.62275445114552831e-13*V062*V12 - 4.11091841812275455e-12*V01*V02*V07*V12 + 
      8.54827264660022273e-13*V05*V07*V12 - 6.6677690271151634e-13*V012*V08*V12 + 5.11140088822477658e-13*V04*V08*V12 + 
      2.69716890703278048e-13*V03*V09*V12 + 7.01887047142654836e-14*V02*V10*V12 + 1.89467326589422553e-14*V01*V11*V12 - 
      4.66110018483599495e-14*V015*V13 + 2.99423691357777777e-12*V01*V023*V13 + 
      9.82167794662163755e-12*V012*V02*V03*V13 - 2.87880905295321031e-12*V033*V13 + 
      1.77930100984392145e-12*V013*V04*V13 - 9.67816167205109803e-12*V02*V03*V04*V13 - 
      2.98580071451049345e-12*V01*V042*V13 - 2.48794034649747452e-12*V022*V05*V13 - 
      5.49948735789160165e-12*V01*V03*V05*V13 - 2.26100990709481797e-12*V01*V02*V06*V13 + 4.7500858695694337e-13*V05*V06*V13 - 
      4.26483138776411711e-13*V012*V07*V13 + 3.34748910337749257e-13*V04*V07*V13 + 
      1.91031803190879603e-13*V03*V08*V13 + 5.60095614202921938e-14*V02*V09*V13 + 1.62074470333207622e-14*V01*V10*V13 - 
      6.43752435954743197e-17*V132 + 9.10425077769586236e-13*V012*V022*V14 + 
      5.39910771410169415e-13*V013*V03*V14 - 1.66140669058117387e-12*V02*V032*V14 - 
      8.28263992410037937e-13*V022*V04*V14 - 2.00219641298408411e-12*V01*V03*V04*V14 - 
      1.06363153783049786e-12*V01*V02*V05*V14 + 1.12234590097211278e-13*V052*V14 - 
      2.21355079481772612e-13*V012*V06*V14 + 1.70954099969788965e-13*V04*V06*V14 + 
      1.15073071065298605e-13*V03*V07*V14 + 3.64577550958467795e-14*V02*V08*V14 + 1.18950180456313298e-14*V01*V09*V14 - 
      1.19600364870750189e-16*V12*V14 + 9.71062538507498948e-14*V013*V02*V15 - 
      2.85947268917745482e-13*V022*V03*V15 - 3.0871699887519981e-13*V01*V032*V15 - 
      3.55411636751721068e-13*V01*V02*V04*V15 - 9.56295552285267934e-14*V012*V05*V15 + 
      7.69887767065883574e-14*V04*V05*V15 + 5.59914492163303378e-14*V03*V06*V15 + 2.09270410588993816e-14*V02*V07*V15 + 
      7.37375232850873924e-15*V01*V08*V15 - 9.76340983082182663e-17*V11*V15 + 3.23687512835832983e-15*V014*V16 - 
      1.39609618717725926e-14*V023*V16 - 1.05698917519649446e-13*V01*V02*V03*V16 - 
      3.08646430976438706e-14*V012*V04*V16 + 1.21795591493021946e-14*V042*V16 + 
      2.33127207864400535e-14*V03*V05*V16 + 9.39590908722569e-15*V02*V06*V16 + 3.91432583953079108e-15*V01*V07*V16 - 
      6.8486373534522317e-17*V10*V16 - 8.15973999748765058e-15*V01*V022*V17 - 
      8.26669761042470843e-15*V012*V03*V17 + 7.12626876408814967e-15*V03*V04*V17 + 
      3.78036522690319113e-15*V02*V05*V17 + 1.69613932127181637e-15*V01*V06*V17 - 4.21126985370719144e-17*V09*V17 - 
      1.28067668122003484e-15*V012*V02*V18 + 9.60189184686046794e-16*V032*V18 + 
      1.05979178633247677e-15*V02*V04*V18 + 6.29005926858352959e-16*V01*V05*V18 - 2.19183431885879037e-17*V08*V18 - 
      5.62934804931883448e-17*V013*V19 + 2.81701958634663342e-16*V02*V03*V19 + 1.73672088926306661e-16*V01*V04*V19 - 
      9.96873024851350019e-18*V07*V19 + 1.85321711972813694e-17*V022*V20 + 4.17241916131655518e-17*V01*V03*V20 - 
      3.6971583673871015e-18*V06*V20 + 5.61594483967759916e-18*V01*V02*V21 - 1.20219344254302358e-18*V05*V21 + 
      3.61886660313353645e-19*V012*V22 - 2.88913630044405791e-19*V04*V22 - 6.29206230380213642e-20*V03*V23 - 
      7.44622757846406677e-21*V02*V24 - 9.30778447308008347e-22*V01*V25 + 8.02395213196558919e-25*V28) + 
   delta2*eps13*(6.26037729789820904e-8*V025*V032 + 
      4.32286855970912927e-7*V01*V023*V033 + 2.65611018375665901e-7*V012*V02*V034 - 
      1.0056479547259229e-8*V036 + 6.86627585651083939e-9*V026*V04 + 
      3.95802566746899341e-7*V01*V024*V03*V04 + 1.07162878384648343e-6*V012*V022*V032*V04 + 
      1.78563679745402434e-7*V013*V033*V04 - 2.00100852048114414e-7*V02*V034*V04 + 
      2.40940930801944652e-7*V012*V023*V042 + 
      3.71028688605719418e-7*V013*V02*V03*V042 - 3.786789464730803e-7*V022*V032*V042 - 
      2.36280973326511114e-7*V01*V033*V042 + 1.49288633236900044e-8*V014*V043 - 
      4.47785160224899766e-8*V023*V043 - 3.11478549885343524e-7*V01*V02*V03*V043 - 
      2.30545145737442503e-8*V012*V044 + 2.19249275444418889e-9*V045 + 
      3.75622637873892542e-8*V01*V025*V05 + 3.80256762866230264e-7*V012*V023*V03*V05 + 
      2.93511920167790849e-7*V013*V02*V032*V05 - 2.22910418782730152e-7*V022*V033*V05 - 
      9.93600987223710436e-8*V01*V034*V05 + 2.03066187598021165e-7*V013*V022*V04*V05 + 
      7.068880712087995e-8*V014*V03*V04*V05 - 2.71181513017230613e-7*V023*V03*V04*V05 - 
      7.99658959096722232e-7*V01*V02*V032*V04*V05 - 2.55860711226782637e-7*V01*V022*V042*V05 - 
      2.29459772380387721e-7*V012*V03*V042*V05 + 4.01679166923128863e-8*V03*V043*V05 + 
      1.93668779267081088e-8*V014*V02*V052 - 1.77379742813162922e-8*V024*V052 - 
      2.22534401542033469e-7*V01*V022*V03*V052 - 9.521874323339043e-8*V012*V032*V052 - 
      1.29568314594432361e-7*V012*V02*V04*V052 + 5.27035762312654575e-8*V032*V04*V052 + 
      3.38001761885005644e-8*V02*V042*V052 - 6.53865642029561654e-9*V013*V053 + 
      1.99735057415167033e-8*V02*V03*V053 + 1.22479913352590455e-8*V01*V04*V053 + 
      4.23093812467791226e-8*V012*V024*V06 + 1.33534491939312201e-7*V013*V022*V03*V06 + 
      2.31786657294360376e-8*V014*V032*V06 - 9.86821340376802218e-8*V023*V032*V06 - 
      1.87628983514970859e-7*V01*V02*V033*V06 + 3.22085884826606115e-8*V014*V02*V04*V06 - 
      2.54812550973248439e-8*V024*V04*V06 - 3.66514117038712385e-7*V01*V022*V03*V04*V06 - 
      1.5958495148039661e-7*V012*V032*V04*V06 - 1.08852043899466103e-7*V012*V02*V042*V06 + 
      4.34041600832955616e-8*V032*V042*V06 + 1.77200747105181666e-8*V02*V043*V06 + 
      2.28056978100745608e-9*V015*V05*V06 - 6.60077636103449389e-8*V01*V023*V05*V06 - 
      1.80647912983891509e-7*V012*V02*V03*V05*V06 + 2.51194422978490909e-8*V033*V05*V06 - 
      3.3036760746107917e-8*V013*V04*V05*V06 + 9.79806517215620028e-8*V02*V03*V04*V05*V06 + 
      3.04115383559460582e-8*V01*V042*V05*V06 + 1.36283104170069822e-8*V022*V052*V06 + 
      2.61204247533627771e-8*V01*V03*V052*V06 - 2.11807889001744888e-8*V012*V022*V062 - 
      1.1333556656753781e-8*V013*V03*V062 + 1.76746991456447859e-8*V02*V032*V062 + 
      1.06677036842741399e-8*V022*V04*V062 + 2.1702681959296302e-8*V01*V03*V04*V062 + 
      1.23289861151022954e-8*V01*V02*V05*V062 - 7.90901730498100935e-10*V052*V062 + 
      8.69955863714949038e-10*V012*V063 - 4.28930339326720835e-10*V04*V063 + 
      1.7269235611954644e-8*V013*V023*V07 + 1.80196135531394635e-8*V014*V02*V03*V07 - 
      1.8548270418758121e-8*V024*V03*V07 - 1.13948565609417724e-7*V01*V022*V032*V07 - 
      3.20680607512308394e-8*V012*V033*V07 + 1.61914634735012886e-9*V015*V04*V07 - 
      4.7288839506620564e-8*V01*V023*V04*V07 - 1.31384056746108091e-7*V012*V02*V03*V04*V07 + 
      1.83196164302877053e-8*V033*V04*V07 - 1.2047569175203672e-8*V013*V042*V07 + 
      3.54792234131722972e-8*V02*V03*V042*V07 + 7.37777134042991446e-9*V01*V043*V07 - 
      3.66318637990656579e-8*V012*V022*V05*V07 - 1.96262914574951561e-8*V013*V03*V05*V07 + 
      3.1297380532310738e-8*V02*V032*V05*V07 + 1.96511394126519307e-8*V022*V04*V05*V07 + 
      3.81400923195861699e-8*V01*V03*V04*V05*V07 + 1.08726304366174659e-8*V01*V02*V052*V07 - 
      4.66805721270364971e-10*V053*V07 - 9.37224948779954554e-9*V013*V02*V06*V07 + 
      1.43114854589958633e-8*V022*V03*V06*V07 + 1.35332733566607584e-8*V01*V032*V06*V07 + 
      1.79211033285429649e-8*V01*V02*V04*V06*V07 + 4.55414833979787922e-9*V012*V05*V06*V07 - 
      2.30576331233322882e-9*V04*V05*V06*V07 - 8.32632663866097855e-10*V03*V062*V07 - 
      3.56422123491067297e-10*V014*V072 + 9.38987455031989622e-10*V023*V072 + 
      5.64466615821918792e-9*V01*V02*V03*V072 + 1.66530240177509072e-9*V012*V04*V072 - 
      4.19734176015411067e-10*V042*V072 - 7.36328011081932439e-10*V03*V05*V072 - 
      3.45983715856640743e-10*V02*V06*V072 - 4.59703508778850503e-11*V01*V073 + 
      3.03321094528202371e-9*V014*V022*V08 - 1.04471088085659645e-9*V025*V08 + 
      7.83763996080172551e-10*V015*V03*V08 - 2.63937953457177631e-8*V01*V023*V03*V08 - 
      3.50566928973522331e-8*V012*V02*V032*V08 + 2.53313431522826346e-9*V034*V08 - 
      2.36319893513054495e-8*V012*V022*V04*V08 - 1.26474364551414176e-8*V013*V03*V04*V08 + 
      1.9953363374100479e-8*V02*V032*V04*V08 + 5.99519201575933914e-9*V022*V042*V08 + 
      1.22625520447323922e-8*V01*V03*V042*V08 - 7.16912037204157159e-9*V013*V02*V05*V08 + 
      1.11541958989999938e-8*V022*V03*V05*V08 + 1.04698608963253418e-8*V01*V032*V05*V08 + 
      1.39123975502834464e-8*V01*V02*V04*V05*V08 + 1.75830385152653858e-9*V012*V052*V08 - 
      8.97418632544638092e-10*V04*V052*V08 - 6.29395016672954164e-10*V014*V06*V08 + 
      1.5886748524893385e-9*V023*V06*V08 + 9.94336310560763942e-9*V01*V02*V03*V06*V08 + 
      2.94820165189933703e-9*V012*V04*V06*V08 - 7.29384657133766073e-10*V042*V06*V08 - 
      1.29495456392085736e-9*V03*V05*V06*V08 - 3.00324904831965124e-10*V02*V062*V08 + 
      2.02862826846065116e-9*V01*V022*V07*V08 + 1.80786199791238447e-9*V012*V03*V07*V08 - 
      9.45167289704024987e-10*V03*V04*V07*V08 - 5.39343867628521465e-10*V02*V05*V07*V08 - 
      2.43084042759038705e-10*V01*V06*V07*V08 + 3.35452430689708632e-10*V012*V02*V082 - 
      1.32292084412831336e-10*V032*V082 - 1.70110732268529292e-10*V02*V04*V082 - 
      9.43311982681580721e-11*V01*V05*V082 + 8.21637941907666639e-13*V083 + 
      2.3114395816601699e-10*V015*V02*V09 - 1.95942959641549458e-9*V01*V024*V09 - 
      1.1279391898141591e-8*V012*V022*V03*V09 - 2.96983274530447457e-9*V013*V032*V09 + 
      3.3499775104416207e-9*V02*V033*V09 - 4.14151236512458962e-9*V013*V02*V04*V09 + 
      6.37297699327406587e-9*V022*V03*V04*V09 + 6.07421868620520999e-9*V01*V032*V04*V09 + 
      4.0048526338949564e-9*V01*V02*V042*V09 - 4.30909278909142232e-10*V014*V05*V09 + 
      1.1596879253737509e-9*V023*V05*V09 + 6.93903765995887209e-9*V01*V02*V03*V05*V09 + 
      2.04341393515044019e-9*V012*V04*V05*V09 - 5.1850245911125742e-10*V042*V05*V09 - 
      4.54321365784394465e-10*V03*V052*V09 + 1.6067111920432139e-9*V01*V022*V06*V09 + 
      1.43643437206426077e-9*V012*V03*V06*V09 - 7.49981534908386298e-10*V03*V04*V06*V09 - 
      4.27517072375866469e-10*V02*V05*V06*V09 - 9.65503667363073166e-11*V01*V062*V09 + 
      6.02020936065519019e-10*V012*V02*V07*V09 - 2.38718295375480113e-10*V032*V07*V09 - 
      3.10667159008854608e-10*V02*V04*V07*V09 - 1.70043575180262805e-10*V01*V05*V07*V09 + 
      6.09077193529588257e-11*V013*V08*V09 - 1.75696170557529793e-10*V02*V03*V08*V09 - 
      1.09663819995065411e-10*V01*V04*V08*V09 + 4.46497234172275058e-12*V07*V08*V09 - 
      1.42528415799870108e-11*V022*V092 - 2.74113180136972269e-11*V01*V03*V092 + 
      1.77303866649813176e-12*V06*V092 + 6.19926324583187328e-12*V016*V10 - 
      1.08013598211852221e-9*V012*V023*V10 - 1.75570881426551545e-9*V013*V02*V03*V10 + 
      1.47307460970132083e-9*V022*V032*V10 + 9.04896052257042606e-10*V01*V033*V10 - 
      2.24642833193929071e-10*V014*V04*V10 + 5.75877358442485548e-10*V023*V04*V10 + 
      3.63624248841115733e-9*V01*V02*V03*V04*V10 + 5.39568743006184196e-10*V012*V042*V10 - 
      8.93783511579785148e-11*V043*V10 + 1.02043843621241647e-9*V01*V022*V05*V10 + 
      9.04205048358374603e-10*V012*V03*V05*V10 - 4.77151607123061347e-10*V03*V04*V05*V10 - 
      1.36304962154936436e-10*V02*V052*V10 + 4.34684552305441662e-10*V012*V02*V06*V10 - 
      1.71766859580324334e-10*V032*V06*V10 - 2.20617707752033349e-10*V02*V04*V06*V10 - 
      1.22486998470881226e-10*V01*V05*V06*V10 + 4.96346324840088191e-11*V013*V07*V10 - 
      1.4373321721592951e-10*V02*V03*V07*V10 - 8.96259820389039816e-11*V01*V04*V07*V10 + 
      1.82594934724659227e-12*V072*V10 - 2.55378844470172402e-11*V022*V08*V10 - 
      4.97209607691980023e-11*V01*V03*V08*V10 + 3.20226136731066484e-12*V06*V08*V10 - 1.66424128279075483e-11*V01*V02*V09*V10 + 
      2.25874092088892671e-12*V05*V09*V10 - 1.12653412881304331e-12*V012*V102 + 
      5.92609032826688976e-13*V04*V102 - 2.35307874331137145e-10*V013*V022*V11 - 
      8.59390346579136569e-11*V014*V03*V11 + 2.56122800222029521e-10*V023*V03*V11 + 
      7.49755212651196611e-10*V01*V02*V032*V11 + 4.86471165308878208e-10*V01*V022*V04*V11 + 
      4.3713910750440046e-10*V012*V03*V04*V11 - 1.14780689171311559e-10*V03*V042*V11 + 
      2.50421907850127219e-10*V012*V02*V05*V11 - 1.00095716619238854e-10*V032*V05*V11 - 
      1.30555855138937328e-10*V02*V04*V05*V11 - 3.56124023162364183e-11*V01*V052*V11 + 
      3.28078102742084746e-11*V013*V06*V11 - 9.47291834291967603e-11*V02*V03*V06*V11 - 
      5.91897930748147892e-11*V01*V04*V06*V11 - 1.93856434348288081e-11*V022*V07*V11 - 
      3.72456668581856948e-11*V01*V03*V07*V11 + 2.41080199563574167e-12*V06*V07*V11 - 1.38343978742014259e-11*V01*V02*V08*V11 + 
      1.87750330278607734e-12*V05*V08*V11 - 2.06379980709586934e-12*V012*V09*V11 + 
      1.09092874076500041e-12*V04*V09*V11 + 5.0298800777905358e-13*V03*V10*V11 + 7.0070765338504517e-14*V02*V112 - 
      2.1208005841003777e-11*V014*V02*V12 + 1.43260393895278697e-11*V024*V12 + 
      1.87465703907169474e-10*V01*V022*V03*V12 + 8.15053018303082035e-11*V012*V032*V12 + 
      1.11649857489976707e-10*V012*V02*V04*V12 - 4.4564767919231618e-11*V032*V04*V12 - 
      2.84835600049112391e-11*V02*V042*V12 + 1.73871521984163422e-11*V013*V05*V12 - 
      5.10750075917268583e-11*V02*V03*V05*V12 - 3.17784325607582635e-11*V01*V04*V05*V12 - 
      1.16381576566694122e-11*V022*V06*V12 - 2.27141689369831666e-11*V01*V03*V06*V12 + 
      7.31381556139377256e-13*V062*V12 - 9.56832624987960252e-12*V01*V02*V07*V12 + 
      1.29918256119366774e-12*V05*V07*V12 - 1.58491086696809916e-12*V012*V08*V12 + 
      8.33446556463244752e-13*V04*V08*V12 + 4.25530730443919345e-13*V03*V09*V12 + 1.28805732732071082e-13*V02*V10*V12 + 
      3.43922679955297765e-14*V01*V11*V12 - 6.52554025877039293e-13*V015*V13 + 
      1.40670431381859411e-11*V01*V023*V13 + 3.87184829818105716e-11*V012*V02*V03*V13 - 
      5.32620413852048442e-12*V033*V13 + 7.21263636637434183e-12*V013*V04*V13 - 
      2.10052472792949051e-11*V02*V03*V04*V13 - 6.57704165621252631e-12*V01*V042*V13 - 
      5.91280120430917342e-12*V022*V05*V13 - 1.13084914015245695e-11*V01*V03*V05*V13 - 
      5.41157832841609232e-12*V01*V02*V06*V13 + 7.34867886046282007e-13*V05*V06*V13 - 
      1.01573925615648402e-12*V012*V07*V13 + 5.37612816248197697e-13*V04*V07*V13 + 
      3.03057183654965243e-13*V03*V08*V13 + 1.01567905899118282e-13*V02*V09*V13 + 2.94634403383630342e-14*V01*V10*V13 - 
      9.6568031213594039e-17*V132 + 4.23286160535418791e-12*V012*V022*V14 + 
      2.29364971595471251e-12*V013*V03*V14 - 3.55109930502696861e-12*V02*V032*V14 - 
      2.22905375128135736e-12*V022*V04*V14 - 4.3827866246146841e-12*V01*V03*V04*V14 - 
      2.52199778603470324e-12*V01*V02*V05*V14 + 1.71668370770168171e-13*V052*V14 - 
      5.38067360972162115e-13*V012*V06*V14 + 2.8277801582513226e-13*V04*V06*V14 + 1.81793451574552243e-13*V03*V07*V14 + 
      6.72568307750133747e-14*V02*V08*V14 + 2.16039025365449634e-14*V01*V09*V14 - 1.8004300704052234e-16*V12*V14 + 
      4.77762768945689482e-13*V013*V02*V15 - 7.24117615574366523e-13*V022*V03*V15 - 
      6.80930463628860136e-13*V01*V032*V15 - 9.12230925712573974e-13*V01*V02*V04*V15 - 
      2.33698865924940589e-13*V012*V05*V15 + 1.24464156570915188e-13*V04*V05*V15 + 
      9.00859793439058392e-14*V03*V06*V15 + 3.79980993329021327e-14*V02*V07*V15 + 1.3473894818080785e-14*V01*V08*V15 - 
      1.46461479103092518e-16*V11*V15 + 1.74791256931349811e-14*V014*V16 - 4.44825721573317806e-14*V023*V16 - 
      2.69225580940119444e-13*V01*V02*V03*V16 - 8.02978247680623291e-14*V012*V04*V16 + 
      2.11371564748402071e-14*V042*V16 + 3.71537976495766168e-14*V03*V05*V16 + 1.76383558236728567e-14*V02*V06*V16 + 
      7.13233371645080865e-15*V01*V07*V16 - 1.03218422065554138e-16*V10*V16 - 2.46324186786622714e-14*V01*V022*V17 - 
      2.1924300170650675e-14*V012*V03*V17 + 1.20094852636974912e-14*V03*V04*V17 + 6.92055462711326482e-15*V02*V05*V17 + 
      3.1493186613769601e-15*V01*V06*V17 - 6.31793794463729905e-17*V09*V17 - 3.90837593138421937e-15*V012*V02*V18 + 
      1.60247936770006911e-15*V032*V18 + 2.10075206311901791e-15*V02*V04*V18 + 1.16097764211777766e-15*V01*V05*V18 - 
      3.31561898500058733e-17*V08*V18 - 1.80943330156676823e-16*V013*V19 + 5.40568198843072007e-16*V02*V03*V19 + 
      3.39494923206464888e-16*V01*V04*V19 - 1.49634270135353692e-17*V07*V19 + 4.23206344422005235e-17*V022*V20 + 
      8.13491055162726215e-17*V01*V03*V20 - 5.65926592798230618e-18*V06*V20 + 1.25906400567354289e-17*V01*V02*V21 - 
      1.81362180457965426e-18*V05*V21 + 8.29323596551435437e-19*V012*V22 - 4.60735331417464132e-19*V04*V22 - 
      9.84298208028218827e-20*V03*V23 - 1.34032096412353202e-20*V02*V24 - 1.67540120515441502e-21*V01*V25 + 
      1.20359281979483838e-24*V28) + delta4*eps12*
    (1.20882353260258126e-8*V025*V032 + 1.04426097371018395e-7*V01*V023*V033 + 
      6.9719079284711093e-8*V012*V02*V034 - 7.23344550992912055e-9*V036 + 
      5.52620037914155561e-11*V026*V04 + 7.90326424631072416e-8*V01*V024*V03*V04 + 
      2.54323416726398753e-7*V012*V022*V032*V04 + 
      4.51281960847592656e-8*V013*V033*V04 - 1.324883216725678e-7*V02*V034*V04 + 
      5.06434542722669084e-8*V012*V023*V042 + 
      8.66226005370204717e-8*V013*V02*V03*V042 - 
      2.22409766088872341e-7*V022*V032*V042 - 1.53016681070112025e-7*V01*V033*V042 + 
      3.41313722134800566e-9*V014*V043 - 1.96395897468419557e-8*V023*V043 - 
      1.82156807683404165e-7*V01*V02*V03*V043 - 1.34927607259456209e-8*V012*V044 + 
      1.73105497543500998e-9*V045 + 7.25294119561548755e-9*V01*V025*V05 + 
      8.59807307885671175e-8*V012*V023*V03*V05 + 6.99591777342322005e-8*V013*V02*V032*V05 - 
      1.39049724059185477e-7*V022*V033*V05 - 6.57865723958235981e-8*V01*V034*V05 + 
      4.46305625278255997e-8*V013*V022*V04*V05 + 1.61950340242143074e-8*V014*V03*V04*V05 - 
      1.47756732055728671e-7*V023*V03*V04*V05 - 4.89030123593119722e-7*V01*V02*V032*V04*V05 - 
      1.38963331863418844e-7*V01*V022*V042*V05 - 1.37800085223021031e-7*V012*V03*V042*V05 + 
      3.44050669150184239e-8*V03*V043*V05 + 4.18302667587798307e-9*V014*V02*V052 - 
      9.04196340258141116e-9*V024*V052 - 1.28790956572407237e-7*V01*V022*V03*V052 - 
      5.83555802365083814e-8*V012*V032*V052 - 
      7.37360574267513578e-8*V012*V02*V04*V052 + 4.69398212292297161e-8*V032*V04*V052 + 
      2.73458931028917595e-8*V02*V042*V052 - 3.72952775189787807e-9*V013*V053 + 
      1.6958793336841598e-8*V02*V03*V053 + 1.02386762080878323e-8*V01*V04*V053 + 
      8.71170327812938561e-9*V012*V024*V06 + 2.89591202453743303e-8*V013*V022*V03*V06 + 
      5.14017324083364388e-9*V014*V032*V06 - 5.41574870492825955e-8*V023*V032*V06 - 
      1.13699493062326463e-7*V01*V02*V033*V06 + 6.72413420064563855e-9*V014*V02*V04*V06 - 
      1.03756170676674664e-8*V024*V04*V06 - 2.00346967720785699e-7*V01*V022*V03*V04*V06 - 
      9.4732859862585303e-8*V012*V032*V04*V06 - 5.95676145783665186e-8*V012*V02*V042*V06 + 
      3.73178531516166455e-8*V032*V042*V06 + 1.32159742949447015e-8*V02*V043*V06 + 
      4.60713500269600487e-10*V015*V05*V06 - 3.37780054041672907e-8*V01*V023*V05*V06 - 
      1.01912862830765567e-7*V012*V02*V03*V05*V06 + 2.23348100714193579e-8*V033*V05*V06 - 
      1.83126783282942847e-8*V013*V04*V05*V06 + 7.97301498466301465e-8*V02*V03*V04*V05*V06 + 
      2.45304974411087697e-8*V01*V042*V05*V06 + 1.04873740107954018e-8*V022*V052*V06 + 
      2.17844261436320787e-8*V01*V03*V052*V06 - 1.0911096004189193e-8*V012*V022*V062 - 
      6.19369308313955983e-9*V013*V03*V062 + 1.44345788288939075e-8*V02*V032*V062 + 
      7.52095144554799776e-9*V022*V04*V062 + 1.75328066449056264e-8*V01*V03*V04*V062 + 
      9.45427784090595249e-9*V01*V02*V05*V062 - 7.70529739619229361e-10*V052*V062 + 
      6.62001241850818438e-10*V012*V063 - 3.99981412133341695e-10*V04*V063 + 
      3.33215319513658294e-9*V013*V023*V07 + 3.57136603562257157e-9*V014*V02*V03*V07 - 
      8.94594528544603356e-9*V024*V03*V07 - 6.29789259431921199e-8*V01*V022*V032*V07 - 
      1.87936322738569965e-8*V012*V033*V07 + 3.09963162291593664e-10*V015*V04*V07 - 
      2.27966376917771864e-8*V01*V023*V04*V07 - 7.15304904904188209e-8*V012*V02*V03*V04*V07 + 
      1.59574377651104258e-8*V033*V04*V07 - 6.47274061062662212e-9*V013*V042*V07 + 
      2.80661408894938849e-8*V02*V03*V042*V07 + 5.79788133003006763e-9*V01*V043*V07 - 
      1.89350223704757276e-8*V012*V022*V05*V07 - 1.07012255785477306e-8*V013*V03*V05*V07 + 
      2.59524523300590123e-8*V02*V032*V05*V07 + 1.46388001108568292e-8*V022*V04*V05*V07 + 
      3.1127191581057809e-8*V01*V03*V04*V05*V07 + 8.45935591506244628e-9*V01*V02*V052*V07 - 
      4.60775985578051114e-10*V053*V07 - 4.74234229789098545e-9*V013*V02*V06*V07 + 
      1.07393279794729315e-8*V022*V03*V06*V07 + 1.10090898685328405e-8*V01*V032*V06*V07 + 
      1.33582456330230875e-8*V01*V02*V04*V06*V07 + 3.48362573500462324e-9*V012*V05*V06*V07 - 
      2.2032984342683328e-9*V04*V05*V06*V07 - 7.99139107397828057e-10*V03*V062*V07 - 
      1.73530910238513601e-10*V014*V072 + 6.40666703698504504e-10*V023*V072 + 
      4.27646404882137475e-9*V01*V02*V03*V072 + 1.2450965718386082e-9*V012*V04*V072 - 
      3.92905777070812353e-10*V042*V072 - 7.15578374379870009e-10*V03*V05*V072 - 
      3.09694258732338897e-10*V02*V06*V072 - 4.14768341729476862e-11*V01*V073 + 
      5.32251030106422263e-10*V014*V022*V08 - 3.7599196224330001e-10*V025*V08 + 
      1.39926227548776568e-10*V015*V03*V08 - 1.29607199114575347e-8*V01*V023*V03*V08 - 
      1.87787565822432913e-8*V012*V02*V032*V08 + 2.20249261839429827e-9*V034*V08 - 
      1.16240437448587649e-8*V012*V022*V04*V08 - 6.6443470413816776e-9*V013*V03*V04*V08 + 
      1.59373880158148374e-8*V02*V032*V04*V08 + 4.10863213632520728e-9*V022*V042*V08 + 
      9.69019621454820376e-9*V01*V03*V042*V08 - 3.59849807784135024e-9*V013*V02*V05*V08 + 
      8.42325230947116132e-9*V022*V03*V05*V08 + 8.51769281088870386e-9*V01*V032*V05*V08 + 
      1.04141439935135217e-8*V01*V02*V04*V05*V08 + 1.34401063281953465e-9*V012*V052*V08 - 
      8.61241971193464998e-10*V04*V052*V08 - 3.05016292273996891e-10*V014*V06*V08 + 
      1.02953600221241218e-9*V023*V06*V08 + 7.45566703073174797e-9*V01*V02*V03*V06*V08 + 
      2.19130998543030349e-9*V012*V04*V06*V08 - 6.6905946103917063e-10*V042*V06*V08 - 
      1.24720512530691495e-9*V03*V05*V06*V08 - 2.63072992129871742e-10*V02*V062*V08 + 
      1.39859646064307274e-9*V01*V022*V07*V08 + 1.34354140443118404e-9*V012*V03*V07*V08 - 
      8.93225254027936508e-10*V03*V04*V07*V08 - 4.85337063910672764e-10*V02*V05*V07*V08 - 
      2.17489322951947217e-10*V01*V06*V07*V08 + 2.30893271575664754e-10*V012*V02*V082 - 
      1.25747164684605609e-10*V032*V082 - 1.46299824985844711e-10*V02*V04*V082 - 
      8.46083818310006371e-11*V01*V05*V082 + 8.12672495620012848e-13*V083 + 
      3.66051734515786803e-11*V015*V02*V09 - 8.29133332629294245e-10*V01*V024*V09 - 
      5.47087570944765504e-9*V012*V022*V03*V09 - 1.51631914791537193e-9*V013*V032*V09 + 
      2.69669756136912825e-9*V02*V033*V09 - 1.98663118520845969e-9*V013*V02*V04*V09 + 
      4.61220388749224967e-9*V022*V03*V04*V09 + 4.80632079808038063e-9*V01*V032*V04*V09 + 
      2.88370634770292973e-9*V01*V02*V042*V09 - 2.05719876229253226e-10*V014*V05*V09 + 
      7.89190574074530246e-10*V023*V05*V09 + 5.22812950672100975e-9*V01*V02*V03*V05*V09 + 
      1.51791882925948914e-9*V012*V04*V05*V09 - 4.84854684995298139e-10*V042*V05*V09 - 
      4.40672046256432976e-10*V03*V052*V09 + 1.09662515229161045e-9*V01*V022*V06*V09 + 
      1.0613831516673568e-9*V012*V03*V06*V09 - 7.04914834356448994e-10*V03*V04*V06*V09 - 
      3.82230795717939654e-10*V02*V05*V06*V09 - 8.5942197180477207e-11*V01*V062*V09 + 
      4.14350377197574503e-10*V012*V02*V07*V09 - 2.27728148229236456e-10*V032*V07*V09 - 
      2.71296133326879144e-10*V02*V04*V07*V09 - 1.53009091405004201e-10*V01*V05*V07*V09 + 
      4.10498544838390642e-11*V013*V08*V09 - 1.55152746080081988e-10*V02*V03*V08*V09 - 
      9.59423029015289857e-11*V01*V04*V08*V09 + 4.44773535618112588e-12*V07*V08*V09 - 
      1.15555001237355942e-11*V022*V092 - 2.41257779299523541e-11*V01*V03*V092 + 
      1.75819821034290929e-12*V06*V092 + 8.8560903511883904e-13*V016*V10 - 
      4.7028558739918174e-10*V012*V023*V10 - 8.1843740245514698e-10*V013*V02*V03*V10 + 
      1.08025794505111839e-9*V022*V032*V10 + 7.1154440620899848e-10*V01*V033*V10 - 
      1.02649078820550699e-10*V014*V04*V10 + 3.57535624229162578e-10*V023*V04*V10 + 
      2.63925751474864757e-9*V01*V02*V03*V04*V10 + 3.88468872118375081e-10*V012*V042*V10 - 
      8.02194685956035236e-11*V043*V10 + 7.01148303994630507e-10*V01*V022*V05*V10 + 
      6.66210883791491801e-10*V012*V03*V05*V10 - 4.50711553031096479e-10*V03*V04*V05*V10 - 
      1.22690085869169305e-10*V02*V052*V10 + 2.96824185621000256e-10*V012*V02*V06*V10 - 
      1.62614166065059905e-10*V032*V06*V10 - 1.88755241645819331e-10*V02*V04*V06*V10 - 
      1.09389510016645682e-10*V01*V05*V06*V10 + 3.33774532149794918e-11*V013*V07*V10 - 
      1.27115440921079826e-10*V02*V03*V07*V10 - 7.84755984592965309e-11*V01*V04*V07*V10 + 
      1.82130306750850787e-12*V072*V10 - 2.04109508615751688e-11*V022*V08*V10 - 
      4.3660858041144564e-11*V01*V03*V08*V10 + 3.15711796440761009e-12*V06*V08*V10 - 1.35716438685426404e-11*V01*V02*V09*V10 + 
      2.25146259575764275e-12*V05*V09*V10 - 9.11392969230539979e-13*V012*V102 + 
      5.74360148619121813e-13*V04*V102 - 9.9642669201331482e-11*V013*V022*V11 - 
      3.77898697485578291e-11*V014*V03*V11 + 1.68168394627053444e-10*V023*V03*V11 + 
      5.43769172804245806e-10*V01*V02*V032*V11 + 3.18163757684645535e-10*V01*V022*V04*V11 + 
      3.12142097152999357e-10*V012*V03*V04*V11 - 1.05468421638837286e-10*V03*V042*V11 + 
      1.70517703181524832e-10*V012*V02*V05*V11 - 9.51761282987384297e-11*V032*V05*V11 - 
      1.13828360332427639e-10*V02*V04*V05*V11 - 3.19184559893581372e-11*V01*V052*V11 + 
      2.1895471877193824e-11*V013*V06*V11 - 8.30677175300375597e-11*V02*V03*V06*V11 - 
      5.1450365942944162e-11*V01*V04*V06*V11 - 1.57105521096675428e-11*V022*V07*V11 - 
      3.27396475996945943e-11*V01*V03*V07*V11 + 2.39040097981453856e-12*V06*V07*V11 - 1.12578722185719423e-11*V01*V02*V08*V11 + 
      1.8688161409045364e-12*V05*V08*V11 - 1.66948591790450449e-12*V012*V09*V11 + 1.06199280278071825e-12*V04*V09*V11 + 
      4.9427418823354929e-13*V03*V10*V11 + 6.40281712049283203e-14*V02*V112 - 
      8.50650783732569078e-12*V014*V02*V12 + 7.98040773312985024e-12*V024*V12 + 
      1.23857732036580147e-10*V01*V022*V03*V12 + 5.74712727968812932e-11*V012*V032*V12 + 
      7.32396637436056347e-11*V012*V02*V04*V12 - 4.12875645130824172e-11*V032*V04*V12 - 
      2.37244082451593395e-11*V02*V042*V12 + 1.15172641174315601e-11*V013*V05*V12 - 
      4.50673354173006439e-11*V02*V03*V05*V12 - 2.77261980520601875e-11*V01*V04*V05*V12 - 
      9.22551319763251332e-12*V022*V06*V12 - 1.98248863022593421e-11*V01*V03*V06*V12 + 
      7.17967666041412286e-13*V062*V12 - 7.79601827328047531e-12*V01*V02*V07*V12 + 
      1.29534634912714369e-12*V05*V07*V12 - 1.28004691923030537e-12*V012*V08*V12 + 
      8.06898150216084409e-13*V04*V08*V12 + 4.18311280199754674e-13*V03*V09*V12 + 1.17212660295230542e-13*V02*V10*V12 + 
      3.14292422906541054e-14*V01*V11*V12 - 2.44707759703889735e-13*V015*V13 + 
      8.29470830809344407e-12*V01*V023*V13 + 2.51527855599340736e-11*V012*V02*V03*V13 - 
      4.95163469108411185e-12*V033*V13 + 4.62128662075718749e-12*V013*V04*V13 - 
      1.79399282081407719e-11*V02*V03*V04*V13 - 5.57203912826001651e-12*V01*V042*V13 - 
      4.78132194911426031e-12*V022*V05*V13 - 9.8862445917739025e-12*V01*V03*V05*V13 - 
      4.36794692598014939e-12*V01*V02*V06*V13 + 7.28040642889289817e-13*V05*V06*V13 - 
      8.19479307658213228e-13*V012*V07*V13 + 5.23260039465917009e-13*V04*V07*V13 + 
      2.97359507159829527e-13*V03*V08*V13 + 9.28014863712321666e-14*V02*V09*V13 + 2.69121310061478652e-14*V01*V10*V13 - 
      9.65673331297585579e-17*V132 + 2.51116772458039228e-12*V012*V022*V14 + 
      1.44008574460662094e-12*V013*V03*V14 - 3.06151557533819164e-12*V02*V032*V14 - 
      1.7112000522365447e-12*V022*V04*V14 - 3.72993907514810658e-12*V01*V03*V04*V14 - 
      2.0446358065653108e-12*V01*V02*V05*V14 + 1.70985078442690671e-13*V052*V14 - 
      4.31254469191205498e-13*V012*V06*V14 + 2.72387093882243787e-13*V04*V06*V14 + 1.7864407249719243e-13*V03*V07*V14 + 
      6.10919899771084163e-14*V02*V08*V14 + 1.97384141183837402e-14*V01*V09*V14 - 1.79826806083139243e-16*V12*V14 + 
      2.767528234746372e-13*V013*V02*V15 - 5.713527912711336e-13*V022*V03*V15 - 
      5.7875508238377094e-13*V01*V032*V15 - 7.14478161232486493e-13*V01*V02*V04*V15 - 
      1.87009153727962485e-13*V012*V05*V15 + 1.21020252115635927e-13*V04*V05*V15 + 
      8.79582868294079383e-14*V03*V06*V15 + 3.47072260237016761e-14*V02*V07*V15 + 1.22859180855419439e-14*V01*V08*V15 - 
      1.46460082935421556e-16*V11*V15 + 9.71062538507498948e-15*V014*V16 - 3.12672755152665796e-14*V023*V16 - 
      2.11989988841248669e-13*V01*V02*V03*V16 - 6.25139100876856569e-14*V012*V04*V16 + 
      1.99525674035381883e-14*V042*V16 + 3.64406463725905885e-14*V03*V05*V16 + 1.59224099093537048e-14*V02*V06*V16 + 
      6.50930227029003634e-15*V01*V07*V16 - 1.03053420431713173e-16*V10*V16 - 1.77282243443173395e-14*V01*V022*V17 - 
      1.69492633079928458e-14*V012*V03*V17 + 1.14998784791256728e-14*V03*V04*V17 + 
      6.31266880784708842e-15*V02*V05*V17 + 2.85571297717967464e-15*V01*V06*V17 - 6.31779832787020285e-17*V09*V17 - 
      2.80060065453612015e-15*V012*V02*V18 + 1.54455237103185521e-15*V032*V18 + 
      1.85252462056333978e-15*V02*V04*V18 + 1.05585459350036389e-15*V01*V05*V18 - 3.30612504483804565e-17*V08*V18 - 
      1.26660331109673776e-16*V013*V19 + 4.84358488410141383e-16*V02*V03*V19 + 3.01170120638557645e-16*V01*V04*V19 - 
      1.49620308458644072e-17*V07*V19 + 3.4680804946696391e-17*V022*V20 + 7.2377332062670729e-17*V01*V03*V20 - 
      5.61937542309767725e-18*V06*V20 + 1.04042414840089173e-17*V01*V02*V21 - 1.81222563690869225e-18*V05*V21 + 
      6.78537488087538085e-19*V012*V22 - 4.49565990049768031e-19*V04*V22 - 9.70336531318598701e-20*V03*V23 - 
      1.22862755044657102e-20*V02*V24 - 1.53578443805821377e-21*V01*V25 + 1.20359281979483838e-24*V28) + 
   1.13099628864477169e-31*delta28*V28 + 7.91697402051340185e-31*delta26*eps*V28 + 
   delta26*eps2*(-4.94047679986510124e-25*V142 - 1.05867359997109312e-24*V13*V15 - 
      7.47299011744301028e-25*V12*V16 - 6.07180447042244585e-25*V11*V17 - 3.19568656338023466e-25*V10*V18 - 
      1.9529195665101434e-25*V09*V19 - 7.4396935867053082e-26*V08*V20 - 3.34786211401738869e-26*V07*V21 - 
      8.73355334091492701e-27*V06*V22 - 2.77885788120020405e-27*V05*V23 - 4.44617260992032648e-28*V04*V24 - 
      9.26285960400068017e-29*V03*V25 - 6.86137748444494827e-30*V02*V26 - 7.91697402051340185e-31*V01*V27 + 
      6.38465646815596924e-33*V30) + delta24*eps3*
    (-6.42261983982463161e-24*V142 - 1.37627567996242106e-23*V13*V15 - 9.71488715267591336e-24*V12*V16 - 
      7.8933458115491796e-24*V11*V17 - 4.15439253239430505e-24*V10*V18 - 2.53879543646318642e-24*V09*V19 - 
      9.67160166271690066e-25*V08*V20 - 4.3522207482226053e-25*V07*V21 - 1.13536193431894051e-25*V06*V22 - 
      3.61251524556026527e-26*V05*V23 - 5.78002439289642442e-27*V04*V24 - 1.20417174852008842e-27*V03*V25 - 
      8.91979072977843275e-29*V02*V26 - 1.02920662266674224e-29*V01*V27 + 4.15002670430138e-32*V30) + 
   delta22*eps4*(5.50715506077594399e-19*V08*V092 + 3.5340032475567555e-19*V082*V10 + 
      8.9528082271437806e-19*V07*V09*V10 + 2.16553315883834953e-19*V06*V102 + 7.20936662501578122e-19*V07*V08*V11 + 
      5.43563356648015251e-19*V06*V09*V11 + 3.41834495945489805e-19*V05*V10*V11 + 6.94815768932680364e-20*V04*V112 + 
      2.45857887468486898e-19*V072*V12 + 2.92599934817490315e-19*V06*V08*V12 + 2.86834202046568048e-19*V05*V09*V12 + 
      9.28707543611102179e-20*V04*V10*V12 + 5.21516730993760087e-20*V03*V11*V12 + 3.55319091446298081e-21*V02*V122 + 
      2.50875395376007039e-19*V06*V07*V13 + 1.94098332211963341e-19*V05*V08*V13 + 9.79868392084549231e-20*V04*V09*V13 + 
      4.3824935377626898e-20*V03*V10*V13 + 8.9402868170358872e-21*V02*V11*V13 + 2.0058335807452311e-21*V01*V12*V13 + 
      4.36137225807519929e-20*V062*V14 + 1.13472871139301645e-19*V05*V07*V14 + 4.51814177991727375e-20*V04*V08*V14 + 
      3.15202419831393459e-20*V03*V09*V14 + 5.11740399255674086e-21*V02*V10*V14 + 1.71928592635305523e-21*V01*V11*V14 - 
      5.30277843185520866e-23*V142 + 5.01750790752014078e-20*V05*V06*V15 + 3.35954877286131165e-20*V04*V07*V15 + 
      1.84855554487584134e-20*V03*V08*V15 + 4.68300738035213139e-21*V02*V09*V15 + 1.25214101078933994e-21*V01*V10*V15 - 
      1.11925325596943901e-22*V13*V15 + 9.86061045996605206e-21*V052*V16 + 1.01400090053859715e-20*V04*V06*V16 + 
      9.39105758092004958e-21*V03*V07*V16 + 1.87425738667625411e-21*V02*V08*V16 + 7.82588131743337465e-22*V01*V09*V16 - 
      8.04107575507455763e-23*V12*V16 + 5.18753854632996652e-21*V04*V05*V17 + 3.68934404964716234e-21*V03*V06*V17 + 
      1.23961960068144654e-21*V02*V07*V17 + 4.07769605487317942e-22*V01*V08*V17 - 6.45185445394148042e-23*V11*V17 + 
      4.57805102972235216e-22*V042*V18 + 1.26861655040498915e-21*V03*V05*V18 + 3.26733487063489043e-22*V02*V06*V18 + 
      1.81230935772141308e-22*V01*V07*V18 - 3.46436095222738772e-23*V10*V18 + 3.03364827270758276e-22*V03*V04*V19 + 
      1.52233986048598698e-22*V02*V05*V19 + 6.47253342043361813e-23*V01*V06*V19 - 2.09613366805422058e-23*V09*V19 + 
      3.23626671021680907e-23*V032*V20 + 2.33686597927307674e-23*V02*V04*V20 + 1.94176002613008544e-23*V01*V05*V20 - 
      8.16506371140907575e-24*V08*V20 + 7.24923743088565231e-24*V02*V03*V21 + 4.33378324672511823e-24*V01*V04*V21 - 
      3.64730978088227734e-24*V07*V21 + 2.36388177094097358e-25*V022*V22 + 7.8796059031365786e-25*V01*V03*V22 - 
      9.74923324796947779e-25*V06*V22 + 8.59593371251263119e-26*V01*V02*V23 - 3.08710526468889335e-25*V05*V23 + 
      3.581639046880263e-27*V012*V24 - 5.07069518855450567e-26*V04*V24 - 1.05390758161074405e-26*V03*V25 - 
      8.02781165680058948e-28*V02*V26 - 9.26285960400068017e-29*V01*V27 + 2.490016022580828e-31*V30) + 
   delta20*eps5*(7.98537483812511878e-18*V08*V092 + 5.34812491463588999e-18*V082*V10 + 
      1.30095494550683062e-17*V07*V09*V10 + 3.27882067539551445e-18*V06*V102 + 1.04535816062728828e-17*V07*V08*V11 + 
      7.86807958748002075e-18*V06*V09*V11 + 4.96728251920789872e-18*V05*V10*V11 + 1.00432461145723798e-18*V04*V112 + 
      3.58250064596938051e-18*V072*V12 + 4.43336435533937491e-18*V06*V08*V12 + 4.17958408696427727e-18*V05*V09*V12 + 
      1.40838098847909328e-18*V04*V10*V12 + 7.59924379448050412e-19*V03*V11*V12 + 5.39855780874859342e-20*V02*V122 + 
      3.63142134806770189e-18*V06*V07*V13 + 2.81442581707346844e-18*V05*V08*V13 + 1.41635522128584843e-18*V04*V09*V13 + 
      6.36831092206140862e-19*V03*V10*V13 + 1.29075390920955621e-19*V02*V11*V13 + 2.92278607480019389e-20*V01*V12*V13 + 
      6.62311043792658582e-19*V062*V14 + 1.65954074041228656e-18*V05*V07*V14 + 6.86376711010421088e-19*V04*V08*V14 + 
      4.60983539003412934e-19*V03*V09*V14 + 7.78330852306653709e-20*V02*V10*V14 + 2.51445566729134328e-20*V01*V11*V14 - 
      3.45092304470577321e-22*V142 + 7.26284269613540377e-19*V05*V06*V15 + 4.8560750444086232e-19*V04*V07*V15 + 
      2.68040554006996994e-19*V03*V08*V15 + 6.7610919053833897e-20*V02*V09*V15 + 1.81951740630325961e-20*V01*V10*V15 - 
      7.11340436380576987e-22*V13*V15 + 1.44950973761500965e-19*V052*V16 + 1.54647969833178317e-19*V04*V06*V16 + 
      1.38048546439524729e-19*V03*V07*V16 + 2.86041728591055321e-20*V02*V08*V16 + 1.15040455366270607e-20*V01*V09*V16 - 
      5.25299309491539157e-22*V12*V16 + 7.49835117151331524e-20*V04*V05*V17 + 5.34032551186426748e-20*V03*V06*V17 + 
      1.78970079848383845e-20*V02*V07*V17 + 5.91265927956611016e-21*V01*V08*V17 - 4.13354955447536952e-22*V11*V17 + 
      7.0325482685493964e-21*V042*V18 + 1.87913826528739018e-20*V03*V05*V18 + 5.02061472356194891e-21*V02*V06*V18 + 
      2.68448323612484312e-21*V01*V07*V18 - 2.28882173194988807e-22*V10*V18 + 4.38500068509550599e-21*V03*V04*V19 + 
      2.19787817357664371e-21*V02*V05*V19 + 9.36899212607766225e-22*V01*V06*V19 - 1.36411431720733517e-22*V09*V19 + 
      4.8544000653252136e-22*V032*V20 + 3.63767634808230963e-22*V02*V04*V20 + 2.91264003919512816e-22*V01*V05*V20 - 
      5.49328375208353194e-23*V08*V20 + 1.04660865408411605e-22*V02*V03*V21 + 6.26428669299357998e-23*V01*V04*V21 - 
      2.42747902117210825e-23*V07*V21 + 3.78221083350555773e-24*V022*V22 + 1.21148940760724896e-23*V01*V03*V22 - 
      6.71949890101837912e-24*V06*V22 + 1.24103792974401113e-24*V01*V02*V23 - 2.11339860914945519e-24*V05*V23 + 
      5.90970442735243395e-26*V012*V24 - 3.59812693697538421e-25*V04*V24 - 7.45505817128654742e-26*V03*V25 - 
      5.88706188165376562e-27*V02*V26 - 6.79276370960049879e-28*V01*V27 + 1.3695088124194554e-30*V30) + 
   delta18*eps6*(-4.48616519584018787e-16*V064 - 8.94203167249278406e-15*V05*V062*V07 - 
      4.68756430676455096e-15*V052*V072 - 5.97195093749807253e-15*V04*V06*V072 - 
      1.47936203145323831e-15*V03*V073 - 6.90101777365995919e-15*V052*V06*V08 - 
      2.77113458677757312e-15*V04*V062*V08 - 9.26081661527549284e-15*V04*V05*V07*V08 - 
      6.57239787967615161e-15*V03*V06*V07*V08 - 1.10332073076130262e-15*V02*V072*V08 - 
      7.12558774566068427e-16*V042*V082 - 2.52308041457366025e-15*V03*V05*V082 - 
      5.05380902678429376e-16*V02*V06*V082 - 3.60440059224808607e-16*V01*V07*V082 - 
      1.81221848853021693e-15*V053*V09 - 6.96727609374775129e-15*V04*V05*V06*V09 - 
      2.48389768680355113e-15*V03*V062*V09 - 2.31331611781168147e-15*V042*V07*V09 - 
      5.14232352504223456e-15*V03*V05*V07*V09 - 1.65069972803369648e-15*V02*V06*V07*V09 - 
      3.62588733199323114e-16*V01*V072*V09 - 2.57244905979874801e-15*V03*V04*V08*V09 - 
      1.28720751922151973e-15*V02*V05*V08*V09 - 5.47699823306345967e-16*V01*V06*V08*V09 - 
      3.50880726819000322e-16*V032*V092 - 3.16781136756807561e-16*V02*V04*V092 - 
      2.0925186629108305e-16*V01*V05*V092 + 6.47900595385405175e-17*V08*V092 - 
      2.18878336926376849e-15*V04*V052*V10 - 8.67705487992327205e-16*V042*V06*V10 - 
      3.09080814108455986e-15*V03*V05*V06*V10 - 3.07417181543249318e-16*V02*V062*V10 - 
      2.08455558977501761e-15*V03*V04*V07*V10 - 1.04794169938382275e-15*V02*V05*V07*V10 - 
      4.41544020154937123e-16*V01*V06*V07*V10 - 5.60676683231374374e-16*V032*V08*V10 - 
      3.15013122383262073e-16*V02*V04*V08*V10 - 3.36406009938824624e-16*V01*V05*V08*V10 + 
      4.59978794695492182e-17*V082*V10 - 2.91094916495506318e-16*V02*V03*V09*V10 - 
      1.73712965814584801e-16*V01*V04*V09*V10 + 1.05912840428139317e-16*V07*V09*V10 - 
      8.56483107862193025e-18*V022*V102 - 3.67972626510464579e-17*V01*V03*V102 + 
      2.83060212558496971e-17*V06*V102 - 8.83266154073551106e-16*V042*V05*V11 - 
      9.69100796005463596e-16*V03*V052*V11 - 1.26677747159050023e-15*V03*V04*V06*V11 - 
      6.30267168885593203e-16*V02*V05*V06*V11 - 1.35485328371102789e-16*V01*V062*V11 - 
      4.56549526453272109e-16*V032*V07*V11 - 4.14695306299820807e-16*V02*V04*V07*V11 - 
      2.71996429415012383e-16*V01*V05*V07*V11 - 2.34037730767549042e-16*V02*V03*V08*V11 - 
      1.40315403261749892e-16*V01*V04*V08*V11 + 8.51383790375393081e-17*V07*V08*V11 - 
      2.78422604550881203e-17*V022*V09*V11 - 7.30794763610125791e-17*V01*V03*V09*V11 + 
      6.41281743874469234e-17*V06*V09*V11 - 1.58779045361185265e-17*V01*V02*V10*V11 + 4.07445354511027254e-17*V05*V10*V11 - 
      8.90066848916775158e-19*V012*V112 + 8.2559002258536699e-18*V04*V112 - 
      6.07146609342992803e-17*V043*V12 - 6.61813833733044596e-16*V03*V04*V05*V12 - 
      1.67205415189365619e-16*V02*V052*V12 - 2.31855790198954275e-16*V032*V06*V12 - 
      1.28577657496500636e-16*V02*V04*V06*V12 - 1.39113474119372565e-16*V01*V05*V06*V12 - 
      1.59243252561300589e-16*V02*V03*V07*V12 - 9.45448333904349422e-17*V01*V04*V07*V12 + 
      2.93874473238087814e-17*V072*V12 - 1.14938253020557183e-17*V022*V08*V12 - 
      4.96896749165462919e-17*V01*V03*V08*V12 + 3.84223034757161606e-17*V06*V08*V12 - 1.32702710467750491e-17*V01*V02*V09*V12 + 
      3.44130121911419594e-17*V05*V09*V12 - 1.5544213563282003e-18*V012*V10*V12 + 1.22950122296540487e-17*V04*V10*V12 + 
      6.32654238749765499e-18*V03*V11*V12 + 4.78129678540683892e-19*V02*V122 - 
      1.13239250522250142e-16*V03*V042*V13 - 1.2043230636304643e-16*V032*V05*V13 - 
      1.11648736311490217e-16*V02*V04*V05*V13 - 3.5731738429929615e-17*V01*V052*V13 - 
      8.0803483190460667e-17*V02*V03*V06*V13 - 4.87222104457884705e-17*V01*V04*V06*V13 - 
      1.28502740561945171e-17*V022*V07*V13 - 3.32668823746511836e-17*V01*V03*V07*V13 + 
      2.98222184467548409e-17*V06*V07*V13 - 9.00145118336727083e-18*V01*V02*V08*V13 + 2.31821913954806098e-17*V05*V08*V13 - 
      1.24629541770092667e-18*V012*V09*V13 + 1.16868394101382844e-17*V04*V09*V13 + 
      5.30188590081608009e-18*V03*V10*V13 + 1.07830062601667895e-18*V02*V11*V13 + 2.47792084135634085e-19*V01*V12*V13 - 
      3.5709051611878866e-17*V032*V04*V14 - 9.59963275489394107e-18*V02*V042*V14 - 
      3.63607867100278612e-17*V02*V03*V05*V14 - 2.14254309671273196e-17*V01*V04*V05*V14 - 
      3.34953107171274943e-18*V022*V06*V14 - 1.47827306418680236e-17*V01*V03*V06*V14 + 
      5.80715783574750585e-18*V062*V14 - 5.1943981014325516e-18*V01*V02*V07*V14 + 1.38256377767680936e-17*V05*V07*V14 - 
      7.55408505672181901e-19*V012*V08*V14 + 6.03944361528490781e-18*V04*V08*V14 + 
      3.86839333429437427e-18*V03*V09*V14 + 6.92096131220533651e-19*V02*V10*V14 + 2.14051097830955376e-19*V01*V11*V14 - 
      1.89356124546829668e-21*V142 - 3.66013997885416585e-18*V033*V15 - 
      1.06332129820466874e-17*V02*V03*V04*V15 - 3.23540715777857548e-18*V01*V042*V15 - 
      2.57005481123890341e-18*V022*V05*V15 - 6.43558302164304669e-18*V01*V03*V05*V15 - 
      2.3086709482988762e-18*V01*V02*V06*V15 + 6.05428348883193408e-18*V05*V06*V15 - 
      4.17158943881495489e-19*V012*V07*V15 + 4.05207394035795021e-18*V04*V07*V15 + 
      2.24914840530658248e-18*V03*V08*V15 + 5.69023573403384661e-19*V02*V09*V15 + 1.54835061865419317e-19*V01*V10*V15 - 
      3.80383188925613711e-21*V13*V15 - 1.47350206309834647e-18*V02*V032*V16 - 
      3.71375281741910713e-19*V022*V04*V16 - 1.71067504894039623e-18*V01*V03*V04*V16 - 
      8.84101237859007882e-19*V01*V02*V05*V16 + 1.2315902464497599e-18*V052*V16 - 
      1.69050640967072785e-19*V012*V06*V16 + 1.38238068358027677e-18*V04*V06*V16 + 
      1.17707515719251901e-18*V03*V07*V16 + 2.57422856685301392e-19*V02*V08*V16 + 9.91226127666111233e-20*V01*V09*V16 - 
      2.89406903444333095e-21*V12*V16 - 1.8897461847344878e-19*V022*V03*V17 - 
      2.20195586963151689e-19*V01*V032*V17 - 2.34556168721618103e-19*V01*V02*V04*V17 - 
      6.11760782910669257e-20*V012*V05*V17 + 6.37309321605777932e-19*V04*V05*V17 + 
      4.55076705003925214e-19*V03*V06*V17 + 1.52847117882936513e-19*V02*V07*V17 + 5.08896467648172792e-20*V01*V08*V17 - 
      2.22924951841677783e-21*V11*V17 - 3.61673910953968958e-21*V023*V18 - 5.45702106821723751e-20*V01*V02*V03*V18 - 
      1.51583918561589931e-20*V012*V04*V18 + 6.43738193567073277e-20*V042*V18 + 
      1.64120470048554016e-19*V03*V05*V18 + 4.61046435143389756e-20*V02*V06*V18 + 2.36030639976242536e-20*V01*V07*V18 - 
      1.27617896511908607e-21*V10*V18 - 3.31534418374471544e-21*V01*V022*V19 - 
      3.19124039077031433e-21*V012*V03*V19 + 3.82210133839018665e-20*V03*V04*V19 + 1.9180241204193692e-20*V02*V05*V19 + 
      8.21558667055639149e-21*V01*V06*V19 - 7.47995534847316065e-22*V09*V19 - 3.79403024236026259e-22*V012*V02*V20 + 
      4.37963973893640771e-21*V032*V20 + 3.43894143062534349e-21*V02*V04*V20 + 2.63593923547159098e-21*V01*V05*V20 - 
      3.12286346087466005e-22*V08*V20 - 1.06374679692343811e-23*V013*V21 + 9.39347518727669376e-22*V02*V03*V21 + 
      5.63490317148054577e-22*V01*V04*V21 - 1.36341126616339151e-22*V07*V21 + 3.72311378923203339e-23*V022*V22 + 
      1.14057295447901975e-22*V01*V03*V22 - 3.92087540068889534e-23*V06*V22 + 1.15239236333372462e-23*V01*V02*V23 - 
      1.22373336419380386e-23*V05*V23 + 5.90970442735243395e-25*V012*V24 - 2.16757089973351916e-24*V04*V24 - 
      4.47473309369932858e-25*V03*V25 - 3.67941367603360351e-26*V02*V26 - 4.24547731850031174e-27*V01*V27 + 
      6.84754406209727701e-30*V30) + delta16*eps7*
    (-7.34206382378028133e-15*V064 - 1.26850963458063282e-13*V05*V062*V07 - 
      6.55247959665185957e-14*V052*V072 - 8.45494331555300777e-14*V04*V06*V072 - 
      2.07110684403453363e-14*V03*V073 - 9.82765845876355675e-14*V052*V06*V08 - 
      4.54709966735524697e-14*V04*V062*V08 - 1.31480939504825697e-13*V04*V05*V07*V08 - 
      9.35967472263195881e-14*V03*V06*V07*V08 - 1.56430238338706235e-14*V02*V072*V08 - 
      1.17259622953321769e-14*V042*V082 - 3.61090033102099245e-14*V03*V05*V082 - 
      8.33714019981313481e-15*V02*V06*V082 - 5.15842904431570351e-15*V01*V07*V082 - 
      2.5371058839423037e-14*V053*V09 - 9.8641005348118424e-14*V04*V05*V06*V09 - 
      3.52363787383509116e-14*V03*V062*V09 - 3.27320935750135619e-14*V042*V07*V09 - 
      7.21224891624196487e-14*V03*V05*V07*V09 - 2.33708877377919834e-14*V02*V06*V07*V09 - 
      5.10283210522514063e-15*V01*V072*V09 - 3.6522483195784916e-14*V03*V04*V08*V09 - 
      1.82501944728490607e-14*V02*V05*V08*V09 - 7.79972893552663234e-15*V01*V06*V08*V09 - 
      4.94418043201276432e-15*V032*V092 - 4.49312020502002561e-15*V02*V04*V092 - 
      2.95331703793771478e-15*V01*V05*V092 + 3.79750736470270608e-16*V08*V092 - 
      3.12313497958389332e-14*V04*V052*V10 - 1.43212533605983009e-14*V042*V06*V10 - 
      4.42842469492141436e-14*V03*V05*V06*V10 - 5.08775746460910372e-15*V02*V062*V10 - 
      2.97441426627037459e-14*V03*V04*V07*V10 - 1.49166848148849441e-14*V02*V05*V07*V10 - 
      6.32632099274487766e-15*V01*V06*V07*V10 - 8.08521985387725728e-15*V032*V08*V10 - 
      5.23418054551202919e-15*V02*V04*V08*V10 - 4.85113191232635437e-15*V01*V05*V08*V10 + 
      2.86640883007379905e-16*V082*V10 - 4.14352355969026224e-15*V02*V03*V09*V10 - 
      2.47867855522531216e-15*V01*V04*V09*V10 + 6.23018090819736941e-16*V07*V09*V10 - 
      1.44378242369284632e-16*V022*V102 - 5.36268736401798886e-16*V01*V03*V102 + 
      1.77476156057167523e-16*V06*V102 - 1.24977084559142691e-14*V042*V05*V11 - 
      1.36384785357835577e-14*V03*V052*V11 - 1.79347282451124407e-14*V03*V04*V06*V11 - 
      8.92342986352057548e-15*V02*V05*V06*V11 - 1.92198429481914063e-15*V01*V062*V11 - 
      6.44360081004592315e-15*V032*V07*V11 - 5.88190281384439716e-15*V02*V04*V07*V11 - 
      3.84618319263906144e-15*V01*V05*V07*V11 - 3.3182171768816474e-15*V02*V03*V08*V11 - 
      1.9921354470428136e-15*V01*V04*V08*V11 + 5.02325342009665761e-16*V07*V08*V11 - 
      3.97980546505083131e-16*V022*V09*V11 - 1.04280831740192632e-15*V01*V03*V09*V11 + 
      3.79448276278040429e-16*V06*V09*V11 - 2.26010375983105213e-16*V01*V02*V10*V11 + 2.42826407126078001e-16*V05*V10*V11 - 
      1.31199082797811721e-17*V012*V112 + 4.96118762076116878e-17*V04*V112 - 
      1.01180421757528827e-15*V043*V12 - 9.51670270746231298e-15*V03*V04*V05*V12 - 
      2.39601757314829602e-15*V02*V052*V12 - 3.3527522090915847e-15*V032*V06*V12 - 
      2.15097048744028581e-15*V02*V04*V06*V12 - 2.01165132545495082e-15*V01*V05*V06*V12 - 
      2.2819214982364724e-15*V02*V03*V07*V12 - 1.35952895820890185e-15*V01*V04*V07*V12 + 
      1.74604354164330062e-16*V072*V12 - 1.94446677797083224e-16*V022*V08*V12 - 
      7.25320499429494088e-16*V01*V03*V08*V12 + 2.42360576913313143e-16*V06*V08*V12 - 1.90160124853039367e-16*V01*V02*V09*V12 + 
      2.0579014386556974e-16*V05*V09*V12 - 2.31440927460396376e-17*V012*V10*V12 + 7.84854587587295795e-17*V04*V10*V12 + 
      3.85536974340224988e-17*V03*V11*V12 + 3.12336320357788239e-18*V02*V122 - 
      1.60227031486080373e-15*V03*V042*V13 - 1.70913857306692002e-15*V032*V05*V13 - 
      1.58358921911195308e-15*V02*V04*V05*V13 - 5.08629385970571426e-16*V01*V052*V13 - 
      1.14402946968212506e-15*V02*V03*V06*V13 - 6.89797240196632336e-16*V01*V04*V06*V13 - 
      1.83683329156192214e-16*V022*V07*V13 - 4.76521043771045156e-16*V01*V03*V07*V13 + 
      1.78736043395954438e-16*V06*V07*V13 - 1.27623737572371054e-16*V01*V02*V08*V13 + 1.39439100106179099e-16*V05*V08*V13 - 
      1.84101884509505308e-17*V012*V09*V13 + 7.06679175536846871e-17*V04*V09*V13 + 
      3.23999938493564539e-17*V03*V10*V13 + 6.6556548271607382e-18*V02*V11*V13 + 1.55573885260872085e-18*V01*V12*V13 - 
      5.19573506998252725e-16*V032*V04*V14 - 1.63128039200778097e-16*V02*V042*V14 - 
      5.2646913923462922e-16*V02*V03*V05*V14 - 3.11744104198951635e-16*V01*V04*V05*V14 - 
      5.73340801598107289e-17*V022*V06*V14 - 2.16913204746820974e-16*V01*V03*V06*V14 + 
      3.72838824329503798e-17*V062*V14 - 7.520987703351846e-17*V01*V02*V07*V14 + 8.39982928608680429e-17*V05*V07*V14 - 
      1.1289970254467218e-17*V012*V08*V14 + 3.90013947631343566e-17*V04*V08*V14 + 2.37938426670223137e-17*V03*V09*V14 + 
      4.54630205875946513e-18*V02*V10*V14 + 1.34813507700158943e-18*V01*V11*V14 - 8.97659932151489569e-21*V142 - 
      5.25729196962689277e-17*V033*V15 - 1.50818020867805055e-16*V02*V03*V04*V15 - 
      4.57791518531658209e-17*V01*V042*V15 - 3.67366658312384429e-17*V022*V05*V15 - 
      9.30536764035747341e-17*V01*V03*V05*V15 - 3.26865562766321446e-17*V01*V02*V06*V15 + 3.71896365708575066e-17*V05*V06*V15 - 
      6.20726040915139994e-18*V012*V07*V15 + 2.49515214428033644e-17*V04*V07*V15 + 
      1.39462098311928584e-17*V03*V08*V15 + 3.55329547765984752e-18*V02*V09*V15 + 9.80074246788768674e-19*V01*V10*V15 - 
      1.76222043419988291e-20*V13*V15 - 2.16829892097685931e-17*V02*V032*V16 - 
      6.50910920024639473e-18*V022*V04*V16 - 2.53626170299423963e-17*V01*V03*V04*V16 - 
      1.30097935258611558e-17*V01*V02*V05*V16 + 7.6893040366815274e-18*V052*V16 - 
      2.54869477555668077e-18*V012*V06*V16 + 9.12964400060918768e-18*V04*V06*V16 + 
      7.39235879597283543e-18*V03*V07*V16 + 1.71889491055298644e-18*V02*V08*V16 + 6.33332923257248144e-19*V01*V09*V16 - 
      1.37678571153793654e-20*V12*V16 - 2.70122542876753257e-18*V022*V03*V17 - 
      3.25155483415587327e-18*V01*V032*V17 - 3.32686810737805269e-18*V01*V02*V04*V17 - 
      9.25012939668683312e-19*V012*V05*V17 + 4.03875139818214825e-18*V04*V05*V17 + 
      2.89362341237922317e-18*V03*V06*V17 + 9.76048851618077564e-19*V02*V07*V17 + 3.28213755456742212e-19*V01*V08*V17 - 
      1.03994426280195746e-20*V11*V17 - 6.63778001280225381e-20*V023*V18 - 8.24935641014126255e-19*V01*V02*V03*V18 - 
      2.32481862467617399e-19*V012*V04*V18 + 4.39027805114913171e-19*V042*V18 + 
      1.063340800229279e-18*V03*V05*V18 + 3.16082736330017946e-19*V02*V06*V18 + 1.54605845920516598e-19*V01*V07*V18 - 
      6.13607824904285805e-21*V10*V18 - 4.73899198029391678e-20*V01*V022*V19 - 
      5.0102474135093935e-20*V012*V03*V19 + 2.51407690896213569e-19*V03*V04*V19 + 1.26399713144427533e-19*V02*V05*V19 + 
      5.44867572132232625e-20*V01*V06*V19 - 3.5391823902471404e-21*V09*V19 - 6.03144433855589409e-21*V012*V02*V20 + 
      2.95370826374777947e-20*V032*V20 + 2.44281853722060966e-20*V02*V04*V20 + 1.78690466404621113e-20*V01*V05*V20 - 
      1.5288112779523826e-21*V08*V20 - 1.9147442344621886e-22*V013*V21 + 6.43389521005859484e-21*V02*V03*V21 + 
      3.87115188513721186e-21*V01*V04*V21 - 6.59309551492957433e-22*V07*V21 + 2.76574167200093909e-22*V022*V22 + 
      8.07561109997710099e-22*V01*V03*V22 - 1.96911642637827796e-22*V06*V22 + 8.24403767615664536e-23*V01*V02*V23 - 
      6.09519782235234957e-23*V05*V23 + 4.43227832051432546e-24*V012*V24 - 1.12498356176548661e-23*V04*V24 - 
      2.31293604311896984e-24*V03*V25 - 1.9868833850581459e-25*V02*V26 - 2.29255775199016834e-26*V01*V27 + 
      3.08139482794377465e-29*V30) + delta14*eps8*
    (2.35507378426005005e-12*V043*V052 + 5.39330385626284643e-12*V03*V04*V053 + 
      6.88466707637125585e-13*V02*V054 + 3.1637336346366468e-13*V044*V06 + 
      1.0128598222905747e-11*V03*V042*V05*V06 + 5.60203400580988479e-12*V032*V052*V06 + 
      5.00458911220634749e-12*V02*V04*V052*V06 + 1.1016481335927049e-12*V01*V053*V06 + 
      3.59755664865051297e-12*V032*V04*V062 + 6.61421923585583323e-13*V02*V042*V062 + 
      3.5956297266427196e-12*V02*V03*V05*V062 + 2.15853398919030778e-12*V01*V04*V05*V062 + 
      7.63853768139394869e-14*V022*V063 + 5.04755377957519226e-13*V01*V03*V063 - 
      6.2256926751198383e-14*V064 + 2.24292741358100004e-12*V03*V043*V07 + 
      7.59694726657796423e-12*V032*V04*V05*V07 + 3.29027994910963913e-12*V02*V042*V05*V07 + 
      3.88847318858481207e-12*V02*V03*V052*V07 + 2.24675242154841578e-12*V01*V04*V052*V07 + 
      1.74864783109953159e-12*V033*V06*V07 + 4.76627534495842619e-12*V02*V03*V04*V06*V07 + 
      1.44694260327224958e-12*V01*V042*V06*V07 + 1.15692431047412348e-12*V022*V05*V06*V07 + 
      3.07762258254794945e-12*V01*V03*V05*V06*V07 + 5.13661389520388515e-13*V01*V02*V062*V07 - 
      9.42006032871439169e-13*V05*V062*V07 + 9.13017171480372307e-13*V02*V032*V072 + 
      3.76241252751854662e-13*V022*V04*V072 + 1.04684224853117798e-12*V01*V03*V04*V072 + 
      5.41292833798604223e-13*V01*V02*V05*V072 - 4.75911104879919518e-13*V052*V072 + 
      1.01723480862693579e-13*V012*V06*V072 - 6.29308193489189785e-13*V04*V06*V072 - 
      1.51545961948382109e-13*V03*V073 + 1.85358347412499737e-12*V032*V042*V08 + 
      2.23657512618854329e-13*V02*V043*V08 + 1.32637060567983116e-12*V033*V05*V08 + 
      3.69646701706884502e-12*V02*V03*V04*V05*V08 + 1.11215008447499842e-12*V01*V042*V05*V08 + 
      4.52270181011196878e-13*V022*V052*V08 + 1.16357203439198338e-12*V01*V03*V052*V08 + 
      1.31660051684880815e-12*V02*V032*V06*V08 + 2.31925124161845252e-13*V022*V04*V06*V08 + 
      1.56122149013202281e-12*V01*V03*V04*V06*V08 + 7.8996031010928489e-13*V01*V02*V05*V06*V08 - 
      7.3328091220647616e-13*V052*V06*V08 + 8.00286287486456962e-14*V012*V062*V08 - 
      3.87975902269054153e-13*V04*V062*V08 + 4.30733505724949408e-13*V022*V03*V07*V08 + 
      5.39719296986723196e-13*V01*V032*V07*V08 + 5.28066716724120717e-13*V01*V02*V04*V07*V08 + 
      1.5292828601852896e-13*V012*V05*V07*V08 - 9.82752412489036078e-13*V04*V05*V07*V08 - 
      7.02569620265405834e-13*V03*V06*V07*V08 - 1.17931399348594738e-13*V02*V072*V08 + 
      6.69504784238175546e-15*V023*V082 + 1.42768095707150999e-13*V01*V02*V03*V082 + 
      4.12321448947806462e-14*V012*V04*V082 - 1.00684561450507463e-13*V042*V082 - 
      2.7244245951980103e-13*V03*V05*V082 - 7.20150591440760036e-14*V02*V06*V082 - 
      3.93805813103512825e-14*V01*V07*V082 + 6.83463167630692065e-13*V033*V04*V09 + 
      9.13966652530455315e-13*V02*V03*V042*V09 + 1.8691061779841667e-13*V01*V043*V09 + 
      1.05251384349728599e-12*V02*V032*V05*V09 + 4.38948128210497106e-13*V022*V04*V05*V09 + 
      1.20335386860583348e-12*V01*V03*V04*V05*V09 + 3.11270730685248432e-13*V01*V02*V052*V09 - 
      1.85663164695406226e-13*V053*V09 + 3.21367864020589857e-13*V022*V03*V06*V09 + 
      4.10289288341899865e-13*V01*V032*V06*V09 + 3.97189612079868849e-13*V01*V02*V04*V06*V09 + 
      1.1644421962918155e-13*V012*V05*V06*V09 - 7.3867914771912083e-13*V04*V05*V06*V09 - 
      2.64857061775150264e-13*V03*V062*V09 + 3.28144186416223419e-14*V023*V07*V09 + 
      2.89513621919572316e-13*V01*V02*V03*V07*V09 + 7.95621864156627378e-14*V012*V04*V07*V09 - 
      2.45860160648114288e-13*V042*V07*V09 - 5.31756052052083213e-13*V03*V05*V07*V09 - 
      1.76653134013751701e-13*V02*V06*V07*V09 - 3.81738632799045893e-14*V01*V072*V09 + 
      3.58944588104124506e-14*V01*V022*V08*V09 + 4.00863087575386264e-14*V012*V03*V08*V09 - 
      2.76287578102280811e-13*V03*V04*V08*V09 - 1.38414799522561442e-13*V02*V05*V08*V09 - 
      5.95991800393076211e-14*V01*V06*V08*V09 + 5.46573122039895515e-15*V012*V02*V092 - 
      3.70205749417367073e-14*V032*V092 - 3.43136211819166243e-14*V02*V04*V092 - 
      2.22694838787587368e-14*V01*V05*V092 + 1.75815601364974319e-15*V08*V092 + 
      7.13960256425088574e-14*V034*V10 + 4.12382840676584542e-13*V02*V032*V04*V10 + 
      3.52902630852678872e-14*V022*V042*V10 + 2.45227411077153522e-13*V01*V03*V042*V10 + 
      2.03543540650939398e-13*V022*V03*V05*V10 + 2.48086925858791731e-13*V01*V032*V05*V10 + 
      2.47429704405950725e-13*V01*V02*V04*V05*V10 + 3.49710714692579749e-14*V012*V052*V10 - 
      2.36083996391657882e-13*V04*V052*V10 + 8.052229042807684e-15*V023*V06*V10 + 
      1.74006404430094811e-13*V01*V02*V03*V06*V10 + 5.02953956410009868e-14*V012*V04*V06*V10 - 
      1.23751897475290984e-13*V042*V06*V10 - 3.36313607147811151e-13*V03*V05*V06*V10 - 
      4.42315251698325436e-14*V02*V062*V10 + 2.90776486644199139e-14*V01*V022*V07*V10 + 
      3.20288157153542396e-14*V012*V03*V07*V10 - 2.26174512961892422e-13*V03*V04*V07*V10 - 
      1.13658394798520683e-13*V02*V05*V07*V10 - 4.86081734818727821e-14*V01*V06*V07*V10 + 
      9.16444207788403927e-15*V012*V02*V08*V10 - 6.21136505345846184e-14*V032*V08*V10 - 
      4.58131085651719322e-14*V02*V04*V08*V10 - 3.74819600969795208e-14*V01*V05*V08*V10 + 
      1.40272626093548825e-15*V082*V10 + 7.35595415710697318e-16*V013*V09*V10 - 
      3.19446931879264903e-14*V02*V03*V09*V10 - 1.91810289892836924e-14*V01*V04*V09*V10 + 2.89231312706572991e-15*V07*V09*V10 - 
      1.29087015069869918e-15*V022*V102 - 4.22201059214955624e-15*V01*V03*V102 + 
      8.7531860031276066e-16*V06*V102 + 6.12091820913871831e-14*V02*V033*V11 + 
      7.98087505837267465e-14*V022*V03*V04*V11 + 1.03686350858970266e-13*V01*V032*V04*V11 + 
      4.9852726501661199e-14*V01*V02*V042*V11 + 1.25291416631648942e-14*V023*V05*V11 + 
      1.0752873588460693e-13*V01*V02*V03*V05*V11 + 2.93985391034053639e-14*V012*V04*V05*V11 - 
      9.50165954753263758e-14*V042*V05*V11 - 1.0207624806039861e-13*V03*V052*V11 + 
      1.75291562193049013e-14*V01*V022*V06*V11 + 1.97058943271430255e-14*V012*V03*V06*V11 - 
      1.36752347938967104e-13*V03*V04*V06*V11 - 6.82645199531197787e-14*V02*V05*V06*V11 - 
      1.4794609112556735e-14*V01*V062*V11 + 7.0563895204977358e-15*V012*V02*V07*V11 - 
      4.86066102769434268e-14*V032*V07*V11 - 4.51897795363406399e-14*V02*V04*V07*V11 - 
      2.92199066434005037e-14*V01*V05*V07*V11 + 5.94536014549359353e-16*V013*V08*V11 - 
      2.56180546127571243e-14*V02*V03*V08*V11 - 1.54303184625236455e-14*V01*V04*V08*V11 + 2.34408338056338325e-15*V07*V08*V11 - 
      3.11648381170519151e-15*V022*V09*V11 - 8.05853468833981609e-15*V01*V03*V09*V11 + 
      1.77963751824100912e-15*V06*V09*V11 - 1.78311964897825348e-15*V01*V02*V10*V11 + 1.1459049713302062e-15*V05*V10*V11 - 
      1.05459850752079744e-16*V012*V112 + 2.37547917906263567e-16*V04*V112 + 
      1.52525141068358642e-14*V022*V032*V12 + 1.17596105971387453e-14*V01*V033*V12 + 
      1.62032944752791867e-15*V023*V04*V12 + 3.66192626889360174e-14*V01*V02*V03*V04*V12 + 
      5.30808529895446134e-15*V012*V042*V12 - 8.91213407167000147e-15*V043*V12 + 
      9.15150846410151852e-15*V01*V022*V05*V12 + 9.80679950661887164e-15*V012*V03*V05*V12 - 
      7.36852272780232135e-14*V03*V04*V05*V12 - 1.85802239602777975e-14*V02*V052*V12 + 
      3.75473724082799042e-15*V012*V02*V06*V12 - 2.60928654740262308e-14*V032*V06*V12 - 
      1.90697685334469798e-14*V02*V04*V06*V12 - 1.57439574873784056e-14*V01*V05*V06*V12 + 
      3.93004735476517777e-16*V013*V07*V12 - 1.77969527992233029e-14*V02*V03*V07*V12 - 
      1.0646790530117513e-14*V01*V04*V07*V12 + 8.18619305942503411e-16*V072*V12 - 
      1.7496502802931511e-15*V022*V08*V12 - 5.74719224038411533e-15*V01*V03*V08*V12 + 
      1.20375159168186655e-15*V06*V08*V12 - 1.50845475205591107e-15*V01*V02*V09*V12 + 9.73061545993915613e-16*V05*V09*V12 - 
      1.88581051499437961e-16*V012*V10*V12 + 3.9600806983082428e-16*V04*V10*V12 + 1.86845920911636295e-16*V03*V11*V12 + 
      1.62416456368852207e-17*V02*V122 + 1.60630021322626848e-15*V023*V03*V13 + 
      6.4254987020082125e-15*V01*V02*V032*V13 + 3.0695673301433364e-15*V01*V022*V04*V13 + 
      3.45546360666068958e-15*V012*V03*V04*V13 - 1.24746188955898646e-14*V03*V042*V13 + 
      1.81050555833806705e-15*V012*V02*V05*V13 - 1.3182339638802919e-14*V032*V05*V13 - 
      1.23846610202144402e-14*V02*V04*V05*V13 - 3.95227360913456059e-15*V01*V052*V13 + 
      2.02879916602831963e-16*V013*V06*V13 - 8.96087217642702106e-15*V02*V03*V06*V13 - 
      5.41656776391363267e-15*V01*V04*V06*V13 - 1.45533965028767569e-15*V022*V07*V13 - 
      3.73673003834541619e-15*V01*V03*V07*V13 + 8.50569575782453662e-16*V06*V07*V13 - 1.01426667913404723e-15*V01*V02*V08*V13 + 
      6.65816973411454945e-16*V05*V08*V13 - 1.49055682538065716e-16*V012*V09*V13 + 
      3.40638052108108738e-16*V04*V09*V13 + 1.57745758916597785e-16*V03*V10*V13 + 3.29867430439438251e-17*V02*V11*V13 + 
      7.83601936716412597e-18*V01*V12*V13 + 1.94336611494474191e-17*V024*V14 + 
      9.68033413128579765e-16*V01*V022*V03*V14 + 4.87276452248782066e-16*V012*V032*V14 + 
      5.65577151975441268e-16*V012*V02*V04*V14 - 4.14782248581965959e-15*V032*V04*V14 - 
      1.48441281213257568e-15*V02*V042*V14 + 8.50891062859058144e-17*V013*V05*V14 - 
      4.20642581189548862e-15*V02*V03*V05*V14 - 2.50222130134117737e-15*V01*V04*V05*V14 - 
      5.25947800152932185e-16*V022*V06*V14 - 1.75182054295518458e-15*V01*V03*V06*V14 + 
      1.89031595263368786e-16*V062*V14 - 6.07493346661976358e-16*V01*V02*V07*V14 + 
      4.03522144097446741e-16*V05*V07*V14 - 9.31577804673769177e-17*V012*V08*V14 + 
      1.99320373596417201e-16*V04*V08*V14 + 1.16245219695545947e-16*V03*V09*V14 + 2.3778878613523285e-17*V02*V10*V14 + 
      6.8008036727040445e-18*V01*V11*V14 - 3.69652918266080612e-20*V142 + 
      4.58942918064648138e-17*V01*V023*V15 + 1.54226265605147751e-16*V012*V02*V03*V15 - 
      4.20893758885493681e-16*V033*V15 + 2.57533099535164367e-17*V013*V04*V15 - 
      1.21412357561987932e-15*V02*V03*V04*V15 - 3.6897500091946079e-16*V01*V042*V15 - 
      2.97852932627031595e-16*V022*V05*V15 - 7.51525836310361637e-16*V01*V03*V05*V15 - 
      2.64982518354019204e-16*V01*V02*V06*V15 + 1.81997009349986521e-16*V05*V06*V15 - 
      5.13606738464949776e-17*V012*V07*V15 + 1.22654111747908539e-16*V04*V07*V15 + 
      6.90465812794839058e-17*V03*V08*V15 + 1.78208791724052304e-17*V02*V09*V15 + 4.98398737326352444e-18*V01*V10*V15 - 
      7.12953494384185117e-20*V13*V15 + 1.1137428963788397e-17*V012*V022*V16 + 
      6.10803410793438163e-18*V013*V03*V16 - 1.79641304077242534e-16*V02*V032*V16 - 
      6.17156106664664935e-17*V022*V04*V16 - 2.11308620722934517e-16*V01*V03*V04*V16 - 
      1.08337292532667554e-16*V01*V02*V05*V16 + 3.80219780308867073e-17*V052*V16 - 
      2.15593818319660896e-17*V012*V06*V16 + 4.78338732852947527e-17*V04*V06*V16 + 
      3.68625447919736493e-17*V03*V07*V16 + 9.14643664831279325e-18*V02*V08*V16 + 3.2361788577276163e-18*V01*V09*V16 - 
      5.6845179760082636e-20*V12*V16 + 8.36104982381822355e-19*V013*V02*V17 - 
      2.26492968000938442e-17*V022*V03*V17 - 2.74893447260954876e-17*V01*V032*V17 - 
      2.78516568851276107e-17*V01*V02*V04*V17 - 7.94172083647100424e-18*V012*V05*V17 + 
      2.04835189590256935e-17*V04*V05*V17 + 1.4730218574014496e-17*V03*V06*V17 + 5.00934322873200858e-18*V02*V07*V17 + 
      1.7028990598548859e-18*V01*V08*V17 - 4.22620822393289065e-20*V11*V17 + 1.9147442344621886e-20*V014*V18 - 
      6.61650507686378505e-19*V023*V18 - 7.1707171580608963e-18*V01*V02*V03*V18 - 
      2.03984085778038492e-18*V012*V04*V18 + 2.38412250860465566e-18*V042*V18 + 
      5.47547707514385916e-18*V03*V05*V18 + 1.72956111350063122e-18*V02*V06*V18 + 8.09085813739967027e-19*V01*V07*V18 - 
      2.55481496550053068e-20*V10*V18 - 4.14861250800140863e-19*V01*V022*V19 - 
      4.54751755684769792e-19*V012*V03*V19 + 1.3286197493573742e-18*V03*V04*V19 + 6.70532793440689213e-19*V02*V05*V19 + 
      2.91185489274977991e-19*V01*V06*V19 - 1.45291153206743851e-20*V09*V19 - 5.55275827994034694e-20*V012*V02*V20 + 
      1.58730017579493456e-19*V032*V20 + 1.38834153381321865e-19*V02*V04*V20 + 9.67857621372196761e-20*V01*V05*V20 - 
      6.46373776182450114e-21*V08*V20 - 1.9147442344621886e-21*V013*V21 + 3.55823303570890048e-20*V02*V03*V21 + 
      2.14876852978534498e-20*V01*V04*V21 - 2.75476796222807948e-21*V07*V21 + 1.64880753523132907e-21*V022*V22 + 
      4.57411122677078387e-21*V01*V03*V22 - 8.52473408053365111e-22*V06*V22 + 4.7868605861554715e-22*V01*V02*V23 - 
      2.6161140693877141e-22*V05*V23 + 2.65936699230859528e-23*V012*V24 - 5.03323412590268159e-23*V04*V24 - 
      1.03012261656091564e-23*V03*V25 - 9.27212246360468085e-25*V02*V26 - 1.06986028426207856e-25*V01*V27 + 
      1.23255793117750986e-28*V30) + delta12*eps9*
    (2.99274705639916675e-11*V043*V052 + 6.58249687646379103e-11*V03*V04*V053 + 
      8.38355745128408355e-12*V02*V054 + 5.91350753111858379e-12*V044*V06 + 
      1.29112358279710881e-10*V03*V042*V05*V06 + 6.87725617938263416e-11*V032*V052*V06 + 
      6.37949307878690797e-11*V02*V04*V052*V06 + 1.35878554204104533e-11*V01*V053*V06 + 
      4.60783274315401983e-11*V032*V04*V062 + 1.24775010640780169e-11*V02*V042*V062 + 
      4.5956102350150425e-11*V02*V03*V05*V062 + 2.7646996458924119e-11*V01*V04*V05*V062 + 
      1.45662197747842583e-12*V022*V063 + 6.5030447635881829e-12*V01*V03*V063 - 
      3.50616975686924707e-13*V064 + 2.85023529180873024e-11*V03*V043*V07 + 
      9.31233517847333218e-11*V032*V04*V05*V07 + 4.19179686773922271e-11*V02*V042*V05*V07 + 
      4.7546133452372778e-11*V02*V03*V052*V07 + 2.76633101717094601e-11*V01*V04*V052*V07 + 
      2.15680244768419894e-11*V033*V06*V07 + 6.0757076940827695e-11*V02*V03*V04*V06*V07 + 
      1.84446226113872687e-11*V01*V042*V06*V07 + 1.48093880265108019e-11*V022*V05*V06*V07 + 
      3.81885381911825697e-11*V01*V03*V05*V06*V07 + 6.56515747859291785e-12*V01*V02*V062*V07 - 
      4.7504363079003252e-12*V05*V062*V07 + 1.12180398817314233e-11*V02*V032*V072 + 
      4.82828651882513257e-12*V022*V04*V072 + 1.29708627581858364e-11*V01*V03*V04*V072 + 
      6.67940833955408062e-12*V01*V02*V05*V072 - 2.33622696927972026e-12*V052*V072 + 
      1.28726504296064179e-12*V012*V06*V072 - 3.19493265130704942e-12*V04*V06*V072 - 
      7.53032381752962175e-13*V03*V073 + 2.38132382141785785e-11*V032*V042*V08 + 
      4.25662720272345912e-12*V02*V043*V08 + 1.64457007008087424e-11*V033*V05*V08 + 
      4.74111459426845681e-11*V02*V03*V04*V05*V08 + 1.42879429285071471e-11*V01*V042*V05*V08 + 
      5.81308164503694043e-12*V022*V052*V08 + 1.45202422111765354e-11*V01*V03*V052*V08 + 
      1.69597472347494122e-11*V02*V032*V06*V08 + 4.46521874484051658e-12*V022*V04*V06*V08 + 
      2.01747533438157336e-11*V01*V03*V04*V06*V08 + 1.01758483408496473e-11*V01*V02*V05*V06*V08 - 
      3.71345497569127969e-12*V052*V06*V08 + 1.03943458475259342e-12*V012*V062*V08 - 
      2.20757693571267634e-12*V04*V062*V08 + 5.53626823336851469e-12*V022*V03*V07*V08 + 
      6.78064466267866795e-12*V01*V032*V07*V08 + 6.7730208489549383e-12*V01*V02*V04*V07*V08 + 
      1.94795764325240098e-12*V012*V05*V07*V08 - 5.0094286982996104e-12*V04*V05*V07*V08 - 
      3.59771978939794215e-12*V03*V06*V07*V08 - 6.11503626802998923e-13*V02*V072*V08 + 
      1.32049579085802776e-13*V023*V082 + 1.85627442163221303e-12*V01*V02*V03*V082 + 
      5.37293571340890865e-13*V012*V04*V082 - 5.78765396274511515e-13*V042*V082 - 
      1.40113686956856952e-12*V03*V05*V082 - 4.18231179472413647e-13*V02*V06*V082 - 
      2.06931258449005453e-13*V01*V07*V082 + 8.45358481728361841e-12*V033*V04*V09 + 
      1.16438801881645075e-11*V02*V03*V042*V09 + 2.3751960765072752e-12*V01*V043*V09 + 
      1.29877384380218234e-11*V02*V032*V05*V09 + 5.63300093862932133e-12*V022*V04*V05*V09 + 
      1.49806202380442889e-11*V01*V03*V04*V05*V09 + 3.8604577023148137e-12*V01*V02*V052*V09 - 
      9.2230203265481826e-13*V053*V09 + 4.11371889625300052e-12*V022*V03*V06*V09 + 
      5.14978745042163907e-12*V01*V032*V06*V09 + 5.06308974506897458e-12*V01*V02*V04*V06*V09 + 
      1.48196910507850886e-12*V012*V05*V06*V09 - 3.79139809589677287e-12*V04*V05*V06*V09 - 
      1.3653837904260381e-12*V03*V062*V09 + 4.2657375191981404e-13*V023*V07*V09 + 
      3.61884510384372809e-12*V01*V02*V03*V07*V09 + 1.01146544171423152e-12*V012*V04*V07*V09 - 
      1.27036881179183744e-12*V042*V07*V09 - 2.67329456629419149e-12*V03*V05*V07*V09 - 
      9.22306872596369582e-13*V02*V06*V07*V09 - 1.96466069544989172e-13*V01*V072*V09 + 
      4.61355686114042891e-13*V01*V022*V08*V09 + 5.18806613637465929e-13*V012*V03*V08*V09 - 
      1.43902158379398903e-12*V03*V04*V08*V09 - 7.25267774033968481e-13*V02*V05*V08*V09 - 
      3.15083983206152218e-13*V01*V06*V08*V09 + 7.0485888718273877e-14*V012*V02*V092 - 
      1.90459173684033928e-13*V032*V092 - 1.8224445417882732e-13*V02*V04*V092 - 
      1.1590010335608468e-13*V01*V05*V092 + 6.66293197487206057e-15*V08*V092 + 
      8.98486392168483228e-13*V034*V10 + 5.3505977617576787e-12*V02*V032*V04*V10 + 
      6.92130118710875523e-13*V022*V042*V10 + 3.19014976317693238e-12*V01*V03*V042*V10 + 
      2.64221084431906982e-12*V022*V03*V05*V10 + 3.1487892345961313e-12*V01*V032*V05*V10 + 
      3.21035865705460722e-12*V01*V02*V04*V05*V10 + 4.50486713382125994e-13*V012*V052*V10 - 
      1.22086069399478844e-12*V04*V052*V10 + 1.60245330251889559e-13*V023*V06*V10 + 
      2.2707190824963045e-12*V01*V02*V03*V06*V10 + 6.57692559761716392e-13*V012*V04*V06*V10 - 
      7.18267362471191286e-13*V042*V06*V10 - 1.74734351445411948e-12*V03*V05*V06*V10 - 
      2.59351340588797288e-13*V02*V062*V10 + 3.77458692045581402e-13*V01*V022*V07*V10 + 
      4.1678328266720452e-13*V012*V03*V07*V10 - 1.18216262517081052e-12*V03*V04*V07*V10 - 
      5.97523377217129259e-13*V02*V05*V07*V10 - 2.57927361435616765e-13*V01*V06*V07*V10 + 
      1.20749385687371266e-13*V012*V02*V08*V10 - 3.27626770755060952e-13*V032*V08*V10 - 
      2.71341121964510637e-13*V02*V04*V08*V10 - 1.99780448697639718e-13*V01*V05*V08*V10 + 
      5.5606575809184384e-15*V082*V10 + 1.0081873984243812e-14*V013*V09*V10 - 
      1.7137744656538277e-13*V02*V03*V09*V10 - 1.03373090772463402e-13*V01*V04*V09*V10 + 1.09739905445472126e-14*V07*V09*V10 - 
      7.87879228963516412e-15*V022*V102 - 2.30636426462300249e-14*V01*V03*V102 + 
      3.50048518125410756e-15*V06*V102 + 7.66586150711844289e-13*V02*V033*V11 + 
      1.02418198884169479e-12*V022*V03*V04*V11 + 1.31278925866360826e-12*V01*V032*V04*V11 + 
      6.35120737536245865e-13*V01*V02*V042*V11 + 1.62873614369383543e-13*V023*V05*V11 + 
      1.35779312827081092e-12*V01*V02*V03*V05*V11 + 3.77902097026932749e-13*V012*V04*V05*V11 - 
      5.01242840122766278e-13*V042*V05*V11 - 5.24745050938145996e-13*V03*V052*V11 + 
      2.24384667068345483e-13*V01*V022*V06*V11 + 2.56237000807609342e-13*V012*V03*V06*V11 - 
      7.24241473456803361e-13*V03*V04*V06*V11 - 3.6371964082039179e-13*V02*V05*V06*V11 - 
      7.94738230424327435e-14*V01*V062*V11 + 9.14934120571831756e-14*V012*V02*V07*V11 - 
      2.52748391469663746e-13*V032*V07*V11 - 2.4238944525262867e-13*V02*V04*V07*V11 - 
      1.5367966920862549e-13*V01*V05*V07*V11 + 8.15645688805532779e-15*V013*V08*V11 - 
      1.38328800422795945e-13*V02*V03*V08*V11 - 8.3675389520846374e-14*V01*V04*V08*V11 + 8.95086340497616003e-15*V07*V08*V11 - 
      1.71730482603146296e-14*V022*V09*V11 - 4.33420930802019802e-14*V01*V03*V09*V11 + 
      6.84543656472515582e-15*V06*V09*V11 - 9.93681315866477881e-15*V01*V02*V10*V11 + 4.4240463229207593e-15*V05*V10*V11 - 
      5.94163351315726398e-16*V012*V112 + 9.3665674474549308e-16*V04*V112 + 
      2.01270218202110796e-13*V022*V032*V12 + 1.52799514246731647e-13*V01*V033*V12 + 
      3.32065678848475826e-14*V023*V04*V12 + 4.83607299216812802e-13*V01*V02*V03*V04*V12 + 
      7.02057716553328008e-14*V012*V042*V12 - 5.32089848910127126e-14*V043*V12 + 
      1.20762130921266477e-13*V01*V022*V05*V12 + 1.29790110531419956e-13*V012*V03*V05*V12 - 
      3.94246334572618666e-13*V03*V04*V05*V12 - 9.99410226990819012e-14*V02*V052*V12 + 
      4.98706797625107438e-14*V012*V02*V06*V12 - 1.40282084301902682e-13*V032*V06*V12 - 
      1.15008179472858505e-13*V02*V04*V06*V12 - 8.55001637105705976e-14*V01*V05*V06*V12 + 
      5.44434314048299544e-15*V013*V07*V12 - 9.66769172545415174e-14*V02*V03*V07*V12 - 
      5.81098215819723718e-14*V01*V04*V07*V12 + 3.1305300129232274e-15*V072*V12 - 
      1.07705648115281712e-14*V022*V08*V12 - 3.16775769328511526e-14*V01*V03*V08*V12 + 
      4.8471969496679166e-15*V06*V08*V12 - 8.43015748982767218e-15*V01*V02*V09*V12 + 3.75792799881330772e-15*V05*V09*V12 - 
      1.07661086695732196e-15*V012*V10*V12 + 1.62508303589957569e-15*V04*V10*V12 + 
      7.42606428117459797e-16*V03*V11*V12 + 6.91148457300207282e-17*V02*V122 + 
      2.08812326114594285e-14*V023*V03*V13 + 8.32526963655690678e-14*V01*V02*V032*V13 + 
      3.93916149554497995e-14*V01*V022*V04*V13 + 4.57365013933917663e-14*V012*V03*V04*V13 - 
      6.84139359557092387e-14*V03*V042*V13 + 2.39215124392911501e-14*V012*V02*V05*V13 - 
      7.06946037695791054e-14*V032*V05*V13 - 6.83399517277351354e-14*V02*V04*V05*V13 - 
      2.14304816562599629e-14*V01*V052*V13 + 2.82215301563922655e-15*V013*V06*V13 - 
      4.95963918095970232e-14*V02*V03*V06*V13 - 3.00923877683344605e-14*V01*V04*V06*V13 - 
      8.16551007923820238e-15*V022*V07*V13 - 2.04912253403889833e-14*V01*V03*V07*V13 + 
      3.31414088223259229e-15*V06*V07*V13 - 5.7345649147626554e-15*V01*V02*V08*V13 + 2.60071064651362746e-15*V05*V08*V13 - 
      8.47393424709072174e-16*V012*V09*V13 + 1.35032310931830388e-15*V04*V09*V13 + 
      6.30052494144506083e-16*V03*V10*V13 + 1.35429493274973811e-16*V02*V11*V13 + 3.25870090660667398e-17*V01*V12*V13 + 
      4.22720155402648721e-16*V024*V14 + 1.30944372200882539e-14*V01*V022*V03*V14 + 
      6.68593617069795287e-15*V012*V032*V14 + 7.65069503078662727e-15*V012*V02*V04*V14 - 
      2.31183957278804889e-14*V032*V04*V14 - 9.2720456855547129e-15*V02*V042*V14 + 
      1.20986603543987295e-15*V013*V05*V14 - 2.35498271527213396e-14*V02*V03*V05*V14 - 
      1.40780188347643777e-14*V01*V04*V05*V14 - 3.31993282381864712e-15*V022*V06*V14 - 
      9.90907097838467691e-15*V01*V03*V06*V14 + 7.77103483977842813e-16*V062*V14 - 
      3.4636178802245616e-15*V01*V02*V07*V14 + 1.57864644075648917e-15*V05*V07*V14 - 
      5.40570669636768498e-16*V012*V08*V14 + 8.27767841122725696e-16*V04*V08*V14 + 4.6449732961539699e-16*V03*V09*V14 + 
      1.01702824367818314e-16*V02*V10*V14 + 2.82857341081140983e-17*V01*V11*V14 - 1.31462543389314789e-19*V142 + 
      5.96606646041697958e-16*V01*V023*V15 + 2.12968065726135081e-15*V012*V02*V03*V15 - 
      2.36877902480583199e-15*V033*V15 + 3.70840004353698839e-16*V013*V04*V15 - 
      6.99765491517326585e-15*V02*V03*V04*V15 - 2.13262817198601003e-15*V01*V042*V15 - 
      1.72889713794637442e-15*V022*V05*V15 - 4.27665294420541087e-15*V01*V03*V05*V15 - 
      1.5441398500240083e-15*V01*V02*V06*V15 + 7.27963100135749636e-16*V05*V06*V15 - 
      2.99764272871743629e-16*V012*V07*V15 + 4.94288703046505278e-16*V04*V07*V15 + 
      2.79989233213771876e-16*V03*V08*V15 + 7.38235073570117765e-17*V02*V09*V15 + 2.09010108073024989e-17*V01*V10*V15 - 
      2.50523536821150808e-19*V13*V15 + 1.55959747385414186e-16*V012*V022*V16 + 
      9.17851796231794727e-17*V013*V03*V16 - 1.05216684929212956e-15*V02*V032*V16 - 
      4.05666904285484695e-16*V022*V04*V16 - 1.24447282488443941e-15*V01*V03*V04*V16 - 
      6.39992835650376689e-16*V01*V02*V05*V16 + 1.52749966371494767e-16*V052*V16 - 
      1.29046102425813663e-16*V012*V06*V16 + 2.03527003449825917e-16*V04*V06*V16 + 
      1.49780046963446622e-16*V03*V07*V16 + 3.97317255248549377e-17*V02*V08*V16 + 1.35841698946364935e-17*V01*V09*V16 - 
      2.02519366355126002e-19*V12*V16 + 1.30904680829398294e-17*V013*V02*V17 - 
      1.37690428021652598e-16*V022*V03*V17 - 1.64877349533382752e-16*V01*V032*V17 - 
      1.69464225721716617e-16*V01*V02*V04*V17 - 4.83275062297474862e-17*V012*V05*V17 + 
      8.49423943276741339e-17*V04*V05*V17 + 6.13083950957692399e-17*V03*V06*V17 + 2.11481798701473653e-17*V02*V07*V17 + 
      7.26677349382308276e-18*V01*V08*V17 - 1.48835991452750896e-19*V11*V17 + 3.35080241030883005e-19*V014*V18 - 
      4.59879015245940764e-18*V023*V18 - 4.44785511944394101e-17*V01*V02*V03*V18 - 
      1.27509201053618679e-17*V012*V04*V18 + 1.05246469839526813e-17*V042*V18 + 
      2.29119491810892027e-17*V03*V05*V18 + 7.7165894643701278e-18*V02*V06*V18 + 3.46361275812256066e-18*V01*V07*V18 - 
      9.15650428368490872e-20*V10*V18 - 2.66277098205875028e-18*V01*V022*V19 - 
      2.92860130660991746e-18*V012*V03*V19 + 5.74150685221944949e-18*V03*V04*V19 + 
      2.91758088979379064e-18*V02*V05*V19 + 1.27718759172612597e-18*V01*V06*V19 - 5.14786812698952865e-20*V09*V19 - 
      3.66354396860432085e-19*V012*V02*V20 + 6.9325708438996616e-19*V032*V20 + 
      6.43737011626187807e-19*V02*V04*V20 + 4.2762621236322212e-19*V01*V05*V20 - 2.34489837383993854e-20*V08*V20 - 
      1.34032096412353202e-20*V013*V21 + 1.61452829470047128e-19*V02*V03*V21 + 9.79178926568024781e-20*V01*V04*V21 - 
      9.88618151018885634e-21*V07*V21 + 8.04192578474119211e-21*V022*V22 + 2.11286707538917895e-20*V01*V03*V22 - 
      3.15801358708480349e-21*V06*V22 + 2.28971498037770053e-21*V01*V02*V23 - 9.60681042253133442e-22*V05*V23 + 
      1.30308982623121169e-22*V012*V24 - 1.92553453961488899e-22*V04*V24 - 3.92103794182051792e-23*V03*V25 - 
      3.70884898544187234e-24*V02*V26 - 4.27944113704831424e-25*V01*V27 + 4.31395275912128451e-28*V30) + 
   delta10*eps10*(-2.83147397803971713e-10*V034*V042 - 
      5.06254614839170405e-10*V02*V032*V043 - 1.14623038722347948e-11*V022*V044 - 
      1.54810757003022798e-10*V01*V03*V044 - 1.09529688867210913e-10*V035*V05 - 
      1.1541005125191192e-9*V02*V033*V04*V05 - 7.30524805740573423e-10*V022*V03*V042*V05 - 
      9.83508372811947777e-10*V01*V032*V042*V05 - 3.03752768903502243e-10*V01*V02*V043*V05 - 
      4.36594739373776737e-10*V022*V032*V052 - 3.10252614595279692e-10*V01*V033*V052 - 
      1.14908473825788093e-10*V023*V04*V052 - 1.00816232934700338e-9*V01*V02*V03*V04*V052 - 
      1.39639358019218935e-10*V012*V042*V052 + 1.86642603593877716e-10*V043*V052 - 
      8.53257609945033718e-11*V01*V022*V053 - 8.5597727110223257e-11*V012*V03*V053 + 
      3.91377601529063344e-10*V03*V04*V053 + 5.00934710005086973e-11*V02*V054 - 
      1.99096974289751206e-10*V02*V034*V06 - 5.31131576240508968e-10*V022*V032*V04*V06 - 
      4.46808032689607542e-10*V01*V033*V04*V06 - 1.5429439176868032e-11*V023*V042*V06 - 
      6.53366437479125617e-10*V01*V02*V03*V042*V06 - 6.5359057922723474e-11*V012*V043*V06 + 
      4.79079742525889495e-11*V044*V06 - 1.69233958038536371e-10*V023*V03*V05*V06 - 
      6.90041724024096878e-10*V01*V02*V032*V05*V06 - 3.18678945744305381e-10*V01*V022*V04*V05*V06 - 
      3.76942641940912647e-10*V012*V03*V04*V05*V06 + 8.08647268213460881e-10*V03*V042*V05*V06 - 
      9.76725501388835622e-11*V012*V02*V052*V06 + 4.12341529647321837e-10*V032*V052*V06 + 
      4.02719371915161521e-10*V02*V04*V052*V06 + 8.26330431252899527e-11*V01*V053*V06 - 
      1.29070701481524603e-12*V024*V062 - 1.14464374269921289e-10*V01*V022*V03*V062 - 
      6.33206080539851901e-11*V012*V032*V062 - 6.90498148639599e-11*V012*V02*V04*V062 + 
      2.89910887081657422e-10*V032*V04*V062 + 1.02209999015727333e-10*V02*V042*V062 - 
      1.142007595082246e-11*V013*V05*V062 + 2.91231750057451425e-10*V02*V03*V05*V062 + 
      1.7583202327727012e-10*V01*V04*V05*V062 + 1.20738847348225361e-11*V022*V063 + 
      4.15428266827867303e-11*V01*V03*V063 - 1.42760703378761961e-12*V064 - 
      1.35437715864291066e-10*V022*V033*V07 - 7.08526174689070824e-11*V01*V034*V07 - 
      1.09436641738845803e-10*V023*V03*V04*V07 - 4.65540094012761655e-10*V01*V02*V032*V04*V07 - 
      1.04360686534367632e-10*V01*V022*V042*V07 - 1.27872399168444168e-10*V012*V03*V042*V07 + 
      1.79727254021590893e-10*V03*V043*V07 - 1.26606282934859687e-11*V024*V05*V07 - 
      2.36897739508122665e-10*V01*V022*V03*V05*V07 - 1.16393161739913878e-10*V012*V032*V05*V07 - 
      1.32254650451981218e-10*V012*V02*V04*V05*V07 + 5.61661612493264455e-10*V032*V04*V05*V07 + 
      2.666416824335273e-10*V02*V042*V05*V07 - 1.02689340983093492e-11*V013*V052*V07 + 
      2.88100796208181595e-10*V02*V03*V052*V07 + 1.69178248851878072e-10*V01*V04*V052*V07 - 
      2.41762797197909101e-11*V01*V023*V06*V07 - 8.92061358343166122e-11*V012*V02*V03*V06*V07 + 
      1.31194537764959105e-10*V033*V06*V07 - 1.55511174753068746e-11*V013*V04*V06*V07 + 
      3.87738650698101693e-10*V02*V03*V04*V06*V07 + 1.18054076106699637e-10*V01*V042*V06*V07 + 
      9.54200122661066923e-11*V022*V05*V06*V07 + 2.35682116756852721e-10*V01*V03*V05*V06*V07 + 
      4.25042085868382114e-11*V01*V02*V062*V07 - 1.77540839305428114e-11*V05*V062*V07 - 
      7.77259687480252758e-12*V012*V022*V072 - 4.59651872487241882e-12*V013*V03*V072 + 
      6.89322026462861178e-11*V02*V032*V072 + 3.13805915832851226e-11*V022*V04*V072 + 
      8.04890627969764801e-11*V01*V03*V04*V072 + 4.15936567180707272e-11*V01*V02*V05*V072 - 
      8.48599897372070743e-12*V052*V072 + 8.2002675722444813e-12*V012*V06*V072 - 
      1.20762474939533595e-11*V04*V06*V072 - 2.77896531802062462e-12*V03*V073 - 
      3.1406770411793385e-11*V023*V032*V08 - 7.98266942205689067e-11*V01*V02*V033*V08 - 
      1.28161804561128541e-12*V024*V04*V08 - 1.16873026333121435e-10*V01*V022*V03*V04*V08 - 
      6.44993064794030546e-11*V012*V032*V04*V08 - 3.53283964846833836e-11*V012*V02*V042*V08 + 
      1.51602595389973449e-10*V032*V042*V08 + 3.52405353526509445e-11*V02*V043*V08 - 
      1.8844062247076031e-11*V01*V023*V05*V08 - 6.69581899549187723e-11*V012*V02*V03*V05*V08 + 
      1.00764892659486774e-10*V033*V05*V08 - 1.16017842317448639e-11*V013*V04*V05*V08 + 
      3.04080770992841975e-10*V02*V03*V04*V05*V08 + 9.19333218147416301e-11*V01*V042*V05*V08 + 
      3.76182883364071839e-11*V022*V052*V08 + 9.02789308548414284e-11*V01*V03*V052*V08 - 
      1.23777258930322607e-11*V012*V022*V06*V08 - 7.6577477249667976e-12*V013*V03*V06*V08 + 
      1.09212690827840409e-10*V02*V032*V06*V08 + 3.74163458071209689e-11*V022*V04*V06*V08 + 
      1.30371084812711088e-10*V01*V03*V04*V06*V08 + 6.62179747756822236e-11*V01*V02*V05*V06*V08 - 
      1.39138776739401995e-11*V052*V06*V08 + 6.81113143208472836e-12*V012*V062*V08 - 
      9.11527037083692531e-12*V04*V062*V08 - 2.72316763179677546e-12*V013*V02*V07*V08 + 
      3.62077053204156496e-11*V022*V03*V07*V08 + 4.27859951220466131e-11*V01*V032*V07*V08 + 
      4.43658895932414209e-11*V01*V02*V04*V07*V08 + 1.25063243117776522e-11*V012*V05*V07*V08 - 
      1.89791484872501004e-11*V04*V05*V07*V08 - 1.36874210104183073e-11*V03*V06*V07*V08 - 
      2.37702872190506103e-12*V02*V072*V08 - 7.92151622321874899e-14*V014*V082 + 
      1.13353984756073838e-12*V023*V082 + 1.22688215292282076e-11*V01*V02*V03*V082 + 
      3.56058950679644889e-12*V012*V04*V082 - 2.42287900363913201e-12*V042*V082 - 
      5.34578088957031999e-12*V03*V05*V082 - 1.77694022465065124e-12*V02*V06*V082 - 
      8.14192771338936449e-13*V01*V07*V082 - 3.51684119263499131e-12*V024*V03*V09 - 
      3.11545515003692533e-11*V01*V022*V032*V09 - 9.91132733697322221e-12*V012*V033*V09 - 
      9.11972014490381693e-12*V01*V023*V04*V09 - 3.43145352906135209e-11*V012*V02*V03*V04*V09 + 
      5.24478092747042114e-11*V033*V04*V09 - 2.99256308014199351e-12*V013*V042*V09 + 
      7.56891251299102765e-11*V02*V03*V042*V09 + 1.54703695324641749e-11*V01*V043*V09 - 
      8.83074553485866602e-12*V012*V022*V05*V09 - 5.17758147319585576e-12*V013*V03*V05*V09 + 
      8.09178799563830596e-11*V02*V032*V05*V09 + 3.70058109033106848e-11*V022*V04*V05*V09 + 
      9.42675261719759545e-11*V01*V03*V04*V05*V09 + 2.43743465493817395e-11*V01*V02*V052*V09 - 
      3.39585461230969546e-12*V053*V09 - 2.06330471385501017e-12*V013*V02*V06*V09 + 
      2.70776609945128878e-11*V022*V03*V06*V09 + 3.27086838033074454e-11*V01*V032*V06*V09 + 
      3.33606521576621069e-11*V01*V02*V04*V06*V09 + 9.57451088234425317e-12*V012*V05*V06*V09 - 
      1.45206027634999439e-11*V04*V05*V06*V09 - 5.24961158700746602e-12*V03*V062*V09 - 
      1.42335628479819232e-13*V014*V07*V09 + 2.86858561012979369e-12*V023*V07*V09 + 
      2.3176605664144501e-11*V01*V02*V03*V07*V09 + 6.56563869675572709e-12*V012*V04*V07*V09 - 
      4.91902242363934911e-12*V042*V07*V09 - 9.99781704581917746e-12*V03*V05*V07*V09 - 
      3.62306438031649679e-12*V02*V06*V07*V09 - 7.58651502437713266e-13*V01*V072*V09 + 
      3.11249978861302989e-12*V01*V022*V08*V09 + 3.43074524903875492e-12*V012*V03*V08*V09 - 
      5.60577627792254974e-12*V03*V04*V08*V09 - 2.855180461060563e-12*V02*V05*V08*V09 - 
      1.2517058538252239e-12*V01*V06*V08*V09 + 4.71724460539165804e-13*V012*V02*V092 - 
      7.32769969810313421e-13*V032*V092 - 7.32583790015828685e-13*V02*V04*V092 - 
      4.53301268054394796e-13*V01*V05*V092 + 2.08431369621129702e-14*V08*V092 - 
      2.50109090726160402e-14*V025*V10 - 4.18886355110222943e-12*V01*V023*V03*V10 - 
      6.87689618785493251e-12*V012*V02*V032*V10 + 5.69751173864715897e-12*V034*V10 - 
      3.83208484261073027e-12*V012*V022*V04*V10 - 2.33988305434653777e-12*V013*V03*V04*V10 + 
      3.52631050361651277e-11*V02*V032*V04*V10 + 5.9222970446754979e-12*V022*V042*V10 + 
      2.10885965835992367e-11*V01*V03*V042*V10 - 1.22205123720504815e-12*V013*V02*V05*V10 + 
      1.75606500821715209e-11*V022*V03*V05*V10 + 2.0270218289170958e-11*V01*V032*V05*V10 + 
      2.13742921698198171e-11*V01*V02*V04*V05*V10 + 2.95140459100951693e-12*V012*V052*V10 - 
      4.69130966557547262e-12*V04*V052*V10 - 9.51994401387715332e-14*V014*V06*V10 + 
      1.38948133380905834e-12*V023*V06*V10 + 1.51773425231397669e-11*V01*V02*V03*V06*V10 + 
      4.40720670726728527e-12*V012*V04*V06*V10 - 3.0427377813810252e-12*V042*V06*V10 - 
      6.74419985568290098e-12*V03*V05*V06*V10 - 1.11483113055115267e-12*V02*V062*V10 + 
      2.55983962018950329e-12*V01*V022*V07*V10 + 2.7732047011699478e-12*V012*V03*V07*V10 - 
      4.61001271959722056e-12*V03*V04*V07*V10 - 2.35421510610348157e-12*V02*V05*V07*V10 - 
      1.02615652192418426e-12*V01*V06*V07*V10 + 8.27290853592509651e-13*V012*V02*V08*V10 - 
      1.28739533983589227e-12*V032*V08*V10 - 1.18185338357454263e-12*V02*V04*V08*V10 - 
      7.97433834392765342e-13*V01*V05*V08*V10 + 1.79838061478275356e-14*V082*V10 + 
      7.07667942690225346e-14*V013*V09*V10 - 6.93266595037648323e-13*V02*V03*V09*V10 - 
      4.20343673537467043e-13*V01*V04*V09*V10 + 3.43127327957938456e-14*V07*V09*V10 - 
      3.56620081849067188e-14*V022*V102 - 9.47289723171371046e-14*V01*V03*V102 + 
      1.14227646427996491e-14*V06*V102 - 1.91827701416454072e-13*V01*V024*V11 - 
      1.45805132639047492e-12*V012*V022*V03*V11 - 4.12892092087527572e-13*V013*V032*V11 + 
      4.97504660232350187e-12*V02*V033*V11 - 5.05026505741119072e-13*V013*V02*V04*V11 + 
      6.94384964940814728e-12*V022*V03*V04*V11 + 8.61220411311333573e-12*V01*V032*V04*V11 + 
      4.30544222024206645e-12*V01*V02*V042*V11 - 5.06432234368291832e-14*V014*V05*V11 + 
      1.11830112714242857e-12*V023*V05*V11 + 8.93255102955499645e-12*V01*V02*V03*V05*V11 + 
      2.52069915148951116e-12*V012*V04*V05*V11 - 1.98640000143620835e-12*V042*V05*V11 - 
      2.00955788888641668e-12*V03*V052*V11 + 1.53937445770493643e-12*V01*V022*V06*V11 + 
      1.7276704271902925e-12*V012*V03*V06*V11 - 2.88037708353703038e-12*V03*V04*V06*V11 - 
      1.46165874516332932e-12*V02*V05*V06*V11 - 3.22050403429014343e-13*V01*V062*V11 + 
      6.20392232335052706e-13*V012*V02*V07*V11 - 9.82589150691560702e-13*V032*V07*V11 - 
      9.84312166513688056e-13*V02*V04*V07*V11 - 6.07256462944098659e-13*V01*V05*V07*V11 + 
      5.7643268997213004e-14*V013*V08*V11 - 5.64729490641266178e-13*V02*V03*V08*V11 - 
      3.43243938216667035e-13*V01*V04*V08*V11 + 2.81675723048505771e-14*V07*V08*V11 - 
      7.22873015865764146e-14*V022*V09*V11 - 1.75988706085494922e-13*V01*V03*V09*V11 + 
      2.17404411903046408e-14*V06*V09*V11 - 4.22232998182778095e-14*V01*V02*V10*V11 + 1.40581481641081888e-14*V05*V10*V11 - 
      2.5456729818479927e-15*V012*V112 + 3.05713520165617753e-15*V04*V112 - 
      9.18623106269282349e-14*V012*V023*V12 - 1.61969532137189844e-13*V013*V02*V03*V12 + 
      1.3878422469854658e-12*V022*V032*V12 + 1.0302241901089193e-12*V01*V033*V12 - 
      1.90513221840518841e-14*V014*V04*V12 + 2.96922204744444057e-13*V023*V04*V12 + 
      3.34057350116526412e-12*V01*V02*V03*V04*V12 + 4.86041584682261339e-13*V012*V042*V12 - 
      2.33307524072229123e-13*V043*V12 + 8.40732798509608141e-13*V01*V022*V05*V12 + 
      8.91481723719246785e-13*V012*V03*V05*V12 - 1.57370827229456183e-12*V03*V04*V05*V12 - 
      4.02799456284057844e-13*V02*V052*V12 + 3.49059614851123976e-13*V012*V02*V06*V12 - 
      5.62604433823534657e-13*V032*V06*V12 - 5.1145449319346481e-13*V02*V04*V06*V12 - 
      3.48171946516168537e-13*V01*V05*V06*V12 + 3.89147976407890454e-14*V013*V07*V12 - 
      3.95056942445859434e-13*V02*V03*V07*V12 - 2.38775055165300741e-13*V01*V04*V07*V12 + 
      9.83816916868575191e-15*V072*V12 - 4.92019150679978326e-14*V022*V08*V12 - 
      1.31271558584103721e-13*V01*V03*V08*V12 + 1.59101406322255024e-14*V06*V08*V12 - 3.58303645343328356e-14*V01*V02*V09*V12 + 
      1.19308055858564106e-14*V05*V09*V12 - 4.65810520796089365e-15*V012*V10*V12 + 
      5.44895773954939066e-15*V04*V10*V12 + 2.43100075755068269e-15*V03*V11*V12 + 2.41628575888465093e-16*V02*V122 - 
      1.43976205709378511e-14*V013*V022*V13 - 5.38616021358826083e-15*V014*V03*V13 + 
      1.49275268888226993e-13*V023*V03*V13 + 5.77482000854680938e-13*V01*V02*V032*V13 + 
      2.80886550250361437e-13*V01*V022*V04*V13 + 3.22151830262168042e-13*V012*V03*V04*V13 - 
      2.8328680477699054e-13*V03*V042*V13 + 1.68640684865502617e-13*V012*V02*V05*V13 - 
      2.83422711088884393e-13*V032*V05*V13 - 2.85869921228774187e-13*V02*V04*V05*V13 - 
      8.72941443715518424e-14*V01*V052*V13 + 2.05783856003702008e-14*V013*V06*V13 - 
      2.08090712199965333e-13*V02*V03*V06*V13 - 1.2680389091150609e-13*V01*V04*V06*V13 - 
      3.49718824504750984e-14*V022*V07*V13 - 8.46870590547369439e-14*V01*V03*V07*V13 + 
      1.06219391275561935e-14*V06*V07*V13 - 2.47578183972894002e-14*V01*V02*V08*V13 + 8.34401027553271522e-15*V05*V08*V13 - 
      3.65805829890077738e-15*V012*V09*V13 + 4.42115660397718329e-15*V04*V09*V13 + 
      2.07093407511499004e-15*V03*V10*V13 + 4.62363159206493138e-16*V02*V11*V13 + 1.12206352754376923e-16*V01*V12*V13 - 
      8.87828606635427609e-16*V014*V02*V14 + 3.99211739812803882e-15*V024*V14 + 
      9.53601265889606092e-14*V01*V022*V03*V14 + 4.86331950191297589e-14*V012*V032*V14 + 
      5.58051747595388596e-14*V012*V02*V04*V14 - 9.64521471645753854e-14*V032*V04*V14 - 
      4.29266509808032957e-14*V02*V042*V14 + 9.02435424502445861e-15*V013*V05*V14 - 
      9.91053011406376153e-14*V02*V03*V05*V14 - 5.95908660361035031e-14*V01*V04*V05*V14 - 
      1.55838885364026884e-14*V022*V06*V14 - 4.21589680955393128e-14*V01*V03*V06*V14 + 
      2.598712458397398e-15*V062*V14 - 1.49747351593544257e-14*V01*V02*V07*V14 + 5.05576992588472146e-15*V05*V07*V14 - 
      2.37489897771310463e-15*V012*V08*V14 + 2.80249121973150038e-15*V04*V08*V14 + 
      1.52464088464662998e-15*V03*V09*V14 + 3.56902535545661175e-16*V02*V10*V14 + 9.73421414696800047e-17*V01*V11*V14 - 
      3.97796467101277375e-19*V142 - 1.84964293049047419e-17*V015*V15 + 
      4.51800751870616667e-15*V01*V023*V15 + 1.60147178141528924e-14*V012*V02*V03*V15 - 
      9.98391124498909381e-15*V033*V15 + 2.85418668668177896e-15*V013*V04*V15 - 
      3.06748893910163551e-14*V02*V03*V04*V15 - 9.38258741377643886e-15*V01*V042*V15 - 
      7.65815838468852181e-15*V022*V05*V15 - 1.8308165588415677e-14*V01*V03*V05*V15 - 
      6.87680710931134112e-15*V01*V02*V06*V15 + 2.38355627618465332e-15*V05*V06*V15 - 
      1.32382608079171842e-15*V012*V07*V15 + 1.63649620317106183e-15*V04*V07*V15 + 
      9.31012724243195772e-16*V03*V08*V15 + 2.53305692642547847e-16*V02*V09*V15 + 7.23939531063726578e-17*V01*V10*V15 - 
      7.52489723265375153e-19*V13*V15 + 1.20665075437149217e-15*V012*V022*V16 + 
      7.3296792244059472e-16*V013*V03*V16 - 4.64329625469588737e-15*V02*V032*V16 - 
      1.99012465138218982e-15*V022*V04*V16 - 5.52581294596366606e-15*V01*V03*V04*V16 - 
      2.86243971301836961e-15*V01*V02*V05*V16 + 4.99966872963872092e-16*V052*V16 - 
      5.84427968525741054e-16*V012*V06*V16 + 7.04003833968776113e-16*V04*V06*V16 + 
      4.97326189233487643e-16*V03*V07*V16 + 1.41170457293979315e-16*V02*V08*V16 + 4.69976522923450451e-17*V01*V09*V16 - 
      6.13465562735739467e-19*V12*V16 + 1.08565998094006094e-16*V013*V02*V17 - 
      6.4005687320755148e-16*V022*V03*V17 - 7.44038973604255094e-16*V01*V032*V17 - 
      7.89546221138659315e-16*V01*V02*V04*V17 - 2.21803014747982696e-16*V012*V05*V17 + 
      2.87834373819183209e-16*V04*V05*V17 + 2.08417237257381959e-16*V03*V06*V17 + 7.35056908400392968e-17*V02*V07*V17 + 
      2.55024385682970053e-17*V01*V08*V17 - 4.47427087160175417e-19*V11*V17 + 3.01572216927794704e-18*V014*V18 - 
      2.39694065750758309e-17*V023*V18 - 2.09157086451477172e-16*V01*V02*V03*V18 - 
      6.03982134458166616e-17*V012*V04*V18 + 3.77410183257556608e-17*V042*V18 + 
      7.79570696207480467e-17*V03*V05*V18 + 2.80752670993088866e-17*V02*V06*V18 + 1.21528151719567033e-17*V01*V07*V18 - 
      2.78446831189661083e-19*V10*V18 - 1.31518994604621579e-17*V01*V022*V19 - 
      1.42074022197094394e-17*V012*V03*V19 + 2.02337272768051394e-17*V03*V04*V19 + 
      1.03973164923609457e-17*V02*V05*V19 + 4.58941588381151984e-18*V01*V06*V19 - 1.55209193627826197e-19*V09*V19 - 
      1.8395905232595477e-18*V012*V02*V20 + 2.45776038062168067e-18*V032*V20 + 
      2.43226768863341047e-18*V02*V04*V20 + 1.54116965621763868e-18*V01*V05*V20 - 7.19439622289528542e-20*V08*V20 - 
      7.0366850616485431e-20*V013*V21 + 5.99104855394272652e-19*V02*V03*V21 + 3.65144384878931674e-19*V01*V04*V21 - 
      3.00494103435625461e-20*V07*V21 + 3.20560097252878075e-20*V022*V22 + 7.94884794001039128e-20*V01*V03*V22 - 
      9.86103979350869749e-21*V06*V22 + 8.99131980099536063e-21*V01*V02*V23 - 2.97373015312066046e-21*V05*V23 + 
      5.21235930492484674e-22*V012*V24 - 6.20005431935559767e-22*V04*V24 - 1.25548104358154919e-22*V03*V25 - 
      1.25173653258663191e-23*V02*V26 - 1.44431138375380606e-24*V01*V27 + 1.29418582773638535e-27*V30) + 
   delta8*eps11*(-2.70769233078483378e-9*V034*V042 - 
      5.2849037735279136e-9*V02*V032*V043 - 3.15709843216944468e-10*V022*V044 - 
      1.61037939893695159e-9*V01*V03*V044 - 1.00986373135568462e-9*V035*V05 - 
      1.1057785719031284e-8*V02*V033*V04*V05 - 7.66974404297867338e-9*V022*V03*V042*V05 - 
      9.51540934945386793e-9*V01*V032*V042*V05 - 3.17094226411674816e-9*V01*V02*V043*V05 - 
      4.19369923254413275e-9*V022*V032*V052 - 2.90983540450796314e-9*V01*V033*V052 - 
      1.21852959418989951e-9*V023*V04*V052 - 9.77152738667720209e-9*V01*V02*V03*V04*V052 - 
      1.37159931983338818e-9*V012*V042*V052 + 7.34782729020672138e-10*V043*V052 - 
      8.28491729834760568e-10*V01*V022*V053 - 8.21336321588804959e-10*V012*V03*V053 + 
      1.46453395338214103e-9*V03*V04*V053 + 1.89782847320951886e-10*V02*V054 - 
      1.92357192532689145e-9*V02*V034*V06 - 5.58835387896902411e-9*V022*V032*V04*V06 - 
      4.36051478170372235e-9*V01*V033*V04*V06 - 4.3569327826351269e-10*V023*V042*V06 - 
      6.83968891953341714e-9*V01*V02*V03*V042*V06 - 6.77992580765286073e-10*V012*V043*V06 + 
      2.26257954018371214e-10*V044*V06 - 1.79365774695378641e-9*V023*V03*V05*V06 - 
      6.75297478382221273e-9*V01*V02*V032*V05*V06 - 3.35301232738141446e-9*V01*V022*V04*V05*V06 - 
      3.74016205972046605e-9*V012*V03*V04*V05*V06 + 3.19520179769643088e-9*V03*V042*V05*V06 - 
      9.72039096167003577e-10*V012*V02*V052*V06 + 1.55664001306521241e-9*V032*V052*V06 + 
      1.6175969284219239e-9*V02*V04*V052*V06 + 3.19314200223651209e-10*V01*V053*V06 - 
      3.74309240912914694e-11*V024*V062 - 1.20684284142954094e-9*V01*V022*V03*V062 - 
      6.3413946401022949e-10*V012*V032*V062 - 
      7.20202163712626555e-10*V012*V02*V04*V062 + 1.1497464459863449e-9*V032*V04*V062 + 
      4.92267262977367602e-10*V02*V042*V062 - 1.17205990640662389e-10*V013*V05*V062 + 
      1.17381796268426579e-9*V02*V03*V05*V062 + 7.12011064353481034e-10*V01*V04*V05*V062 + 
      5.93013262597060489e-11*V022*V063 + 1.68814100807082011e-10*V01*V03*V063 - 
      4.32974712630363354e-12*V064 - 1.31506623783295328e-9*V022*V033*V07 - 
      6.7454712747304742e-10*V01*V034*V07 - 1.16050437541895192e-9*V023*V03*V04*V07 - 
      4.56716553629821362e-9*V01*V02*V032*V04*V07 - 1.09567772042552477e-9*V01*V022*V042*V07 - 
      1.27310177488348393e-9*V012*V03*V042*V07 + 7.22286779408660039e-10*V03*V043*V07 - 
      1.36344455668646115e-10*V024*V05*V07 - 2.32927025459899152e-9*V01*V022*V03*V05*V07 - 
      1.13596860395683898e-9*V012*V032*V05*V07 - 1.31967414597038001e-9*V012*V02*V04*V05*V07 + 
      2.14846013369944086e-9*V032*V04*V05*V07 + 1.08891690401549956e-9*V02*V042*V05*V07 - 
      1.03574214004454016e-10*V013*V052*V07 + 1.11508967056077928e-9*V02*V03*V052*V07 + 
      6.61937463231797974e-10*V01*V04*V052*V07 - 2.56236820993398059e-10*V01*V023*V06*V07 - 
      9.01196641965537243e-10*V012*V02*V03*V06*V07 + 5.06221494252538875e-10*V033*V06*V07 - 
      1.60550455814033235e-10*V013*V04*V06*V07 + 1.58863211987852681e-9*V02*V03*V04*V06*V07 + 
      4.85765929649484683e-10*V01*V042*V06*V07 + 3.97280172036646943e-10*V022*V05*V06*V07 + 
      9.302970874451516e-10*V01*V03*V05*V06*V07 + 1.78140977416299296e-10*V01*V02*V062*V07 - 
      5.05575733027045824e-11*V05*V062*V07 - 7.8930631473357521e-11*V012*V022*V072 - 
      4.73259067769259649e-11*V013*V03*V072 + 2.72368016632682124e-10*V02*V032*V072 + 
      1.32717469230699681e-10*V022*V04*V072 + 3.21496242822697314e-10*V01*V03*V04*V072 + 
      1.67889888642869614e-10*V01*V02*V05*V072 - 2.35208557414920747e-11*V052*V072 + 
      3.38045756691589119e-11*V012*V06*V072 - 3.4929126803506077e-11*V04*V06*V072 - 
      7.8456365347813506e-12*V03*V073 - 3.3606077243994217e-10*V023*V032*V08 - 
      7.97558643198112695e-10*V01*V02*V033*V08 - 3.79125297581047968e-11*V024*V04*V08 - 
      1.24138886084073368e-9*V01*V022*V03*V04*V08 - 6.53786770772800742e-10*V012*V032*V04*V08 - 
      3.70952627427921929e-10*V012*V02*V042*V08 + 6.12638869143912934e-10*V032*V042*V08 + 
      1.72768087835016637e-10*V02*V043*V08 - 2.01636463463965302e-10*V01*V023*V05*V08 - 
      6.82315412603310794e-10*V012*V02*V03*V05*V08 + 3.91350565437022265e-10*V033*V05*V08 - 
      1.20697537152166511e-10*V013*V04*V05*V08 + 1.24824322132544079e-9*V02*V03*V04*V05*V08 + 
      3.79063693721972457e-10*V01*V042*V05*V08 + 1.56899850601904995e-10*V022*V052*V08 + 
      3.5870249760142936e-10*V01*V03*V052*V08 - 1.30822250667700514e-10*V012*V022*V06*V08 - 
      8.05230798728697216e-11*V013*V03*V06*V08 + 4.49879017717270193e-10*V02*V032*V06*V08 + 
      1.87017356849217665e-10*V022*V04*V06*V08 + 5.39452386670568975e-10*V01*V03*V04*V06*V08 + 
      2.78119084952677826e-10*V01*V02*V05*V06*V08 - 3.96354560188055355e-11*V052*V06*V08 + 
      2.88090219036862163e-11*V012*V062*V08 - 2.81085044764062211e-11*V04*V062*V08 - 
      2.91114609549204539e-11*V013*V02*V07*V08 + 1.53836256560521283e-10*V022*V03*V07*V08 + 
      1.7353844815332962e-10*V01*V032*V07*V08 + 1.89133487527127768e-10*V01*V02*V04*V07*V08 + 
      5.19059393198766873e-11*V012*V05*V07*V08 - 5.48898304568036419e-11*V04*V05*V07*V08 - 
      3.97070283494940312e-11*V03*V06*V07*V08 - 7.11612428347958144e-12*V02*V072*V08 - 
      8.96751732530399836e-13*V014*V082 + 5.87597767868451872e-12*V023*V082 + 
      5.26019657389852216e-11*V01*V02*V03*V082 + 1.53193584740453577e-11*V012*V04*V082 - 
      7.59515759376866709e-12*V042*V082 - 1.55236972611883851e-11*V03*V05*V082 - 
      5.68265534731106992e-12*V02*V06*V082 - 2.46116741375142167e-12*V01*V07*V082 - 
      3.78734599079572541e-11*V024*V03*V09 - 3.14186242742249013e-10*V01*V022*V032*V09 - 
      9.99691694792499952e-11*V012*V033*V09 - 9.67086979515793265e-11*V01*V023*V04*V09 - 
      3.52252361146458457e-10*V012*V02*V03*V04*V09 + 2.08892379826975924e-10*V033*V04*V09 - 
      3.14944508532419064e-11*V013*V042*V09 + 3.20821332750362179e-10*V02*V03*V042*V09 + 
      6.58139909884409326e-11*V01*V043*V09 - 9.08657228291473481e-11*V012*V022*V05*V09 - 
      5.41728749948350846e-11*V013*V03*V05*V09 + 3.25758686854994221e-10*V02*V032*V05*V09 + 
      1.59282849594574961e-10*V022*V04*V05*V09 + 3.83582639290067379e-10*V01*V03*V04*V05*V09 + 
      1.0018185639911531e-10*V01*V02*V052*V09 - 9.53000374697754342e-12*V053*V09 - 
      2.21867621467716394e-11*V013*V02*V06*V09 + 1.16860626687187126e-10*V022*V03*V06*V09 + 
      1.34252881626236139e-10*V01*V032*V06*V09 + 1.44401914144765153e-10*V01*V02*V04*V06*V09 + 
      4.01855462494203005e-11*V012*V05*V06*V09 - 4.25198473038538317e-11*V04*V05*V06*V09 - 
      1.54117389351079318e-11*V03*V062*V09 - 1.60096404346460718e-12*V014*V07*V09 + 
      1.27580139152221315e-11*V023*V07*V09 + 9.70894929477466002e-11*V01*V02*V03*V07*V09 + 
      2.78385224692644464e-11*V012*V04*V07*V09 - 1.46329303132615509e-11*V042*V07*V09 - 
      2.85819369795551925e-11*V03*V05*V07*V09 - 1.09841618384869999e-11*V02*V06*V07*V09 - 
      2.2592770034367596e-12*V01*V072*V09 + 1.39216449006725716e-11*V01*V022*V08*V09 + 
      1.47802408512010082e-11*V012*V03*V08*V09 - 1.6713873136280412e-11*V03*V04*V08*V09 - 
      8.65385818649188504e-12*V02*V05*V08*V09 - 3.82596696541192332e-12*V01*V06*V08*V09 + 
      2.08973196445988763e-12*V012*V02*V092 - 2.16106844250979952e-12*V032*V092 - 
      2.28384166378228319e-12*V02*V04*V092 - 1.36716828894291613e-12*V01*V05*V092 + 
      5.32252711422059609e-14*V08*V092 - 7.90314933119651833e-13*V025*V10 - 
      4.55865268533332244e-11*V01*V023*V03*V10 - 7.26771740633275153e-11*V012*V02*V032*V10 + 
      2.31335411714399361e-11*V034*V10 - 4.11072267643068035e-11*V012*V022*V04*V10 - 
      2.52936187739062626e-11*V013*V03*V04*V10 + 1.50234688757787613e-10*V02*V032*V04*V10 + 
      3.05757962507838267e-11*V022*V042*V10 + 9.0229736448768765e-11*V01*V03*V042*V10 - 
      1.33466964293355892e-11*V013*V02*V05*V10 + 7.59248434520164238e-11*V022*V03*V05*V10 + 
      8.41214926683626087e-11*V01*V032*V05*V10 + 9.27395871431695045e-11*V01*V02*V04*V05*V10 + 
      1.25303992223556671e-11*V012*V052*V10 - 1.37210528476302462e-11*V04*V052*V10 - 
      1.09379027043054598e-12*V014*V06*V10 + 7.31106688615551354e-12*V023*V06*V10 + 
      6.60849329722809952e-11*V01*V02*V03*V06*V10 + 1.92572466566963193e-11*V012*V04*V06*V10 - 
      9.65377752972800324e-12*V042*V06*V10 - 1.97981237688494499e-11*V03*V05*V06*V10 - 
      3.60790224457745026e-12*V02*V062*V10 + 1.14546291076524415e-11*V01*V022*V07*V10 + 
      1.20054634519351767e-11*V012*V03*V07*V10 - 1.37301661786255464e-11*V03*V04*V07*V10 - 
      7.12459506348421325e-12*V02*V05*V07*V10 - 3.13550385611748061e-12*V01*V06*V07*V10 + 
      3.73553117385012201e-12*V012*V02*V08*V10 - 3.85483594627473664e-12*V032*V08*V10 - 
      3.88619480703953173e-12*V02*V04*V08*V10 - 2.44102095064815417e-12*V01*V05*V08*V10 + 
      4.69649607688543926e-14*V082*V10 + 3.25472637589004965e-13*V013*V09*V10 - 
      2.16213993830881259e-12*V02*V03*V09*V10 - 1.31851796934635121e-12*V01*V04*V09*V10 + 8.74729103498187793e-14*V07*V09*V10 - 
      1.22842961118007378e-13*V022*V102 - 2.99027520708754681e-13*V01*V03*V102 + 
      3.00797036495938604e-14*V06*V102 - 2.0658250858885775e-12*V01*V024*V11 - 
      1.57257505117001011e-11*V012*V022*V03*V11 - 4.5708191133987549e-12*V013*V032*V11 + 
      2.11112938649033068e-11*V02*V033*V11 - 5.63430214366642788e-12*V013*V02*V04*V11 + 
      3.13855011037910835e-11*V022*V03*V04*V11 + 3.69339070498637689e-11*V01*V032*V04*V11 + 
      1.95005543283774608e-11*V01*V02*V042*V11 - 5.90375196030384519e-13*V014*V05*V11 + 
      5.12988824279130284e-12*V023*V05*V11 + 3.86494704849125462e-11*V01*V02*V03*V05*V11 + 
      1.10382124643695347e-11*V012*V04*V05*V11 - 6.02574402553772853e-12*V042*V05*V11 - 
      5.86065950487755921e-12*V03*V052*V11 + 7.08385491133828903e-12*V01*V022*V06*V11 + 
      7.63429429891017533e-12*V012*V03*V06*V11 - 8.75762270419255321e-12*V03*V04*V06*V11 - 
      4.51908922194792723e-12*V02*V05*V06*V11 - 1.00319318895153867e-12*V01*V062*V11 + 
      2.78856534194745054e-12*V012*V02*V07*V11 - 2.91931345055065142e-12*V032*V07*V11 - 
      3.09097195181517997e-12*V02*V04*V07*V11 - 1.84530720111911496e-12*V01*V05*V07*V11 + 
      2.67537093328460769e-13*V013*V08*V11 - 1.77672651862831385e-12*V02*V03*V08*V11 - 
      1.08549916667667726e-12*V01*V04*V08*V11 + 7.21969685808930552e-14*V07*V08*V11 - 
      2.37718869184732011e-13*V022*V09*V11 - 5.51568550731522464e-13*V01*V03*V09*V11 + 
      5.62759032607874966e-14*V06*V09*V11 - 1.39485595689417132e-13*V01*V02*V10*V11 + 3.63036838344687864e-14*V05*V10*V11 - 
      8.4762325330435429e-15*V012*V112 + 8.13619376933364333e-15*V04*V112 - 
      1.01814211656491648e-12*V012*V023*V12 - 1.87567973747534509e-12*V013*V02*V03*V12 + 
      6.29198029883627969e-12*V022*V032*V12 + 4.5179317601098536e-12*V01*V033*V12 - 
      2.30243551987454227e-13*V014*V04*V12 + 1.63183234523232524e-12*V023*V04*V12 + 
      1.51983607990053672e-11*V01*V02*V03*V04*V12 + 2.21899508353305481e-12*V012*V042*V12 - 
      7.67622409575923744e-13*V043*V12 + 3.87421497906201032e-12*V01*V022*V05*V12 + 
      3.9974675075661919e-12*V012*V03*V05*V12 - 4.77688649044064251e-12*V03*V04*V05*V12 - 
      1.24167226614877991e-12*V02*V052*V12 + 1.61928091951465818e-12*V012*V02*V06*V12 - 
      1.71501986259447189e-12*V032*V06*V12 - 1.71570347365917145e-12*V02*V04*V06*V12 - 
      1.08491507130179143e-12*V01*V05*V06*V12 + 1.822452783408343e-13*V013*V07*V12 - 
      1.23955218846814539e-12*V02*V03*V07*V12 - 7.53992943398918739e-13*V01*V04*V07*V12 + 
      2.514108289774699e-14*V072*V12 - 1.70860271545318255e-13*V022*V08*V12 - 
      4.17272476972729539e-13*V01*V03*V08*V12 + 4.20775619553044381e-14*V06*V08*V12 - 1.18222543305119371e-13*V01*V02*V09*V12 + 
      3.07695292892914839e-14*V05*V09*V12 - 1.55943732580682249e-14*V012*V10*V12 + 
      1.47395049716510006e-14*V04*V10*V12 + 6.46014360006089842e-15*V03*V11*V12 + 6.84806977386757954e-16*V02*V122 - 
      1.75611265297200587e-13*V013*V022*V13 - 6.84922777160622591e-14*V014*V03*V13 + 
      7.23997612170711996e-13*V023*V03*V13 + 2.65331298483672984e-12*V01*V02*V032*V13 + 
      1.36258228576674328e-12*V01*V022*V04*V13 + 1.49844947815938967e-12*V012*V03*V04*V13 - 
      8.95974776441620578e-13*V03*V042*V13 + 7.9019326108408995e-13*V012*V02*V05*V13 - 
      8.6310803951469148e-13*V032*V05*V13 - 9.19356878384301417e-13*V02*V04*V05*V13 - 
      2.7192294469240702e-13*V01*V052*V13 + 9.8852323478737723e-14*V013*V06*V13 - 
      6.70585221398290731e-13*V02*V03*V06*V13 - 4.1056167171177864e-13*V01*V04*V06*V13 - 
      1.16335394741710843e-13*V022*V07*V13 - 2.68634844375280028e-13*V01*V03*V07*V13 + 
      2.76345042190096508e-14*V06*V07*V13 - 8.28360300089827386e-14*V01*V02*V08*V13 + 2.16940773074746741e-14*V05*V08*V13 - 
      1.22343703058866892e-14*V012*V09*V13 + 1.17814293524730856e-14*V04*V09*V13 + 
      5.51810263502300414e-15*V03*V10*V13 + 1.29201754511031737e-15*V02*V11*V13 + 3.14988372293160695e-16*V01*V12*V13 - 
      1.20226790481880822e-14*V014*V02*V14 + 2.35311275767894987e-14*V024*V14 + 
      4.63845526109898326e-13*V01*V022*V03*V14 + 2.32187093336954648e-13*V012*V032*V14 + 
      2.72272029967499923e-13*V012*V02*V04*V14 - 3.05483133968956297e-13*V032*V04*V14 - 
      1.50047739995673031e-13*V02*V042*V14 + 4.4166334595188201e-14*V013*V05*V14 - 
      3.18481901590034896e-13*V02*V03*V05*V14 - 1.92823333578249204e-13*V01*V04*V05*V14 - 
      5.55022048180016092e-14*V022*V06*V14 - 1.37060588895774704e-13*V01*V03*V06*V14 + 
      6.97791424950739716e-15*V062*V14 - 4.99776947621698893e-14*V01*V02*V07*V14 + 
      1.31000250534010513e-14*V05*V07*V14 - 8.04238829701328171e-15*V012*V08*V14 + 
      7.63265362252156149e-15*V04*V08*V14 + 4.05508994062944655e-15*V03*V09*V14 + 1.01396710076047469e-15*V02*V10*V14 + 
      2.73107322985628684e-16*V01*V11*V14 - 9.99010714395400467e-19*V142 - 2.77446439573571128e-16*V015*V15 + 
      2.35279160188349072e-14*V01*V023*V15 + 8.00606549734606702e-14*V012*V02*V03*V15 - 
      3.18661002063482126e-14*V033*V15 + 1.44958727992129266e-14*V013*V04*V15 - 
      1.03115616401421854e-13*V02*V03*V04*V15 - 3.16736787025350229e-14*V01*V042*V15 - 
      2.61676664298677674e-14*V022*V05*V15 - 5.97501107375548902e-14*V01*V03*V05*V15 - 
      2.36292459591238514e-14*V01*V02*V06*V15 + 6.29646953310172236e-15*V05*V06*V15 - 
      4.49715324143854128e-15*V012*V07*V15 + 4.38688044831203657e-15*V04*V07*V15 + 
      2.49993389888186668e-15*V03*V08*V15 + 7.09232706371279065e-16*V02*V09*V15 + 2.03937042180346142e-16*V01*V10*V15 - 
      1.88185619821475976e-18*V13*V15 + 6.30972847873204242e-15*V012*V022*V16 + 
      3.84303528438319718e-15*V013*V03*V16 - 1.56196704962529859e-14*V02*V032*V16 - 
      7.41008061130717081e-15*V022*V04*V16 - 1.87214323359545695e-14*V01*V03*V04*V16 - 
      9.82547302075418786e-15*V01*V02*V05*V16 + 1.31609881312271195e-15*V052*V16 - 
      2.03093139329541282e-15*V012*V06*V16 + 1.95087014910293091e-15*V04*V06*V16 + 
      1.33140296669692414e-15*V03*V07*V16 + 4.04612857892306656e-16*V02*V08*V16 + 1.3218544889613861e-16*V01*V09*V16 - 
      1.54156523737838203e-18*V12*V16 + 5.94767427829817333e-16*V013*V02*V17 - 
      2.29051638062083273e-15*V022*V03*V17 - 2.55243185102262243e-15*V01*V032*V17 - 
      2.83479280079797984e-15*V01*V02*V04*V17 - 7.77877051744758815e-16*V012*V05*V17 + 
      7.84540541187959212e-16*V04*V05*V17 + 5.69382765977192195e-16*V03*V06*V17 + 2.07275949967380283e-16*V02*V07*V17 + 
      7.24776167919506862e-17*V01*V08*V17 - 1.11919960795176042e-18*V11*V17 + 1.75917126541213578e-17*V014*V18 - 
      9.52521431837123422e-17*V023*V18 - 7.53578708066404334e-16*V01*V02*V03*V18 - 
      2.19226247694455206e-16*V012*V04*V18 + 1.08173395744931576e-16*V042*V18 + 
      2.1251235659833308e-16*V03*V05*V18 + 8.20474286947829355e-17*V02*V06*V18 + 3.44742319671513401e-17*V01*V07*V18 - 
      7.01323707274126518e-19*V10*V18 - 5.02787901666839949e-17*V01*V022*V19 - 
      5.2523827781590911e-17*V012*V03*V19 + 5.71416523532977674e-17*V03*V04*V19 + 2.9865562266315506e-17*V02*V05*V19 + 
      1.32911372677619552e-17*V01*V06*V19 - 3.88654874120887369e-19*V09*V19 - 7.10705191226502853e-18*V012*V02*V20 + 
      6.95676443511218904e-18*V032*V20 + 7.36713800411280915e-18*V02*V04*V20 + 4.46314913901670774e-18*V01*V05*V20 - 
      1.82286287562215143e-19*V08*V20 - 2.81467402465941724e-19*V013*V21 + 1.78625691822879882e-18*V02*V03*V21 + 
      1.09487468756841022e-18*V01*V04*V21 - 7.55642739076560618e-20*V07*V21 + 1.02757940582804121e-19*V022*V22 + 
      2.39582372337081348e-19*V01*V03*V22 - 2.53337718849022358e-20*V06*V22 + 2.84818204876250554e-20*V01*V02*V23 - 
      7.57589464491663069e-21*V05*V23 + 1.67540120515441502e-21*V012*V24 - 1.63881198343265194e-21*V04*V24 - 
      3.29784432623785716e-22*V03*V25 - 3.47704592385175532e-23*V02*V26 - 4.0119760659827946e-24*V01*V27 + 
      3.23546456934096338e-27*V30) + eps15*(-6.94206524686864971e-10*V028 - 
      4.54639386231988551e-8*V01*V026*V03 - 2.53851546801452458e-7*V012*V024*V032 - 
      2.2386601636791296e-7*V013*V022*V033 - 1.7497802026109877e-8*V014*V034 + 
      5.82321609376665683e-8*V023*V034 + 5.68952526355953279e-8*V01*V02*V035 - 
      8.02033267037497897e-8*V012*V025*V04 - 3.42381597943718625e-7*V013*V023*V03*V04 - 
      1.57460316491376832e-7*V014*V02*V032*V04 + 1.23015905721350914e-7*V024*V032*V04 + 
      4.20140204066269924e-7*V01*V022*V033*V04 + 8.03264375297130437e-8*V012*V034*V04 - 
      5.8539769345966825e-8*V014*V022*V042 + 1.55258266251201437e-8*V025*V042 - 
      1.38203085397588199e-8*V015*V03*V042 + 3.06655008449177551e-7*V01*V023*V03*V042 + 
      3.61660918326332802e-7*V012*V02*V032*V042 - 1.80890848399191371e-8*V034*V042 + 
      9.08700312449270914e-8*V012*V022*V043 + 4.3865201265538045e-8*V013*V03*V043 - 
      5.19912794462820501e-8*V02*V032*V043 - 8.87063997906019346e-9*V022*V044 - 
      1.60972767434028839e-8*V01*V03*V044 - 5.27147785356624448e-8*V013*V024*V05 - 
      9.4583154597524929e-8*V014*V022*V03*V05 + 2.91617791598488678e-8*V025*V03*V05 - 
      1.10898943522270631e-8*V015*V032*V05 + 2.55904363772325924e-7*V01*V023*V032*V05 + 
      1.97413677627478624e-7*V012*V02*V033*V05 - 6.07572300720626769e-9*V035*V05 - 
      1.61646843431536475e-8*V015*V02*V04*V05 + 9.23641668053448817e-8*V01*V024*V04*V05 + 
      4.44160770415495624e-7*V012*V022*V03*V04*V05 + 1.06946035281486025e-7*V013*V032*V04*V05 - 
      8.82916460558425759e-8*V02*V033*V04*V05 + 8.11535252964248265e-8*V013*V02*V042*V05 - 
      9.42461290386927715e-8*V022*V03*V042*V05 - 8.08199662875465147e-8*V01*V032*V042*V05 - 
      3.9343271570668984e-8*V01*V02*V043*V05 - 4.4215788239092005e-10*V016*V052 + 
      4.54036675918749289e-8*V012*V023*V052 + 
      6.58069309998302386e-8*V013*V02*V03*V052 - 
      4.02737285295749096e-8*V022*V032*V052 - 2.245245242685755e-8*V01*V033*V052 + 
      8.48207471303910781e-9*V014*V04*V052 - 1.88785363563949947e-8*V023*V04*V052 - 
      9.91840918028478183e-8*V01*V02*V03*V04*V052 - 1.46710678526782349e-8*V012*V042*V052 + 
      2.06176703909365558e-9*V043*V052 - 1.01178869715510899e-8*V01*V022*V053 - 
      8.0857279035660943e-9*V012*V03*V053 + 3.50820802817152802e-9*V03*V04*V053 + 
      5.36491683617947045e-10*V02*V054 - 1.56362709521994069e-8*V014*V023*V06 + 
      2.18414198041136536e-9*V026*V06 - 1.08113464132955263e-8*V015*V02*V03*V06 + 
      6.53452271788922513e-8*V01*V024*V03*V06 + 1.54115501019122208e-7*V012*V022*V032*V06 + 
      2.45674819171181349e-8*V013*V033*V06 - 1.56446306688506395e-8*V02*V034*V06 - 
      7.37965357406884018e-10*V016*V04*V06 + 7.75054431271121163e-8*V012*V023*V04*V06 + 
      1.11688681151582586e-7*V013*V02*V03*V04*V06 - 6.72961703587403294e-8*V022*V032*V04*V06 - 
      3.79433180973422844e-8*V01*V033*V04*V06 + 7.17244087745385852e-9*V014*V042*V06 - 
      1.52458893817500879e-8*V023*V042*V06 - 8.35490099178811725e-8*V01*V02*V03*V042*V06 - 
      8.29670664585292318e-9*V012*V043*V06 + 8.54108890191812222e-10*V044*V06 + 
      3.44275149917664599e-8*V013*V022*V05*V06 + 1.16192374107110268e-8*V014*V03*V05*V06 - 
      2.70668530957032087e-8*V023*V03*V05*V06 - 6.99456808524552684e-8*V01*V02*V032*V05*V06 - 
      5.10000496945692542e-8*V01*V022*V04*V05*V06 - 4.11083020764441806e-8*V012*V03*V04*V05*V06 + 
      8.83086349348011714e-9*V03*V042*V05*V06 - 1.26930442310423802e-8*V012*V02*V052*V06 + 
      3.74332101481123714e-9*V032*V052*V06 + 5.38614315013184056e-9*V02*V04*V052*V06 + 
      9.49993437743467316e-10*V01*V053*V06 + 3.0114948425280142e-9*V014*V02*V062 - 
      1.63620013152507348e-9*V024*V062 - 1.80584740578789607e-8*V01*V022*V03*V062 - 
      7.1929056405474561e-9*V012*V032*V062 - 1.07684886489502604e-8*V012*V02*V04*V062 + 
      3.14672738103771724e-9*V032*V04*V062 + 2.22930859597044076e-9*V02*V042*V062 - 
      1.66798448619505426e-9*V013*V05*V062 + 3.84844365382511371e-9*V02*V03*V05*V062 + 
      2.40407175189785005e-9*V01*V04*V05*V062 + 3.23109770393266229e-10*V022*V063 + 
      5.67857461620184775e-10*V01*V03*V063 - 8.24720775442092173e-12*V064 - 
      2.22730672332388019e-9*V015*V022*V07 + 5.74832684711426961e-9*V01*V025*V07 - 
      4.18007464576092027e-10*V016*V03*V07 + 4.6434845998860201e-8*V012*V023*V03*V07 + 
      3.33343996582832413e-8*V013*V02*V032*V07 - 1.40280482779142205e-8*V022*V033*V07 - 
      5.82303383547719375e-9*V01*V034*V07 + 2.53665641824400394e-8*V013*V022*V04*V07 + 
      8.530772859016492e-9*V014*V03*V04*V07 - 1.98269640247326998e-8*V023*V03*V04*V07 - 
      5.15631486875711777e-8*V01*V02*V032*V04*V07 - 1.87539200523709339e-8*V01*V022*V042*V07 - 
      1.51747452738871774e-8*V012*V03*V042*V07 + 2.16718128580535291e-9*V03*V043*V07 + 
      5.23129368023274051e-9*V014*V02*V05*V07 - 2.96604718038281032e-9*V024*V05*V07 - 
      3.15981234782751671e-8*V01*V022*V03*V05*V07 - 1.25314642189172153e-8*V012*V032*V05*V07 - 
      1.87396397034696155e-8*V012*V02*V04*V05*V07 + 5.5211014707465104e-9*V032*V04*V05*V07 + 
      3.96041468981929047e-9*V02*V042*V05*V07 - 1.45062232163661665e-9*V013*V052*V07 + 
      3.38170717130058158e-9*V02*V03*V052*V07 + 2.10457748122992872e-9*V01*V04*V052*V07 + 
      3.43631842626725668e-10*V015*V06*V07 - 5.39783543705181403e-9*V01*V023*V06*V07 - 
      1.31260650334553307e-8*V012*V02*V03*V06*V07 + 1.30836224655562808e-9*V033*V06*V07 - 
      2.46435173785586098e-9*V013*V04*V06*V07 + 5.66570096524915792e-9*V02*V03*V04*V06*V07 + 
      1.77427655588753536e-9*V01*V042*V06*V07 + 1.72322372090584275e-9*V022*V05*V06*V07 + 
      2.98020226518573325e-9*V01*V03*V05*V06*V07 + 7.74976901766769758e-10*V01*V02*V062*V07 - 
      8.71776361934645449e-11*V05*V062*V07 - 1.49511564735614854e-9*V012*V022*V072 - 
      7.45256511956404467e-10*V013*V03*V072 + 8.87980713987765631e-10*V02*V032*V072 + 
      6.32997636546799913e-10*V022*V04*V072 + 1.10078412033046672e-9*V01*V03*V04*V072 + 
      6.78931013741368324e-10*V01*V02*V05*V072 - 3.82721782951213454e-11*V052*V072 + 
      1.43978074925781938e-10*V012*V06*V072 - 6.43123832372462254e-11*V04*V06*V072 - 
      1.34477087404639948e-11*V03*V073 - 1.46715896818021001e-10*V016*V02*V08 + 
      4.67786220396497877e-9*V012*V024*V08 + 1.33664331694032427e-8*V013*V022*V03*V08 + 
      2.23978478446155502e-9*V014*V032*V08 - 5.50717848709859038e-9*V023*V032*V08 - 
      9.35981329925486542e-9*V01*V02*V033*V08 + 3.39152044441936349e-9*V014*V02*V04*V08 - 
      1.85912736904691369e-9*V024*V04*V08 - 2.05812179693864974e-8*V01*V022*V03*V04*V08 - 
      8.19813509983616513e-9*V012*V032*V04*V08 - 6.1382480463705707e-9*V012*V02*V042*V08 + 
      1.79774164950644287e-9*V032*V042*V08 + 8.48045452956239672e-10*V02*V043*V08 + 
      2.63371396729710816e-10*V015*V05*V08 - 4.18223509668411617e-9*V01*V023*V05*V08 - 
      1.01322501728694028e-8*V012*V02*V03*V05*V08 + 1.01345303804956742e-9*V033*V05*V08 - 
      1.8997957778747097e-9*V013*V04*V05*V08 + 4.39621114644282016e-9*V02*V03*V04*V05*V08 + 
      1.37430016250060562e-9*V01*V042*V05*V08 + 6.69231294397409884e-10*V022*V052*V08 + 
      1.15333970536551651e-9*V01*V03*V052*V08 - 2.65391812960214649e-9*V012*V022*V06*V08 - 
      1.3211813507329157e-9*V013*V03*V06*V08 + 1.56837918999985064e-9*V02*V032*V06*V08 + 
      1.10629910626498957e-9*V022*V04*V06*V08 + 1.94821463148274307e-9*V01*V03*V04*V06*V08 + 
      1.20080021374790508e-9*V01*V02*V05*V06*V08 - 6.76310012259065884e-11*V052*V06*V08 + 
      1.27634421168221221e-10*V012*V062*V08 - 5.66401102840554386e-11*V04*V062*V08 - 
      6.05110657245563602e-10*V013*V02*V07*V08 + 7.04806175345157051e-10*V022*V03*V07*V08 + 
      6.02854330585281706e-10*V01*V032*V07*V08 + 8.86224786502716822e-10*V01*V02*V04*V07*V08 + 
      2.22670865768818283e-10*V012*V05*V07*V08 - 9.98173085443164546e-11*V04*V05*V07*V08 - 
      7.13165068345512982e-11*V03*V06*V07*V08 - 1.61779418183039124e-11*V02*V072*V08 - 
      2.1515879747530703e-11*V014*V082 + 4.57369966971094349e-11*V023*V082 + 
      2.43542008755544192e-10*V01*V02*V03*V082 + 7.30330831775538141e-11*V012*V04*V082 - 
      1.62117180060434137e-11*V042*V082 - 2.76589309412361286e-11*V03*V05*V082 - 
      1.42437756285810815e-11*V02*V06*V082 - 5.64273854878146676e-12*V01*V07*V082 - 
      3.54243614047535616e-12*V017*V09 + 1.6090617241645087e-9*V013*V023*V09 + 
      1.59583030346124509e-9*V014*V02*V03*V09 - 9.62818371692481156e-10*V024*V03*V09 - 
      5.05625715084009515e-9*V01*V022*V032*V09 - 1.32487387979222179e-9*V012*V033*V09 + 
      1.52457040502828994e-10*V015*V04*V09 - 2.4440274769942435e-9*V01*V023*V04*V09 - 
      5.95530002485853638e-9*V012*V02*V03*V04*V09 + 5.95146924057484682e-10*V033*V04*V09 - 
      5.58696871612924697e-10*V013*V042*V09 + 1.286303864806352e-9*V02*V03*V042*V09 + 
      2.69059187025538313e-10*V01*V043*V09 - 1.83782961588857547e-9*V012*V022*V05*V09 - 
      9.14650866732722728e-10*V013*V03*V05*V09 + 1.09535713420573542e-9*V02*V032*V05*V09 + 
      7.81703691827714168e-10*V022*V04*V05*V09 + 1.35682439590345054e-9*V01*V03*V04*V05*V09 + 
      4.18551100180693069e-10*V01*V02*V052*V09 - 1.57475509151900846e-11*V053*V09 - 
      4.81760810253798968e-10*V013*V02*V06*V09 + 5.60297060359912343e-10*V022*V03*V06*V09 + 
      4.80021826540252563e-10*V01*V032*V06*V09 + 7.05251608405353447e-10*V01*V02*V04*V06*V09 + 
      1.77360964063524029e-10*V012*V05*V06*V09 - 7.94125479229651329e-11*V04*V05*V06*V09 - 
      2.83782175221970736e-11*V03*V062*V09 - 3.86516654716933898e-11*V014*V07*V09 + 
      8.31912471394392337e-11*V023*V07*V09 + 4.38232746904444785e-10*V01*V02*V03*V07*V09 + 
      1.31238727592392633e-10*V012*V04*V07*V09 - 2.9289154646082385e-11*V042*V07*V09 - 
      4.98077375263285322e-11*V03*V05*V07*V09 - 2.57386696300187456e-11*V02*V06*V07*V09 - 
      5.07729690116426888e-12*V01*V072*V09 + 8.80826733090481605e-11*V01*V022*V08*V09 + 
      7.14320907923061499e-11*V012*V03*V08*V09 - 3.25160503607965922e-11*V03*V04*V08*V09 - 
      1.99887537618312879e-11*V02*V05*V08*V09 - 8.98843796485071897e-12*V01*V06*V08*V09 + 
      1.30883673907849959e-11*V012*V02*V092 - 4.05326230632449257e-12*V032*V092 - 
      5.86359466285590627e-12*V02*V04*V092 - 3.13447692082000853e-12*V01*V05*V092 + 
      8.14222107503231745e-14*V08*V092 + 2.57242234950944531e-10*V014*V022*V10 - 
      5.87301313679052441e-11*V025*V10 + 6.460284856182689e-11*V015*V03*V10 - 
      1.09713114453516043e-9*V01*V023*V03*V10 - 1.3119364205979096e-9*V012*V02*V032*V10 + 
      6.68681476847252555e-11*V034*V10 - 9.82804181968081521e-10*V012*V022*V04*V10 - 
      4.88387406314574565e-10*V013*V03*V04*V10 + 5.8256690412993581e-10*V02*V032*V04*V10 + 
      2.0505713664970509e-10*V022*V042*V10 + 3.621811975504736e-10*V01*V03*V042*V10 - 
      3.02814254531642585e-10*V013*V02*V05*V10 + 3.55598901672197009e-10*V022*V03*V05*V10 + 
      3.03353265594763652e-10*V01*V032*V05*V10 + 4.46412441089847844e-10*V01*V02*V04*V05*V10 + 
      5.59799407823170449e-11*V012*V052*V10 - 2.51745013553585784e-11*V04*V052*V10 - 
      2.79153744073092494e-11*V014*V06*V10 + 5.94184616169428093e-11*V023*V06*V10 + 
      3.1669088230577897e-10*V01*V02*V03*V06*V10 + 9.49799676693291079e-11*V012*V04*V06*V10 - 
      2.107428769023373e-11*V042*V06*V10 - 3.59669998312640944e-11*V03*V05*V06*V10 - 
      9.25931070080285951e-12*V02*V062*V10 + 7.19612109412063777e-11*V01*V022*V07*V10 + 
      5.83105868595580086e-11*V012*V03*V07*V10 - 2.65648270006084215e-11*V03*V04*V07*V10 - 
      1.63347006978280897e-11*V02*V05*V07*V10 - 7.34124330143065495e-12*V01*V06*V07*V10 + 
      2.37844377442280042e-11*V012*V02*V08*V10 - 7.35572861887589855e-12*V032*V08*V10 - 
      1.06068293236070169e-11*V02*V04*V08*V10 - 5.69038571165579452e-12*V01*V05*V08*V10 + 
      7.38118704042372502e-14*V082*V10 + 2.21424581520748837e-12*V013*V09*V10 - 
      5.33325309661845308e-12*V02*V03*V09*V10 - 3.35493174987895847e-12*V01*V04*V09*V10 + 1.33055696769074783e-13*V07*V09*V10 - 
      4.34122908129308479e-13*V022*V102 - 7.54941039233087581e-13*V01*V03*V102 + 
      4.80271780163465663e-14*V06*V102 + 1.86521692396520398e-11*V015*V02*V11 - 
      8.10942926747239152e-11*V01*V024*V11 - 3.96477722595544085e-10*V012*V022*V03*V11 - 
      9.77436962938848269e-11*V013*V032*V11 + 8.0375823741328775e-11*V02*V033*V11 - 
      1.4824222216426174e-10*V013*V02*V04*V11 + 1.7298258566256559e-10*V022*V03*V04*V11 + 
      1.48590409606267406e-10*V01*V032*V04*V11 + 1.09067321886929221e-10*V01*V02*V042*V11 - 
      1.60624841726723269e-11*V014*V05*V11 + 3.49526394288851528e-11*V023*V05*V11 + 
      1.83606679979698007e-10*V01*V02*V03*V05*V11 + 5.49248057153216295e-11*V012*V04*V05*V11 - 
      1.22923391293521476e-11*V042*V05*V11 - 1.0446792304868878e-11*V03*V052*V11 + 
      4.76413757370896413e-11*V01*V022*V06*V11 + 3.8658068197123744e-11*V012*V03*V06*V11 - 
      1.75847032334727575e-11*V03*V04*V06*V11 - 1.08076661904845378e-11*V02*V05*V06*V11 - 
      2.43224858269392821e-12*V01*V062*V11 + 1.77843616743720234e-11*V012*V02*V07*V11 - 
      5.50850002975259586e-12*V032*V07*V11 - 7.97072545840528282e-12*V02*V04*V07*V11 - 
      4.25971711984207076e-12*V01*V05*V07*V11 + 1.84277925954200593e-12*V013*V08*V11 - 
      4.43579732906346624e-12*V02*V03*V08*V11 - 2.79114913508688147e-12*V01*V04*V08*V11 + 1.10664397215694492e-13*V07*V08*V11 - 
      7.98333217385680069e-13*V022*V09*V11 - 1.38379684282090099e-12*V01*V03*V09*V11 + 
      8.81269760956428437e-14*V06*V09*V11 - 4.60197858864066942e-13*V01*V02*V10*V11 + 5.59270822439706111e-14*V05*V10*V11 - 
      2.87074769954414473e-14*V012*V112 + 1.3707384175085021e-14*V04*V112 + 
      4.8941551940777947e-13*V016*V12 - 3.68939674505308105e-11*V012*V023*V12 - 
      5.46897890062243706e-11*V013*V02*V03*V12 + 3.32330990814048066e-11*V022*V032*V12 + 
      1.8721759496117176e-11*V01*V033*V12 - 7.23538697441937466e-12*V014*V04*V12 + 
      1.55021592504695736e-11*V023*V04*V12 + 8.29336363766594459e-11*V01*V02*V03*V04*V12 + 
      1.24423928025188784e-11*V012*V042*V12 - 1.83942195507536128e-12*V043*V12 + 
      2.5529052654857421e-11*V01*V022*V05*V12 + 2.06395758967976596e-11*V012*V03*V05*V12 - 
      9.42960630802113288e-12*V03*V04*V05*V12 - 2.90095001374260037e-12*V02*V052*V12 + 
      1.08881724313547913e-11*V012*V02*V06*V12 - 3.36603551200924369e-12*V032*V06*V12 - 
      4.85085477426325783e-12*V02*V04*V06*V12 - 2.60477467870958926e-12*V01*V05*V06*V12 + 
      1.27177044032302656e-12*V013*V07*V12 - 3.06610095035663138e-12*V02*V03*V07*V12 - 
      1.92812417912411146e-12*V01*V04*V07*V12 + 3.82298429511408287e-14*V072*V12 - 
      6.10756068809190184e-13*V022*V08*V12 - 1.06242185727121409e-12*V01*V03*V08*V12 + 
      6.75539400924665015e-14*V06*V08*V12 - 3.89206143623505356e-13*V01*V02*V09*V12 + 4.72915247454560573e-14*V05*V09*V12 - 
      5.2991199283453253e-14*V012*V10*V12 + 2.52667401380365162e-14*V04*V10*V12 + 1.05459953346924882e-14*V03*V11*V12 + 
      1.4766341583303441e-15*V02*V122 - 7.11555785716754929e-12*V013*V022*V13 - 
      2.46339144768582333e-12*V014*V03*V13 + 5.62440125972049555e-12*V023*V03*V13 + 
      1.46009104023688775e-11*V01*V02*V032*V13 + 1.06921309271487798e-11*V01*V022*V04*V13 + 
      8.6847501660786755e-12*V012*V03*V04*V13 - 1.97549110248894333e-12*V03*V042*V13 + 
      5.3986102204678356e-12*V012*V02*V05*V13 - 1.67557339451327477e-12*V032*V05*V13 - 
      2.42717978677294722e-12*V02*V04*V05*V13 - 6.4764122026905492e-13*V01*V052*V13 + 
      7.22983502990573396e-13*V013*V06*V13 - 1.73922308420895268e-12*V02*V03*V06*V13 - 
      1.09495221645456034e-12*V01*V04*V06*V13 - 3.93396483661090429e-13*V022*V07*V13 - 
      6.81518970387004692e-13*V01*V03*V07*V13 + 4.33824756032214481e-14*V06*V07*V13 - 2.77472319191368747e-13*V01*V02*V08*V13 + 
      3.36948446010558919e-14*V05*V08*V13 - 4.16044141348250533e-14*V012*V09*V13 + 
      1.98581958233045517e-14*V04*V09*V13 + 9.03400927755136257e-15*V03*V10*V13 + 2.74481174903921748e-15*V02*V11*V13 + 
      6.6957340331953677e-16*V01*V12*V13 - 5.94290273566589356e-13*V014*V02*V14 + 
      3.26526205412169494e-13*V024*V14 + 3.53165157621617237e-12*V01*V022*V03*V14 + 
      1.41422904995290895e-12*V012*V032*V14 + 2.1222078205886351e-12*V012*V02*V04*V14 - 
      6.56529547573298755e-13*V032*V04*V14 - 4.72246285669338679e-13*V02*V042*V14 + 
      3.34290021298459873e-13*V013*V05*V14 - 8.09457743294230293e-13*V02*V03*V05*V14 - 
      5.08530535522526643e-13*V01*V04*V05*V14 - 2.07562923318431888e-13*V022*V06*V14 - 
      3.61469907005137093e-13*V01*V03*V06*V14 + 1.14763722080072174e-14*V062*V14 - 
      1.66218031724160062e-13*V01*V02*V07*V14 + 2.01778356332199215e-14*V05*V07*V14 - 
      2.77021573058864015e-14*V012*V08*V14 + 1.3193158382616169e-14*V04*V08*V14 + 6.62064796499135065e-15*V03*V09*V14 + 
      2.19238390252560255e-15*V02*V10*V14 + 5.8025038393457835e-16*V01*V11*V14 - 1.50517840249464591e-18*V142 - 
      1.74791256931349811e-14*V015*V15 + 2.65481762915105492e-13*V01*V023*V15 + 
      6.48795028717106641e-13*V012*V02*V03*V15 - 6.8066566646838548e-14*V033*V15 + 
      1.23328862829272428e-13*V013*V04*V15 - 2.96958128500775342e-13*V02*V03*V04*V15 - 
      9.36089208510382596e-14*V01*V042*V15 - 9.10448282076277624e-14*V022*V05*V15 - 
      1.57393480343731102e-13*V01*V03*V05*V15 - 8.26574011863596269e-14*V01*V02*V06*V15 + 1.00222724476427083e-14*V05*V06*V15 - 
      1.55511745103155895e-14*V012*V07*V15 + 7.41676406594806596e-15*V04*V07*V15 + 
      4.12915890603179722e-15*V03*V08*V15 + 1.50809968969394093e-15*V02*V09*V15 + 4.35022301807857333e-16*V01*V10*V15 - 
      2.82305945583492788e-18*V13*V15 + 7.00422583869988146e-14*V012*V022*V16 + 
      3.52314758148065441e-14*V013*V03*V16 - 4.36975629226566795e-14*V02*V032*V16 - 
      3.12776227931096133e-14*V022*V04*V16 - 5.46391859924164651e-14*V01*V03*V04*V16 - 
      3.39318000839200582e-14*V01*V02*V05*V16 + 2.05813842385241595e-15*V052*V16 - 
      7.29186541920561205e-15*V012*V06*V16 + 3.46486059113790441e-15*V04*V06*V16 + 
      2.18328689576093845e-15*V03*V07*V16 + 8.84553654206952134e-16*V02*V08*V16 + 2.81413332699775377e-16*V01*V09*V16 - 
      2.32407253900997186e-18*V12*V16 + 7.22265459542068317e-15*V013*V02*V17 - 
      8.78123007453968083e-15*V022*V03*V17 - 7.52219119988421526e-15*V01*V032*V17 - 
      1.11206514163389709e-14*V01*V02*V04*V17 - 2.82233898517299869e-15*V012*V05*V17 + 
      1.34680644218868476e-15*V04*V05*V17 + 9.65298560004194491e-16*V03*V06*V17 + 4.42539636628884607e-16*V02*V07*V17 + 
      1.56176711841481682e-16*V01*V08*V17 - 1.67907457044042887e-18*V11*V17 + 2.48797078965430631e-16*V014*V18 - 
      5.5087191625477166e-16*V023*V18 - 2.91318761552249684e-15*V01*V02*V03*V18 - 
      8.80213908158000793e-16*V012*V04*V18 + 2.08558130520634468e-16*V042*V18 + 
      3.55172489983697327e-16*V03*V05*V18 + 1.85183531263893339e-16*V02*V06*V18 + 7.39438321894901071e-17*V01*V07*V18 - 
      1.0599208202361611e-18*V10*V18 - 2.67017067071484894e-16*V01*V022*V19 - 
      2.17131996188012187e-16*V012*V03*V19 + 1.04869644185134165e-16*V03*V04*V19 + 
      6.49398072626889921e-17*V02*V05*V19 + 2.9490651356157321e-17*V01*V06*V19 - 5.83257469694119294e-19*V09*V19 - 
      3.84253266402165086e-17*V012*V02*V20 + 1.25254190812490606e-17*V032*V20 + 
      1.822142416423011e-17*V02*V04*V20 + 9.82353545915093166e-18*V01*V05*V20 - 2.77454967888408531e-19*V08*V20 - 
      1.65864719310287087e-18*V013*V21 + 4.18347680927057431e-18*V02*V03*V21 + 2.64922815565041876e-18*V01*V04*V21 - 
      1.13621569374272333e-19*V07*V21 + 3.31729438620574175e-19*V022*V22 + 5.75919164271830164e-19*V01*V03*V22 - 
      3.94083799893853967e-20*V06*V22 + 8.92151141744726e-20*V01*V02*V23 - 1.15268084351751672e-20*V05*V23 + 
      5.44505391675184883e-21*V012*V24 - 2.73504432370179073e-21*V04*V24 - 5.31988026349318564e-22*V03*V25 - 
      7.30179644008868617e-23*V02*V26 - 8.42514973856386865e-24*V01*V27 + 4.85319685401144508e-27*V30) + 
   delta6*eps12*(5.11979806754947562e-9*V023*V034 + 
      6.28439861063648883e-9*V01*V02*V035 + 6.53023637886137954e-9*V024*V032*V04 + 
      3.49980746918015368e-8*V01*V022*V033*V04 + 8.12007747685893213e-9*V012*V034*V04 + 
      3.28023733515722384e-11*V025*V042 + 1.68287738767928895e-8*V01*V023*V03*V042 + 
      2.86971448111571193e-8*V012*V02*V032*V042 - 1.14011502994645109e-8*V034*V042 + 
      5.31442780537228258e-9*V012*V022*V043 + 3.3217247603230432e-9*V013*V03*V043 - 
      2.44669543095360546e-8*V02*V032*V043 - 2.2483490443839068e-9*V022*V044 - 
      7.44902850484399929e-9*V01*V03*V044 + 1.1932876828753958e-9*V025*V03*V05 + 
      1.75728789142813378e-8*V01*V023*V032*V05 + 1.68148565221743299e-8*V012*V02*V033*V05 - 
      4.1049971768015793e-9*V035*V05 + 3.91814182731682773e-9*V01*V024*V04*V05 + 
      2.92665774374379783e-8*V012*V022*V03*V04*V05 + 8.38741865123177882e-9*V013*V032*V04*V05 - 
      4.74196353548498438e-8*V02*V033*V04*V05 + 5.15464435388368656e-9*V013*V02*V042*V05 - 
      3.63871166639014982e-8*V022*V03*V042*V05 - 4.13378911271000792e-8*V01*V032*V042*V05 - 
      1.50406776685619115e-8*V01*V02*V043*V05 + 2.47093865671367944e-9*V012*V023*V052 + 
      4.35277990005716866e-9*V013*V02*V03*V052 - 
      1.83047795249389219e-8*V022*V032*V052 - 1.22535420198100562e-8*V01*V033*V052 + 
      5.20406508665299024e-10*V014*V04*V052 - 5.92348005622407077e-9*V023*V04*V052 - 
      4.31842619130223981e-8*V01*V02*V03*V04*V052 - 6.14380375992455298e-9*V012*V042*V052 + 
      1.95886723402046206e-9*V043*V052 - 3.72248018267106585e-9*V01*V022*V053 - 
      3.58469188452092172e-9*V012*V03*V053 + 3.71483687960949889e-9*V03*V04*V053 + 
      4.91686207259443451e-10*V02*V054 + 3.53516909891734025e-12*V026*V06 + 
      2.89822592784347662e-9*V01*V024*V03*V06 + 9.8192521769111579e-9*V012*V022*V032*V06 + 
      1.81960754075656323e-9*V013*V033*V06 - 8.34065762220297975e-9*V02*V034*V06 + 
      3.68238259078683943e-9*V012*V023*V04*V06 + 6.78462467642534162e-9*V013*V02*V03*V04*V06 - 
      2.65313239174880345e-8*V022*V032*V04*V06 - 1.91516830337312622e-8*V01*V033*V04*V06 + 
      4.11328034025504827e-10*V014*V042*V06 - 3.16575486934029777e-9*V023*V042*V06 - 
      3.24246916566614558e-8*V01*V02*V03*V042*V06 - 3.19738692173967551e-9*V012*V043*V06 + 
      6.84929102303401647e-10*V044*V06 + 1.75213121024745504e-9*V013*V022*V05*V06 + 
      6.69738984358509069e-10*V014*V03*V05*V06 - 8.7274680127617514e-9*V023*V03*V05*V06 - 
      3.01789381324240246e-8*V01*V02*V032*V05*V06 - 1.62986003298929212e-8*V01*V022*V04*V05*V06 - 
      1.69439953449533837e-8*V012*V03*V04*V05*V06 + 8.53085614730325306e-9*V03*V042*V05*V06 - 
      4.4749593140078434e-9*V012*V02*V052*V06 + 3.97697790915409732e-9*V032*V052*V06 + 
      4.43407216018668314e-9*V02*V04*V052*V06 + 8.43257909093604133e-10*V01*V053*V06 + 
      1.37410959782366922e-10*V014*V02*V062 - 2.77651142359177797e-10*V024*V062 - 
      5.86181969526591239e-9*V01*V022*V03*V062 - 
      2.90489936779296046e-9*V012*V032*V062 - 
      3.47910405228289676e-9*V012*V02*V04*V062 + 3.07630464250431054e-9*V032*V04*V062 + 
      1.53447542271686522e-9*V02*V042*V062 - 5.54327998196170465e-10*V013*V05*V062 + 
      3.22275771746109623e-9*V02*V03*V05*V062 + 1.96603510686366572e-9*V01*V04*V05*V062 + 
      1.90167457525560969e-10*V022*V063 + 4.67302790292369799e-10*V01*V03*V063 - 
      9.74159399052878431e-12*V064 + 1.704696689821994e-10*V01*V025*V07 + 
      2.23064717845634598e-9*V012*V023*V03*V07 + 1.91530648761817301e-9*V013*V02*V032*V07 - 
      5.91122341729889937e-9*V022*V033*V07 - 2.9345597027074377e-9*V01*V034*V07 + 
      1.18110466033672231e-9*V013*V022*V04*V07 + 4.53053758965853336e-10*V014*V03*V04*V07 - 
      5.77498970741263911e-9*V023*V03*V04*V07 - 2.07863171360354468e-8*V01*V02*V032*V04*V07 - 
      5.44857058956791019e-9*V01*V022*V042*V07 - 5.87404784004939108e-9*V012*V03*V042*V07 + 
      1.97545842080561341e-9*V03*V043*V07 + 2.3500403965242191e-10*V014*V02*V05*V07 - 
      6.95192346142862497e-10*V024*V05*V07 - 1.07656539437527827e-8*V01*V022*V03*V05*V07 - 
      5.11715779114514648e-9*V012*V032*V05*V07 - 6.1791537751692598e-9*V012*V02*V04*V05*V07 + 
      5.59153958991555632e-9*V032*V04*V05*V07 + 3.05700850431379675e-9*V02*V042*V05*V07 - 
      4.84061761895630746e-10*V013*V052*V07 + 2.96246128582513109e-9*V02*V03*V052*V07 + 
      1.77927481862708762e-9*V01*V04*V052*V07 + 1.34343265327384121e-11*V015*V06*V07 - 
      1.30512177049964425e-9*V01*V023*V06*V07 - 4.26971068766919061e-9*V012*V02*V03*V06*V07 + 
      1.3270401978967495e-9*V033*V06*V07 - 7.72603172167892948e-10*V013*V04*V06*V07 + 
      4.46415591730487322e-9*V02*V03*V04*V06*V07 + 1.37165986795685994e-9*V01*V042*V06*V07 + 
      1.14508847898528788e-9*V022*V05*V06*V07 + 2.51878644127009434e-9*V01*V03*V05*V06*V07 + 
      5.16319316726959078e-10*V01*V02*V062*V07 - 1.08850614769310101e-10*V05*V062*V07 - 
      3.84773749074983452e-10*V012*V022*V072 - 2.27884497215983798e-10*V013*V03*V072 + 
      7.41772174069159035e-10*V02*V032*V072 + 3.9144279022788022e-10*V022*V04*V072 + 
      8.85677405563816411e-10*V01*V03*V04*V072 + 4.71370770236882858e-10*V01*V02*V05*V072 - 
      4.94855862918812107e-11*V052*V072 + 9.67103795229027201e-11*V012*V06*V072 - 
      7.6625570113420455e-11*V04*V06*V072 - 1.68312526894861991e-11*V03*V073 + 
      1.61156100279536366e-10*V012*V024*V08 + 5.73405955238421412e-10*V013*V022*V03*V08 + 
      1.06432770053926362e-10*V014*V032*V08 - 1.673633831909941e-9*V023*V032*V08 - 
      3.70147417166368546e-9*V01*V02*V033*V08 + 1.36352717407068972e-10*V014*V02*V04*V08 - 
      2.86027394978351203e-10*V024*V04*V08 - 6.16804076535413498e-9*V01*V022*V03*V04*V08 - 
      3.07698365846992364e-9*V012*V032*V04*V08 - 1.83312092233597914e-9*V012*V02*V042*V08 + 
      1.67630450366641758e-9*V032*V042*V08 + 5.5157774023424302e-10*V02*V043*V08 + 
      9.79694205516454494e-12*V015*V05*V08 - 1.0268241252494614e-9*V01*V023*V05*V08 - 
      3.26109401547046174e-9*V012*V02*V03*V05*V08 + 1.02963562449849968e-9*V033*V05*V08 - 
      5.86127182393026158e-10*V013*V04*V05*V08 + 3.50203179509138935e-9*V02*V03*V04*V05*V08 + 
      1.06953985887064151e-9*V01*V042*V05*V08 + 4.51264040776772681e-10*V022*V052*V08 + 
      9.74958549557480348e-10*V01*V03*V052*V08 - 6.61751944627894005e-10*V012*V022*V06*V08 - 
      3.95913008205852347e-10*V013*V03*V06*V08 + 1.26516276710161553e-9*V02*V032*V06*V08 + 
      6.13746680956556656e-10*V022*V04*V06*V08 + 1.52608371743575697e-9*V01*V03*V04*V06*V08 + 
      8.05647184182053699e-10*V01*V02*V05*V06*V08 - 8.51846151754080845e-11*V052*V06*V08 + 
      8.40794836246013737e-11*V012*V062*V08 - 6.4371827522933752e-11*V04*V062*V08 - 
      1.47386887486764788e-10*V013*V02*V07*V08 + 4.53075924877154874e-10*V022*V03*V07*V08 + 
      4.83526849808222882e-10*V01*V032*V07*V08 + 5.59542013331216125e-10*V01*V02*V04*V07*V08 + 
      1.49151659534563166e-10*V012*V05*V07*V08 - 1.20125921231230535e-10*V04*V05*V07*V08 - 
      8.70140862613131953e-11*V03*V06*V07*V08 - 1.62674219902326489e-11*V02*V072*V08 - 
      4.7563091534383478e-12*V014*V082 + 2.02446178250942866e-11*V023*V082 + 
      1.559941386553093e-10*V01*V02*V03*V082 + 4.56477230215849797e-11*V012*V04*V082 - 
      1.77076067842490649e-11*V042*V082 - 3.39867060567049583e-11*V03*V05*V082 - 
      1.3599319053460568e-11*V02*V06*V082 - 5.66297273293752118e-12*V01*V07*V082 + 
      4.98262978091958905e-11*V013*V023*V09 + 5.61403622262468725e-11*V014*V02*V03*V09 - 
      2.01899918293381204e-10*V024*V03*V09 - 1.53316860284183457e-9*V01*V022*V032*V09 - 
      4.77549691948423172e-10*V012*V033*V09 + 4.9842697976512906e-12*V015*V04*V09 - 
      5.14644174798481903e-10*V01*V023*V04*V09 - 1.74223362108663988e-9*V012*V02*V03*V04*V09 + 
      5.67132202535366518e-10*V033*V04*V09 - 1.58258307111341508e-10*V013*V042*V09 + 
      9.38739487460745643e-10*V02*V03*V042*V09 + 1.93317012840331813e-10*V01*V043*V09 - 
      4.54691469248870354e-10*V012*V022*V05*V09 - 2.68115364654485169e-10*V013*V03*V05*V09 + 
      9.02147166076120031e-10*V02*V032*V05*V09 + 4.77820900689788176e-10*V022*V04*V05*V09 + 
      1.07451264921469746e-9*V01*V03*V04*V05*V09 + 2.85961725017197014e-10*V01*V02*V052*V09 - 
      2.02339587700019931e-11*V053*V09 - 1.14219378179443237e-10*V013*V02*V06*V09 + 
      3.50740721736689704e-10*V022*V03*V06*V09 + 3.78863656404391676e-10*V01*V032*V06*V09 + 
      4.34933526502581131e-10*V01*V02*V04*V06*V09 + 1.16892418034049972e-10*V012*V05*V06*V09 - 
      9.41191151745447931e-11*V04*V05*V06*V09 - 3.41386592126541537e-11*V03*V062*V09 - 
      8.48420562756683746e-12*V014*V07*V09 + 4.01108025868168489e-11*V023*V07*V09 + 
      2.83803228930310805e-10*V01*V02*V03*V07*V09 + 8.22932008262253215e-11*V012*V04*V07*V09 - 
      3.30369962928504209e-11*V042*V07*V09 - 6.19049816386646244e-11*V03*V05*V07*V09 - 
      2.54234090504837223e-11*V02*V06*V07*V09 - 5.14561535828993438e-12*V01*V072*V09 + 
      4.38188657597689247e-11*V01*V022*V08*V09 + 4.42347429883074868e-11*V012*V03*V08*V09 - 
      3.76567929567064099e-11*V03*V04*V08*V09 - 1.99748141911944075e-11*V02*V05*V08*V09 - 
      8.89594472467524737e-12*V01*V06*V08*V09 + 6.53698262961084901e-12*V012*V02*V092 - 
      4.82472953064684911e-12*V032*V092 - 5.44781387945981346e-12*V02*V04*V092 - 
      3.14651554524169159e-12*V01*V05*V092 + 1.07575291861976373e-13*V08*V092 + 
      6.56127536018746889e-12*V014*V022*V10 - 6.28774044833033701e-12*V025*V10 + 
      1.79296987110024606e-12*V015*V03*V10 - 2.41757644247508925e-10*V01*V023*V03*V10 - 
      3.68971152625495764e-10*V012*V02*V032*V10 + 6.36323062085581609e-11*V034*V10 - 
      2.16798786742613556e-10*V012*V022*V04*V10 - 1.30720790092825723e-10*V013*V03*V04*V10 + 
      4.38357008930931796e-10*V02*V032*V04*V10 + 1.0446570949042646e-10*V022*V042*V10 + 
      2.64822088351250341e-10*V01*V03*V042*V10 - 6.98241988643341569e-11*V013*V02*V05*V10 + 
      2.26747723384300617e-10*V022*V03*V05*V10 + 2.38870613282232708e-10*V01*V032*V05*V10 + 
      2.78428969089413285e-10*V01*V02*V04*V05*V10 + 3.67017671466749688e-11*V012*V052*V10 - 
      3.02380994200035547e-11*V04*V052*V10 - 5.9430069882674303e-12*V014*V06*V10 + 
      2.56284495868919324e-11*V023*V06*V10 + 1.98967827109950021e-10*V01*V02*V03*V06*V10 + 
      5.8256138568474289e-11*V012*V04*V06*V10 - 2.27353181971655497e-11*V042*V06*V10 - 
      4.3724148612602726e-11*V03*V05*V06*V10 - 8.72301578279986702e-12*V02*V062*V10 + 
      3.59582341691263453e-11*V01*V022*V07*V10 + 3.60209595550557504e-11*V012*V03*V07*V10 - 
      3.08701492905044799e-11*V03*V04*V07*V10 - 1.6400310605246681e-11*V02*V05*V07*V10 - 
      7.28110082862992133e-12*V01*V06*V07*V10 + 1.18147269427759815e-11*V012*V02*V08*V10 - 
      8.68518815762356603e-12*V032*V08*V10 - 9.56691528282165788e-12*V02*V04*V08*V10 - 
      5.66887034209853768e-12*V01*V05*V08*V10 + 9.62247634512707986e-14*V082*V10 + 
      1.04787292123532807e-12*V013*V09*V10 - 5.12984446506550949e-12*V02*V03*V09*V10 - 
      3.14826839683573533e-12*V01*V04*V09*V10 + 1.76413003057521021e-13*V07*V09*V10 - 
      3.19252624712480135e-13*V022*V102 - 7.15818092995833094e-13*V01*V03*V102 + 
      6.20539464634700527e-14*V06*V102 + 3.78067014992252924e-13*V015*V02*V11 - 
      1.19717337164059396e-11*V01*V024*V11 - 8.46960314502890135e-11*V012*V022*V03*V11 - 
      2.44333268665229764e-11*V013*V032*V11 + 6.15338385818178016e-11*V02*V033*V11 - 
      3.08448921279165463e-11*V013*V02*V04*V11 + 9.89506946202887356e-11*V022*V03*V04*V11 + 
      1.08874762208412445e-10*V01*V032*V04*V11 + 6.1640059570193134e-11*V01*V02*V042*V11 - 
      3.28346763377738487e-12*V014*V05*V11 + 1.65657775138424744e-11*V023*V05*V11 + 
      1.16013706631553032e-10*V01*V02*V03*V05*V11 + 3.35097210103525611e-11*V012*V04*V05*V11 - 
      1.3775121634296125e-11*V042*V05*V11 - 1.28639116910717489e-11*V03*V052*V11 + 
      2.29290783794404451e-11*V01*V022*V06*V11 + 2.33583671552289551e-11*V012*V03*V06*V11 - 
      2.00275499582776916e-11*V03*V04*V06*V11 - 1.05972587995833547e-11*V02*V05*V06*V11 - 
      2.36722937397376589e-12*V01*V062*V11 + 8.81100105228480801e-12*V012*V02*V07*V11 - 
      6.5419696088928592e-12*V032*V07*V11 - 7.39754261427104556e-12*V02*V04*V07*V11 - 
      4.2642394709697889e-12*V01*V05*V07*V11 + 8.67444323067818835e-13*V013*V08*V11 - 
      4.24148487064918072e-12*V02*V03*V08*V11 - 2.60631376470732166e-12*V01*V04*V08*V11 + 1.46154500206913671e-13*V07*V08*V11 - 
      6.01627874460204652e-13*V022*V09*V11 - 1.31544886072074995e-12*V01*V03*V09*V11 + 
      1.14951150502220865e-13*V06*V09*V11 - 3.52765740749065523e-13*V01*V02*V10*V11 + 7.38298834827120743e-14*V05*V10*V11 - 
      2.16031149964390739e-14*V012*V112 + 1.70547328854261923e-14*V04*V112 + 
      7.76850030805999158e-15*V016*V12 - 5.80492553852773915e-12*V012*V023*V12 - 
      1.06214388878599787e-11*V013*V02*V03*V12 + 1.97197142892801617e-11*V022*V032*V12 + 
      1.35352057718260657e-11*V01*V033*V12 - 1.33915997810440822e-12*V014*V04*V12 + 
      6.01591230281355151e-12*V023*V04*V12 + 4.7889397352850306e-11*V01*V02*V03*V04*V12 + 
      7.02444858191099965e-12*V012*V042*V12 - 1.87036436876604568e-12*V043*V12 + 
      1.24670955283429506e-11*V01*V022*V05*V12 + 1.23472438047503549e-11*V012*V03*V05*V12 - 
      1.08735697945315405e-11*V03*V04*V05*V12 - 2.89291843869845839e-12*V02*V052*V12 + 
      5.24950725762423915e-12*V012*V02*V06*V12 - 3.91570200497004835e-12*V032*V06*V12 - 
      4.29197145083369922e-12*V02*V04*V06*V12 - 2.55405751841666671e-12*V01*V05*V06*V12 + 
      5.94197492894031914e-13*V013*V07*V12 - 2.94768185112356462e-12*V02*V03*V07*V12 - 
      1.80584512202607689e-12*V01*V04*V07*V12 + 5.07296905825507555e-14*V072*V12 - 
      4.46579170970001173e-13*V022*V08*V12 - 1.00327225406175927e-12*V01*V03*V08*V12 + 
      8.70451114595495944e-14*V06*V08*V12 - 2.98609512458644278e-13*V01*V02*V09*V12 + 6.25058680994150899e-14*V05*V09*V12 - 
      3.98329661776719889e-14*V012*V10*V12 + 3.11752051737664818e-14*V04*V10*V12 + 
      1.34757903197493909e-14*V03*V11*V12 + 1.5242600261923723e-15*V02*V122 - 
      1.05457391681914386e-12*V013*V022*V13 - 4.1561476648120955e-13*V014*V03*V13 + 
      2.46716357999120439e-12*V023*V03*V13 + 8.4271512529546842e-12*V01*V02*V032*V13 + 
      4.64959415930984757e-12*V01*V022*V04*V13 + 4.81392178513526814e-12*V012*V03*V04*V13 - 
      2.121851497377257e-12*V03*V042*V13 + 2.58010539095283279e-12*V012*V02*V05*V13 - 
      1.96569597824408638e-12*V032*V05*V13 - 2.23359220316250296e-12*V02*V04*V05*V13 - 
      6.39027559710706371e-13*V01*V052*V13 + 3.2953117820731517e-13*V013*V06*V13 - 
      1.62961536632294704e-12*V02*V03*V06*V13 - 1.00300437532686563e-12*V01*V04*V06*V13 - 
      2.95880855578268284e-13*V022*V07*V13 - 6.44690952420211278e-13*V01*V03*V07*V13 + 
      5.65583100846434713e-14*V06*V07*V13 - 2.11163145684643087e-13*V01*V02*V08*V13 + 4.43021613255248087e-14*V05*V08*V13 - 
      3.12441950867249054e-14*V012*V09*V13 + 2.47039189381940438e-14*V04*V09*V13 + 
      1.15280407549107147e-14*V03*V10*V13 + 2.85359927240368288e-15*V02*V11*V13 + 6.96948686726006253e-16*V01*V12*V13 - 
      7.76850030805999158e-14*V014*V02*V14 + 9.40120931201604073e-14*V024*V14 + 
      1.57530362297593423e-12*V01*V022*V03*V14 + 7.61492253441465227e-13*V012*V032*V14 + 
      9.2858843731490628e-13*V012*V02*V04*V14 - 7.21538883562920543e-13*V032*V04*V14 - 
      3.90055797864802146e-13*V02*V042*V14 + 1.49319909022559885e-13*V013*V05*V14 - 
      7.69518552471470787e-13*V02*V03*V05*V14 - 4.69609309231927464e-13*V01*V04*V05*V14 - 
      1.48032747489434744e-13*V022*V06*V14 - 3.3506035137855168e-13*V01*V03*V06*V14 + 
      1.45962351557873286e-14*V062*V14 - 1.26969285076618503e-13*V01*V02*V07*V14 + 
      2.66592566671645643e-14*V05*V07*V14 - 2.06883186243081459e-14*V012*V08*V14 + 
      1.62116115495872565e-14*V04*V08*V14 + 8.45993826501182513e-15*V03*V09*V14 + 2.26003067224343582e-15*V02*V10*V14 + 
      6.04094333616496415e-16*V01*V11*V14 - 2.00270726228861898e-18*V142 - 1.9421250770149979e-15*V015*V15 + 
      8.68225295600984184e-14*V01*V023*V15 + 2.77836472974131076e-13*V012*V02*V03*V15 - 
      7.55807605983034929e-14*V033*V15 + 5.0945599846335452e-14*V013*V04*V15 - 
      2.60303008435242253e-13*V02*V03*V04*V15 - 8.03462851894543522e-14*V01*V042*V15 - 
      6.77323235479431739e-14*V022*V05*V15 - 1.4623953982237985e-13*V01*V03*V05*V15 - 
      6.14571865194268863e-14*V01*V02*V06*V15 + 1.3005073880775731e-14*V05*V06*V15 - 
      1.15858695629143599e-14*V012*V07*V15 + 9.21976298918643866e-15*V04*V07*V15 + 
      5.24658998541442498e-15*V03*V08*V15 + 1.56728430766123504e-15*V02*V09*V15 + 4.52070968700141329e-16*V01*V10*V15 - 
      3.76401171276961936e-18*V13*V15 + 2.32351340735634893e-14*V012*V022*V16 + 
      1.38693062565092785e-14*V013*V03*V16 - 3.92994616343351408e-14*V02*V032*V16 - 
      2.06111743188892094e-14*V022*V04*V16 - 4.74978352666795154e-14*V01*V03*V04*V16 - 
      2.54617947711181351e-14*V01*V02*V05*V16 + 2.70437149860113534e-15*V052*V16 - 
      5.32649917667271211e-15*V012*V06*V16 + 4.19608175913933472e-15*V04*V06*V16 + 
      2.78561256612454225e-15*V03*V07*V16 + 9.0681178229854095e-16*V02*V08*V16 + 2.9268286813651306e-16*V01*V09*V16 - 
      3.09136437900701946e-18*V12*V16 + 2.2634670281636147e-15*V013*V02*V17 - 
      6.17770127909519067e-15*V022*V03*V17 - 6.53047934152318814e-15*V01*V032*V17 - 
      7.67783317950771849e-15*V01*V02*V04*V17 - 2.0511501350392163e-15*V012*V05*V17 + 
      1.66542502867832306e-15*V04*V05*V17 + 1.20968981248612763e-15*V03*V06*V17 + 4.59361781662771704e-16*V02*V07*V17 + 
      1.61506163075077877e-16*V01*V08*V17 - 2.23869853224362068e-18*V11*V17 + 7.0366850616485431e-17*V014*V18 - 
      2.84125705711453396e-16*V023*V18 - 2.0406386678780775e-15*V01*V02*V03*V18 - 
      5.98352786408847782e-16*V012*V04*V18 + 2.39743769319844557e-16*V042*V18 + 
      4.49730179367873164e-16*V03*V05*V18 + 1.8656693397329227e-16*V02*V06*V18 + 7.66568652077034898e-17*V01*V07*V18 - 
      1.40818661755944889e-18*V10*V18 - 1.45659380776124842e-16*V01*V022*V19 - 
      1.45307546523042415e-16*V012*V03*V19 + 1.24989118407532247e-16*V03*V04*V19 + 
      6.69560129963252344e-17*V02*V05*V19 + 3.00247453260576178e-17*V01*V06*V19 - 7.77609064581874575e-19*V09*V19 - 
      2.07347653149910403e-17*V012*V02*V20 + 1.52043457177860856e-17*V032*V20 + 
      1.73045010189520295e-17*V02*V04*V20 + 1.006317766724534e-17*V01*V05*V20 - 3.67331530825485335e-19*V08*V20 - 
      8.44402207397825172e-19*V013*V21 + 4.13600710845786589e-18*V02*V03*V21 + 2.55163603545017408e-18*V01*V04*V21 - 
      1.5142786415541196e-19*V07*V21 + 2.56336384388625499e-19*V022*V22 + 5.59584002521574618e-19*V01*V03*V22 - 
      5.15649425762435032e-20*V06*V22 + 7.0366850616485431e-20*V01*V02*V23 - 1.53015162366157393e-20*V05*V23 + 
      4.18850301288603756e-21*V012*V24 - 3.42109223098484861e-21*V04*V24 - 6.83640721643468199e-22*V03*V25 - 
      7.6495010324738617e-23*V02*V26 - 8.82634734516214811e-24*V01*V27 + 6.47092913868192677e-27*V30) + 
   delta2*eps14*(-6.77936059264516573e-13*V028 - 1.48040897261592484e-8*V01*V026*V03 - 
      1.0920431292139003e-7*V012*V024*V032 - 
      1.07964182500246926e-7*V013*V022*V033 - 8.92507451554681558e-9*V014*V034 + 
      7.16508135962120041e-8*V023*V034 + 7.57774721395485856e-8*V01*V02*V035 - 
      2.96224161095630517e-8*V012*V025*V04 - 1.4644677288380603e-7*V013*V023*V03*V04 - 
      7.2639238722338629e-8*V014*V02*V032*V04 + 1.2940615229427052e-7*V024*V032*V04 + 
      5.05016599550344609e-7*V01*V022*V033*V04 + 1.03441260132924524e-7*V012*V034*V04 - 
      2.46279691325938992e-8*V014*V022*V042 + 1.18453251754498057e-8*V025*V042 - 
      6.12267071585173826e-9*V015*V03*V042 + 3.22712172227540327e-7*V01*V023*V03*V042 + 
      4.25770866093976561e-7*V012*V02*V032*V042 - 3.30997366463326056e-8*V034*V042 + 
      9.65038343425999201e-8*V012*V022*V043 + 5.06341396258389646e-8*V013*V03*V043 - 
      8.6350273137192877e-8*V02*V032*V043 - 1.26192122113177278e-8*V022*V044 - 
      2.64956794647521221e-8*V01*V03*V044 - 1.88743499761483344e-8*V013*V024*V05 - 
      3.74446296044101833e-8*V014*V022*V03*V05 + 2.63101690059325117e-8*V025*V03*V05 - 
      4.65396263472438387e-9*V015*V032*V05 + 2.76000471266865928e-7*V01*V023*V032*V05 + 
      2.32938477713765083e-7*V012*V02*V033*V05 - 1.12923567412594535e-8*V035*V05 - 
      6.30933179733950042e-9*V015*V02*V04*V05 + 8.41258680984350279e-8*V01*V024*V04*V05 + 
      4.7303392047082652e-7*V012*V022*V03*V04*V05 + 1.22747958597260093e-7*V013*V032*V04*V05 - 
      1.50625866327595507e-7*V02*V033*V04*V05 + 8.56954301256626993e-8*V013*V02*V042*V05 - 
      1.43644128220758013e-7*V022*V03*V042*V05 - 1.35481906677124622e-7*V01*V032*V042*V05 - 
      5.97025578326132457e-8*V01*V02*V043*V05 - 1.6179936498758472e-10*V016*V052 + 
      4.30610085160696067e-8*V012*V023*V052 + 
      6.89960454252874742e-8*V013*V02*V03*V052 - 
      6.35442194507606639e-8*V022*V032*V052 - 3.81480440064081809e-8*V01*V033*V052 + 
      8.73826353934827941e-9*V014*V04*V052 - 2.60823277846440233e-8*V023*V04*V052 - 
      1.54285479010351589e-7*V01*V02*V03*V04*V052 - 2.25413187427161668e-8*V012*V042*V052 + 
      3.90532729857493823e-9*V043*V052 - 1.44700335087487811e-8*V01*V022*V053 - 
      1.2548990277193841e-8*V012*V03*V053 + 6.82133692581095513e-9*V03*V04*V053 + 
      9.76207031356627678e-10*V02*V054 - 5.19540431859526164e-9*V014*V023*V06 + 
      1.38886154515450825e-9*V026*V06 - 3.8735695758921716e-9*V015*V02*V03*V06 + 
      6.05037934744465566e-8*V01*V024*V03*V06 + 1.62813979656106218e-7*V012*V022*V032*V06 + 
      2.77706287178561103e-8*V013*V033*V06 - 2.68152680018224238e-8*V02*V034*V06 - 
      2.61381180936503065e-10*V016*V04*V06 + 7.28294581997430096e-8*V012*V023*V04*V06 + 
      1.1605961161004761e-7*V013*V02*V03*V04*V06 - 1.03812989500712505e-7*V022*V032*V04*V06 - 
      6.37045359727982307e-8*V01*V033*V04*V06 + 7.32743954930033309e-9*V014*V042*V06 - 
      1.98537041988457781e-8*V023*V042*V06 - 1.27794949774625604e-7*V01*V02*V03*V042*V06 - 
      1.26114910845384246e-8*V012*V043*V06 + 1.57281609314195526e-9*V044*V06 + 
      3.23875808705728429e-8*V013*V022*V05*V06 + 1.17184474854237752e-8*V014*V03*V05*V06 - 
      3.80028671413827997e-8*V023*V03*V05*V06 - 1.09151784957895969e-7*V01*V02*V032*V05*V06 - 
      7.13545647343056767e-8*V01*V022*V04*V05*V06 - 6.31167276173674111e-8*V012*V03*V04*V05*V06 + 
      1.68878402086659347e-8*V03*V042*V05*V06 - 1.80483951533649046e-8*V012*V02*V052*V06 + 
      7.32499751470139244e-9*V032*V052*V06 + 9.60483973802659006e-9*V02*V04*V052*V06 + 
      1.7207268319421702e-9*V01*V053*V06 + 2.754461247299629e-9*V014*V02*V062 - 
      1.93139129787781293e-9*V024*V062 - 2.54888909561111366e-8*V01*V022*V03*V062 - 
      1.10211399583123908e-8*V012*V032*V062 - 
      1.51314059819809196e-8*V012*V02*V04*V062 + 6.06637024576421478e-9*V032*V04*V062 + 
      3.8565665577134839e-9*V02*V042*V062 - 2.33763648977358349e-9*V013*V05*V062 + 
      6.93392617221292808e-9*V02*V03*V05*V062 + 4.29258599213449928e-9*V01*V04*V05*V062 + 
      5.22374495747423834e-10*V022*V063 + 1.01967876714698683e-9*V01*V03*V063 - 
      1.61981873814974697e-11*V064 - 6.76014896807380468e-10*V015*V022*V07 + 
      4.33593802567739913e-9*V01*V025*V07 - 1.34612573338063534e-10*V016*V03*V07 + 
      4.29779447460624464e-8*V012*V023*V03*V07 + 3.38617434007307793e-8*V013*V02*V032*V07 - 
      2.19839631920941821e-8*V022*V033*V07 - 9.78909311560696705e-9*V01*V034*V07 + 
      2.35149281507133859e-8*V013*V022*V04*V07 + 8.47854989254558951e-9*V014*V03*V04*V07 - 
      2.73069340166947404e-8*V023*V03*V04*V07 - 7.9489428303064087e-8*V01*V02*V032*V04*V07 - 
      2.5800452177153592e-8*V01*V022*V042*V07 - 2.30477711618587558e-8*V012*V03*V042*V07 + 
      4.09879309868663075e-9*V03*V043*V07 + 4.75385163937119807e-9*V014*V02*V05*V07 - 
      3.64980746805947723e-9*V024*V05*V07 - 4.48016354102446272e-8*V01*V022*V03*V05*V07 - 
      1.91957479173865686e-8*V012*V032*V05*V07 - 2.6321071798170227e-8*V012*V02*V04*V05*V07 + 
      1.07016491827136303e-8*V032*V04*V05*V07 + 6.97162671891715349e-9*V02*V042*V05*V07 - 
      2.02895847836695065e-9*V013*V052*V07 + 6.13683665942584858e-9*V02*V03*V052*V07 + 
      3.77504031698813832e-9*V01*V04*V052*V07 + 3.00013932968485403e-10*V015*V06*V07 - 
      6.77525654269573126e-9*V01*V023*V06*V07 - 1.84281357169532686e-8*V012*V02*V03*V06*V07 + 
      2.55043702902929874e-9*V033*V06*V07 - 3.41800311567959914e-9*V013*V04*V06*V07 + 
      1.0085871061286609e-8*V02*V03*V04*V06*V07 + 3.13455186563870756e-9*V01*V042*V06*V07 + 
      2.83842094588102551e-9*V022*V05*V06*V07 + 5.3701181453537078e-9*V01*V03*V05*V06*V07 + 
      1.28296863415100783e-9*V01*V02*V062*V07 - 1.72806439901323266e-10*V05*V062*V07 - 
      1.89915492800495541e-9*V012*V022*V072 - 1.0244667592580363e-9*V013*V03*V072 + 
      1.60608676981416515e-9*V02*V032*V072 + 1.02721000574645548e-9*V022*V04*V072 + 
      1.96454191897263409e-9*V01*V03*V04*V072 + 1.13026648804552892e-9*V01*V02*V05*V072 - 
      7.6328448375778562e-11*V052*V072 + 2.3815653771309217e-10*V012*V06*V072 - 
      1.26247187420585492e-10*V04*V06*V072 - 2.6781123079734594e-11*V03*V073 - 
      4.04428126037603162e-11*V016*V02*V08 + 3.70619912339080818e-9*V012*V024*V08 + 
      1.20260728100298047e-8*V013*V022*V03*V08 + 2.15443241954833434e-9*V014*V032*V08 - 
      7.71747719679084377e-9*V023*V032*V08 - 1.44395558776375155e-8*V01*V02*V033*V08 + 
      3.02428678807099327e-9*V014*V02*V04*V08 - 2.15236742635870427e-9*V024*V04*V08 - 
      2.86230162779463422e-8*V01*V022*V03*V04*V08 - 1.23979177772740746e-8*V012*V032*V04*V08 - 
      8.50286385362641119e-9*V012*V02*V042*V08 + 3.43557114958981696e-9*V032*V042*V08 + 
      1.45164007832770004e-9*V02*V043*V08 + 2.27482774949404145e-10*V015*V05*V08 - 
      5.2602606225267868e-9*V01*V023*V05*V08 - 1.4191644784518425e-8*V012*V02*V03*V05*V08 + 
      1.97693136346455981e-9*V033*V05*V08 - 2.62535428067254653e-9*V013*V04*V05*V08 + 
      7.84435726611310563e-9*V02*V03*V04*V05*V08 + 2.43079260218527503e-9*V01*V042*V05*V08 + 
      1.10593892775909009e-9*V022*V052*V08 + 2.07867591963896903e-9*V01*V03*V052*V08 - 
      3.3660280812323271e-9*V012*V022*V06*V08 - 1.81316226771450397e-9*V013*V03*V06*V08 + 
      2.82333895319990764e-9*V02*V032*V06*V08 + 1.76789753886470859e-9*V022*V04*V06*V08 + 
      3.46571021569908854e-9*V01*V03*V04*V06*V08 + 1.99041597847113882e-9*V01*V02*V05*V06*V08 - 
      1.34333730514286088e-10*V052*V06*V08 + 2.10717422450450759e-10*V012*V062*V08 - 
      1.10394309545070329e-10*V04*V062*V08 - 7.59700899347595125e-10*V013*V02*V07*V08 + 
      1.1623311866377635e-9*V022*V03*V07*V08 + 1.07988656194421328e-9*V01*V032*V07*V08 + 
      1.4516277931883932e-9*V01*V02*V04*V07*V08 + 3.68058935720497847e-10*V012*V05*V07*V08 - 
      1.96387338771770464e-10*V04*V05*V07*V08 - 1.41486611519128464e-10*V03*V06*V07*V08 - 
      2.97897738597556043e-11*V02*V072*V08 - 2.6304195850885473e-11*V014*V082 + 
      6.69250966893665661e-11*V023*V082 + 4.01963981237859868e-10*V01*V02*V03*V082 + 
      1.19344716084984716e-10*V012*V04*V082 - 3.13507667480873498e-11*V042*V082 - 
      5.49646827795237187e-11*V03*V05*V082 - 2.60236645579306164e-11*V02*V06*V082 - 
      1.04049193000107398e-11*V01*V07*V082 - 8.8560903511883904e-13*V017*V09 + 
      1.26348276242485571e-9*V013*V023*V09 + 1.36659295722797768e-9*V014*V02*V03*V09 - 
      1.17867330162185437e-9*V024*V03*V09 - 7.06709184954519616e-9*V01*V022*V032*V09 - 
      1.98966279088787719e-9*V012*V033*V09 + 1.28624502322035063e-10*V015*V04*V09 - 
      2.99767945928471044e-9*V01*V023*V04*V09 - 8.21467894032972682e-9*V012*V02*V03*V04*V09 + 
      1.14767620547007992e-9*V033*V04*V09 - 7.61934606059657645e-10*V013*V042*V09 + 
      2.25942171059143868e-9*V02*V03*V042*V09 + 4.69453392948443198e-10*V01*V043*V09 - 
      2.32137801159080445e-9*V012*V022*V05*V09 - 1.24889421106117333e-9*V013*V03*V05*V09 + 
      1.97845454436777427e-9*V02*V032*V05*V09 + 1.26790266671206678e-9*V022*V04*V05*V09 + 
      2.4168111085869988e-9*V01*V03*V04*V05*V09 + 6.95470218757794505e-10*V01*V02*V052*V09 - 
      3.13955417032004739e-11*V053*V09 - 6.03075372380114091e-10*V013*V02*V06*V09 + 
      9.20556279457317563e-10*V022*V03*V06*V09 + 8.58027639641721463e-10*V01*V032*V06*V09 + 
      1.15164715012412271e-9*V01*V02*V04*V06*V09 + 2.92551756297764259e-10*V012*V05*V06*V09 - 
      1.5587211714914697e-10*V04*V05*V06*V09 - 5.61799912315210078e-11*V03*V062*V09 - 
      4.71894390005186623e-11*V014*V07*V09 + 1.23183751740294702e-10*V023*V07*V09 + 
      7.24053685037420673e-10*V01*V02*V03*V07*V09 + 2.14416071472199152e-10*V012*V04*V07*V09 - 
      5.69109190781872441e-11*V042*V07*V09 - 9.91441248502297078e-11*V03*V05*V07*V09 - 
      4.72626720917242638e-11*V02*V06*V07*V09 - 9.37359839638285725e-12*V01*V072*V09 + 
      1.32215555519699599e-10*V01*V022*V08*V09 + 1.16668487953866229e-10*V012*V03*V08*V09 - 
      6.38887627485246274e-11*V03*V04*V08*V09 - 3.67997757187780279e-11*V02*V05*V08*V09 - 
      1.65412582801487421e-11*V01*V06*V08*V09 + 1.96601932915358918e-11*V012*V02*V092 - 
      8.04602612395276514e-12*V032*V092 - 1.06428913065741181e-11*V02*V04*V092 - 
      5.78054069214448597e-12*V01*V05*V092 + 1.62632558940427334e-13*V08*V092 + 
      1.9412705419811113e-10*V014*V022*V10 - 5.89145968178609168e-11*V025*V10 + 
      5.19246560590729837e-11*V015*V03*V10 - 1.36312053847988926e-9*V01*V023*V03*V10 - 
      1.79732212015054018e-9*V012*V02*V032*V10 + 1.29601038036394919e-10*V034*V10 - 
      1.22012956609610616e-9*V012*V022*V04*V10 - 6.57258348854173704e-10*V013*V03*V04*V10 + 
      1.03588313558849776e-9*V02*V032*V04*V10 + 3.2271738633025647e-10*V022*V042*V10 + 
      6.3658428055647338e-10*V01*V03*V042*V10 - 3.765897500234988e-10*V013*V02*V05*V10 + 
      5.86238396084506771e-10*V022*V03*V05*V10 + 5.42017894611096117e-10*V01*V032*V05*V10 + 
      7.30121262429277007e-10*V01*V02*V04*V05*V10 + 9.22147741274854067e-11*V012*V052*V10 - 
      4.95502197888923637e-11*V04*V052*V10 - 3.39419945042495016e-11*V014*V06*V10 + 
      8.66163518400452365e-11*V023*V06*V10 + 5.21265209735285932e-10*V01*V02*V03*V06*V10 + 
      1.54798501770924273e-10*V012*V04*V06*V10 - 4.06784605136035292e-11*V042*V06*V10 - 
      7.13592261235662384e-11*V03*V05*V06*V10 - 1.68821023675533033e-11*V02*V062*V10 + 
      1.08049422230365136e-10*V01*V022*V07*V10 + 9.51787234038196936e-11*V012*V03*V07*V10 - 
      5.22225283382564195e-11*V03*V04*V07*V10 - 3.0094626591773042e-11*V02*V05*V07*V10 - 
      1.35129524767109043e-11*V01*V06*V07*V10 + 3.57152687395549535e-11*V012*V02*V08*V10 - 
      1.45855281201946647e-11*V032*V08*V10 - 1.91696225099222167e-11*V02*V04*V08*V10 - 
      1.04839019807551887e-11*V01*V05*V08*V10 + 1.4713929172631016e-13*V082*V10 + 
      3.27819589554603023e-12*V013*V09*V10 - 9.80933643597082688e-12*V02*V03*V09*V10 - 
      6.11262980200101886e-12*V01*V04*V09*V10 + 2.65918018350277643e-13*V07*V09*V10 - 
      7.28143247993447997e-13*V022*V102 - 1.38379506279499121e-12*V01*V03*V102 + 
      9.56054332045064385e-14*V06*V102 + 1.32957882772446756e-11*V015*V02*V11 - 
      8.68807341148996196e-11*V01*V024*V11 - 4.88946218755240774e-10*V012*V022*V03*V11 - 
      1.29527858681071958e-10*V013*V032*V11 + 1.44206716454350163e-10*V02*V033*V11 - 
      1.81419637337055474e-10*V013*V02*V04*V11 + 2.79732194370144444e-10*V022*V03*V04*V11 + 
      2.62230714485338964e-10*V01*V032*V04*V11 + 1.75445358954831996e-10*V01*V02*V042*V11 - 
      1.93660851697481006e-11*V014*V05*V11 + 5.16989741219468034e-11*V023*V05*V11 + 
      3.02356972436665113e-10*V01*V02*V03*V05*V11 + 8.93626099442325906e-11*V012*V04*V05*V11 - 
      2.38801446825827763e-11*V042*V05*V11 - 2.07784261180881639e-11*V03*V052*V11 + 
      7.11866337992756831e-11*V01*V022*V06*V11 + 6.29234847190653318e-11*V012*V03*V06*V11 - 
      3.44669003995249385e-11*V03*V04*V06*V11 - 1.98395331355610534e-11*V02*V05*V06*V11 - 
      4.46521002108368282e-12*V01*V062*V11 + 2.66763769286107457e-11*V012*V02*V07*V11 - 
      1.09315029182250901e-11*V032*V07*V11 - 1.44657640966603623e-11*V02*V04*V07*V11 - 
      7.85227128068329769e-12*V01*V05*V07*V11 + 2.72634164282573239e-12*V013*V08*V11 - 
      8.15182677906967336e-12*V02*V03*V08*V11 - 5.08212081601418996e-12*V01*V04*V08*V11 + 2.21038981336943604e-13*V07*V08*V11 - 
      1.34370108884726639e-12*V022*V09*V11 - 2.5371484700633984e-12*V01*V03*V09*V11 + 
      1.75676362412669289e-13*V06*V09*V11 - 7.79611618767132229e-13*V01*V02*V10*V11 + 1.11766482746642467e-13*V05*V10*V11 - 
      4.83756686640468386e-14*V012*V112 + 2.70814602647639111e-14*V04*V112 + 
      3.26277012938519646e-13*V016*V12 - 4.02756511239172396e-11*V012*V023*V12 - 
      6.57591528398230099e-11*V013*V02*V03*V12 + 5.44939173456632224e-11*V022*V032*V12 + 
      3.30799528352632082e-11*V01*V033*V12 - 8.57822774195545892e-12*V014*V04*V12 + 
      2.21675498707230582e-11*V023*V04*V12 + 1.34501481579439527e-10*V01*V02*V03*V04*V12 + 
      1.99894366419085294e-11*V012*V042*V12 - 3.51285763980346816e-12*V043*V12 + 
      3.82125520792679901e-11*V01*V022*V05*V12 + 3.35204196381054197e-11*V012*V03*V05*V12 - 
      1.85276925409456902e-11*V03*V04*V05*V12 - 5.34314323034669448e-12*V02*V052*V12 + 
      1.62804051213802143e-11*V012*V02*V06*V12 - 6.66003485802059185e-12*V032*V06*V12 - 
      8.74143070000553672e-12*V02*V04*V06*V12 - 4.78773954294365829e-12*V01*V05*V06*V12 + 
      1.8785836646914791e-12*V013*V07*V12 - 5.63893970098855739e-12*V02*V03*V07*V12 - 
      3.51171089485861346e-12*V01*V04*V07*V12 + 7.64176113497140217e-14*V072*V12 - 
      1.02349834383406234e-12*V022*V08*V12 - 1.94627804910327678e-12*V01*V03*V08*V12 + 
      1.34421930926666523e-13*V06*V08*V12 - 6.5937823064122352e-13*V01*V02*V09*V12 + 9.45263141379961822e-14*V05*V09*V12 - 
      8.92900822274547796e-14*V012*V10*V12 + 4.98582285777993878e-14*V04*V10*V12 + 
      2.10554191507460786e-14*V03*V11*V12 + 2.73367901264936733e-15*V02*V122 - 
      7.67883886700446585e-12*V013*V022*V13 - 2.84812642544249441e-12*V014*V03*V13 + 
      8.28486616371376446e-12*V023*V03*V13 + 2.37708585199823394e-11*V01*V02*V032*V13 + 
      1.56915366812789102e-11*V01*V022*V04*V13 + 1.39250811534182378e-11*V012*V03*V04*V13 - 
      3.8317759348780895e-12*V03*V042*V13 + 8.05162484985795154e-12*V012*V02*V05*V13 - 
      3.32098005943193082e-12*V032*V05*V13 - 4.40302957590590206e-12*V02*V04*V05*V13 - 
      1.19163275497142891e-12*V01*V052*V13 + 1.0645704326658664e-12*V013*V06*V13 - 
      3.18661047020081131e-12*V02*V03*V06*V13 - 1.98819927437716755e-12*V01*V04*V06*V13 - 
      6.61923698739859333e-13*V022*V07*V13 - 1.24857508865107947e-12*V01*V03*V07*V13 + 
      8.64789162414414022e-14*V06*V07*V13 - 4.69573425370452756e-13*V01*V02*V08*V13 + 6.72970639484009865e-14*V05*V08*V13 - 
      7.00838913454008995e-14*V012*V09*V13 + 3.92328863562626869e-14*V04*V09*V13 + 
      1.80332553128012751e-14*V03*V10*V13 + 5.08665613983146216e-15*V02*V11*V13 + 1.24192598405031732e-15*V01*V12*V13 - 
      6.21480024644799327e-13*V014*V02*V14 + 4.18259528017247027e-13*V024*V14 + 
      5.23025907843860777e-12*V01*V022*V03*V14 + 2.25848421073776013e-12*V012*V032*V14 + 
      3.11904302232700031e-12*V012*V02*V04*V14 - 1.28593290472853242e-12*V032*V04*V14 - 
      8.40404354685060075e-13*V02*V042*V14 + 4.90003317166595845e-13*V013*V05*V14 - 
      1.48716504495359629e-12*V02*V03*V05*V14 - 9.24523562360027521e-13*V01*V04*V05*V14 - 
      3.46489932206207614e-13*V022*V06*V14 - 6.60401436972625256e-13*V01*V03*V06*V14 + 
      2.27906452953688396e-14*V062*V14 - 2.81370861279224713e-13*V01*V02*V07*V14 + 
      4.03313985028964391e-14*V05*V07*V14 - 4.66334872556251264e-14*V012*V08*V14 + 
      2.60180000244437969e-14*V04*V08*V14 + 1.32184006254634684e-14*V03*V09*V14 + 4.05787048516569194e-15*V02*V10*V14 + 
      1.07626420210453919e-15*V01*V11*V14 - 3.00945075209797647e-18*V142 - 1.74791256931349811e-14*V015*V15 + 
      3.50887818941635426e-13*V01*V023*V15 + 9.50691335254026416e-13*V012*V02*V03*V15 - 
      1.34268202327189588e-13*V033*V15 + 1.78420075417641964e-13*V013*V04*V15 - 
      5.3755497302158974e-13*V02*V03*V04*V15 - 1.68020548512624352e-13*V01*V042*V15 - 
      1.53067225843757269e-13*V022*V05*V15 - 2.87650864332847304e-13*V01*V03*V05*V15 - 
      1.39401480833674252e-13*V01*V02*V06*V15 + 1.99767692321399744e-14*V05*V06*V15 - 
      2.61603343157269433e-14*V012*V07*V15 + 1.46521399827194866e-14*V04*V07*V15 + 8.2374395207120285e-15*V03*V08*V15 + 
      2.79456488207778428e-15*V02*V09*V15 + 8.06693305159312762e-16*V01*V10*V15 - 5.64611770807703596e-18*V13*V15 + 
      9.30348278740800477e-14*V012*V022*V16 + 5.0419255803724141e-14*V013*V03*V16 - 
      7.99581874357534261e-14*V02*V032*V16 - 5.1449212045395228e-14*V022*V04*V16 - 
      9.86891159457388108e-14*V01*V03*V04*V16 - 5.72981683338832929e-14*V01*V02*V05*V16 + 
      4.11288111408038484e-15*V052*V16 - 1.22350361509414043e-14*V012*V06*V16 + 
      6.81791291295605637e-15*V04*V06*V16 + 4.35826189767930515e-15*V03*V07*V16 + 1.63579949301951267e-15*V02*V08*V16 + 
      5.21877956080570993e-16*V01*V09*V16 - 4.6465463027520719e-18*V12*V16 + 9.45730472285564193e-15*V013*V02*V17 - 
      1.47208372960350357e-14*V022*V03*V17 - 1.36339794032332893e-14*V01*V032*V17 - 
      1.85038680862556275e-14*V01*V02*V04*V17 - 4.72902932669898071e-15*V012*V05*V17 + 
      2.66027784544871341e-15*V04*V05*V17 + 1.92177254251781137e-15*V03*V06*V17 + 8.1988815581430706e-16*V02*V07*V17 + 
      2.89404615675360765e-16*V01*V08*V17 - 3.35814793728803795e-18*V11*V17 + 3.1665082777418444e-16*V014*V18 - 
      8.29424120623744702e-16*V023*V18 - 4.8804939726509656e-15*V01*V02*V03*V18 - 
      1.45787548968319155e-15*V012*V04*V18 + 4.0645987167588428e-16*V042*V18 + 
      7.08583714450476075e-16*V03*V05*V18 + 3.41523594722877577e-16*V02*V06*V18 + 1.37054101336150478e-16*V01*V07*V18 - 
      2.11874812168677405e-18*V10*V18 - 4.08102602557538184e-16*V01*V022*V19 - 
      3.59172510361003493e-16*V012*V03*V19 + 2.06870163806441395e-16*V03*V04*V19 + 
      1.20265743559900662e-16*V02*V05*V19 + 5.45211453611642815e-17*V01*V06*V19 - 1.16651373579541879e-18*V09*V19 - 
      5.85804031382241213e-17*V012*V02*V20 + 2.49212937478852888e-17*V032*V20 + 
      3.32330189624136686e-17*V02*V04*V20 + 1.81795989698585766e-17*V01*V05*V20 - 5.54337713361920317e-19*V08*V20 - 
      2.48797078965430631e-18*V013*V21 + 7.73323311269149115e-18*V02*V03*V21 + 4.84819223741558848e-18*V01*V04*V21 - 
      2.27241935155724871e-19*V07*V21 + 5.6209710432930624e-19*V022*V22 + 1.0596912622601675e-18*V01*V03*V22 - 
      7.85935794816145506e-20*V06*V22 + 1.52042659367763163e-19*V01*V02*V23 - 2.30524132775305395e-20*V05*V23 + 
      9.21470662834928263e-21*V012*V24 - 5.40846469503008574e-21*V04*V24 - 1.06277245987884229e-21*V03*V25 - 
      1.35604791030218457e-22*V02*V26 - 1.56467066573328989e-23*V01*V27 + 9.70639370802289015e-27*V30) + 
   delta4*eps13*(3.18505244927949122e-8*V023*V034 + 
      3.63721924280541002e-8*V01*V02*V035 + 4.86280695245372734e-8*V024*V032*V04 + 
      2.20211288493910388e-7*V01*V022*V033*V04 + 4.81455433084979275e-8*V012*V034*V04 + 
      2.55551047231023315e-9*V025*V042 + 1.22467626134807859e-7*V01*V023*V03*V042 + 
      1.82618989316787222e-7*V012*V02*V032*V042 - 2.63043652949928417e-8*V034*V042 + 
      3.73852520711127092e-8*V012*V022*V043 + 2.13886804421684309e-8*V013*V03*V043 - 
      6.22302068234421287e-8*V02*V032*V043 - 7.48454109323006102e-9*V022*V044 - 
      1.89889705506979006e-8*V01*V03*V044 + 9.08877376716545462e-9*V025*V03*V05 + 
      1.127081971564928e-7*V01*V023*V032*V05 + 1.02227016938670972e-7*V012*V02*V033*V05 - 
      9.18722452646237804e-9*V035*V05 + 2.91768417147223641e-8*V01*V024*V04*V05 + 
      1.90491982020819433e-7*V012*V022*V03*V04*V05 + 5.2436987914532368e-8*V013*V032*V04*V05 - 
      1.1342515053938193e-7*V02*V033*V04*V05 + 3.41235578420273205e-8*V013*V02*V042*V05 - 
      9.68540158679057273e-8*V022*V03*V042*V05 - 1.00369376300120491e-7*V01*V032*V042*V05 - 
      4.01248891726478198e-8*V01*V02*V043*V05 + 1.63956984563859441e-8*V012*V023*V052 + 
      2.79747121631947565e-8*V013*V02*V03*V052 - 
      4.53148478367601859e-8*V022*V032*V052 - 2.89100329191507154e-8*V01*V033*V052 + 
      3.45255048570379637e-9*V014*V04*V052 - 1.64487535725404588e-8*V023*V04*V052 - 
      1.08434403511903222e-7*V01*V02*V03*V04*V052 - 1.56374099398400389e-8*V012*V042*V052 + 
      3.51432810587743948e-9*V043*V052 - 9.6527288121086455e-9*V01*V022*V053 - 
      8.89236660403888461e-9*V012*V03*V053 + 6.37070244243975691e-9*V03*V04*V053 + 
      8.70665404797237582e-10*V02*V054 + 2.88337306258509828e-10*V026*V06 + 
      2.14127839125225537e-8*V01*V024*V03*V06 + 6.46748847236896075e-8*V012*V022*V032*V06 + 
      1.15939507572439985e-8*V013*V033*V06 - 2.01311269479684964e-8*V02*V034*V06 + 
      2.62297576837808744e-8*V012*V023*V04*V06 + 4.53983681217831457e-8*V013*V02*V03*V04*V06 - 
      7.04622926468160372e-8*V022*V032*V04*V06 - 4.69515380809358884e-8*V01*V033*V04*V06 + 
      2.81550684672345435e-9*V014*V042*V06 - 1.10057452915525098e-8*V023*V042*V06 - 
      8.62832503087032985e-8*V01*V02*V03*V042*V06 - 8.49593548288469685e-9*V012*V043*V06 + 
      1.33994572989674115e-9*V044*V06 + 1.20600599618847086e-8*V013*V022*V05*V06 + 
      4.53345299684557244e-9*V014*V03*V05*V06 - 2.41832286704071995e-8*V023*V03*V05*V06 - 
      7.64383659411645021e-8*V01*V02*V032*V05*V06 - 4.52448497920386642e-8*V01*V022*V04*V05*V06 - 
      4.35333307398547151e-8*V012*V03*V04*V05*V06 + 1.52791783583975097e-8*V03*V042*V05*V06 - 
      1.18566082543781223e-8*V012*V02*V052*V06 + 6.84649330739555099e-9*V032*V052*V06 + 
      8.24900618460748895e-9*V02*V04*V052*V06 + 1.51752357682272738e-9*V01*V053*V06 + 
      9.89573025098675417e-10*V014*V02*V062 - 1.00621175759930092e-9*V024*V062 - 
      1.62398406121865215e-8*V01*V022*V03*V062 - 
      7.54303035550392635e-9*V012*V032*V062 - 
      9.62212950083595293e-9*V012*V02*V04*V062 + 5.50852218256165074e-9*V032*V04*V062 + 
      3.12314385202035802e-9*V02*V042*V062 - 1.50463180780930825e-9*V013*V05*V062 + 
      5.98730146085247858e-9*V02*V03*V05*V062 + 3.67732894685077508e-9*V01*V04*V05*V062 + 
      4.02216236474883255e-10*V022*V063 + 8.74923136859372532e-10*V01*V03*V063 - 
      1.56326322935584384e-11*V064 + 1.2983962524522078e-9*V01*V025*V07 + 
      1.53358521940482015e-8*V012*V023*V03*V07 + 1.28821030582685537e-8*V013*V02*V032*V07 - 
      1.52057234858673829e-8*V022*V033*V07 - 7.1966015555823278e-9*V01*V034*V07 + 
      8.33788698921045719e-9*V013*V022*V04*V07 + 3.1524744417257051e-9*V014*V03*V04*V07 - 
      1.66690503320626575e-8*V023*V03*V04*V07 - 5.41831353659940985e-8*V01*V02*V032*V04*V07 - 
      1.57423995044342967e-8*V01*V022*V042*V07 - 1.55071770654304034e-8*V012*V03*V042*V07 + 
      3.63056176385854998e-9*V03*V043*V07 + 1.68644227601874988e-9*V014*V02*V05*V07 - 
      2.08275626822208695e-9*V024*V05*V07 - 2.89353723479750314e-8*V01*V022*V03*V05*V07 - 
      1.31723789622309176e-8*V012*V032*V05*V07 - 1.68135074683681121e-8*V012*V02*V04*V05*V07 + 
      9.82556959504886347e-9*V032*V04*V05*V07 + 5.84401911197995448e-9*V02*V042*V05*V07 - 
      1.30597937309827061e-9*V013*V052*V07 + 5.37533867082611707e-9*V02*V03*V052*V07 + 
      3.26748690758610518e-9*V01*V04*V052*V07 + 1.01868714468176768e-10*V015*V06*V07 - 
      3.90428078727924281e-9*V01*V023*V06*V07 - 1.17152393177145516e-8*V012*V02*V03*V06*V07 + 
      2.34193868762891403e-9*V033*V06*V07 - 2.14733137714440164e-9*V013*V04*V06*V07 + 
      8.51170268603944697e-9*V02*V03*V04*V06*V07 + 2.62917968353437623e-9*V01*V042*V06*V07 + 
      2.26767323426982697e-9*V022*V05*V06*V07 + 4.64599993088529148e-9*V01*V03*V05*V06*V07 + 
      1.02554412273967743e-9*V01*V02*V062*V07 - 1.69692547625464458e-10*V05*V062*V07 - 
      1.11385142759241345e-9*V012*V022*V072 - 6.36928455389441702e-10*V013*V03*V072 + 
      1.38039185954295375e-9*V02*V032*V072 + 7.97930242680080783e-10*V022*V04*V072 + 
      1.66777940865396535e-9*V01*V03*V04*V072 + 9.15168885829463326e-10*V01*V02*V05*V072 - 
      7.5808356099106596e-11*V052*V072 + 1.90681145709286893e-10*V012*V06*V072 - 
      1.21840726101504731e-10*V04*V06*V072 - 2.6258350610958125e-11*V03*V073 + 
      1.17873064363543779e-9*V012*V024*V08 + 4.1417004738106205e-9*V013*V022*V03*V08 + 
      7.69598135768425156e-10*V014*V032*V08 - 4.78582454024383036e-9*V023*V032*V08 - 
      9.78364364295661489e-9*V01*V02*V033*V08 + 1.02236238518465225e-9*V014*V02*V04*V08 - 
      1.07335922095479893e-9*V024*V04*V08 - 1.7666598363670202e-8*V01*V022*V03*V04*V08 - 
      8.25645236091534951e-9*V012*V032*V04*V08 - 5.24241953228154301e-9*V012*V02*V042*V08 + 
      3.06749469303890093e-9*V032*V042*V08 + 1.15147301410125573e-9*V02*V043*V08 + 
      7.5684614251274468e-11*V015*V05*V08 - 3.05268802684342601e-9*V01*V023*V05*V08 - 
      9.00080673055107691e-9*V012*V02*V03*V05*V08 + 1.81776654893730941e-9*V033*V05*V08 - 
      1.64167928677275453e-9*V013*V04*V05*V08 + 6.64996784730874228e-9*V02*V03*V04*V05*V08 + 
      2.04479743791149181e-9*V01*V042*V05*V08 + 8.88924442047801394e-10*V022*V052*V08 + 
      1.79996744733944907e-9*V01*V03*V052*V08 - 1.96127162358134322e-9*V012*V022*V06*V08 - 
      1.12213642527512182e-9*V013*V03*V06*V08 + 2.40249365253839521e-9*V02*V032*V06*V08 + 
      1.33104575196264348e-9*V022*V04*V06*V08 + 2.92046432769812936e-9*V01*V03*V04*V06*V08 + 
      1.59613241280570689e-9*V01*V02*V05*V06*V08 - 1.32373220655687102e-10*V052*V06*V08 + 
      1.67849912174092015e-10*V012*V062*V08 - 1.05064239499054197e-10*V04*V062*V08 - 
      4.38134433995168848e-10*V013*V02*V07*V08 + 9.1562977374539827e-10*V022*V03*V07*V08 + 
      9.16073224999735284e-10*V01*V032*V07*V08 + 1.13678748467010487e-9*V01*V02*V04*V07*V08 + 
      2.94635690820664217e-10*V012*V05*V07*V08 - 1.90277073571282235e-10*V04*V05*V07*V08 - 
      1.37676614479106501e-10*V03*V06*V07*V08 - 2.71602960967982247e-11*V02*V072*V08 - 
      1.46974476899703569e-11*V014*V082 + 4.67020500796749011e-11*V023*V082 + 
      3.16437915317272677e-10*V01*V02*V03*V082 + 9.31924276075612557e-11*V012*V04*V082 - 
      2.9411372146011677e-11*V042*V082 - 5.36415084260776916e-11*V03*V05*V082 - 
      2.33647418122495086e-11*V02*V06*V082 - 9.48457735842490118e-12*V01*V07*V082 + 
      3.91230923728553628e-10*V013*V023*V09 + 4.42135871640047214e-10*V014*V02*V03*V09 - 
      6.43958473146301573e-10*V024*V03*V09 - 4.37396336505996984e-9*V01*V022*V032*V09 - 
      1.30616120901256233e-9*V012*V033*V09 + 4.06848568776442996e-11*V015*V04*V09 - 
      1.63998021246363375e-9*V01*V023*V04*V09 - 5.02644834460716071e-9*V012*V02*V03*V04*V09 + 
      1.0317800007922306e-9*V033*V04*V09 - 4.61641505642926528e-10*V013*V042*V09 + 
      1.85715228858623926e-9*V02*V03*V042*V09 + 3.83987891618186205e-10*V01*V043*V09 - 
      1.34869854465960826e-9*V012*V022*V05*V09 - 7.67563284728317524e-10*V013*V03*V05*V09 + 
      1.69535068127518958e-9*V02*V032*V05*V09 + 9.83370620053382776e-10*V022*V04*V05*V09 + 
      2.04414704178147889e-9*V01*V03*V04*V05*V09 + 5.61122958220973023e-10*V01*V02*V052*V09 - 
      3.11475340296209412e-11*V053*V09 - 3.45447052772571488e-10*V013*V02*V06*V09 + 
      7.19545429367092386e-10*V022*V03*V06*V09 + 7.24520732552396125e-10*V01*V032*V06*V09 + 
      8.95806134417942697e-10*V01*V02*V04*V06*V09 + 2.33114762235612664e-10*V012*V05*V06*V09 - 
      1.50326399455284042e-10*V04*V05*V06*V09 - 5.44357367725202814e-11*V03*V062*V09 - 
      2.63007328148715229e-11*V014*V07*V09 + 8.808547805048216e-11*V023*V07*V09 + 
      5.71606658686828422e-10*V01*V02*V03*V07*V09 + 1.6750913293993274e-10*V012*V04*V07*V09 - 
      5.38933383863524193e-11*V042*V07*V09 - 9.70805070320080759e-11*V03*V05*V07*V09 - 
      4.28576455668270535e-11*V02*V06*V07*V09 - 8.56808169350499234e-12*V01*V072*V09 + 
      9.56567284175025444e-11*V01*V022*V08*V09 + 9.07855616440092102e-11*V012*V03*V08*V09 - 
      6.10575889780192126e-11*V03*V04*V08*V09 - 3.35235469163562455e-11*V02*V05*V08*V09 - 
      1.50159266354684833e-11*V01*V06*V08*V09 + 1.4237649197214055e-11*V012*V02*V092 - 
      7.75804452920970187e-12*V032*V092 - 9.44547422724473388e-12*V02*V04*V092 - 
      5.27275798192250623e-12*V01*V05*V092 + 1.62209010435199681e-13*V08*V092 + 
      5.66129459949871887e-11*V014*V022*V10 - 2.60147233692765675e-11*V025*V10 + 
      1.55641903671981931e-11*V015*V03*V10 - 7.58058485366556084e-10*V01*V023*V03*V10 - 
      1.08531681094815636e-9*V012*V02*V032*V10 + 1.16495112081095023e-10*V034*V10 - 
      6.78578220258866758e-10*V012*V022*V04*V10 - 3.90624018049454307e-10*V013*V03*V04*V10 + 
      8.60439499924655013e-10*V02*V032*V04*V10 + 2.35713014144629767e-10*V022*V042*V10 + 
      5.23776101821119376e-10*V01*V03*V042*V10 - 2.13815204239396951e-10*V013*V02*V05*V10 + 
      4.61452611775551575e-10*V022*V03*V05*V10 + 4.5768945085936976e-10*V01*V032*V05*V10 + 
      5.70409450823507391e-10*V01*V02*V04*V05*V10 + 7.34056698297882596e-11*V012*V052*V10 - 
      4.80236999816768472e-11*V04*V052*V10 - 1.87661492815095823e-11*V014*V06*V10 + 
      5.99864583279271968e-11*V023*V06*V10 + 4.08055882260348244e-10*V01*V02*V03*V06*V10 + 
      1.20220118169600808e-10*V012*V04*V06*V10 - 3.80214936113489014e-11*V042*V06*V10 - 
      6.9418737144367214e-11*V03*V05*V06*V10 - 1.50966009032377833e-11*V02*V062*V10 + 
      7.82649779494927435e-11*V01*V022*V07*V10 + 7.40002881260226992e-11*V012*V03*V07*V10 - 
      4.9960064984061922e-11*V03*V04*V07*V10 - 2.74551878188769003e-11*V02*V05*V07*V10 - 
      1.22743487738676006e-11*V01*V06*V07*V10 + 2.58338107903474653e-11*V012*V02*V08*V10 - 
      1.4031300967953815e-11*V032*V08*V10 - 1.68679055416063672e-11*V02*V04*V08*V10 - 
      9.54269372783091531e-12*V01*V05*V08*V10 + 1.46184206223479291e-13*V082*V10 + 
      2.33285777480705712e-12*V013*V09*V10 - 8.80977169171704396e-12*V02*V03*V09*V10 - 
      5.44534025109327628e-12*V01*V04*V09*V10 + 2.65515777874997473e-13*V07*V09*V10 - 
      5.98556989462812633e-13*V022*V102 - 1.23709872544326281e-12*V01*V03*V102 + 
      9.4728248490629138e-14*V06*V102 + 3.6006998927858061e-12*V015*V02*V11 - 
      4.22611965687255014e-11*V01*V024*V11 - 2.69223481997489627e-10*V012*V022*V03*V11 - 
      7.52158684916149196e-11*V013*V032*V11 + 1.20466492812944193e-10*V02*V033*V11 - 
      9.90726554912275802e-11*V013*V02*V04*V11 + 2.11889475625539213e-10*V022*V03*V04*V11 + 
      2.15882504608447582e-10*V01*V032*V04*V11 + 1.3239082818032087e-10*V01*V02*V042*V11 - 
      1.05676574369177507e-11*V014*V05*V11 + 3.68766460694458115e-11*V023*V05*V11 + 
      2.37258763444041042e-10*V01*V02*V03*V05*V11 + 6.93111458769612241e-11*V012*V04*V05*V11 - 
      2.25927798366105915e-11*V042*V05*V11 - 2.03066668092039309e-11*V03*V052*V11 + 
      5.10166528102996563e-11*V01*V022*V06*V11 + 4.86208624060895373e-11*V012*V03*V06*V11 - 
      3.27779746623279576e-11*V03*V04*V06*V11 - 1.79715269198994481e-11*V02*V05*V06*V11 - 
      4.03359948842296111e-12*V01*V062*V11 + 1.92723621175207832e-11*V012*V02*V07*V11 - 
      1.05337095924375969e-11*V032*V07*V11 - 1.28352990708805977e-11*V02*V04*V07*V11 - 
      7.15694508662561397e-12*V01*V05*V07*V11 + 1.93735860627909373e-12*V013*V08*V11 - 
      7.308725112011296e-12*V02*V03*V08*V11 - 4.52103645943165979e-12*V01*V04*V08*V11 + 2.20451685999036251e-13*V07*V08*V11 - 
      1.11236124366589006e-12*V022*V09*V11 - 2.26969308599313256e-12*V01*V03*V09*V11 + 
      1.74545415140438758e-13*V06*V09*V11 - 6.49342593590556008e-13*V01*V02*V10*V11 + 1.11535517267321896e-13*V05*V10*V11 - 
      4.00456907400402159e-14*V012*V112 + 2.6471027975282667e-14*V04*V112 + 
      8.15692532346299116e-14*V016*V12 - 2.00220764487376347e-11*V012*V023*V12 - 
      3.51011363026503513e-11*V013*V02*V03*V12 + 4.17954534326439906e-11*V022*V032*V12 + 
      2.71142029427501048e-11*V01*V033*V12 - 4.50989187526839868e-12*V014*V04*V12 + 
      1.47773497138961349e-11*V023*V04*V12 + 1.02231643770260481e-10*V01*V02*V03*V04*V12 + 
      1.50829757112720278e-11*V012*V042*V12 - 3.21772792392402653e-12*V043*V12 + 
      2.75369411008746056e-11*V01*V022*V05*V12 + 2.58349588575002053e-11*V012*V03*V05*V12 - 
      1.76999490677589296e-11*V03*V04*V05*V12 - 4.86997794082214239e-12*V02*V052*V12 + 
      1.16751937284455787e-11*V012*V02*V06*V12 - 6.37893891160118162e-12*V032*V06*V12 - 
      7.64809430805109003e-12*V02*V04*V06*V12 - 4.33755560748989182e-12*V01*V05*V06*V12 + 
      1.33162343252392584e-12*V013*V07*V12 - 5.06384511615505956e-12*V02*V03*V07*V12 - 
      3.12657910430170865e-12*V01*V04*V07*V12 + 7.6325566608852036e-14*V072*V12 - 
      8.39941755135893245e-13*V022*V08*V12 - 1.73792092326055824e-12*V01*V03*V08*V12 + 
      1.33082218080737001e-13*V06*V08*V12 - 5.49319219559307979e-13*V01*V02*V09*V12 + 9.43649626429614981e-14*V05*V09*V12 - 
      7.38962920359087716e-14*V012*V10*V12 + 4.86168110418902168e-14*V04*V10*V12 + 
      2.07659253560811614e-14*V03*V11*V12 + 2.51193328373489934e-15*V02*V122 - 
      3.74830139863894594e-12*V013*V022*V13 - 1.45173849506871093e-12*V014*V03*V13 + 
      5.74286457874053768e-12*V023*V03*V13 + 1.80651852232010083e-11*V01*V02*V032*V13 + 
      1.08460109051957683e-11*V01*V022*V04*V13 + 1.04432046814520366e-11*V012*V03*V04*V13 - 
      3.57219783345162278e-12*V03*V042*V13 + 5.76120195662436643e-12*V012*V02*V05*V13 - 
      3.19113738750312649e-12*V032*V05*V13 - 3.90162991167765306e-12*V02*V04*V05*V13 - 
      1.08233472484424937e-12*V01*V052*V13 + 7.49500111372576426e-13*V013*V06*V13 - 
      2.83998617873802873e-12*V02*V03*V06*V13 - 1.75880291043392719e-12*V01*V04*V06*V13 - 
      5.47705382846011738e-13*V022*V07*V13 - 1.11537468855877233e-12*V01*V03*V07*V13 + 
      8.5915233489542932e-14*V06*V07*V13 - 3.90304155294798801e-13*V01*V02*V08*V13 + 6.70794781977199116e-14*V05*V08*V13 - 
      5.79802142644036248e-14*V012*V09*V13 + 3.83471522803672365e-14*V04*V09*V13 + 
      1.77783711966391176e-14*V03*V10*V13 + 4.68364899080586693e-15*V02*V11*V13 + 1.14416186673276144e-15*V01*V12*V13 - 
      2.91318761552249684e-13*V014*V02*V14 + 2.52540059289842007e-13*V024*V14 + 
      3.64672614610554305e-12*V01*V022*V03*V14 + 1.67736648427608526e-12*V012*V032*V14 + 
      2.16095643264539821e-12*V012*V02*V04*V14 - 1.20810668715732339e-12*V032*V04*V14 - 
      7.18035830608108554e-13*V02*V042*V14 + 3.42893139470879588e-13*V013*V05*V14 - 
      1.33245749293661185e-12*V02*V03*V05*V14 - 8.20379330291747371e-13*V01*V04*V05*V14 - 
      2.82251563338370215e-13*V022*V06*V14 - 5.86499596277395136e-13*V01*V03*V06*V14 + 
      2.24758463681045585e-14*V062*V14 - 2.34106216881593815e-13*V01*V02*V07*V14 + 
      4.02608362610552551e-14*V05*V07*V14 - 3.85218541191054779e-14*V012*V08*V14 + 
      2.53398129021924342e-14*V04*V08*V14 + 1.3036682773732178e-14*V03*V09*V14 + 3.72723483358878026e-15*V02*V10*V14 + 
      9.91590347838307129e-16*V01*V11*V14 - 3.00764386188423156e-18*V142 - 7.76850030805999158e-15*V015*V15 + 
      2.20677982838721506e-13*V01*V023*V15 + 6.54111143757109806e-13*V012*V02*V03*V15 - 
      1.26586780996767497e-13*V033*V15 + 1.21334063138367375e-13*V013*V04*V15 - 
      4.68214925541707296e-13*V02*V03*V04*V15 - 1.45347384212898577e-13*V01*V042*V15 - 
      1.26430357163248255e-13*V022*V05*V15 - 2.55796628759366927e-13*V01*V03*V05*V15 - 
      1.1508045222300198e-13*V01*V02*V06*V15 + 1.98341955813692e-14*V05*V06*V15 - 2.1591020985915333e-14*V012*V07*V15 + 
      1.43192025798299961e-14*V04*V07*V15 + 8.11096627607026363e-15*V03*V08*V15 + 2.57288500931838043e-15*V02*V09*V15 + 
      7.42846303717552481e-16*V01*V10*V15 - 5.64610486975362482e-18*V13*V15 + 
      5.88020587176660504e-14*V012*V022*V16 + 3.37409048706047642e-14*V013*V03*V16 - 
      7.02484835213412716e-14*V02*V032*V16 - 4.07633155139853916e-14*V022*V04*V16 - 
      8.57325247053663237e-14*V01*V03*V04*V16 - 4.74695276879172264e-14*V01*V02*V05*V16 + 
      4.10209108608402237e-15*V052*V16 - 1.00416846632135019e-14*V012*V06*V16 + 
      6.61145782073216814e-15*V04*V06*V16 + 4.2966690724044799e-15*V03*V07*V16 + 1.50007808449502892e-15*V02*V08*V16 + 
      4.80674763472474975e-16*V01*V09*V16 - 4.64335918335409983e-18*V12*V16 + 5.86859534141488495e-15*V013*V02*V17 - 
      1.19149926357267822e-14*V022*V03*V17 - 1.18390969611332872e-14*V01*V032*V17 - 
      1.4884523993778622e-14*V01*V02*V04*V17 - 3.87688676573334214e-15*V012*V05*V17 + 
      2.59785490964646764e-15*V04*V05*V17 + 1.8845229885090693e-15*V03*V06*V17 + 7.54640493580170944e-16*V02*V07*V17 + 
      2.66124915929740168e-16*V01*V08*V17 - 3.3581350989646268e-18*V11*V17 + 1.89990496664510664e-16*V014*V18 - 
      6.05825075783836473e-16*V023*V18 - 3.94506721777710106e-15*V01*V02*V03*V18 - 
      1.16688343136594698e-15*V012*V04*V18 + 3.87179633840501464e-16*V042*V18 + 
      6.97503727813721544e-16*V03*V05*V18 + 3.11560799350905788e-16*V02*V06*V18 + 1.26116523801834072e-16*V01*V07*V18 - 
      2.11657151525344931e-18*V10*V18 - 3.03582698373980002e-16*V01*V022*V19 - 
      2.85990985719858645e-16*V012*V03*V19 + 1.99407647605149438e-16*V03*V04*V19 + 
      1.10578573791697835e-16*V02*V05*V19 + 4.99049164096528102e-17*V01*V06*V19 - 1.16650089747200765e-18*V09*V19 - 
      4.34263992376024374e-17*V012*V02*V20 + 2.41702552671699376e-17*V032*V20 + 
      2.97024699370947006e-17*V02*V04*V20 + 1.66810124276052793e-17*V01*V05*V20 - 5.5320369966989838e-19*V08*V20 - 
      1.80943330156676823e-18*V013*V21 + 7.00387512138093581e-18*V02*V03*V21 + 4.35325079805955504e-18*V01*V04*V21 - 
      2.27229096832313726e-19*V07*V21 + 4.69112337443236207e-19*V022*V22 + 9.54280603102535557e-19*V01*V03*V22 - 
      7.81576496250736201e-20*V06*V22 + 1.27749341893024146e-19*V01*V02*V23 - 2.30395749541193945e-20*V05*V23 + 
      7.67892219029106886e-21*V012*V24 - 5.29564792805464956e-21*V04*V24 - 1.04993413646769735e-21*V03*V25 - 
      1.25173653258663191e-22*V02*V26 - 1.44431138375380606e-23*V01*V27 + 9.70639370802289015e-27*V30) + 
   1.21612504155351795e-34*delta30*V30 + 9.12093781165138462e-34*delta28*eps*V30 + 
   delta28*eps2*(-2.35802875569598315e-27*V152 - 3.88381206820514871e-27*V14*V16 - 
      3.64107381394232692e-27*V13*V17 - 2.299625566700417e-27*V12*V18 - 1.66084068706141228e-27*V11*V19 - 
      7.90876517648291561e-28*V10*V20 - 4.34982084706560358e-28*V09*V21 - 1.51298116419673168e-28*V08*V22 - 
      6.1894683989866296e-29*V07*V23 - 1.48547241575679111e-29*V06*V24 - 4.33262787929064072e-30*V05*V25 - 
      6.41870796931946774e-31*V04*V26 - 1.23436691717682072e-31*V03*V27 - 8.51287529087462565e-33*V02*V28 - 
      9.12093781165138462e-34*V01*V29 + 6.90980137246317017e-36*V32) + 
   delta26*eps3*(-3.3012402579743764e-26*V152 - 5.43733689548720819e-26*V14*V16 - 
      5.09750333951925768e-26*V13*V17 - 3.2194757933805838e-26*V12*V18 - 2.32517696188597719e-26*V11*V19 - 
      1.10722712470760818e-26*V10*V20 - 6.08974918589184502e-27*V09*V21 - 2.11817362987542435e-27*V08*V22 - 
      8.66525575858128145e-28*V07*V23 - 2.07966138205950755e-28*V06*V24 - 6.06567903100689701e-29*V05*V25 - 
      8.98619115704725483e-30*V04*V26 - 1.72811368404754901e-30*V03*V27 - 1.19180254072244759e-31*V02*V28 - 
      1.27693129363119385e-32*V01*V29 + 4.83686096072421912e-35*V32) + 
   delta24*eps4*(5.82653552668301284e-21*V092*V10 + 3.78906976049804394e-21*V08*V102 + 
      9.37178201117267674e-21*V08*V09*V11 + 7.62746468947594408e-21*V07*V10*V11 + 2.31034800014561205e-21*V06*V112 + 
      2.56133770803090351e-21*V082*V12 + 6.41182552076610282e-21*V07*V09*V12 + 3.14022056007147858e-21*V06*V10*V12 + 
      2.44815156247433017e-21*V05*V11*V12 + 3.37091638217619308e-22*V04*V122 + 4.32543785131046619e-21*V07*V08*V13 + 
      3.25818307712842725e-21*V06*V09*V13 + 2.05354818562813879e-21*V05*V10*V13 + 8.32371531241272257e-22*V04*V11*V13 + 
      3.13865584932606432e-22*V03*V12*V13 + 2.67609159992692984e-23*V02*V132 + 
      1.27167872828527706e-21*V072*V14 + 1.53007662427225882e-21*V06*V08*V14 + 1.4836251829994899e-21*V05*V09*V14 + 
      4.85955699038520547e-22*V04*V10*V14 + 2.69750033272634528e-22*V03*V11*V14 + 3.72376329778067631e-23*V02*V12*V14 + 
      1.03750012797167126e-23*V01*V13*V14 + 1.11709134072974648e-21*V06*V07*V15 + 8.65087570262093237e-22*V05*V08*V15 + 
      4.36004135412094992e-22*V04*V09*V15 + 1.95576017678870361e-22*V03*V10*V15 + 3.97590751989143862e-23*V02*V11*V15 + 
      8.96758814093161233e-24*V01*V12*V15 - 2.90992945153344817e-25*V152 + 1.7231972553420606e-22*V062*V16 + 
      4.4389561297611481e-22*V05*V07*V16 + 1.78560337579527806e-22*V04*V08*V16 + 1.2330433693780967e-22*V03*V09*V16 + 
      2.02411691387662042e-23*V02*V10*V16 + 6.72569110569870925e-24*V01*V11*V16 - 4.86547904958251906e-25*V14*V16 + 
      1.72492045259740266e-22*V05*V06*V17 + 1.15412859373789851e-22*V04*V07*V17 + 6.36093801663303851e-23*V03*V08*V17 + 
      1.60790377642668473e-23*V02*V09*V17 + 4.31417686056331679e-24*V01*V10*V17 - 4.5030038736910881e-25*V13*V17 + 
      3.01992380239432175e-23*V052*V18 + 3.13441830481553256e-23*V04*V06*V18 + 2.87611790704221119e-23*V03*V07*V18 + 
      5.79619763982404466e-24*V02*V08*V18 + 2.39676492253517599e-24*V01*V09*V18 - 2.89316685520912808e-25*V12*V18 + 
      1.41735090459040168e-23*V04*V05*V19 + 1.00872541087567407e-23*V03*V06*V19 + 3.38506058195091523e-24*V02*V07*V19 + 
      1.11595403800579623e-24*V01*V08*V19 - 2.06731712762756309e-25*V11*V19 + 1.13738035553550752e-24*V042*V20 + 
      3.12467130641622944e-24*V03*V05*V20 + 8.11896995766535808e-25*V02*V06*V20 + 4.46381615202318492e-25*V01*V07*V20 - 
      1.00345867127134096e-25*V10*V20 + 6.7492900218590556e-25*V03*V04*V21 + 3.38506058195091523e-25*V02*V05*V21 + 
      1.44103630125096296e-25*V01*V06*V21 - 5.47252460707546713e-26*V09*V21 + 6.55016500568619526e-26*V032*V22 + 
      4.76916705401665496e-26*V02*V04*V22 + 3.93009900341171716e-26*V01*V05*V22 - 1.94391993717138698e-26*V08*V22 + 
      1.33796860946676491e-26*V02*V03*V23 + 8.00311069785658766e-27*V01*V04*V23 - 7.90277728080956647e-27*V07*V23 + 
      4.03448996085362958e-28*V022*V24 + 1.33385178297609794e-27*V01*V03*V24 - 1.94033431409887059e-27*V06*V24 + 
      1.33796860946676491e-28*V01*V02*V25 - 5.63615126711170418e-28*V05*V25 + 5.1460331133337112e-30*V012*V26 - 
      8.55569505358772501e-29*V04*V26 - 1.64202723266857935e-29*V03*V27 - 1.1620074772043864e-30*V02*V28 - 
      1.245008011290414e-31*V01*V29 + 3.14395962447074243e-34*V32) + 
   delta22*eps5*(9.2361377978530722e-20*V092*V10 + 6.23514970647636699e-20*V08*V102 + 
      1.48308450326807609e-19*V08*V09*V11 + 1.20909440262803854e-19*V07*V10*V11 + 3.65104994568465661e-20*V06*V112 + 
      4.21687784249326233e-20*V082*V12 + 1.01854519991336529e-19*V07*V09*V12 + 5.17177686442779896e-20*V06*V10*V12 + 
      3.88899076330557657e-20*V05*V11*V12 + 5.55793177798659469e-21*V04*V122 + 6.84500539969881274e-20*V07*V08*V13 + 
      5.14891659006810548e-20*V06*V09*V13 + 3.25525416092164223e-20*V05*V10*V13 + 1.31387534063292489e-20*V04*V11*V13 + 
      4.98588559398150842e-21*V03*V12*V13 + 4.21999059988477397e-22*V02*V132 + 
      2.02560254576869131e-20*V072*V14 + 2.52289625490870287e-20*V06*V08*V14 + 2.3632029700634732e-20*V05*V09*V14 + 
      8.01786339498781064e-21*V04*V10*V14 + 4.29673267284267855e-21*V03*V11*V14 + 6.15215295305554607e-22*V02*V12*V14 + 
      1.65258948955487636e-22*V01*V13*V14 + 1.76534283088049331e-20*V06*V07*V15 + 1.36900107993976255e-20*V05*V08*V15 + 
      6.88220416522008275e-21*V04*V09*V15 + 3.10024205802061165e-21*V03*V10*V15 + 6.26970031982880705e-22*V02*V11*V15 + 
      1.42453874113757383e-22*V01*V12*V15 - 2.01916376123518971e-24*V152 + 2.84855994289744897e-21*V062*V16 + 
      7.09616459077094648e-21*V05*V07*V16 + 2.95253996288112937e-21*V04*V08*V16 + 1.97115683076970736e-21*V03*V09*V16 + 
      3.34980788003237315e-22*V02*V10*V16 + 1.0751764531471131e-22*V01*V11*V16 - 3.45645881614850631e-24*V14*V16 + 
      2.72589701827134996e-21*V05*V06*V17 + 1.82175992608766896e-21*V04*V07*V17 + 1.00661844113217834e-21*V03*V08*V17 + 
      2.53554057051900285e-22*V02*V09*V17 + 6.83876924563370217e-23*V01*V10*V17 - 3.13534121661268234e-24*V13*V17 + 
      4.85201090918021028e-22*V052*V18 + 5.20446290236962824e-22*V04*V06*V18 + 4.62096277064781931e-22*V03*V07*V18 + 
      9.62899250853849753e-23*V02*V08*V18 + 3.85080230887318276e-23*V01*V09*V18 - 2.06871144083036133e-24*V12*V18 + 
      2.2372490320374882e-22*V04*V05*V19 + 1.59409182355049705e-22*V03*V06*V19 + 5.33798014846105863e-23*V02*V07*V19 + 
      1.76599726514417253e-23*V01*V08*V19 - 1.45412329189078581e-24*V11*V19 + 1.90229989134620048e-23*V042*V20 + 
      5.05806167726127141e-23*V03*V05*V20 + 1.35822927698154735e-23*V02*V06*V20 + 7.22580239608753059e-24*V01*V07*V20 - 
      7.26679161698495756e-25*V10*V20 + 1.06535668192261343e-23*V03*V04*V21 + 5.33798014846105863e-24*V02*V05*V21 + 
      2.27727403364356722e-24*V01*V06*V21 - 3.91303883649129194e-25*V09*V21 + 1.07349926482079311e-24*V032*V22 + 
      8.08170679674412105e-25*V02*V04*V22 + 6.44099558892475867e-25*V01*V05*V22 - 1.43383659777995782e-25*V08*V22 + 
      2.10987357646682159e-25*V02*V03*V23 + 1.26326879279361276e-25*V01*V04*V23 - 5.77637474084047024e-26*V07*V23 + 
      7.02330599307784905e-27*V022*V24 + 2.23975945224736446e-26*V01*V03*V24 - 1.4649319178699472e-26*V06*V24 + 
      2.10987357646682159e-27*V01*V02*V25 - 4.23103522556934294e-27*V05*V25 + 9.26285960400068017e-29*V012*V26 - 
      6.63871471833683156e-28*V04*V26 - 1.27073817685708256e-28*V03*V27 - 9.29605981763509121e-30*V02*V28 - 
      9.96006409032331201e-31*V01*V29 + 1.88637577468244546e-33*V32) + 
   delta20*eps6*(-1.00257334254113693e-16*V062*V072 - 
      7.07017039248663037e-17*V05*V073 - 3.21511343539348473e-17*V063*V08 - 
      3.10536733348784157e-16*V05*V06*V07*V08 - 1.03868407139048437e-16*V04*V072*V08 - 
      5.98907530363443355e-17*V052*V082 - 4.97247204249392338e-17*V04*V06*V082 - 
      5.70388124155660338e-17*V03*V07*V082 - 3.03453078856873406e-18*V02*V083 - 
      1.16966889963132642e-16*V05*V062*V09 - 1.23142261607194048e-16*V052*V07*V09 - 
      1.55879790772999087e-16*V04*V06*V07*V09 - 5.83602577837486021e-17*V03*V072*V09 - 
      1.21179808328889843e-16*V04*V05*V08*V09 - 8.62602037079955991e-17*V03*V06*V08*V09 - 
      2.88162624805777843e-17*V02*V07*V08*V09 - 4.75323436796383615e-18*V01*V082*V09 - 
      1.50680551293317459e-17*V042*V092 - 3.38351134387826651e-17*V03*V05*V092 - 
      1.07546870972581649e-17*V02*V06*V092 - 4.78710189908625505e-18*V01*V07*V092 - 
      7.34059059105801365e-17*V052*V06*V10 - 3.03274486872751006e-17*V04*V062*V10 - 
      9.85802097791482619e-17*V04*V05*V07*V10 - 6.9910386581504892e-17*V03*V06*V07*V10 - 
      1.17670890594686313e-17*V02*V072*V10 - 1.56135147412818006e-17*V042*V08*V10 - 
      5.3681509330387116e-17*V03*V05*V08*V10 - 1.10895426134636786e-17*V02*V06*V08*V10 - 
      7.66878704719815944e-18*V01*V07*V08*V10 - 2.73833916053189616e-17*V03*V04*V09*V10 - 
      1.37282705693800699e-17*V02*V05*V09*V10 - 5.825865548458741e-18*V01*V06*V09*V10 + 
      8.26881442330332379e-19*V092*V10 - 2.98487498319749016e-18*V032*V102 - 
      1.73189650589126786e-18*V02*V04*V102 - 1.7909249899184941e-18*V01*V05*V102 + 
      5.87948314960381391e-19*V08*V102 - 1.55235590471245558e-17*V053*V11 - 
      5.95177382951451058e-17*V04*V05*V06*V11 - 2.12667072660241167e-17*V03*V062*V11 - 
      1.9725453987488831e-17*V042*V07*V11 - 4.40802502248347676e-17*V03*V05*V07*V11 - 
      1.40788631091379613e-17*V02*V06*V07*V11 - 3.11389181534335473e-18*V01*V072*V11 - 
      2.20326924234345169e-17*V03*V04*V08*V11 - 1.10025729471296995e-17*V02*V05*V08*V11 - 
      4.70510202043612359e-18*V01*V06*V08*V11 - 6.02310011731896899e-18*V032*V09*V11 - 
      5.39545714446703834e-18*V02*V04*V09*V11 - 3.5961109715634425e-18*V01*V05*V09*V11 + 1.32826102027122081e-18*V08*V09*V11 - 
      2.49604919443273998e-18*V02*V03*V10*V11 - 1.493639542108307e-18*V01*V04*V10*V11 + 1.0858541942881714e-18*V07*V10*V11 - 
      1.18434506068070517e-19*V022*V112 - 3.1461063663210527e-19*V01*V03*V112 + 
      3.28222803322434213e-19*V06*V112 - 1.57453370380350096e-17*V04*V052*V12 - 
      6.40336718127529185e-18*V042*V06*V12 - 2.22288804271319921e-17*V03*V05*V06*V12 - 
      2.27087938858978355e-18*V02*V062*V12 - 1.49955590838428663e-17*V03*V04*V07*V12 - 
      7.54594593076355941e-18*V02*V05*V07*V12 - 3.17555434673314173e-18*V01*V06*V07*V12 - 
      4.03381227828263949e-18*V032*V08*V12 - 2.32910919761252539e-18*V02*V04*V08*V12 - 
      2.4202873669695837e-18*V01*V05*V08*V12 + 3.98904689800207498e-19*V082*V12 - 
      2.0960960918787665e-18*V02*V03*V09*V12 - 1.24962992365357219e-18*V01*V04*V09*V12 + 9.17526789885770638e-19*V07*V09*V12 - 
      1.27038081069734319e-19*V022*V10*V12 - 5.29948267474020914e-19*V01*V03*V10*V12 + 
      4.90740637360763913e-19*V06*V10*V12 - 1.14332514102478173e-19*V01*V02*V11*V12 + 3.52501397062798547e-19*V05*V11*V12 - 
      5.60200664336703829e-21*V012*V122 + 5.32241053887221532e-20*V04*V122 - 
      5.31069915047776218e-18*V042*V05*V13 - 5.83981680004042109e-18*V03*V052*V13 - 
      7.63047926860834689e-18*V03*V04*V06*V13 - 3.79046314476791266e-18*V02*V05*V06*V13 - 
      8.17950279462466026e-19*V01*V062*V13 - 2.75258605595038739e-18*V032*V07*V13 - 
      2.49021098975401769e-18*V02*V04*V07*V13 - 1.64106026341282726e-18*V01*V05*V07*V13 - 
      1.41058627527303839e-18*V02*V03*V08*V13 - 8.47411247055173728e-19*V01*V04*V08*V13 + 6.16894705202644531e-19*V07*V08*V13 - 
      1.67023021378048164e-19*V022*V09*V13 - 4.41406141554515266e-19*V01*V03*V09*V13 + 
      4.64330137582514102e-19*V06*V09*V13 - 9.60018920935669222e-20*V01*V02*V10*V13 + 2.95084418461763211e-19*V05*V10*V13 - 
      1.07885191878654216e-20*V012*V11*V13 + 1.19322884705943999e-19*V04*V11*V13 + 
      4.57496627975743437e-20*V03*V12*V13 + 3.88383232429395271e-21*V02*V132 - 
      3.22571087842829421e-19*V043*V14 - 3.4344369110388403e-18*V03*V04*V05*V14 - 
      8.68112974725472814e-19*V02*V052*V14 - 1.20323699243800299e-18*V032*V06*V14 - 
      6.83671844607442443e-19*V02*V04*V06*V14 - 7.21942195462801794e-19*V01*V05*V06*V14 - 
      8.26774261643307442e-19*V02*V03*V07*V14 - 4.90633844434120043e-19*V01*V04*V07*V14 + 
      1.84237755293049424e-19*V072*V14 - 6.12208350036181333e-20*V022*V08*V14 - 
      2.57975509100448935e-19*V01*V03*V08*V14 + 2.40946893499779723e-19*V06*V08*V14 - 6.88978551369422868e-20*V01*V02*V09*V14 + 
      2.15600719549873064e-19*V05*V09*V14 - 8.07305876889015493e-21*V012*V10*V14 + 
      7.70330401876741074e-20*V04*V10*V14 + 3.95583153952398679e-20*V03*V11*V14 + 5.98132870229315157e-21*V02*V12*V14 + 
      1.54443421827782952e-21*V01*V13*V14 - 5.05780871474072589e-19*V03*V042*V15 - 
      5.38061703240646675e-19*V032*V05*V15 - 4.98042197950803539e-19*V02*V04*V05*V15 - 
      1.59721765756633786e-19*V01*V052*V15 - 3.60996489977896444e-19*V02*V03*V06*V15 - 
      2.18013693388809911e-19*V01*V04*V06*V15 - 5.72650359010450849e-20*V022*V07*V15 - 
      1.48779710086225498e-19*V01*V03*V07*V15 + 1.6069221023886202e-19*V06*V07*V15 - 4.0302465007801097e-20*V01*V02*V08*V15 + 
      1.24919403994592107e-19*V05*V08*V15 - 5.58611408438394283e-21*V012*V09*V15 + 
      6.28913000809248522e-20*V04*V09*V15 + 2.85380491330412075e-20*V03*V10*V15 + 5.78800383184195968e-21*V02*V11*V15 + 
      1.33101219398718638e-21*V01*V12*V15 - 1.18875479835463805e-23*V152 - 
      1.40031751146054429e-19*V032*V04*V16 - 3.85026606869805059e-20*V02*V042*V16 - 
      1.4261556602098269e-19*V02*V03*V05*V16 - 8.40190506876326572e-20*V01*V04*V05*V16 - 
      1.344539111595315e-20*V022*V06*V16 - 5.79760731178861744e-20*V01*V03*V06*V16 + 
      2.75582557653692663e-20*V062*V16 - 2.03736522887118128e-20*V01*V02*V07*V16 + 
      6.55935895232913327e-20*V05*V07*V16 - 2.9626315336860409e-21*V012*V08*V16 + 2.86472605072315212e-20*V04*V08*V16 + 
      1.8329134330323056e-20*V03*V09*V16 + 3.27845539164299015e-21*V02*V10*V16 + 1.0116283594076718e-21*V01*V11*V16 - 
      2.08775768575703593e-23*V14*V16 - 1.26052588362944713e-20*V033*V17 - 3.66207498493237896e-20*V02*V03*V04*V17 - 
      1.115693098839866e-20*V01*V042*V17 - 8.84239524942607929e-21*V022*V05*V17 - 
      2.21743085279628405e-20*V01*V03*V05*V17 - 7.96315786715948039e-21*V01*V02*V06*V17 + 2.51970744293095874e-20*V05*V06*V17 - 
      1.43942670737023234e-21*V012*V07*V17 + 1.68535517844642569e-20*V04*V07*V17 + 
      9.35515429600639037e-21*V03*V08*V17 + 2.36225801738255783e-21*V02*V09*V17 + 6.42942546861701544e-22*V01*V10*V17 - 
      1.85264880642948968e-23*V13*V17 - 4.52106459417288227e-21*V02*V032*V18 - 
      1.16471831828220255e-21*V022*V04*V18 - 5.24821151178411817e-21*V01*V03*V04*V18 - 
      2.71263875650372936e-21*V01*V02*V05*V18 + 4.57399978942371463e-21*V052*V18 - 
      5.18514652310937149e-22*V012*V06*V18 + 5.13320239899415715e-21*V04*V06*V18 + 
      4.36877575729247613e-21*V03*V07*V18 + 9.55020615345528831e-22*V02*V08*V18 + 3.67211016853750464e-22*V01*V09*V18 - 
      1.25819842424408317e-23*V12*V18 - 5.1709913739333797e-22*V022*V03*V19 - 
      6.02649144341677966e-22*V01*V032*V19 - 6.42469295602171748e-22*V01*V02*V04*V19 - 
      1.67573890255026373e-22*V012*V05*V19 + 2.10765503307989388e-21*V04*V05*V19 + 
      1.50497682864813637e-21*V03*V06*V19 + 5.04868766334202272e-22*V02*V07*V19 + 1.68099876591606439e-22*V01*V08*V19 - 
      8.68571954026019155e-24*V11*V19 - 9.1178296879151838e-24*V023*V20 - 1.34572412245711139e-22*V01*V02*V03*V20 - 
      3.73662168506598181e-23*V012*V04*V20 + 1.92019351889600554e-22*V042*V20 + 
      4.89503939154259134e-22*V03*V05*V20 + 1.37463865331431084e-22*V02*V06*V20 + 7.03144040113485441e-23*V01*V07*V20 - 
      4.48000184903091806e-24*V10*V20 - 7.38713053419054243e-24*V01*V022*V21 - 
      7.11134432758076218e-24*V012*V03*V21 + 1.02772182744048584e-22*V03*V04*V21 + 
      5.15440570920910515e-23*V02*V05*V21 + 2.20775737503692354e-23*V01*V06*V21 - 2.37867703114447843e-24*V09*V21 - 
      7.68261575555816413e-25*V012*V02*V22 + 1.07121479369226675e-23*V032*V22 + 
      8.41072239364208502e-24*V02*V04*V22 + 6.44370460778513506e-24*V01*V05*V22 - 9.01560694156798152e-25*V08*V22 - 
      1.96990147578414465e-26*V013*V23 + 2.09103909527202021e-24*V02*V03*V23 + 1.25432910406912944e-24*V01*V04*V23 - 
      3.59528018465730163e-25*V07*V23 + 7.59430982733335765e-26*V022*V24 + 2.32584229416721079e-25*V01*V03*V24 - 
      9.44639180783800301e-26*V06*V24 + 2.15670247779815837e-26*V01*V02*V25 - 2.71071444271557539e-26*V05*V25 + 
      1.01891455644007482e-27*V012*V26 - 4.41127918539056048e-27*V04*V26 - 8.4179141670049192e-28*V03*V27 - 
      6.3910411246241252e-29*V02*V28 - 6.84754406209727701e-30*V01*V29 + 1.037506676075345e-32*V32) + 
   delta18*eps7*(-1.58043972825023154e-15*V062*V072 - 
      1.10109211030529489e-15*V05*V073 - 5.75571536039813033e-16*V063*V08 - 
      4.90798627307351825e-15*V05*V06*V07*V08 - 1.63831048183928858e-15*V04*V072*V08 - 
      9.49791644806858495e-16*V052*V082 - 8.91923363162739066e-16*V04*V06*V082 - 
      9.04563471244627138e-16*V03*V07*V082 - 5.46404022115575157e-17*V02*V083 - 
      1.84384634962527013e-15*V05*V062*V09 - 1.92007778998550959e-15*V052*V07*V09 - 
      2.45450885449180344e-15*V04*V06*V07*V09 - 9.1106875568416815e-16*V03*V072*V09 - 
      1.91136222881250335e-15*V04*V05*V08*V09 - 1.36332952029819951e-15*V03*V06*V08*V09 - 
      4.54211301395479557e-16*V02*V07*V08*V09 - 7.53802892703855948e-17*V01*V082*V09 - 
      2.37300917153591611e-16*V042*V092 - 5.29025787684384527e-16*V03*V05*V092 - 
      1.69447293855703259e-16*V02*V06*V092 - 7.50327789510425139e-17*V01*V07*V092 - 
      1.16502689986907764e-15*V052*V06*V10 - 5.45167959798795072e-16*V04*V062*V10 - 
      1.56015693375287046e-15*V04*V05*V07*V10 - 1.10954942844674061e-15*V03*V06*V07*V10 - 
      1.85936742004213574e-16*V02*V072*V10 - 2.81326420557122804e-16*V042*V08*V10 - 
      8.55688206330917209e-16*V03*V05*V08*V10 - 2.001888044589259e-16*V02*V06*V08*V10 - 
      1.22241172332988173e-16*V01*V07*V08*V10 - 4.33376926042464016e-16*V03*V04*V09*V10 - 
      2.16926199004915837e-16*V02*V05*V09*V10 - 9.24624523705617172e-17*V01*V06*V09*V10 + 
      5.40267516591402899e-18*V092*V10 - 4.78924371923628945e-17*V032*V102 - 
      3.14516562733555531e-17*V02*V04*V102 - 2.87354623154177367e-17*V01*V05*V102 + 
      4.06071735525354572e-18*V08*V102 - 2.42634125222108663e-16*V053*V11 - 
      9.37176108078688587e-16*V04*V05*V06*V11 - 3.35244790840958206e-16*V03*V062*V11 - 
      3.10648473364701745e-16*V042*V07*V11 - 6.90057975496373754e-16*V03*V05*V07*V11 - 
      2.21821911956556994e-16*V02*V06*V07*V11 - 4.88850513842416242e-17*V01*V072*V11 - 
      3.47520405238636972e-16*V03*V04*V08*V11 - 1.73426133260092195e-16*V02*V05*V08*V11 - 
      7.43634283799017917e-17*V01*V06*V08*V11 - 9.46845554714946566e-17*V032*V09*V11 - 
      8.52141910898151561e-17*V02*V04*V09*V11 - 5.66036604632375068e-17*V01*V05*V09*V11 + 8.69953340039142333e-18*V08*V09*V11 - 
      3.94411270918028794e-17*V02*V03*V10*V11 - 2.36387414204980372e-17*V01*V04*V10*V11 + 7.13355003836431577e-18*V07*V10*V11 - 
      1.88547733660368262e-18*V022*V112 - 5.00218765116219884e-18*V01*V03*V112 + 
      2.16632692400698551e-18*V06*V112 - 2.50505293213447478e-16*V04*V052*V12 - 
      1.15917746045849191e-16*V042*V06*V12 - 3.54987364060232191e-16*V03*V05*V06*V12 - 
      4.12020279499965024e-17*V02*V062*V12 - 2.38576469727092836e-16*V03*V04*V07*V12 - 
      1.19770615487532887e-16*V02*V05*V07*V12 - 5.07124805800331702e-17*V01*V06*V07*V12 - 
      6.47918718478982389e-17*V032*V08*V12 - 4.24039803675174197e-17*V02*V04*V08*V12 - 
      3.88751231087389433e-17*V01*V05*V08*V12 + 2.7690975495761338e-18*V082*V12 - 
      3.32696154132035796e-17*V02*V03*V09*V12 - 1.98813724772577363e-17*V01*V04*V09*V12 + 6.04557472487351499e-18*V07*V09*V12 - 
      2.34226984133969081e-18*V022*V10*V12 - 8.59383164855601717e-18*V01*V03*V10*V12 + 
      3.42382501628455562e-18*V06*V10*V12 - 1.8147062952656498e-18*V01*V02*V11*V12 + 2.34757931763448804e-18*V05*V11*V12 - 
      9.26981661958688945e-20*V012*V122 + 3.76888059955406127e-19*V04*V122 - 
      8.36361274443427775e-17*V042*V05*V13 - 9.17950176693134434e-17*V03*V052*V13 - 
      1.20150783087011357e-16*V03*V04*V06*V13 - 5.97212839883038061e-17*V02*V05*V06*V13 - 
      1.2894030416959931e-17*V01*V062*V13 - 4.3381990495060169e-17*V032*V07*V13 - 
      3.93296266568377643e-17*V02*V04*V07*V13 - 2.5906794978533041e-17*V01*V05*V07*V13 - 
      2.22341196487297685e-17*V02*V03*V08*V13 - 1.33661694322552682e-17*V01*V04*V08*V13 + 4.08410497891344671e-18*V07*V08*V13 - 
      2.65900650033852678e-18*V022*V09*V13 - 7.02781940296473079e-18*V01*V03*V09*V13 + 
      3.08097699294414781e-18*V06*V09*V13 - 1.51696642660780306e-18*V01*V02*V10*V13 + 1.96980574001331081e-18*V05*V10*V13 - 
      1.77086450414364689e-19*V012*V11*V13 + 8.01746199349538041e-19*V04*V11*V13 + 3.1104067357809533e-19*V03*V12*V13 + 
      2.66761044808716141e-20*V02*V132 - 5.90103938233287271e-18*V043*V14 - 
      5.50682285659106775e-17*V03*V04*V05*V14 - 1.38738789171722352e-17*V02*V052*V14 - 
      1.93926680625653441e-17*V032*V06*V14 - 1.25492421857998436e-17*V02*V04*V06*V14 - 
      1.16356008375392065e-17*V01*V05*V06*V14 - 1.32132180163545098e-17*V02*V03*V07*V14 - 
      7.86688979513009678e-18*V01*V04*V07*V14 + 1.2304500964992028e-18*V072*V14 - 
      1.13516611217384931e-18*V022*V08*V14 - 4.19421178736286001e-18*V01*V03*V08*V14 + 
      1.69777863381400679e-18*V06*V08*V14 - 1.10110150136287581e-18*V01*V02*V09*V14 + 1.44747653766767693e-18*V05*V09*V14 - 
      1.33775615240206106e-19*V012*V10*V14 + 5.4812363379690805e-19*V04*V10*V14 + 2.69696511440635989e-19*V03*V11*V14 + 
      4.33755457330274038e-20*V02*V12*V14 + 1.07908247437053586e-20*V01*V13*V14 - 
      7.96534547088978833e-18*V03*V042*V15 - 8.53108383960200778e-18*V032*V05*V15 - 
      7.86592533136755287e-18*V02*V04*V05*V15 - 2.53952979103239981e-18*V01*V052*V15 - 
      5.68774133221941011e-18*V02*V03*V06*V15 - 3.43287951677175307e-18*V01*V04*V06*V15 - 
      9.11659371544637752e-19*V022*V07*V15 - 2.37967679913771554e-18*V01*V03*V07*V15 + 
      1.08297554670887428e-18*V06*V07*V15 - 6.35260561392279101e-19*V01*V02*V08*V15 + 8.44395282660420642e-19*V05*V08*V15 - 
      9.20010607677467524e-20*V012*V09*V15 + 4.26880052629373688e-19*V04*V09*V15 + 
      1.95415558705760191e-19*V03*V10*V15 + 3.99479308061092295e-20*V02*V11*V15 + 9.31840351033379809e-21*V01*V12*V15 - 
      6.12384811015537016e-23*V152 - 2.27157433676915669e-18*V032*V04*V16 - 
      7.1824699484293292e-19*V02*V042*V16 - 2.30281582805059822e-18*V02*V03*V05*V16 - 
      1.36294460206149401e-18*V01*V04*V05*V16 - 2.52502728426838716e-19*V022*V06*V16 - 
      9.48012680406330993e-19*V01*V03*V06*V16 + 1.97961255518899566e-19*V062*V16 - 
      3.28973689721514032e-19*V01*V02*V07*V16 + 4.4839281691218025e-19*V05*V07*V16 - 
      4.93178802854843446e-20*V012*V08*V16 + 2.06760867595212884e-19*V04*V08*V16 + 
      1.26551333845250423e-19*V03*V09*V16 + 2.39944514758723903e-20*V02*V10*V16 + 7.12073896521733431e-21*V01*V11*V16 - 
      1.10042011555249594e-22*V14*V16 - 2.02299032055652735e-19*V033*V17 - 5.78376862600555358e-19*V02*V03*V04*V17 - 
      1.75706150093157096e-19*V01*V042*V17 - 1.40770932370863182e-19*V022*V05*V17 - 
      3.58128088297557497e-19*V01*V03*V05*V17 - 1.25464882328369341e-19*V01*V02*V06*V17 + 1.7408019632622931e-19*V05*V06*V17 - 
      2.38952988815568314e-20*V012*V07*V17 + 1.16660003318832422e-19*V04*V07*V17 + 
      6.51291700718395288e-20*V03*V08*V17 + 1.65374140254543315e-20*V02*V09*V17 + 4.55198328438344892e-21*V01*V10*V17 - 
      9.57259928920731273e-23*V13*V17 - 7.41687604647488302e-20*V02*V032*V18 - 
      2.23977797796657247e-20*V022*V04*V18 - 8.67209726684453999e-20*V01*V03*V04*V18 - 
      4.45012562788492981e-20*V01*V02*V05*V18 + 3.21252948859191099e-20*V052*V18 - 
      8.71008822387751992e-21*V012*V06*V18 + 3.79093646077924198e-20*V04*V06*V18 + 
      3.08302381717588055e-20*V03*V07*V18 + 7.11644160570608499e-21*V02*V08*V18 + 2.62786632251028996e-21*V01*V09*V18 - 
      6.6722431671602705e-23*V12*V18 - 8.23221826730194049e-21*V022*V03*V19 - 
      9.93815294533100975e-21*V01*V032*V19 - 1.01469625017641291e-20*V01*V02*V04*V19 - 
      2.8272025980454044e-21*V012*V05*V19 + 1.5001309082161753e-20*V04*V05*V19 + 1.07414409217579733e-20*V03*V06*V19 + 
      3.61559622704554929e-21*V02*V07*V19 + 1.21375810982002089e-21*V01*V08*V19 - 4.52894551504162315e-23*V11*V19 - 
      1.83369685945849808e-22*V023*V20 - 2.2664560722386206e-21*V01*V02*V03*V20 - 
      6.38416926851987221e-22*V012*V04*V20 + 1.46241105846946899e-21*V042*V20 + 
      3.55995847855737364e-21*V03*V05*V20 + 1.05139593517469164e-21*V02*V06*V20 + 5.1592415100404636e-22*V01*V07*V20 - 
      2.40512366917859673e-23*V10*V20 - 1.17603118104313436e-22*V01*V022*V21 - 
      1.24497773269557942e-22*V012*V03*V21 + 7.57182464732729506e-22*V03*V04*V21 + 3.8032457584596206e-22*V02*V05*V21 + 
      1.63758977116233168e-22*V01*V06*V21 - 1.25958062256123308e-23*V09*V21 - 1.35923201829105981e-23*V012*V02*V22 + 
      8.08743212615649862e-23*V032*V22 + 6.65285218507904166e-23*V02*V04*V22 + 4.88529096695696825e-23*V01*V05*V22 - 
      4.93104038705642046e-24*V08*V22 - 3.9398029515682893e-25*V013*V23 + 1.59862033269023072e-23*V02*V03*V23 + 
      9.61334562728361257e-24*V01*V04*V23 - 1.94602637215429881e-24*V07*V23 + 6.26292814025165988e-25*V022*V24 + 
      1.83642366889049485e-24*V01*V03*V24 - 5.29717661161560126e-25*V06*V24 + 1.71517283667412594e-25*V01*V02*V25 - 
      1.50953652345996998e-25*V05*V25 + 8.49095463700062349e-27*V012*V26 - 2.5516688192999293e-26*V04*V26 - 
      4.85262622533960364e-27*V03*V27 - 3.83462467477447512e-28*V02*V28 - 4.1085264372583662e-29*V01*V29 + 
      5.187533380376725e-32*V32) + delta16*eps8*
    (6.57341069930505957e-14*V04*V054 + 2.41780447542352583e-13*V042*V052*V06 + 
      1.83112615511333405e-13*V03*V053*V06 + 2.32956591566679322e-14*V043*V062 + 
      3.45808799634908851e-13*V03*V04*V05*V062 + 8.59054206453527902e-14*V02*V052*V062 + 
      4.08755785254966719e-14*V032*V063 + 1.63216045054023066e-14*V02*V04*V063 + 
      2.45253471152980031e-14*V01*V05*V063 + 1.06575856533959433e-13*V043*V05*V07 + 
      3.71942032371744272e-13*V03*V04*V052*V07 + 6.31908045484744048e-14*V02*V053*V07 + 
      2.30267092897478651e-13*V03*V042*V06*V07 + 2.58305758632705182e-13*V032*V05*V06*V07 + 
      2.26633190383634135e-13*V02*V04*V05*V06*V07 + 7.65066199604802214e-14*V01*V052*V06*V07 + 
      8.18146863289074192e-14*V02*V03*V062*V07 + 4.94012570907012644e-14*V01*V04*V062*V07 + 
      8.75230216216234051e-14*V032*V04*V072 + 3.71114629736766969e-14*V02*V042*V072 + 
      8.94495658668934249e-14*V02*V03*V05*V072 + 5.1987893521549269e-14*V01*V04*V05*V072 + 
      1.30574923577339216e-14*V022*V06*V072 + 3.57165169095362713e-14*V01*V03*V06*V072 - 
      1.32248749498565307e-14*V062*V072 + 4.18112103561410767e-15*V01*V02*V073 - 
      9.03563399349047416e-15*V05*V073 + 5.94143953285383414e-15*V044*V08 + 
      1.78345979057117686e-13*V03*V042*V05*V08 + 9.82531923133393398e-14*V032*V052*V08 + 
      8.83878801351799419e-14*V02*V04*V052*V08 + 1.93436890765980784e-14*V01*V053*V08 + 
      1.26589697667744646e-13*V032*V04*V06*V08 + 2.49265623564595054e-14*V02*V042*V06*V08 + 
      1.26834862741470223e-13*V02*V03*V05*V06*V08 + 7.59538186006467876e-14*V01*V04*V05*V06*V08 + 
      4.3336715890727296e-15*V022*V062*V08 + 2.66296006059710312e-14*V01*V03*V062*V08 - 
      5.43812770565260411e-15*V063*V08 + 3.07042683755525054e-14*V033*V07*V08 + 
      8.41789334620761351e-14*V02*V03*V04*V07*V08 + 2.54779970081596694e-14*V01*V042*V07*V08 + 
      2.05115037806444606e-14*V022*V05*V07*V08 + 5.41097980697126504e-14*V01*V03*V05*V07*V08 + 
      1.81192661059243176e-14*V01*V02*V06*V07*V08 - 4.12183254424205178e-14*V05*V06*V07*V08 + 
      1.7939909602322838e-15*V012*V072*V08 - 1.37796983210993712e-14*V04*V072*V08 + 
      1.16146829828271081e-14*V02*V032*V082 + 2.1990236776215582e-15*V022*V04*V082 + 
      1.37435035871653669e-14*V01*V03*V04*V082 + 6.96880978969626487e-15*V01*V02*V05*V082 - 
      8.00851101498600685e-15*V052*V082 + 1.40784056642455447e-15*V012*V06*V082 - 
      8.46931173233439395e-15*V04*V06*V082 - 7.66342714227269836e-15*V03*V07*V082 - 
      5.23952960440792423e-16*V02*V083 + 2.96044045927665092e-14*V03*V043*V09 + 
      1.01087570736345801e-13*V032*V04*V05*V09 + 4.32967068026228131e-14*V02*V042*V05*V09 + 
      5.16988230543136584e-14*V02*V03*V052*V09 + 2.99641594241599094e-14*V01*V04*V052*V09 + 
      2.33091087441817556e-14*V033*V06*V09 + 6.29536639954539265e-14*V02*V03*V04*V06*V09 + 
      1.91889244081232209e-14*V01*V042*V06*V09 + 1.52337410840229085e-14*V022*V05*V06*V09 + 
      4.11219877114971314e-14*V01*V03*V05*V06*V09 + 6.8178905274089516e-15*V01*V02*V062*V09 - 
      1.55037245837375691e-14*V05*V062*V09 + 2.43170011425591047e-14*V02*V032*V07*V09 + 
      9.87839952988575414e-15*V022*V04*V07*V09 + 2.79710193924951744e-14*V01*V03*V04*V07*V09 + 
      1.44530320089523658e-14*V01*V02*V05*V07*V09 - 1.58497379529772237e-14*V052*V07*V09 + 
      2.73265372150795585e-15*V012*V06*V07*V09 - 2.06796744078499653e-14*V04*V06*V07*V09 - 
      7.56448599141625129e-15*V03*V072*V09 + 5.69763993906790572e-15*V022*V03*V08*V09 + 
      7.23262705798848703e-15*V01*V032*V08*V09 + 7.01491112183967793e-15*V01*V02*V04*V08*V09 + 
      2.05644786002459425e-15*V012*V05*V08*V09 - 1.61536848501606446e-14*V04*V05*V08*V09 - 
      1.15594564821288158e-14*V03*V06*V08*V09 - 3.86557441838306075e-15*V02*V07*V08*V09 - 
      6.47687377189469251e-16*V01*V082*V09 + 2.14994544742205222e-16*V023*V092 + 
      1.93895018150289569e-15*V01*V02*V03*V092 + 5.35156556246168981e-16*V012*V04*V092 - 
      2.01438365652205319e-15*V042*V092 - 4.41902722268736452e-15*V03*V05*V092 - 
      1.44555196446747675e-15*V02*V06*V092 - 6.33921551039423799e-16*V01*V07*V092 + 
      1.99321445674657569e-14*V032*V042*V10 + 2.55431108489700907e-15*V02*V043*V10 + 
      1.42299538645535757e-14*V033*V05*V10 + 3.98080867587723904e-14*V02*V03*V04*V05*V10 + 
      1.19592867404794541e-14*V01*V042*V05*V10 + 4.88039496854636973e-15*V022*V052*V10 + 
      1.24958261172754114e-14*V01*V03*V052*V10 + 1.41722753693654577e-14*V02*V032*V06*V10 + 
      2.65582856876743328e-15*V022*V04*V06*V10 + 1.6784793402493961e-14*V01*V03*V04*V06*V10 + 
      8.50336522161927461e-15*V01*V02*V05*V06*V10 - 9.87448412387743231e-15*V052*V06*V10 + 
      8.59825375650939611e-16*V012*V062*V10 - 5.20320313645630389e-15*V04*V062*V10 + 
      4.64799520813939974e-15*V022*V03*V07*V10 + 5.80223512212028792e-15*V01*V032*V07*V10 + 
      5.68686953696748434e-15*V01*V02*V04*V07*V10 + 1.64618455001600879e-15*V012*V05*V07*V10 - 
      1.32381228876402594e-14*V04*V05*V07*V10 - 9.44870927140571033e-15*V03*V06*V07*V10 - 
      1.58791494464337547e-15*V02*V072*V10 + 1.5412653690466652e-16*V023*V08*V10 + 
      3.07548384717876884e-15*V01*V02*V03*V08*V10 + 8.86711993854333713e-16*V012*V04*V08*V10 - 
      2.69889549547964424e-15*V042*V08*V10 - 7.31861079360522991e-15*V03*V05*V08*V10 - 
      1.92975459403414375e-15*V02*V06*V08*V10 - 1.05524665511427683e-15*V01*V07*V08*V10 + 
      3.87332934011616645e-16*V01*V022*V09*V10 + 4.32580441605811431e-16*V012*V03*V09*V10 - 
      3.71212347626428978e-15*V03*V04*V09*V10 - 1.86132365585678973e-15*V02*V05*V09*V10 - 
      7.98502108592990989e-16*V01*V06*V09*V10 + 2.82138140922191058e-17*V092*V10 + 
      4.93991666333490436e-17*V012*V02*V102 - 4.15662638368108303e-16*V032*V102 - 
      3.06501935556147459e-16*V02*V04*V102 - 2.50529207807130243e-16*V01*V05*V102 + 
      2.23256692586103702e-17*V08*V102 + 5.91823460217204586e-15*V033*V04*V11 + 
      7.8721285095677842e-15*V02*V03*V042*V11 + 1.61478570505999141e-15*V01*V043*V11 + 
      9.1100948478713529e-15*V02*V032*V05*V11 + 3.77175254777456067e-15*V022*V04*V05*V11 + 
      1.04366080795315093e-14*V01*V03*V04*V05*V11 + 2.69849460045561286e-15*V01*V02*V052*V11 - 
      2.02663203964642575e-15*V053*V11 + 2.76977110618598336e-15*V022*V03*V06*V11 + 
      3.56300142280697567e-15*V01*V032*V06*V11 + 3.43383621793385053e-15*V01*V02*V04*V06*V11 + 
      1.01352512914148214e-15*V012*V05*V06*V11 - 7.97212456601129004e-15*V04*V05*V06*V11 - 
      2.85960654735498527e-15*V03*V062*V11 + 2.81447404026159563e-16*V023*V07*V11 + 
      2.513322296406864e-15*V01*V02*V03*V07*V11 + 6.92600106185518575e-16*V012*V04*V07*V11 - 
      2.64970193783630049e-15*V042*V07*V11 - 5.79811596929875449e-15*V03*V05*V07*V11 - 
      1.90141480325951133e-15*V02*V06*V07*V11 - 4.15492266218342613e-16*V01*V072*V11 + 
      3.10780360312794857e-16*V01*V022*V08*V11 + 3.49711972591764083e-16*V012*V03*V08*V11 - 
      2.97923550487177807e-15*V03*V04*V08*V11 - 1.49003463605366678e-15*V02*V05*V08*V11 - 
      6.42507259426517807e-16*V01*V06*V08*V11 + 9.54170451377835256e-17*V012*V02*V09*V11 - 
      8.05485824683980561e-16*V032*V09*V11 - 7.3679754894332965e-16*V02*V04*V09*V11 - 
      4.84199819571286264e-16*V01*V05*V09*V11 + 4.56225859076305136e-17*V08*V09*V11 + 
      6.46173058740241587e-18*V013*V10*V11 - 3.43198603122789953e-16*V02*V03*V10*V11 - 
      2.06283148005663802e-16*V01*V04*V10*V11 + 3.75046213739546606e-17*V07*V10*V11 - 
      1.66465901990895724e-17*V022*V112 - 4.36595881941384573e-17*V01*V03*V112 + 
      1.14830628944247647e-17*V06*V112 + 5.17154743166072874e-16*V034*V12 + 
      2.9940711579334275e-15*V02*V032*V04*V12 + 2.7105075742152509e-16*V022*V042*V12 + 
      1.77898762447333379e-15*V01*V03*V042*V12 + 1.47940473406824506e-15*V022*V03*V05*V12 + 
      1.79863434046842553e-15*V01*V032*V05*V12 + 1.7964426947600565e-15*V01*V02*V04*V05*V12 + 
      2.53820788057461147e-16*V012*V052*V12 - 2.15621926055858269e-15*V04*V052*V12 + 
      6.19942905068133179e-17*V023*V06*V12 + 1.26319781573573173e-15*V01*V02*V03*V06*V12 + 
      3.64658350040870808e-16*V012*V04*V06*V12 - 1.1235358944972902e-15*V042*V06*V12 - 
      3.06767648175326695e-15*V03*V05*V06*V12 - 4.01334351954426353e-16*V02*V062*V12 + 
      2.11343533438320723e-16*V01*V022*V07*V12 + 2.32716550302900594e-16*V012*V03*V07*V12 - 
      2.06305941185996262e-15*V03*V04*V07*V12 - 1.03707975547416775e-15*V02*V05*V07*V12 - 
      4.42264188776665289e-16*V01*V06*V07*V12 + 6.65286577728386295e-17*V012*V02*V08*V12 - 
      5.65245253233530121e-16*V032*V08*V12 - 4.15372423348237056e-16*V02*V04*V08*V12 - 
      3.40675459874727449e-16*V01*V05*V08*V12 + 1.53177381298335791e-17*V082*V12 + 
      5.36865718394245333e-18*V013*V09*V12 - 2.90741855524162567e-16*V02*V03*V09*V12 - 
      1.74300932391753565e-16*V01*V04*V09*V12 + 3.18474612554683783e-17*V07*V09*V12 - 
      2.3358425889680214e-17*V022*V10*V12 - 7.64945763017664179e-17*V01*V03*V10*V12 + 
      1.90634692583689766e-17*V06*V10*V12 - 1.61492807380700035e-17*V01*V02*V11*V12 + 1.25373810388224363e-17*V05*V11*V12 - 
      8.49560846249707254e-19*V012*V122 + 2.13892624329950476e-18*V04*V122 + 
      3.7202097604764324e-16*V02*V033*V13 + 4.83558018945456496e-16*V022*V03*V04*V13 + 
      6.31120587797658768e-16*V01*V032*V04*V13 + 3.02774173444914777e-16*V01*V02*V042*V13 + 
      7.57743010839660363e-17*V023*V05*V13 + 6.54379759647705099e-16*V01*V02*V03*V05*V13 + 
      1.79259399636296167e-16*V012*V04*V05*V13 - 7.23631395529061765e-16*V042*V05*V13 - 
      7.85019520623106138e-16*V03*V052*V13 + 1.06529657930230129e-16*V01*V022*V06*V13 + 
      1.20276950978568476e-16*V012*V03*V06*V13 - 1.04161824769735271e-15*V03*V04*V06*V13 - 
      5.1923372499637944e-16*V02*V05*V06*V13 - 1.12596888496343837e-16*V01*V062*V13 + 
      4.30794147028714385e-17*V012*V02*V07*V13 - 3.73360364506457781e-16*V032*V07*V13 - 
      3.43286538490323088e-16*V02*V04*V07*V13 - 2.24225765515909625e-16*V01*V05*V07*V13 + 
      3.64499609263614672e-18*V013*V08*V13 - 1.94642399479642116e-16*V02*V03*V08*V13 - 
      1.17291230684277417e-16*V01*V04*V08*V13 + 2.16926049087650371e-17*V07*V08*V13 - 
      2.35855594531104357e-17*V022*V09*V13 - 6.16926254909953721e-17*V01*V03*V09*V13 + 
      1.64298498920636811e-17*V06*V09*V13 - 1.35061078277827723e-17*V01*V02*V10*V13 + 1.05620300270921628e-17*V05*V10*V13 - 
      1.6080322422110843e-18*V012*V11*V13 + 4.34887966859934512e-18*V04*V11*V13 + 1.70538614916588182e-18*V03*V12*V13 + 
      1.48919167728081617e-19*V02*V132 + 7.97996092208283075e-17*V022*V032*V14 + 
      6.14434655541117718e-17*V01*V033*V14 + 8.94934693116887551e-18*V023*V04*V14 + 
      1.9145389635651338e-16*V01*V02*V03*V04*V14 + 2.77225760465336647e-17*V012*V042*V14 - 
      5.83947259339738379e-17*V043*V14 + 4.78797655324969845e-17*V01*V022*V05*V14 + 
      5.12981545461121592e-17*V012*V03*V05*V14 - 4.8566892188305365e-16*V03*V04*V05*V14 - 
      1.22466613018192245e-16*V02*V052*V14 + 1.96189271597697757e-17*V012*V02*V06*V14 - 
      1.71800313314396063e-16*V032*V06*V14 - 1.24859404698336948e-16*V02*V04*V06*V14 - 
      1.03535058690555155e-16*V01*V05*V06*V14 + 2.06172503052072802e-18*V013*V07*V14 - 
      1.17157958253506907e-16*V02*V03*V07*V14 - 7.00013809147757549e-17*V01*V04*V07*V14 + 
      6.57441371335224691e-18*V072*V14 - 1.14380942270563129e-17*V022*V08*V14 - 
      3.77155120207839055e-17*V01*V03*V08*V14 + 9.56156649599143882e-18*V06*V08*V14 - 9.89393536588510121e-18*V01*V02*V09*V14 + 
      7.78819442939398486e-18*V05*V09*V14 - 1.23222178722002194e-18*V012*V10*V14 + 
      3.12730837746796199e-18*V04*V10*V14 + 1.48095695499180276e-18*V03*V11*V14 + 2.53751811624488645e-19*V02*V12*V14 + 
      6.11899048689692215e-20*V01*V13*V14 + 7.2166001032348606e-18*V023*V03*V15 + 
      2.89515710731464457e-17*V01*V02*V032*V15 + 1.38159433984416142e-17*V01*V022*V04*V15 + 
      1.55936770454600639e-17*V012*V03*V04*V15 - 7.05442764905669477e-17*V03*V042*V15 + 
      8.17104337095175903e-18*V012*V02*V05*V15 - 7.51502606106501204e-17*V032*V05*V15 - 
      6.99477602123483788e-17*V02*V04*V05*V15 - 2.25065944765418917e-17*V01*V052*V15 + 
      9.18247510040250246e-19*V013*V06*V15 - 5.06118396644249416e-17*V02*V03*V06*V15 - 
      3.0598421176122501e-17*V01*V04*V06*V15 - 8.19920784031163526e-18*V022*V07*V15 - 
      2.12535339976096911e-17*V01*V03*V07*V15 + 5.87786098911316112e-18*V06*V07*V15 - 5.71602503945978419e-18*V01*V02*V08*V15 + 
      4.59640263565529704e-18*V05*V08*V15 - 8.44980821185848679e-19*V012*V09*V15 + 
      2.34101112310480958e-18*V04*V09*V15 + 1.08096251899080156e-18*V03*V10*V15 + 2.2412326322593601e-19*V02*V11*V15 + 
      5.30158579798794711e-20*V01*V12*V15 - 2.78882693889320646e-22*V152 + 8.09865894724377548e-20*V024*V16 + 
      3.82097849454898969e-18*V01*V022*V03*V16 + 1.92474345435326892e-18*V012*V032*V16 + 
      2.23003878507029565e-18*V012*V02*V04*V16 - 2.06371515802387261e-17*V032*V04*V16 - 
      7.33867015969240774e-18*V02*V042*V16 + 3.36697136162206631e-19*V013*V05*V16 - 
      2.09249964440749156e-17*V02*V03*V05*V16 - 1.24349747811721972e-17*V01*V04*V05*V16 - 
      2.59810512352910115e-18*V022*V06*V16 - 8.69843038276021982e-18*V01*V03*V06*V16 + 
      1.13989383200724868e-18*V062*V16 - 3.01489212442883254e-18*V01*V02*V07*V16 + 
      2.45796843725963388e-18*V05*V07*V16 - 4.61149709146992944e-19*V012*V08*V16 + 
      1.19832231092828045e-18*V04*V08*V16 + 7.03296688339591914e-19*V03*V09*V16 + 1.4173084544723974e-19*V02*V10*V16 + 
      4.06273155604436202e-20*V01*V11*V16 - 5.10072355542201605e-22*V14*V16 + 1.59189708159592513e-19*V01*V023*V17 + 
      5.3604860463964355e-19*V012*V02*V03*V17 - 1.84639533684677162e-18*V033*V17 + 
      8.96738549806458327e-20*V013*V04*V17 - 5.28554698410103093e-18*V02*V03*V04*V17 - 
      1.60636935676806851e-18*V01*V042*V17 - 1.29506562955975255e-18*V022*V05*V17 - 
      3.29319330297358961e-18*V01*V03*V05*V17 - 1.15229232048020444e-18*V01*V02*V06*V17 + 9.71759090696062791e-19*V05*V06*V17 - 
      2.24564926931514711e-19*V012*V07*V17 + 6.53511261296693495e-19*V04*V07*V17 + 
      3.67051651008345705e-19*V03*V08*V17 + 9.41548313034706551e-20*V02*V09*V17 + 2.62230295177210131e-20*V01*V10*V17 - 
      4.36793441115767937e-22*V13*V17 + 3.4332427870703965e-20*V012*V022*V18 + 
      1.89080993153141124e-20*V013*V03*V18 - 6.97448753315938279e-19*V02*V032*V18 - 
      2.38086794995216372e-19*V022*V04*V18 - 8.19745443100803979e-19*V01*V03*V04*V18 - 
      4.20152631295694308e-19*V01*V02*V05*V18 + 1.81276939988217018e-19*V052*V18 - 
      8.34875341739188238e-20*V012*V06*V18 + 2.2535205110324967e-19*V04*V06*V18 + 1.75153620517778455e-19*V03*V07*V18 + 
      4.28390673519808981e-20*V02*V08*V18 + 1.52279513929838322e-20*V01*V09*V18 - 3.10732187824734333e-22*V12*V18 + 
      2.31364928330847789e-21*V013*V02*V19 - 7.81100408424239576e-20*V022*V03*V19 - 
      9.53883281010232309e-20*V01*V032*V19 - 9.60582353100381104e-20*V01*V02*V04*V19 - 
      2.75291972400230836e-20*V012*V05*V19 + 8.66306705167854345e-20*V04*V05*V19 + 
      6.22218848410562899e-20*V03*V06*V19 + 2.10787683945755804e-20*V02*V07*V19 + 7.14065175512557432e-21*V01*V08*V19 - 
      2.07957700973409441e-22*V11*V19 + 4.7868605861554715e-23*V014*V20 - 2.04442003446809343e-21*V023*V20 - 
      2.2276757475428443e-20*V01*V02*V03*V20 - 6.33309253739775475e-21*V012*V04*V20 + 
      8.99451089582690859e-21*V042*V20 + 2.08686557677241261e-20*V03*V05*V20 + 6.50644600213535392e-21*V02*V06*V20 + 
      3.06399018964562627e-21*V01*V07*V20 - 1.13136039711155753e-22*V10*V20 - 1.15948400864654754e-21*V01*V022*V21 - 
      1.27693938414017716e-21*V012*V03*V21 + 4.54271184634224831e-21*V03*V04*V21 + 
      2.28859264599378179e-21*V02*V05*V21 + 9.914318835664949e-22*V01*V06*V21 - 5.85194080533412181e-23*V09*V21 - 
      1.4094645059235555e-22*V012*V02*V22 + 4.93342234764797947e-22*V032*V22 + 
      4.26699291235306349e-22*V02*V04*V22 + 2.99898358650397184e-22*V01*V05*V22 - 2.35766756601138548e-23*V08*V22 - 
      4.43227832051432546e-24*V013*V23 + 9.99657071323357404e-23*V02*V03*V23 + 6.02952877918978675e-23*V01*V04*V23 - 
      9.21031173761934736e-24*V07*V23 + 4.19792797253310825e-24*V022*V24 + 1.1753179408536263e-23*V01*V03*V24 - 
      2.59300372556460543e-24*V06*V24 + 1.1208060120840823e-24*V01*V02*V25 - 7.33579449635699915e-25*V05*V25 + 
      5.73139437997542085e-26*V012*V26 - 1.28868040231045914e-25*V04*V26 - 2.44149183534078412e-26*V03*V27 - 
      2.01317795425659944e-27*V02*V28 - 2.15697637956064226e-28*V01*V29 + 2.33439002116952625e-31*V32) + 
   delta14*eps9*(9.2027749790270834e-13*V04*V054 + 
      3.51529378509599537e-12*V042*V052*V06 + 2.57531395795744542e-12*V03*V053*V06 + 
      4.68821101206714135e-13*V043*V062 + 5.04156046388224925e-12*V03*V04*V05*V062 + 
      1.25149090147969733e-12*V02*V052*V062 + 5.98358979870006177e-13*V032*V063 + 
      3.30697160923354823e-13*V02*V04*V063 + 3.59015387922003706e-13*V01*V05*V063 + 
      1.54770902073339786e-12*V043*V05*V07 + 5.22245322432256504e-12*V03*V04*V052*V07 + 
      8.85278289269602908e-13*V02*V053*V07 + 3.34789884294856701e-12*V03*V042*V06*V07 + 
      3.64502686791704488e-12*V032*V05*V06*V07 + 3.29942086561925675e-12*V02*V04*V05*V06*V07 + 
      1.08331013876846461e-12*V01*V052*V06*V07 + 1.19189609664733079e-12*V02*V03*V062*V07 + 
      7.20222923411749893e-13*V01*V04*V062*V07 + 1.23310841865774471e-12*V032*V04*V072 + 
      5.40925590449820538e-13*V02*V042*V072 + 1.25698600504328181e-12*V02*V03*V05*V072 + 
      7.34682860463006455e-13*V01*V04*V05*V072 + 1.91100149922503923e-13*V022*V06*V072 + 
      5.08254138526707268e-13*V01*V03*V06*V072 - 7.64611433933906598e-14*V062*V072 + 
      5.91234035409310189e-14*V01*V02*V073 - 5.09638760898725948e-14*V05*V073 + 
      1.20313122609575115e-13*V044*V08 + 2.60592257462469684e-12*V03*V042*V05*V08 + 
      1.39241176895067665e-12*V032*V052*V08 + 1.29118006840152097e-12*V02*V04*V052*V08 + 
      2.75199123413025202e-13*V01*V053*V08 + 1.85702844856635765e-12*V032*V04*V06*V08 + 
      5.0847178291301488e-13*V02*V042*V06*V08 + 1.85678350730495815e-12*V02*V03*V05*V06*V08 + 
      1.11421706913981459e-12*V01*V04*V05*V06*V08 + 8.91774259222156834e-14*V022*V062*V08 + 
      3.9259879858883196e-13*V01*V03*V062*V08 - 3.48925646605874004e-14*V063*V08 + 
      4.3682400541750032e-13*V033*V07*V08 + 1.22969530323954378e-12*V02*V03*V04*V07*V08 + 
      3.72274653517813835e-13*V01*V042*V07*V08 + 3.00655553353100408e-13*V022*V05*V07*V08 + 
      7.73721533059789961e-13*V01*V03*V05*V07*V08 + 2.65254786757851164e-13*V01*V02*V06*V07*V08 - 
      2.39155899875248433e-13*V05*V06*V07*V08 + 2.60987866884088243e-14*V012*V072*V08 - 
      8.03549017520770582e-14*V04*V072*V08 + 1.71100672519167696e-13*V02*V032*V082 + 
      4.56040427967957179e-14*V022*V04*V082 + 2.03079145860440213e-13*V01*V03*V04*V082 + 
      1.02660403511500618e-13*V01*V02*V05*V082 - 4.66375552613764763e-14*V052*V082 + 
      2.09028597185041321e-14*V012*V06*V082 - 5.47894665822828697e-14*V04*V06*V082 - 
      4.50199147508528373e-14*V03*V07*V082 - 3.44520757465401424e-15*V02*V083 + 
      4.29919172425943851e-13*V03*V043*V09 + 1.42855000645584588e-12*V032*V04*V05*V09 + 
      6.31079855524790627e-13*V02*V042*V05*V09 + 7.28751764825826351e-13*V02*V03*V052*V09 + 
      4.24948513106750662e-13*V01*V04*V052*V09 + 3.31207474432659181e-13*V033*V06*V09 + 
      9.16505796005349097e-13*V02*V03*V04*V06*V09 + 2.78991570245713918e-13*V01*V042*V06*V09 + 
      2.22950174909587911e-13*V022*V05*V06*V09 + 5.87297649610798002e-13*V01*V03*V05*V06*V09 + 
      9.93246747206108994e-14*V01*V02*V062*V09 - 9.04268197055167876e-14*V05*V062*V09 + 
      3.44151421213524009e-13*V02*V032*V07*V09 + 1.45157255056839087e-13*V022*V04*V07*V09 + 
      3.98847476489227382e-13*V01*V03*V04*V07*V09 + 2.05207975171136871e-13*V01*V02*V05*V07*V09 - 
      9.02489860168251114e-14*V052*V07*V09 + 3.97090115973782429e-14*V012*V06*V07*V09 - 
      1.21234299171397313e-13*V04*V06*V07*V09 - 4.34832118647183069e-14*V03*V072*V09 + 
      8.35154314869723357e-14*V022*V03*V08*V09 + 1.04413777520522874e-13*V01*V032*V08*V09 + 
      1.02474608603295315e-13*V01*V02*V04*V08*V09 + 3.00577237106305179e-14*V012*V05*V08*V09 - 
      9.5014677101806047e-14*V04*V05*V08*V09 - 6.82441520888817785e-14*V03*V06*V08*V09 - 
      2.30417568730342737e-14*V02*V07*V08*V09 - 3.90245842614702283e-15*V01*V082*V09 + 
      3.2017162874205049e-15*V023*V092 + 2.78331917136132001e-14*V01*V02*V03*V092 + 
      7.8025080030448711e-15*V012*V04*V092 - 1.19727635571010697e-14*V042*V092 - 
      2.56376154508285016e-14*V03*V05*V092 - 8.662679858761405e-15*V02*V06*V092 - 
      3.7461848025400631e-15*V01*V07*V092 + 2.93788533084772445e-13*V032*V042*V10 + 
      5.28025030799124843e-14*V02*V043*V10 + 2.03935806565913325e-13*V033*V05*V10 + 
      5.85903411589022774e-13*V02*V03*V04*V05*V10 + 1.76273119850863467e-13*V01*V042*V05*V10 + 
      7.19706540314973582e-14*V022*V052*V10 + 1.80101432318692569e-13*V01*V03*V052*V10 + 
      2.09325361211895904e-13*V02*V032*V06*V10 + 5.54394432999439431e-14*V022*V04*V06*V10 + 
      2.48633844172469484e-13*V01*V03*V04*V06*V10 + 1.25595216727137542e-13*V01*V02*V05*V06*V10 - 
      5.79874161533721794e-14*V052*V06*V10 + 1.27982079382029731e-14*V012*V062*V10 - 
      3.39279746520210285e-14*V04*V062*V10 + 6.8543480029997484e-14*V022*V03*V07*V10 + 
      8.41241136800300692e-14*V01*V032*V07*V10 + 8.37004873698603963e-14*V01*V02*V04*V07*V10 + 
      2.41714358542785016e-14*V012*V05*V07*V10 - 7.81109406429775976e-14*V04*V05*V07*V10 - 
      5.59662970004502383e-14*V03*V06*V07*V10 - 9.49277390328420895e-15*V02*V072*V10 + 
      3.28404349954127821e-15*V023*V08*V10 + 4.57808003036391903e-14*V01*V02*V03*V08*V10 + 
      1.32332447076646551e-14*V012*V04*V08*V10 - 1.77418016790767639e-14*V042*V08*V10 - 
      4.35126924047974853e-14*V03*V05*V08*V10 - 1.27886819195980349e-14*V02*V06*V08*V10 - 
      6.37991662579634914e-15*V01*V07*V08*V10 + 5.711956669166457e-15*V01*V022*V09*V10 + 
      6.44120888090042317e-15*V012*V03*V09*V10 - 2.22738805660703071e-14*V03*V04*V09*V10 - 
      1.12188685089209663e-14*V02*V05*V09*V10 - 4.84890467791860813e-15*V01*V06*V09*V10 + 
      1.2237837696252004e-16*V092*V10 + 7.43930962391029022e-16*V012*V02*V102 - 
      2.52214658863760293e-15*V032*V102 - 2.06377044423568719e-15*V02*V04*V102 - 
      1.53265165654038824e-15*V01*V05*V102 + 1.01125323142554014e-16*V08*V102 + 
      8.45068847845031664e-14*V033*V04*V11 + 1.14741791913598296e-13*V02*V03*V042*V11 + 
      2.34501366777787555e-14*V01*V043*V11 + 1.29770516663555942e-13*V02*V032*V05*V11 + 
      5.54236792035203787e-14*V022*V04*V05*V11 + 1.49872878869174096e-13*V01*V03*V04*V05*V11 + 
      3.86020397112071863e-14*V01*V02*V052*V11 - 1.17530390982218168e-14*V053*V11 + 
      4.05363954381068928e-14*V022*V03*V06*V11 + 5.15537110214019871e-14*V01*V032*V06*V11 + 
      4.99912252366554053e-14*V01*V02*V04*V06*V11 + 1.48525946824338485e-14*V012*V05*V06*V11 - 
      4.75301556329565193e-14*V04*V05*V06*V11 - 1.71078685354908802e-14*V03*V062*V11 + 
      4.19133768535047914e-15*V023*V07*V11 + 3.62029277783704558e-14*V01*V02*V03*V07*V11 + 
      1.01356742535066135e-14*V012*V04*V07*V11 - 1.5879023741019962e-14*V042*V07*V11 - 
      3.39376622168137121e-14*V03*V05*V07*V11 - 1.14870728254485135e-14*V02*V06*V07*V11 - 
      2.47668355241084042e-15*V01*V072*V11 + 4.55538717201667285e-15*V01*V022*V08*V11 + 
      5.20364664735906474e-15*V012*V03*V08*V11 - 1.79666458681735426e-14*V03*V04*V08*V11 - 
      9.02748006982243085e-15*V02*V05*V08*V11 - 3.92007640620342944e-15*V01*V06*V08*V11 + 
      1.41294868581686319e-15*V012*V02*V09*V11 - 4.80101285674848197e-15*V032*V09*V11 - 
      4.5117615672932807e-15*V02*V04*V09*V11 - 2.91205994069570784e-15*V01*V05*V09*V11 + 1.98987849141275601e-16*V08*V09*V11 + 
      1.01382179741128823e-16*V013*V10*V11 - 2.11832097712529705e-15*V02*V03*V10*V11 - 
      1.27781861860006245e-15*V01*V04*V10*V11 + 1.63809950617857517e-16*V07*V10*V11 - 
      1.05000649236920804e-16*V022*V112 - 2.69645596502875988e-16*V01*V03*V112 + 
      5.07351112155322568e-17*V06*V112 + 7.52792251420101996e-15*V034*V12 + 
      4.46011011930481941e-14*V02*V032*V04*V12 + 5.78095019588847463e-15*V022*V042*V12 + 
      2.65628844296234408e-14*V01*V03*V042*V12 + 2.20514774157545545e-14*V022*V03*V05*V12 + 
      2.63862457128973345e-14*V01*V032*V05*V12 + 2.67606607158289165e-14*V01*V02*V04*V05*V12 + 
      3.77537735499442164e-15*V012*V052*V12 - 1.29735202951829402e-14*V04*V052*V12 + 
      1.33921405092791676e-15*V023*V06*V12 + 1.89108122040942112e-14*V01*V02*V03*V06*V12 + 
      5.4719887384553758e-15*V012*V04*V06*V12 - 7.49855846149601526e-15*V042*V06*V12 - 
      1.85304353138881422e-14*V03*V05*V06*V12 - 2.70008681145409571e-15*V02*V062*V12 + 
      3.15021105939350778e-15*V01*V022*V07*V12 + 3.49355814691473433e-15*V012*V03*V07*V12 - 
      1.25150906872672888e-14*V03*V04*V07*V12 - 6.31790237770523476e-15*V02*V05*V07*V12 - 
      2.71523072084925534e-15*V01*V06*V07*V12 + 1.00483949267842707e-15*V012*V02*V08*V12 - 
      3.45611541419847227e-15*V032*V08*V12 - 2.8171879183297578e-15*V02*V04*V08*V12 - 
      2.09988005142195356e-15*V01*V05*V08*V12 + 6.98212136754078664e-17*V082*V12 + 
      8.45496230065122585e-17*V013*V09*V12 - 1.79928869216053129e-15*V02*V03*V09*V12 - 
      1.08276349214077716e-15*V01*V04*V09*V12 + 1.39186627752246642e-16*V07*V09*V12 - 
      1.62337166319143067e-16*V022*V10*V12 - 4.81023338203284534e-16*V01*V03*V10*V12 + 
      8.75552642883807605e-17*V06*V10*V12 - 1.02977471513988916e-16*V01*V02*V11*V12 + 5.56393997174238829e-17*V05*V11*V12 - 
      5.54077265548279723e-18*V012*V122 + 1.00445090975560777e-17*V04*V122 + 
      5.3822077559896121e-15*V02*V033*V13 + 7.10559989788722804e-15*V022*V03*V04*V13 + 
      9.22461146488819956e-15*V01*V032*V04*V13 + 4.41314584283070369e-15*V01*V02*V042*V13 + 
      1.12843706913282131e-15*V023*V05*V13 + 9.53695715464842802e-15*V01*V02*V03*V05*V13 + 
      2.65711563990588481e-15*V012*V04*V05*V13 - 4.44117347051323363e-15*V042*V05*V13 - 
      4.71486853673569615e-15*V03*V052*V13 + 1.55909213223488049e-15*V01*V022*V06*V13 + 
      1.80249127836553536e-15*V012*V03*V06*V13 - 6.41173686302829501e-15*V03*V04*V06*V13 - 
      3.21127287044997652e-15*V02*V05*V06*V13 - 7.00727545533834012e-16*V01*V062*V13 + 
      6.43158990957590464e-16*V012*V02*V07*V13 - 2.26257553466836103e-15*V032*V07*V13 - 
      2.13450667892601588e-15*V02*V04*V07*V13 - 1.37083677811336777e-15*V01*V05*V07*V13 + 
      5.74582058724160969e-17*V013*V08*V13 - 1.21627138194233472e-15*V02*V03*V08*V13 - 
      7.35335740537542279e-16*V01*V04*V08*V13 + 9.57762462415141741e-17*V07*V08*V13 - 
      1.49851145945854778e-16*V022*V09*V13 - 3.84000231414231224e-16*V01*V03*V09*V13 + 
      7.2975442599378158e-17*V06*V09*V13 - 8.65076467340518385e-17*V01*V02*V10*V13 + 4.70906904971313136e-17*V05*V10*V13 - 
      1.04009323388158306e-17*V012*V11*V13 + 1.97274593329572516e-17*V04*V11*V13 + 
      7.79642821349782592e-18*V03*V12*V13 + 6.99281933109341025e-19*V02*V132 + 
      1.20918254911157337e-15*V022*V032*V14 + 9.22899758304467769e-16*V01*V033*V14 + 
      1.9940595681185048e-16*V023*V04*V14 + 2.90293171933157416e-15*V01*V02*V03*V04*V14 + 
      4.21109080578041838e-16*V012*V042*V14 - 4.01374864411482494e-16*V043*V14 + 
      7.2550952946694402e-16*V01*V022*V05*V14 + 7.83986824111663623e-16*V012*V03*V05*V14 - 
      3.02379252836987497e-15*V03*V04*V05*V14 - 7.65360648320548073e-16*V02*V052*V14 + 
      2.99147570501439979e-16*V012*V02*V06*V14 - 1.07407823184664435e-15*V032*V06*V14 - 
      8.65123363569163036e-16*V02*V04*V06*V14 - 6.52305652880766051e-16*V01*V05*V06*V14 + 
      3.28924241612832803e-17*V013*V07*V14 - 7.37761014004200049e-16*V02*V03*V07*V14 - 
      4.42544687089150515e-16*V01*V04*V07*V14 + 2.90916430685724583e-17*V072*V14 - 
      8.0580724296064444e-17*V022*V08*V14 - 2.40538546610949604e-16*V01*V03*V08*V14 + 
      4.4409170889184152e-17*V06*V08*V14 - 6.36916122107933323e-17*V01*V02*V09*V14 + 3.47529083491382786e-17*V05*V09*V14 - 
      8.08998779911127836e-18*V012*V10*V14 + 1.47581619731088094e-17*V04*V10*V14 + 
      6.77207458530948982e-18*V03*V11*V14 + 1.23471324692631095e-18*V02*V12*V14 + 2.90820549264459201e-19*V01*V13*V14 + 
      1.07470197060268696e-16*V023*V03*V15 + 4.3293175588755746e-16*V01*V02*V032*V15 + 
      2.03017139939635087e-16*V01*V022*V04*V15 + 2.3802483427702605e-16*V012*V03*V04*V15 - 
      4.49326313713130555e-16*V03*V042*V15 + 1.24426462836134556e-16*V012*V02*V05*V15 - 
      4.70133422928142077e-16*V032*V05*V15 - 4.47763410316850013e-16*V02*V04*V05*V15 - 
      1.42017807553593255e-16*V01*V052*V15 + 1.46999169866849912e-17*V013*V06*V15 - 
      3.2466081582771324e-16*V02*V03*V06*V15 - 1.96826503222040197e-16*V01*V04*V06*V15 - 
      5.32015089535069257e-17*V022*V07*V15 - 1.35338612147965536e-16*V01*V03*V07*V15 + 
      2.65277284905838324e-17*V06*V07*V15 - 3.7274988436417146e-17*V01*V02*V08*V15 + 2.07931374226637448e-17*V05*V08*V15 - 
      5.54441914974749562e-18*V012*V09*V15 + 1.07161842163489028e-17*V04*V09*V15 + 4.9831954404502506e-18*V03*V10*V15 + 
      1.05644237631522361e-18*V02*V11*V15 + 2.52842595525402064e-19*V01*V12*V15 - 1.12033920274682871e-21*V152 + 
      1.91221960873082364e-18*V024*V16 + 5.93191593324854952e-17*V01*V022*V03*V16 + 
      3.04768137804471482e-17*V012*V032*V16 + 3.46389996975772999e-17*V012*V02*V04*V16 - 
      1.33610264626806295e-16*V032*V04*V16 - 5.26363320834647129e-17*V02*V042*V16 + 
      5.5155271420480266e-18*V013*V05*V16 - 1.35884442226750404e-16*V02*V03*V05*V16 - 
      8.10896753785914545e-17*V01*V04*V05*V16 - 1.87960192688186679e-17*V022*V06*V16 - 
      5.69970708070561785e-17*V01*V03*V06*V16 + 5.41409458652628806e-18*V062*V16 - 
      1.98558026188562011e-17*V01*V02*V07*V16 + 1.11465390127505871e-17*V05*V07*V16 - 
      3.08687715956669848e-18*V012*V08*V16 + 5.7394607252150346e-18*V04*V08*V16 + 3.24581636355680891e-18*V03*V09*V16 + 
      6.95561579046622471e-19*V02*V10*V16 + 1.93867968278118237e-19*V01*V11*V16 - 2.07401591047088363e-21*V14*V16 + 
      2.37066611162357417e-18*V01*V023*V17 + 8.52252658759120145e-18*V012*V02*V03*V17 - 
      1.20833784666049087e-17*V033*V17 + 1.48520327786450429e-18*V013*V04*V17 - 
      3.52247442731117845e-17*V02*V03*V04*V17 - 1.07255887538915187e-17*V01*V042*V17 - 
      8.68434375033919486e-18*V022*V05*V17 - 2.17454493824073747e-17*V01*V03*V05*V17 - 
      7.74300533661429941e-18*V01*V02*V06*V17 + 4.50522888153391548e-18*V05*V06*V17 - 
      1.51498818817836056e-18*V012*V07*V17 + 3.04769655172028932e-18*V04*V07*V17 + 
      1.72124923794889901e-18*V03*V08*V17 + 4.49065809988584381e-19*V02*V09*V17 + 1.26429679884675416e-19*V01*V10*V17 - 
      1.75645199897746736e-21*V13*V17 + 5.51446339525110316e-19*V012*V022*V18 + 
      3.26783016014880188e-19*V013*V03*V18 - 4.72408686148464432e-18*V02*V032*V18 - 
      1.79051684424090686e-18*V022*V04*V18 - 5.57956115340016117e-18*V01*V03*V04*V18 - 
      2.86476890060310458e-18*V01*V02*V05*V18 + 8.44869019859857331e-19*V052*V18 - 
      5.76287359963741462e-19*V012*V06*V18 + 1.10660891058769752e-18*V04*V06*V18 + 
      8.23858967896625434e-19*V03*V07*V18 + 2.13937771039224332e-19*V02*V08*V18 + 7.35521136839532837e-20*V01*V09*V18 - 
      1.267601613744915e-21*V12*V18 + 4.14861250800140863e-20*V013*V02*V19 - 
      5.46287167560031642e-19*V022*V03*V19 - 6.61290859959799628e-19*V01*V032*V19 - 
      6.71801691405590743e-19*V01*V02*V04*V19 - 1.93290391192395301e-19*V012*V05*V19 + 
      4.15744703723045899e-19*V04*V05*V19 + 2.9953781427900864e-19*V03*V06*V19 + 1.0260987191946225e-19*V02*V07*V19 + 
      3.50795018458547218e-20*V01*V08*V19 - 8.39237718103130917e-22*V11*V19 + 9.57372117231094299e-22*V014*V20 - 
      1.61892131569871819e-20*V023*V20 - 1.58916173268955058e-19*V01*V02*V03*V20 - 
      4.55131665255099592e-20*V012*V04*V20 + 4.57461870444357997e-20*V042*V20 + 
      1.01096312919064441e-19*V03*V05*V20 + 3.33750935988706813e-20*V02*V06*V20 + 1.51164678889381545e-20*V01*V07*V20 - 
      4.6499615399327846e-22*V10*V20 - 8.50997437538750488e-21*V01*V022*V21 - 
      9.44961737933654188e-21*V012*V03*V21 + 2.26600769161009802e-20*V03*V04*V21 + 
      1.14769975234403985e-20*V02*V05*V21 + 5.00502474861152637e-21*V01*V06*V21 - 2.38009237285182019e-22*V09*V21 - 
      1.06374679692343811e-21*V012*V02*V22 + 2.48802923168207927e-21*V032*V22 + 
      2.26992387515185322e-21*V02*V04*V22 + 1.52635511163447262e-21*V01*V05*V22 - 9.82107324566903839e-23*V08*V22 - 
      3.54582265641146037e-23*V013*V23 + 5.21276687074742277e-22*V02*V03*V23 + 3.15509949145338488e-22*V01*V04*V23 - 
      3.80026780719730825e-23*V07*V23 + 2.33902025576383575e-23*V022*V24 + 6.23606275978018991e-23*V01*V03*V24 - 
      1.10341497183457654e-23*V06*V24 + 6.12877105698705003e-24*V01*V02*V25 - 3.09848629792276946e-24*V05*V25 + 
      3.20958085278623568e-25*V012*V26 - 5.65530447035739591e-25*V04*V26 - 1.0669843157559977e-25*V03*V27 - 
      9.20309921945874029e-27*V02*V28 - 9.86046344942007889e-28*V01*V29 + 9.33756008467810501e-31*V32) + 
   delta12*eps10*(-1.2623608842908231e-11*V032*V044 - 
      5.54575148020670988e-13*V02*V045 - 5.74705646606385813e-11*V033*V042*V05 - 
      4.91651886754433664e-11*V02*V03*V043*V05 - 7.57416530574493862e-12*V01*V044*V05 - 
      1.41673422599600606e-11*V034*V052 - 8.76270248886472824e-11*V02*V032*V04*V052 - 
      1.76417730163233288e-11*V022*V042*V052 - 
      5.04242420550523057e-11*V01*V03*V042*V052 - 1.46846020733457747e-11*V022*V03*V053 - 
      1.62450823703169877e-11*V01*V032*V053 - 1.71882686550962415e-11*V01*V02*V04*V053 - 
      1.13663327425446239e-12*V012*V054 + 6.41329382557683476e-12*V04*V054 - 
      1.98433346915017425e-11*V034*V04*V06 - 5.33577966938719842e-11*V02*V032*V042*V06 - 
      1.89201755779574989e-12*V022*V043*V06 - 2.16414031925669668e-11*V01*V03*V043*V06 - 
      4.05651856948794135e-11*V02*V033*V05*V06 - 5.16478589392089559e-11*V022*V03*V04*V05*V06 - 
      6.91490655018469102e-11*V01*V032*V04*V05*V06 - 3.20146780163231905e-11*V01*V02*V042*V05*V06 - 
      4.0916891147178767e-12*V023*V052*V06 - 3.5540896278702817e-11*V01*V02*V03*V052*V06 - 
      9.85457633704859201e-12*V012*V04*V052*V06 + 2.56710944023287782e-11*V042*V052*V06 + 
      1.80666387454398935e-11*V03*V053*V06 - 9.36271046026096767e-12*V022*V032*V062 - 
      7.8656417166148862e-12*V01*V033*V062 - 6.42053512793598194e-13*V023*V04*V062 - 
      2.29077178922460593e-11*V01*V02*V03*V04*V062 - 3.41880572570803806e-12*V012*V042*V062 + 
      4.31644238115062414e-12*V043*V062 - 5.6176262761565806e-12*V01*V022*V05*V062 - 
      6.66533109398845298e-12*V012*V03*V05*V062 + 3.69451619234321807e-11*V03*V04*V05*V062 + 
      9.22110298447443794e-12*V02*V052*V062 - 8.0509151259731452e-13*V012*V02*V063 + 
      4.4016956586828841e-12*V032*V063 + 3.07126590536725037e-12*V02*V04*V063 + 
      2.66220968483005777e-12*V01*V05*V063 - 2.62035237653655311e-12*V035*V07 - 
      2.72829661192003833e-11*V02*V033*V04*V07 - 1.68016885869745988e-11*V022*V03*V042*V07 - 
      2.33928456740618515e-11*V01*V032*V042*V07 - 7.02359838220619519e-12*V01*V02*V043*V07 - 
      2.06196699555050425e-11*V022*V032*V05*V07 - 1.49358422060442242e-11*V01*V033*V05*V07 - 
      5.26432182117911787e-12*V023*V04*V05*V07 - 4.79303538704672626e-11*V01*V02*V03*V04*V05*V07 - 
      6.68789515999118757e-12*V012*V042*V05*V07 + 1.13615334084914975e-11*V043*V05*V07 - 
      6.07840108472626493e-12*V01*V022*V052*V07 - 6.22703868096533244e-12*V012*V03*V052*V07 + 
      3.67793703319310409e-11*V03*V04*V052*V07 + 6.25390255486669154e-12*V02*V053*V07 - 
      3.89684677592178734e-12*V023*V03*V06*V07 - 1.64633930628638866e-11*V01*V02*V032*V06*V07 - 
      7.37826556274413655e-12*V01*V022*V04*V06*V07 - 9.05860517039494058e-12*V012*V03*V04*V06*V07 + 
      2.46484257981910765e-11*V03*V042*V06*V07 - 4.69504492380407939e-12*V012*V02*V05*V06*V07 + 
      2.58459906844252572e-11*V032*V05*V06*V07 + 2.44444701875073728e-11*V02*V04*V05*V06*V07 + 
      7.76237663392838207e-12*V01*V052*V06*V07 - 2.77992294859931609e-13*V013*V062*V07 + 
      8.85302253565730085e-12*V02*V03*V062*V07 + 5.36332983926226054e-12*V01*V04*V062*V07 - 
      1.44555442391423374e-13*V024*V072 - 2.82437452891535005e-12*V01*V022*V03*V072 - 
      1.41762982314936759e-12*V012*V032*V072 - 
      1.59021466306590077e-12*V012*V02*V04*V072 + 8.7767295508406923e-12*V032*V04*V072 + 
      4.03241202203771409e-12*V02*V042*V072 - 2.52551080557655571e-13*V013*V05*V072 + 
      8.971792482394812e-12*V02*V03*V05*V072 + 5.28267580081846432e-12*V01*V04*V05*V072 + 
      1.43889096411765657e-12*V022*V06*V072 + 3.68278361233013768e-12*V01*V03*V06*V072 - 
      3.3500491079814692e-13*V062*V072 + 4.30586229197610898e-13*V01*V02*V073 - 
      2.17257522058938345e-13*V05*V073 - 3.58632999260539863e-12*V02*V034*V08 - 
      9.57281375529056349e-12*V022*V032*V04*V08 - 8.05607528509525142e-12*V01*V033*V04*V08 - 
      3.21252770897937729e-13*V023*V042*V08 - 1.17373432292264333e-11*V01*V02*V03*V042*V08 - 
      1.17010706412317977e-12*V012*V043*V08 + 1.11695017650896361e-12*V044*V08 - 
      3.06196843775062607e-12*V023*V03*V05*V08 - 1.24603347419112635e-11*V01*V02*V032*V05*V08 - 
      5.7436882531743381e-12*V01*V022*V04*V05*V08 - 6.81706928987549431e-12*V012*V03*V04*V05*V08 + 
      1.92682630402366226e-11*V03*V042*V05*V08 - 1.76868599157390636e-12*V012*V02*V052*V08 + 
      9.9324897728717118e-12*V032*V052*V08 + 9.60169276410335796e-12*V02*V04*V052*V08 + 
      1.9841301864990341e-12*V01*V053*V08 - 5.40914475902372699e-14*V024*V06*V08 - 
      4.1207846214552146e-12*V01*V022*V03*V06*V08 - 2.29425089407388893e-12*V012*V032*V06*V08 - 
      2.47672754008752081e-12*V012*V02*V04*V06*V08 + 1.37815491666856249e-11*V032*V04*V06*V08 + 
      4.76271969257700908e-12*V02*V042*V06*V08 - 4.15641843517677158e-13*V013*V05*V06*V08 + 
      1.38485882612334574e-11*V02*V03*V05*V06*V08 + 8.33457278314632135e-12*V01*V04*V05*V06*V08 + 
      8.4339725366479097e-13*V022*V062*V08 + 2.94792451247931615e-12*V01*V03*V062*V08 - 
      1.66141210703491369e-13*V063*V08 - 4.37424062535803724e-13*V01*V023*V07*V08 - 
      1.62011238747969584e-12*V012*V02*V03*V07*V08 + 3.14985411960212745e-12*V033*V07*V08 - 
      2.8334630268833478e-13*V013*V04*V07*V08 + 9.21762404573449882e-12*V02*V03*V04*V07*V08 + 
      2.79669868260047833e-12*V01*V042*V07*V08 + 2.27046049284179341e-12*V022*V05*V07*V08 + 
      5.64136173788458123e-12*V01*V03*V05*V07*V08 + 2.0097338213921578e-12*V01*V02*V06*V07*V08 - 
      1.05042485432129021e-12*V05*V06*V07*V08 + 1.95164092362449316e-13*V012*V072*V08 - 
      3.55990647149046823e-13*V04*V072*V08 - 1.11364999840402184e-13*V012*V022*V082 - 
      7.00444587472482508e-14*V013*V03*V082 + 1.29188979576842434e-12*V02*V032*V082 + 
      4.3514659203188036e-13*V022*V04*V082 + 1.53804125430683321e-12*V01*V03*V04*V082 + 
      7.81158054281493919e-13*V01*V02*V05*V082 - 2.05384806979681607e-13*V052*V082 + 
      1.60081659777896363e-13*V012*V06*V082 - 2.63816131929522945e-13*V04*V06*V082 - 
      2.00679702456063537e-13*V03*V07*V082 - 1.69696312815928487e-14*V02*V083 - 
      1.84287073543241269e-12*V022*V033*V09 - 9.75596461380281964e-13*V01*V034*V09 - 
      1.46231161699419941e-12*V023*V03*V04*V09 - 6.3594614014276299e-12*V01*V02*V032*V04*V09 - 
      1.40014071558121657e-12*V01*V022*V042*V09 - 1.75463229527355072e-12*V012*V03*V042*V09 + 
      3.20761402166334979e-12*V03*V043*V09 - 1.6864801612332727e-13*V024*V05*V09 - 
      3.2353814493316596e-12*V01*V022*V03*V05*V09 - 1.61078053185556068e-12*V012*V032*V05*V09 - 
      1.81511516373959674e-12*V012*V02*V04*V05*V09 + 1.02744290732339591e-11*V032*V04*V05*V09 + 
      4.74259025875859382e-12*V02*V042*V05*V09 - 1.43006632377705003e-13*V013*V052*V09 + 
      5.25553216885621094e-12*V02*V03*V052*V09 + 3.08784485034891785e-12*V01*V04*V052*V09 - 
      3.24737231326815611e-13*V01*V023*V06*V09 - 1.22737193544647799e-12*V012*V02*V03*V06*V09 + 
      2.3989213956727763e-12*V033*V06*V09 - 2.15156813341901962e-13*V013*V04*V06*V09 + 
      6.90006915887170832e-12*V02*V03*V04*V06*V09 + 2.10397659884255448e-12*V01*V042*V06*V09 + 
      1.6921578391716141e-12*V022*V05*V06*V09 + 4.300662772680902e-12*V01*V03*V05*V06*V09 + 
      7.55506801296615058e-13*V01*V02*V062*V09 - 4.00597981312185625e-13*V05*V062*V09 - 
      2.14063562850636073e-13*V012*V022*V07*V09 - 1.28513085209432488e-13*V013*V03*V07*V09 + 
      2.50790594225781283e-12*V02*V032*V07*V09 + 1.10980779444743086e-12*V022*V04*V07*V09 + 
      2.93047942673694445e-12*V01*V03*V04*V07*V09 + 1.51017894607246057e-12*V01*V02*V05*V07*V09 - 
      3.89129192910370228e-13*V052*V07*V09 + 2.98141461712608913e-13*V012*V06*V07*V09 - 
      5.41712906584305521e-13*V04*V06*V07*V09 - 1.89858088690570852e-13*V03*V072*V09 - 
      3.79053328758700677e-14*V013*V02*V08*V09 + 6.40676542313120632e-13*V022*V03*V08*V09 + 
      7.78174727088949434e-13*V01*V032*V08*V09 + 7.86424023791652476e-13*V01*V02*V04*V08*V09 + 
      2.27198971324947864e-13*V012*V05*V08*V09 - 4.25537514808091988e-13*V04*V05*V08*V09 - 
      3.06702885911666218e-13*V03*V06*V08*V09 - 1.05270324241776306e-13*V02*V07*V08*V09 - 
      1.80097439383379314e-14*V01*V082*V09 - 1.01101831876375727e-15*V014*V092 + 
      2.51551265392364768e-14*V023*V092 + 2.0926639912543473e-13*V01*V02*V03*V092 + 
      5.93770226614903069e-14*V012*V04*V092 - 5.45316567881394302e-14*V042*V092 - 
      1.13184122999392208e-13*V03*V05*V092 - 3.9904838880104603e-14*V02*V06*V092 - 
      1.6959878620480182e-14*V01*V07*V092 - 3.44644620572231875e-13*V023*V032*V10 - 
      8.77283007707745707e-13*V01*V02*V033*V10 - 1.61031759883486528e-14*V024*V04*V10 - 
      1.27944533477919338e-12*V01*V022*V03*V04*V10 - 7.10055025965905666e-13*V012*V032*V04*V10 - 
      3.85706574334752339e-13*V012*V02*V042*V10 + 2.21886023175204245e-12*V032*V042*V10 + 
      5.02865499693221607e-13*V02*V043*V10 - 2.06786772343339125e-13*V01*V023*V05*V10 - 
      7.37794811625309912e-13*V012*V02*V03*V05*V10 + 1.49370603604755817e-12*V033*V05*V10 - 
      1.28176814577713295e-13*V013*V04*V05*V10 + 4.44861446587975325e-12*V02*V03*V04*V05*V10 + 
      1.34165672601200623e-12*V01*V042*V05*V10 + 5.50240246801894186e-13*V022*V052*V10 + 
      1.33404059581068825e-12*V01*V03*V052*V10 - 1.3530407725362115e-13*V012*V022*V06*V10 - 
      8.47647083836181451e-14*V013*V03*V06*V10 + 1.59437366872526792e-12*V02*V032*V06*V10 + 
      5.33286892200087703e-13*V022*V04*V06*V10 + 1.8993219805302427e-12*V01*V03*V04*V06*V10 + 
      9.63977042288914403e-13*V01*V02*V05*V06*V10 - 2.57915244920401319e-13*V052*V06*V10 + 
      9.884993686014354e-14*V012*V062*V10 - 1.65002084758868242e-13*V04*V062*V10 - 
      3.02035724286660697e-14*V013*V02*V07*V10 + 5.28095906055248916e-13*V022*V03*V07*V10 + 
      6.30253366843431312e-13*V01*V032*V07*V10 + 6.45373748905365607e-13*V01*V02*V04*V07*V10 + 
      1.83697218384306175e-13*V012*V05*V07*V10 - 3.50306945395216703e-13*V04*V05*V07*V10 - 
      2.51917241416638518e-13*V03*V06*V07*V10 - 4.34221384518788821e-14*V02*V072*V10 - 
      1.77457277176351891e-15*V014*V08*V10 + 3.22329983572826521e-14*V023*V08*V10 + 
      3.55670260028069726e-13*V01*V02*V03*V08*V10 + 1.03079127775903e-13*V012*V04*V08*V10 - 
      8.72303491342608571e-14*V042*V08*V10 - 1.96424063287615967e-13*V03*V05*V08*V10 - 
      6.36060582977409347e-14*V02*V06*V08*V10 - 2.94988919233595527e-14*V01*V07*V08*V10 + 
      4.5022386113203404e-14*V01*V022*V09*V10 + 5.00967541677195804e-14*V012*V03*V09*V10 - 
      1.02139971643221833e-13*V03*V04*V09*V10 - 5.18521279891981853e-14*V02*V05*V09*V10 - 
      2.25856342350204916e-14*V01*V06*V09*V10 + 4.46736304504691193e-16*V092*V10 + 
      5.94348777483171396e-15*V012*V02*V102 - 1.16659141852572711e-14*V032*V102 - 
      1.0473826241200665e-14*V02*V04*V102 - 7.17554024043429019e-15*V01*V05*V102 + 
      3.81814750433060077e-16*V08*V102 - 3.06632756587867763e-14*V024*V03*V11 - 
      2.7583193085567989e-13*V01*V022*V032*V11 - 8.86070125026075195e-14*V012*V033*V11 - 
      7.97624518360472405e-14*V01*V023*V04*V11 - 3.04860204586883083e-13*V012*V02*V03*V04*V11 + 
      6.27008891132999071e-13*V033*V04*V11 - 2.66946478864830395e-14*V013*V042*V11 + 
      8.83076174164068353e-13*V02*V03*V042*V11 + 1.80593403287593678e-13*V01*V043*V11 - 
      7.84757875755383847e-14*V012*V022*V05*V11 - 4.65260579918639509e-14*V013*V03*V05*V11 + 
      9.65075413675485715e-13*V02*V032*V05*V11 + 4.30480932880596467e-13*V022*V04*V05*V11 + 
      1.12404150024869981e-12*V01*V03*V04*V05*V11 + 2.89945629202873823e-13*V01*V02*V052*V11 - 
      5.17376721776157793e-14*V053*V11 - 1.84549849560625706e-14*V013*V02*V06*V11 + 
      3.15002360413574256e-13*V022*V03*V06*V11 + 3.89766896073366935e-13*V01*V032*V06*V11 + 
      3.88360705163631883e-13*V01*V02*V04*V06*V11 + 1.13867613156787662e-13*V012*V05*V06*V11 - 
      2.16666577671350176e-13*V04*V05*V06*V11 - 7.82387665307883403e-14*V03*V062*V11 - 
      1.29196990073744539e-15*V014*V07*V11 + 3.31868423522073003e-14*V023*V07*V11 + 
      2.74930430127039705e-13*V01*V02*V03*V07*V11 + 7.79159789178759675e-14*V012*V04*V07*V11 - 
      7.29893729061787253e-14*V042*V07*V11 - 1.51239574207863572e-13*V03*V05*V07*V11 - 
      5.33946958497341718e-14*V02*V06*V07*V11 - 1.1315461675910363e-14*V01*V072*V11 + 
      3.60361465348199395e-14*V01*V022*V08*V11 + 4.06627079658199657e-14*V012*V03*V08*V11 - 
      8.30248544527045802e-14*V03*V04*V08*V11 - 4.20489482942805629e-14*V02*V05*V08*V11 - 
      1.83917933207467423e-14*V01*V06*V08*V11 + 1.11111795349747364e-14*V012*V02*V09*V11 - 
      2.18888012801646063e-14*V032*V09*V11 - 2.13589351297865403e-14*V02*V04*V09*V11 - 
      1.34460384740768309e-14*V01*V05*V09*V11 + 7.30837081501005168e-16*V08*V09*V11 + 
      8.33132508586688696e-16*V013*V10*V11 - 1.00876934675486252e-14*V02*V03*V10*V11 - 
      6.10957266555290063e-15*V01*V04*V10*V11 + 6.01673246089016685e-16*V07*V10*V11 - 
      5.16052179932381176e-16*V022*V112 - 1.28444987392723747e-15*V01*V03*V112 + 
      1.88971753164141039e-16*V06*V112 - 2.10634336771470859e-16*V025*V12 - 
      3.08756064357409596e-14*V01*V023*V03*V12 - 5.09985706305427914e-14*V012*V02*V032*V12 + 
      5.71366116719396223e-14*V034*V12 - 2.81783620735586578e-14*V012*V022*V04*V12 - 
      1.74007453477845086e-14*V013*V03*V04*V12 + 3.48622551449117888e-13*V02*V032*V04*V12 + 
      5.70006008859766131e-14*V022*V042*V12 + 2.08136520692186794e-13*V01*V03*V042*V12 - 
      9.09472921879830237e-15*V013*V02*V05*V12 + 1.73469968941489005e-13*V022*V03*V05*V12 + 
      2.02664083648281323e-13*V01*V032*V05*V12 + 2.10728538867726186e-13*V01*V02*V04*V05*V12 + 
      2.942489983509629e-14*V012*V052*V12 - 5.93918201775679571e-14*V04*V052*V12 - 
      7.13639681822197556e-16*V014*V06*V12 + 1.33545228888177281e-14*V023*V06*V12 + 
      1.49408535947464649e-13*V01*V02*V03*V06*V12 + 4.33403587146936055e-14*V012*V04*V06*V12 - 
      3.75418653104261691e-14*V042*V06*V12 - 8.51599654085987912e-14*V03*V05*V06*V12 - 
      1.36716812703581842e-14*V02*V062*V12 + 2.51492445678535304e-14*V01*V022*V07*V12 + 
      2.75679930753845956e-14*V012*V03*V07*V12 - 5.79524683559761532e-14*V03*V04*V07*V12 - 
      2.94774631467785703e-14*V02*V05*V07*V12 - 1.27732210931508868e-14*V01*V06*V07*V12 + 
      8.0939288218037996e-15*V012*V02*V08*V12 - 1.61166326322169352e-14*V032*V08*V12 - 
      1.44152296899114129e-14*V02*V04*V08*V12 - 9.91018349492233588e-15*V01*V05*V08*V12 + 
      2.6514303168598345e-16*V082*V12 + 6.97967481666152568e-16*V013*V09*V12 - 
      8.57301228001231678e-15*V02*V03*V09*V12 - 5.18119683469824639e-15*V01*V04*V09*V12 + 5.1094392037277086e-16*V07*V09*V12 - 
      8.56775192399938843e-16*V022*V10*V12 - 2.32443604594001879e-15*V01*V03*V10*V12 + 
      3.35198893347679453e-16*V06*V10*V12 - 5.10447325025000943e-16*V01*V02*V11*V12 + 2.07416814381082479e-16*V05*V11*V12 - 
      2.79569907542884659e-17*V012*V122 + 3.93981774199138512e-17*V04*V122 - 
      1.1793567561071837e-15*V01*V024*V13 - 9.07143167856833355e-15*V012*V022*V03*V13 - 
      2.59355144618755459e-15*V013*V032*V13 + 4.16688009877662522e-14*V02*V033*V13 - 
      3.15361439006697602e-15*V013*V02*V04*V13 + 5.69170782249564593e-14*V022*V03*V04*V13 + 
      7.20966798190456952e-14*V01*V032*V04*V13 + 3.52969705581026537e-14*V01*V02*V042*V13 - 
      3.20006097921040348e-16*V014*V05*V13 + 9.14208803851306967e-15*V023*V05*V13 + 
      7.46184390171179079e-14*V01*V02*V03*V05*V13 + 2.10548643689094511e-14*V012*V04*V05*V13 - 
      2.09654581574581239e-14*V042*V05*V13 - 2.15980016099090461e-14*V03*V052*V13 + 
      1.25858150637277314e-14*V01*V022*V06*V13 + 1.4422115897797496e-14*V012*V03*V06*V13 - 
      3.03559839019422268e-14*V03*V04*V06*V13 - 1.53232765721389445e-14*V02*V05*V06*V13 - 
      3.3657356770042768e-15*V01*V062*V13 + 5.15745170276996653e-15*V012*V02*V07*V13 - 
      1.04875282143891458e-14*V032*V07*V13 - 1.02678072611734215e-14*V02*V04*V07*V13 - 
      6.43390953339681743e-15*V01*V05*V07*V13 + 4.78931136207132883e-16*V013*V08*V13 - 
      5.87710472952073096e-15*V02*V03*V08*V13 - 3.56630553536189456e-15*V01*V04*V08*V13 + 3.5524446204504246e-16*V07*V08*V13 - 
      7.4170932822848788e-16*V022*V09*V13 - 1.84245920933777043e-15*V01*V03*V09*V13 + 
      2.72812350927235332e-16*V06*V09*V13 - 4.31493565475889119e-16*V01*V02*V10*V13 + 1.76296246386168792e-16*V05*V10*V13 - 
      5.21696991270911686e-17*V012*V11*V13 + 7.55607383446355763e-17*V04*V11*V13 + 
      2.99786520677454106e-17*V03*V12*V13 + 2.78624804879448725e-18*V02*V132 - 
      4.85916983842313913e-16*V012*V023*V14 - 8.67562953657879805e-16*V013*V02*V03*V14 + 
      9.86077693956324572e-15*V022*V032*V14 + 7.41256457128787944e-15*V01*V033*V14 - 
      1.02588166594015141e-16*V014*V04*V14 + 2.05432819173900256e-15*V023*V04*V14 + 
      2.37028081247648606e-14*V01*V02*V03*V04*V14 + 3.44591103084061639e-15*V012*V042*V14 - 
      2.08098496225918251e-15*V043*V14 + 5.95802862328810874e-15*V01*V022*V05*V14 + 
      6.39780463824400655e-15*V012*V03*V05*V14 - 1.43830008044455745e-14*V03*V04*V05*V14 - 
      3.66600887873959378e-15*V02*V052*V14 + 2.46853193870987996e-15*V012*V02*V06*V14 - 
      5.12998038632044226e-15*V032*V06*V14 - 4.53486667684704666e-15*V02*V04*V06*V14 - 
      3.1517811154101444e-15*V01*V05*V06*V14 + 2.77918733480979708e-16*V013*V07*V14 - 
      3.57183389173664081e-15*V02*V03*V07*V14 - 2.15231415515267976e-15*V01*V04*V07*V14 + 
      1.07794471732842449e-16*V072*V14 - 4.31512046830488541e-16*V022*V08*V14 - 
      1.1790352521702102e-15*V01*V03*V08*V14 + 1.7166945810462688e-16*V06*V08*V14 - 3.18004427627191559e-16*V01*V02*V09*V14 + 
      1.29964290421125924e-16*V05*V09*V14 - 4.10770317730565991e-17*V012*V10*V14 + 
      5.81131278938362626e-17*V04*V10*V14 + 2.60254312143105024e-17*V03*V11*V14 + 5.03923528126035453e-18*V02*V12*V14 + 
      1.16788187493497208e-18*V01*V13*V14 - 6.65335326590921294e-17*V013*V022*V15 - 
      2.5157824496598696e-17*V014*V03*V15 + 9.03559010602518899e-16*V023*V03*V15 + 
      3.56001794964679816e-15*V01*V02*V032*V15 + 1.70022573650460167e-15*V01*V022*V04*V15 + 
      1.98566778632737594e-15*V012*V03*V04*V15 - 2.21175841958250368e-15*V03*V042*V15 + 
      1.0374151278364344e-15*V012*V02*V05*V15 - 2.25080045874697054e-15*V032*V05*V15 - 
      2.22132026845410529e-15*V02*V04*V05*V15 - 6.88253200922256239e-16*V01*V052*V15 + 
      1.26574699492521439e-16*V013*V06*V15 - 1.61436779303792881e-15*V02*V03*V06*V15 - 
      9.81917063849471799e-16*V01*V04*V06*V15 - 2.68866486615148015e-16*V022*V07*V15 - 
      6.63501180839524423e-16*V01*V03*V07*V15 + 1.00379449772884666e-16*V06*V07*V15 - 1.89513438863776316e-16*V01*V02*V08*V15 + 
      7.87869318843107489e-17*V05*V08*V15 - 2.81628145083251068e-17*V012*V09*V15 + 
      4.12886709486348294e-17*V04*V09*V15 + 1.92854247368759764e-17*V03*V10*V15 + 4.21851742999858811e-18*V02*V11*V15 + 
      1.01815063212727581e-18*V01*V12*V15 - 3.92667508847153465e-21*V152 - 
      3.61886660313353645e-18*V014*V02*V16 + 2.07693158109551136e-17*V024*V16 + 
      5.08220222534432624e-16*V01*V022*V03*V16 + 2.62414069800443655e-16*V012*V032*V16 + 
      2.97229577004034461e-16*V012*V02*V04*V16 - 6.63080462614977798e-16*V032*V04*V16 - 
      2.86857981909223124e-16*V02*V042*V16 + 4.85978042908457318e-17*V013*V05*V16 - 
      6.78533113428835737e-16*V02*V03*V05*V16 - 4.06863406682664178e-16*V01*V04*V05*V16 - 
      1.03563856431089257e-16*V022*V06*V16 - 2.8728585544271663e-16*V01*V03*V06*V16 + 
      2.13639238860347667e-17*V062*V16 - 1.01225227713622024e-16*V01*V02*V07*V16 + 
      4.21906230659045533e-17*V05*V07*V16 - 1.59697381318424224e-17*V012*V08*V16 + 2.288296989061798e-17*V04*V08*V16 + 
      1.25468514310608598e-17*V03*V09*V16 + 2.85766021228006416e-18*V02*V10*V16 + 7.8013399682482647e-19*V01*V11*V16 - 
      7.32393077862487092e-21*V14*V16 - 6.7016048206176601e-20*V015*V17 + 
      2.09469828009772662e-17*V01*V023*V17 + 7.54176267829576075e-17*V012*V02*V03*V17 - 
      6.06371354086839863e-17*V033*V17 + 1.34456531384325654e-17*V013*V04*V17 - 
      1.82538112651459403e-16*V02*V03*V04*V17 - 5.57265247253640908e-17*V01*V042*V17 - 
      4.53802521230535162e-17*V022*V05*V17 - 1.1045249453227598e-16*V01*V03*V05*V17 - 
      4.06096110161841348e-17*V01*V02*V06*V17 + 1.74446249533159852e-17*V05*V06*V17 - 
      7.89169814334567957e-18*V012*V07*V17 + 1.19056320750458795e-17*V04*V07*V17 + 
      6.75295051061236243e-18*V03*V08*V17 + 1.80669295888737295e-18*V02*V09*V17 + 5.13178422030603162e-19*V01*V10*V17 - 
      6.1585577541364041e-21*V13*V17 + 4.98934478894984794e-18*V012*V022*V18 + 
      3.0671011395693491e-18*V013*V03*V18 - 2.46654515625294006e-17*V02*V032*V18 - 
      1.02857294533636771e-17*V022*V04*V18 - 2.9284008789842638e-17*V01*V03*V04*V18 - 
      1.51106163281421692e-17*V01*V02*V05*V18 + 3.27436644330377925e-18*V052*V18 - 
      3.07429029500522334e-18*V012*V06*V18 + 4.51335073260408059e-18*V04*V06*V18 + 
      3.23075213153644842e-18*V03*V07*V18 + 8.91821518254287834e-19*V02*V08*V18 + 2.98362752787039479e-19*V01*V09*V18 - 
      4.48551214014881302e-21*V12*V18 + 4.02096289237059606e-19*V013*V02*V19 - 
      2.98435493560366716e-18*V022*V03*V19 - 3.52819991780909541e-18*V01*V032*V19 - 
      3.67470001313705541e-18*V01*V02*V04*V19 - 1.04574288238550892e-18*V012*V05*V19 + 
      1.66444844273646399e-18*V04*V05*V19 + 1.20266664938861187e-18*V03*V06*V19 + 4.19184647911154002e-19*V02*V07*V19 + 
      1.44536708112573362e-19*V01*V08*V19 - 2.94737211092377531e-21*V11*V19 + 1.00524072309264901e-20*V014*V20 - 
      9.82547458091615668e-20*V023*V20 - 8.78202761870067418e-19*V01*V02*V03*V20 - 
      2.53198331337701356e-19*V012*V04*V20 + 1.93172581089076808e-19*V042*V20 + 
      4.06777029872161843e-19*V03*V05*V20 + 1.42566871168044458e-19*V02*V06*V20 + 6.23354298408211361e-20*V01*V07*V20 - 
      1.65393718735925556e-21*V10*V20 - 4.90520241731320399e-20*V01*V022*V21 - 
      5.38300202026464827e-20*V012*V03*V21 + 9.41877570179047379e-20*V03*V04*V21 + 4.8115129691199e-20*V02*V05*V21 + 
      2.11288235910752555e-20*V01*V06*V21 - 8.3959711892327816e-22*V09*V21 - 6.23621559696365592e-21*V012*V02*V22 + 
      1.04116255577994385e-20*V032*V22 + 1.00520037407621399e-20*V02*V04*V22 + 6.46984506289619178e-21*V01*V05*V22 - 
      3.52962766690107534e-22*V08*V22 - 2.17181637705201948e-22*V013*V23 + 2.27060014329888473e-21*V02*V03*V23 + 
      1.37978454380901256e-21*V01*V04*V23 - 1.35418900751564703e-22*V07*V23 + 1.08740599292397665e-22*V022*V24 + 
      2.75296448346318055e-22*V01*V03*V24 - 4.03984995274373026e-23*V06*V24 + 2.80838324618795622e-23*V01*V02*V25 - 
      1.12597042981571607e-23*V05*V25 + 1.49780439796690998e-24*V012*V26 - 2.13316336033029277e-24*V04*V26 - 
      4.00622412897063288e-25*V03*V27 - 3.62372031766187899e-26*V02*V28 - 3.88255748320915606e-27*V01*V29 + 
      3.26814602963733675e-30*V32) + delta10*eps11*
    (-1.56922126002266075e-10*V032*V044 - 1.49854878334381416e-11*V02*V045 - 
      6.6529736244638615e-10*V033*V042*V05 - 6.13146595992018253e-10*V02*V03*V043*V05 - 
      9.41532756013596447e-11*V01*V044*V05 - 1.59325970188415257e-10*V034*V052 - 
      1.01477262016199264e-9*V02*V032*V04*V052 - 
      2.21492200878613889e-10*V022*V042*V052 - 
      5.88319745968770027e-10*V01*V03*V042*V052 - 1.70276514917027796e-10*V022*V03*V053 - 
      1.84887345597786957e-10*V01*V032*V053 - 2.00505276187654521e-10*V01*V02*V04*V053 - 
      1.31550796375767866e-11*V012*V054 + 2.89509273809282301e-11*V04*V054 - 
      2.31188293302868268e-10*V034*V04*V06 - 6.66612877643652993e-10*V02*V032*V042*V06 - 
      5.2051863226839263e-11*V022*V043*V06 - 2.69652268180291631e-10*V01*V03*V043*V06 - 
      4.72848079140894006e-10*V02*V033*V05*V06 - 6.4819300947376496e-10*V022*V03*V04*V05*V06 - 
      8.12727784477607083e-10*V01*V032*V04*V05*V06 - 3.99967726586191796e-10*V01*V02*V042*V05*V06 - 
      5.1771895711441771e-11*V023*V052*V06 - 4.17833953754584124e-10*V01*V02*V03*V052*V06 - 
      1.17206680594029671e-10*V012*V04*V052*V06 + 1.21938911329772902e-10*V042*V052*V06 + 
      8.21545348193250561e-11*V03*V053*V06 - 1.17645825287794466e-10*V022*V032*V062 - 
      9.31031601174729937e-11*V01*V033*V062 - 1.8011962025833183e-11*V023*V04*V062 - 
      2.86713374746781636e-10*V01*V02*V03*V04*V062 - 4.24902503144277951e-11*V012*V042*V062 + 
      2.42425683147481127e-11*V043*V062 - 7.05874951726766794e-11*V01*V022*V05*V062 - 
      7.99403297140652917e-11*V012*V03*V05*V062 + 1.76056392941749065e-10*V03*V04*V05*V062 + 
      4.44625135312468101e-11*V02*V052*V062 - 1.00445231311265149e-11*V012*V02*V063 + 
      2.10448468067930321e-11*V032*V063 + 1.75042383288447039e-11*V02*V04*V063 + 
      1.29251853057287628e-11*V01*V05*V063 - 2.97436752330203269e-11*V035*V07 - 
      3.18262343155007177e-10*V02*V033*V04*V07 - 2.10944953217727514e-10*V022*V03*V042*V07 - 
      2.75177078921805962e-10*V01*V032*V042*V07 - 8.75923708560026075e-11*V01*V02*V043*V07 - 
      2.40845712949532486e-10*V022*V032*V05*V07 - 1.71799265285156248e-10*V01*V033*V05*V07 - 
      6.68346459501218082e-11*V023*V04*V05*V07 - 5.63879486277508066e-10*V01*V02*V03*V04*V05*V07 - 
      7.96146793101129729e-11*V012*V042*V05*V07 + 5.46306257636557172e-11*V043*V05*V07 - 
      7.15317785195647217e-11*V01*V022*V052*V07 - 7.29563574799599191e-11*V012*V03*V052*V07 + 
      1.68829831915586707e-10*V03*V04*V052*V07 + 2.89485849844917644e-11*V02*V053*V07 - 
      4.93065673442302581e-11*V023*V03*V06*V07 - 1.95287922039220782e-10*V01*V02*V032*V06*V07 - 
      9.25990013533949943e-11*V01*V022*V04*V06*V07 - 1.0883254274487797e-10*V012*V03*V04*V06*V07 + 
      1.18878895376251127e-10*V03*V042*V06*V07 - 5.64297930116890578e-11*V012*V02*V05*V06*V07 + 
      1.1950650646382469e-10*V032*V05*V06*V07 + 1.19293899150755687e-10*V02*V04*V05*V06*V07 + 
      3.65081872111144395e-11*V01*V052*V06*V07 - 3.4397762347973565e-12*V013*V062*V07 + 
      4.33244733205692087e-11*V02*V03*V062*V07 + 2.63388723912757238e-11*V01*V04*V062*V07 - 
      1.86541795883426248e-12*V024*V072 - 3.35530585270003366e-11*V01*V022*V03*V072 - 
      1.68273165828826881e-11*V012*V032*V072 - 
      1.91275890892575566e-11*V012*V02*V04*V072 + 4.0950341413254113e-11*V032*V04*V072 + 
      1.99142144652717262e-11*V02*V042*V072 - 3.08146818295135875e-12*V013*V05*V072 + 
      4.21963509649030337e-11*V02*V03*V05*V072 + 2.50601550341836847e-11*V01*V04*V05*V072 + 
      7.21137147050450377e-12*V022*V06*V072 + 1.76017463557478092e-11*V01*V03*V06*V072 - 
      1.15219777810401066e-12*V062*V072 + 2.08968082175743025e-12*V01*V02*V073 - 
      7.27023147830099414e-13*V05*V073 - 4.23894484352428601e-11*V02*V034*V08 - 
      1.20965804826214873e-10*V022*V032*V04*V08 - 9.60772185585057123e-11*V01*V033*V04*V08 - 
      9.15060794686521137e-12*V023*V042*V08 - 1.47650746266870707e-10*V01*V02*V03*V042*V08 - 
      1.46083141656007071e-11*V012*V043*V08 + 6.35984687876048916e-12*V044*V08 - 
      3.89466985288962726e-11*V023*V03*V05*V08 - 1.48792730142952374e-10*V01*V02*V032*V05*V08 - 
      7.2579482895728924e-11*V01*V022*V04*V05*V08 - 8.24363379617677921e-11*V012*V03*V04*V05*V08 + 
      9.31483158677247527e-11*V03*V042*V05*V08 - 2.14153382701963469e-11*V012*V02*V052*V08 + 
      4.61920636716576164e-11*V032*V052*V08 + 4.69598288098069129e-11*V02*V04*V052*V08 + 
      9.38640831217085405e-12*V01*V053*V08 - 1.57473531060472821e-12*V024*V06*V08 - 
      5.21242914077008215e-11*V01*V022*V03*V06*V08 - 2.79692730859181083e-11*V012*V032*V06*V08 - 
      3.10487188039249292e-11*V012*V02*V04*V06*V08 + 6.6839098689497404e-11*V032*V04*V06*V08 + 
      2.75166867422992434e-11*V02*V042*V06*V08 - 5.1753940092710417e-12*V013*V05*V06*V08 + 
      6.79263768165786627e-11*V02*V03*V05*V06*V08 + 4.1030532923315486e-11*V01*V04*V05*V06*V08 + 
      4.94529771038454355e-12*V022*V062*V08 + 1.45589120548237437e-11*V01*V03*V062*V08 - 
      6.08468234038831303e-13*V063*V08 - 5.56381407555661037e-12*V01*V023*V07*V08 - 
      1.98513767967695796e-11*V012*V02*V03*V07*V08 + 1.48886505636800798e-11*V033*V07*V08 - 
      3.54142954666633783e-12*V013*V04*V07*V08 + 4.57359638541604758e-11*V02*V03*V04*V07*V08 + 
      1.39219209866179298e-11*V01*V042*V07*V08 + 1.14009338759232433e-11*V022*V05*V07*V08 + 
      2.71202826593336162e-11*V01*V03*V05*V07*V08 + 1.01425542698418191e-11*V01*V02*V06*V07*V08 - 
      3.61566337787909831e-12*V05*V06*V07*V08 + 9.70304932719996091e-13*V012*V072*V08 - 
      1.24030427474001362e-12*V04*V072*V08 - 1.41028831786113505e-12*V012*V022*V082 - 
      8.8976805107051436e-13*V013*V03*V082 + 6.4438550314276841e-12*V02*V032*V082 + 
      2.58589495949236358e-12*V022*V04*V082 + 7.69963295582269488e-12*V01*V03*V04*V082 + 
      3.95197019146199652e-12*V01*V02*V05*V082 - 7.07797398630384574e-13*V052*V082 + 
      8.15013515817570697e-13*V012*V06*V082 - 9.79423576048223815e-13*V04*V06*V082 - 
      7.0194913754179623e-13*V03*V07*V082 - 6.48538542462613738e-14*V02*V083 - 
      2.18548898624289191e-11*V022*V033*V09 - 1.14549402137967409e-11*V01*V034*V09 - 
      1.85651794305893912e-11*V023*V03*V04*V09 - 7.6095681095975047e-11*V01*V02*V032*V04*V09 - 
      1.75787461014772928e-11*V01*V022*V042*V09 - 2.12859918533664998e-11*V012*V03*V042*V09 + 
      1.5878184032746685e-11*V03*V043*V09 - 2.17632095197330623e-12*V024*V05*V09 - 
      3.87441597452253794e-11*V01*V022*V03*V05*V09 - 1.93138035517508853e-11*V012*V032*V05*V09 - 
      2.20239434797595296e-11*V012*V02*V04*V05*V09 + 4.86695030053447292e-11*V032*V04*V05*V09 + 
      2.37495385253358106e-11*V02*V042*V05*V09 - 1.764283786161869e-12*V013*V052*V09 + 
      2.50873783636678499e-11*V02*V03*V052*V09 + 1.48663963105311829e-11*V01*V04*V052*V09 - 
      4.10888061201918817e-12*V01*V023*V06*V09 - 1.50615046086262874e-11*V012*V02*V03*V06*V09 + 
      1.14452401219597558e-11*V033*V06*V09 - 2.69673769880929319e-12*V013*V04*V06*V09 + 
      3.46386647750844639e-11*V02*V03*V04*V06*V09 + 1.05932243326139705e-11*V01*V042*V06*V09 + 
      8.59624039298200643e-12*V022*V05*V06*V09 + 2.08598882178596402e-11*V01*V03*V05*V06*V09 + 
      3.8551783613214481e-12*V01*V02*V062*V09 - 1.39347115441546306e-12*V05*V062*V09 - 
      2.63036409119751009e-12*V012*V022*V07*V09 - 1.61226495561203606e-12*V013*V03*V07*V09 + 
      1.21547897831790074e-11*V02*V032*V07*V09 + 5.70256871090663302e-12*V022*V04*V07*V09 + 
      1.43274815099104221e-11*V01*V03*V04*V07*V09 + 7.43357219102010163e-12*V01*V02*V05*V07*V09 - 
      1.31718651614503007e-12*V052*V07*V09 + 1.49436246329253495e-12*V012*V06*V07*V09 - 
      1.90771640918804961e-12*V04*V06*V07*V09 - 6.52449989900935826e-13*V03*V072*V09 - 
      4.88502923294358511e-13*V013*V02*V08*V09 + 3.30445480859409369e-12*V022*V03*V08*V09 + 
      3.85542049251293728e-12*V01*V032*V08*V09 + 4.0644096633375603e-12*V01*V02*V04*V08*V09 + 
      1.14566861972612382e-12*V012*V05*V08*V09 - 1.49943560870502909e-12*V04*V05*V08*V09 - 
      1.08363272954607881e-12*V03*V06*V08*V09 - 3.81119557316415921e-13*V02*V07*V08*V09 - 
      6.57399642517522831e-14*V01*V082*V09 - 1.3672309536623213e-14*V014*V092 + 
      1.34275284265812889e-13*V023*V092 + 1.0597278810072115e-12*V01*V02*V03*V092 + 
      3.03866031999320828e-13*V012*V04*V092 - 1.96617668356892374e-13*V042*V092 - 
      3.93449226968134618e-13*V03*V05*V092 - 1.46022563204140642e-13*V02*V06*V092 - 
      6.08818045029647192e-14*V01*V07*V092 - 4.43778189372115618e-12*V023*V032*V10 - 
      1.0730381935067733e-11*V01*V02*V033*V10 - 4.82756926875573625e-13*V024*V04*V10 - 
      1.63633684721436374e-11*V01*V022*V03*V04*V10 - 8.80455935115634191e-12*V012*V032*V04*V10 - 
      4.8845746457398594e-12*V012*V02*V042*V10 + 1.10552638765312001e-11*V032*V042*V10 + 
      2.98073930495935198e-12*V02*V043*V10 - 2.66266913623269371e-12*V01*V023*V05*V10 - 
      9.17891467411430681e-12*V012*V02*V03*V05*V10 + 7.19798393823591189e-12*V033*V05*V10 - 
      1.62640979803162099e-12*V013*V04*V05*V10 + 2.24067859631364092e-11*V02*V03*V04*V05*V10 + 
      6.78031192748195653e-12*V01*V042*V05*V10 + 2.80349815531331405e-12*V022*V052*V10 + 
      6.53656342900806976e-12*V01*V03*V052*V10 - 1.72259983079063792e-12*V012*V022*V06*V10 - 
      1.08638982632081299e-12*V013*V03*V06*V10 + 8.05431200260468374e-12*V02*V032*V06*V10 + 
      3.20746920720187607e-12*V022*V04*V06*V10 + 9.62914453138276597e-12*V01*V03*V04*V06*V10 + 
      4.93757408155804046e-12*V01*V02*V05*V06*V10 - 8.97722150090213084e-13*V052*V06*V10 + 
      5.09525340614492258e-13*V012*V062*V10 - 6.19150924140375002e-13*V04*V062*V10 - 
      3.91526501867666716e-13*V013*V02*V07*V10 + 2.726822881978324e-12*V022*V03*V07*V10 + 
      3.13628235144787501e-12*V01*V032*V07*V10 + 3.33996439631173268e-12*V01*V02*V04*V07*V10 + 
      9.30532567539012022e-13*V012*V05*V07*V10 - 1.23367777697183735e-12*V04*V05*V07*V10 - 
      8.89945358062026764e-13*V03*V06*V07*V10 - 1.57084196009018042e-13*V02*V072*V10 - 
      2.4278249017839326e-14*V014*V08*V10 + 1.9935667910102446e-13*V023*V08*V10 + 
      1.85098658188588493e-12*V01*V02*V03*V08*V10 + 5.38127227356842203e-13*V012*V04*V08*V10 - 
      3.31723147690850762e-13*V042*V08*V10 - 6.9507863861203009e-13*V03*V05*V08*V10 - 
      2.45643656701424999e-13*V02*V06*V08*V10 - 1.07727084797919002e-13*V01*V07*V08*V10 + 
      2.41441399870557036e-13*V01*V022*V09*V10 + 2.61239380405392769e-13*V012*V03*V09*V10 - 
      3.69139476097666154e-13*V03*V04*V09*V10 - 1.89681522777605376e-13*V02*V05*V09*V10 - 
      8.32491260590072139e-14*V01*V06*V09*V10 + 1.36794697472808766e-15*V092*V10 + 
      3.21862642306851063e-14*V012*V02*V102 - 4.23987889903701045e-14*V032*V102 - 
      4.14059203836150082e-14*V02*V04*V102 - 2.65204783412023643e-14*V01*V05*V102 + 
      1.19794923666809842e-15*V08*V102 - 3.95694718540601133e-13*V024*V03*V11 - 
      3.39521521201775859e-12*V01*V022*V032*V11 - 1.10049064767962365e-12*V012*V033*V11 - 
      1.01264615075942134e-12*V01*V023*V04*V11 - 3.81508583125936463e-12*V012*V02*V03*V04*V11 + 
      3.10131706285434043e-12*V033*V04*V11 - 3.42260471218526235e-13*V013*V042*V11 + 
      4.59970972234403651e-12*V02*V03*V042*V11 + 9.42774788278072168e-13*V01*V043*V11 - 
      9.82444005569503125e-13*V012*V022*V05*V11 - 5.9693867468328123e-13*V013*V03*V05*V11 + 
      4.8062221195149609e-12*V02*V032*V05*V11 + 2.26840538639846653e-12*V022*V04*V05*V11 + 
      5.64654078653829002e-12*V01*V03*V04*V05*V11 + 1.4656930869583549e-12*V01*V02*V052*V11 - 
      1.78524293224988015e-13*V053*V11 - 2.40908449344777059e-13*V013*V02*V06*V11 + 
      1.66275662275677501e-12*V022*V03*V06*V11 + 1.97246960715301193e-12*V01*V032*V06*V11 + 
      2.05317850408183086e-12*V01*V02*V04*V06*V11 + 5.86098871409768281e-13*V012*V05*V06*V11 - 
      7.77539587898587087e-13*V04*V05*V06*V11 - 2.81445124796412342e-13*V03*V062*V11 - 
      1.7673366631887235e-14*V014*V07*V11 + 1.79249586020880299e-13*V023*V07*V11 + 
      1.40975932178320167e-12*V01*V02*V03*V07*V11 + 4.03746924135305121e-13*V012*V04*V07*V11 - 
      2.6517515145568587e-13*V042*V07*V11 - 5.29816717885658922e-13*V03*V05*V07*V11 - 
      1.96875281901392601e-13*V02*V06*V07*V11 - 4.09371277473678743e-14*V01*V072*V11 + 
      1.95246123954086745e-13*V01*V022*V08*V11 + 2.13702144834016469e-13*V012*V03*V08*V11 - 
      3.0248864463170033e-13*V03*V04*V08*V11 - 1.55109889972973452e-13*V02*V05*V08*V11 - 
      6.83045682998040385e-14*V01*V06*V08*V11 + 5.94750377791165904e-14*V012*V02*V09*V11 - 
      7.87362200983820255e-14*V032*V09*V11 - 8.05978799490893614e-14*V02*V04*V09*V11 - 
      4.92025765160774791e-14*V01*V05*V09*V11 + 2.25079343036096795e-15*V08*V09*V11 + 
      4.61611676379027922e-15*V013*V10*V11 - 3.81326311714226798e-14*V02*V03*V10*V11 - 
      2.31952018576234043e-14*V01*V04*V10*V11 + 1.85094285759087006e-15*V07*V10*V11 - 
      2.03651062879723674e-15*V022*V112 - 4.86180727660997464e-15*V01*V03*V112 + 
      5.90028305795501004e-16*V06*V112 - 6.75128020234787436e-15*V025*V12 - 
      4.04832653425374421e-13*V01*V023*V03*V12 - 6.58716245088369999e-13*V012*V02*V032*V12 + 
      2.88257141340156025e-13*V034*V12 - 3.64890993816015221e-13*V012*V022*V04*V12 - 
      2.29780507648557659e-13*V013*V03*V04*V12 + 1.82655886326303188e-12*V02*V032*V04*V12 + 
      3.55163758808754611e-13*V022*V042*V12 + 1.09411286557086103e-12*V01*V03*V042*V12 - 
      1.20983325308449388e-13*V013*V02*V05*V12 + 9.18470686312687476e-13*V022*V03*V05*V12 + 
      1.03912177910466923e-12*V01*V032*V05*V12 + 1.11843978220431307e-12*V01*V02*V04*V05*V12 + 
      1.53544097014393399e-13*V012*V052*V12 - 2.13000766311781401e-13*V04*V052*V12 - 
      9.97016026267345522e-15*V014*V06*V12 + 8.44341519033306796e-14*V023*V06*V12 + 
      7.95446048387897921e-13*V01*V02*V03*V06*V12 + 2.31462404808753328e-13*V012*V04*V06*V12 - 
      1.45411699732690495e-13*V042*V06*V12 - 3.0650120151625333e-13*V03*V05*V06*V12 - 
      5.37678118898051551e-14*V02*V062*V12 + 1.364896867757377e-13*V01*V022*V07*V12 + 
      1.46029306347281841e-13*V012*V03*V07*V12 - 2.10897482500563507e-13*V03*V04*V07*V12 - 
      1.08539214589577744e-13*V02*V05*V07*V12 - 4.74319379315964474e-14*V01*V06*V07*V12 + 
      4.42930148566727395e-14*V012*V02*V08*V12 - 5.89859374240992122e-14*V032*V08*V12 - 
      5.74289100485794227e-14*V02*V04*V08*V12 - 3.68832032236925508e-14*V01*V05*V08*V12 + 
      8.35805916312076048e-16*V082*V12 + 3.88156689550779196e-15*V013*V09*V12 - 
      3.23731867780951408e-14*V02*V03*V09*V12 - 1.9658983913525166e-14*V01*V04*V09*V12 + 1.56992497981666107e-15*V07*V09*V12 - 
      3.5446499869017245e-15*V022*V10*V12 - 8.8833366081989014e-15*V01*V03*V10*V12 + 
      1.06521661876890755e-15*V06*V10*V12 - 2.02184584031280276e-15*V01*V02*V11*V12 + 6.46153160095712129e-16*V05*V11*V12 - 
      1.12278939190792471e-16*V012*V122 + 1.2837672381141367e-16*V04*V122 - 
      1.52190276361769666e-14*V01*V024*V13 - 1.18991302275192557e-13*V012*V022*V03*V13 - 
      3.51648019952198737e-14*V013*V032*V13 + 2.18342790023408337e-13*V02*V033*V13 - 
      4.27330512028613343e-14*V013*V02*V04*V13 + 3.14170169924634943e-13*V022*V03*V04*V13 + 
      3.81136355144762139e-13*V01*V032*V04*V13 + 1.94963951413656301e-13*V01*V02*V042*V13 - 
      4.54962122251329371e-15*V014*V05*V13 + 5.10630298337388618e-14*V023*V05*V13 + 
      3.96620873395049548e-13*V01*V02*V03*V05*V13 + 1.13099733196138602e-13*V012*V04*V05*V13 - 
      7.79855928794921459e-14*V042*V05*V13 - 7.7517302070799046e-14*V03*V052*V13 + 
      7.03498588260794131e-14*V01*V022*V06*V13 + 7.80947366405379117e-14*V012*V03*V06*V13 - 
      1.13161254740707608e-13*V03*V04*V06*V13 - 5.7841315161336787e-14*V02*V05*V06*V13 - 
      1.27827217710707626e-14*V01*V062*V13 + 2.82250758468861961e-14*V012*V02*V07*V13 - 
      3.82084331408955793e-14*V032*V07*V13 - 3.92286283839355442e-14*V02*V04*V07*V13 - 
      2.3846553961852646e-14*V01*V05*V07*V13 + 2.69949323798906058e-15*V013*V08*V13 - 
      2.25078192114582938e-14*V02*V03*V08*V13 - 1.37119418245046624e-14*V01*V04*V08*V13 + 1.10136330838635727e-15*V07*V08*V13 - 
      2.94111717413138581e-15*V022*V09*V13 - 7.00883081039284023e-15*V01*V03*V09*V13 + 
      8.53504614903455699e-16*V06*V09*V13 - 1.7189016813385428e-15*V01*V02*V10*V13 + 5.50986153732985579e-16*V05*V10*V13 - 
      2.08827267126445038e-16*V012*V11*V13 + 2.42602441984774821e-16*V04*V11*V13 + 
      9.62599920821583685e-17*V03*V12*V13 + 9.34343349255274892e-18*V02*V132 - 
      6.49733990568523382e-15*V012*V023*V14 - 1.22195721978178291e-14*V013*V02*V03*V14 + 
      5.46589770837718418e-14*V022*V032*V14 + 4.00724929688669916e-14*V01*V033*V14 - 
      1.50625269948202528e-15*V014*V04*V14 + 1.35570036465602403e-14*V023*V04*V14 + 
      1.31721575602572221e-13*V01*V02*V03*V04*V14 + 1.92075309671340111e-14*V012*V042*V14 - 
      8.36247924829051364e-15*V043*V14 + 3.34129051796852647e-14*V01*V022*V05*V14 + 
      3.52000499590133283e-14*V012*V03*V05*V14 - 5.35875155953537993e-14*V03*V04*V05*V14 - 
      1.38126008328285604e-14*V02*V052*V14 + 1.39232159287826885e-14*V012*V02*V06*V14 - 
      1.91882704459756881e-14*V032*V06*V14 - 1.84963172766463855e-14*V02*V04*V06*V14 - 
      1.19855319020319255e-14*V01*V05*V06*V14 + 1.58409163639456545e-15*V013*V07*V14 - 
      1.36485299754388283e-14*V02*V03*V07*V14 - 8.26745364699971611e-15*V01*V04*V07*V14 + 
      3.33190390238662118e-16*V072*V14 - 1.80879560594266161e-15*V022*V08*V14 - 
      4.55910935670118506e-15*V01*V03*V08*V14 + 5.49609332985696543e-16*V06*V08*V14 - 1.26494334909771631e-15*V01*V02*V09*V14 + 
      4.05398052549426815e-16*V05*V09*V14 - 1.65750582700820046e-16*V012*V10*V14 + 
      1.89871368811768894e-16*V04*V10*V14 + 8.35032058146495524e-17*V03*V11*V14 + 1.7146727704914883e-17*V02*V12*V14 + 
      3.93284879498150998e-18*V01*V13*V14 - 9.78729174422285551e-16*V013*V022*V15 - 
      3.88103338371609931e-16*V014*V03*V15 + 5.30814981036248204e-15*V023*V03*V15 + 
      2.00114343002824938e-14*V01*V02*V032*V15 + 9.97696056385597653e-15*V01*V022*V04*V15 + 
      1.12867825244408776e-14*V012*V03*V04*V15 - 8.57029209245383136e-15*V03*V042*V15 + 
      5.92163854357007373e-15*V012*V02*V05*V15 - 8.43112954258054942e-15*V032*V05*V15 - 
      8.71495496852743328e-15*V02*V04*V05*V15 - 2.62258932363178751e-15*V01*V052*V15 + 
      7.39522091955158792e-16*V013*V06*V15 - 6.3454844923473991e-15*V02*V03*V06*V15 - 
      3.87339449708707427e-15*V01*V04*V06*V15 - 1.08282438301590603e-15*V022*V07*V15 - 
      2.56543578717180271e-15*V01*V03*V07*V15 + 3.16465105928351824e-16*V06*V07*V15 - 7.67061617727595964e-16*V01*V02*V08*V15 + 
      2.48416830315984065e-16*V05*V08*V15 - 1.13686482796883841e-16*V012*V09*V15 + 
      1.32958003589628937e-16*V04*V09*V15 + 6.21886730913371259e-17*V03*V10*V15 + 1.41590027241651129e-17*V02*V11*V15 + 
      3.43461768413402559e-18*V01*V12*V15 - 1.17848895216747797e-20*V152 - 
      5.89741224214354088e-17*V014*V02*V16 + 1.45983589524891168e-16*V024*V16 + 
      2.99695387820415258e-15*V01*V022*V03*V16 + 1.53059337496416333e-15*V012*V032*V16 + 
      1.75726689270894359e-15*V012*V02*V04*V16 - 2.57599886273407615e-15*V032*V04*V16 - 
      1.21771410014017265e-15*V02*V042*V16 + 2.89481404897263676e-16*V013*V05*V16 - 
      2.66365751468332216e-15*V02*V03*V05*V16 - 1.60611644734069043e-15*V01*V04*V05*V16 - 
      4.46050662757591766e-16*V022*V06*V16 - 1.1389784943048891e-15*V01*V03*V06*V16 + 
      6.96035564000206077e-17*V062*V16 - 4.0907750836487084e-16*V01*V02*V07*V16 + 1.32628018838235911e-16*V05*V07*V16 - 
      6.5416639138109311e-17*V012*V08*V16 + 7.54670638892426999e-17*V04*V08*V16 + 4.03772138732376978e-17*V03*V09*V16 + 
      9.76773385755790816e-18*V02*V10*V16 + 2.62923349003821696e-18*V01*V11*V16 - 2.20758400978923311e-20*V14*V16 - 
      1.20628886771117882e-18*V015*V17 + 1.30834313978781808e-16*V01*V023*V17 + 
      4.57022642346841948e-16*V012*V02*V03*V17 - 2.37693689899143784e-16*V033*V17 + 
      8.27346623129353227e-17*V013*V04*V17 - 7.47225387243934369e-16*V02*V03*V04*V17 - 
      2.28831378650312306e-16*V01*V042*V17 - 1.88083629475079693e-16*V022*V05*V17 - 
      4.40314400660602421e-16*V01*V03*V05*V17 - 1.69016867006270465e-16*V01*V02*V06*V17 + 5.59917955053447297e-17*V05*V06*V17 - 
      3.24735755523191262e-17*V012*V07*V17 + 3.86727403256427713e-17*V04*V07*V17 + 
      2.19902798681250644e-17*V03*V08*V17 + 6.08687490031123333e-18*V02*V09*V17 + 1.73996766721273613e-18*V01*V10*V17 - 
      1.84854017749295638e-20*V13*V17 + 3.13579258898068012e-17*V012*V022*V18 + 
      1.94681620038943026e-17*V013*V03*V18 - 1.01175750190730123e-16*V02*V032*V18 - 
      4.62128839721433835e-17*V022*V04*V18 - 1.20823419466605255e-16*V01*V03*V04*V18 - 
      6.29231228429941343e-17*V01*V02*V05*V18 + 1.04869987804805465e-17*V052*V18 - 
      1.29428678961327177e-17*V012*V06*V18 + 1.51744906346414701e-17*V04*V06*V18 + 
      1.04956807161393385e-17*V03*V07*V18 + 3.0821266464416291e-18*V02*V08*V18 + 1.01007465822602649e-18*V01*V09*V18 - 
      1.35366312825614059e-20*V12*V18 + 2.64713390414397574e-18*V013*V02*V19 - 
      1.29206010163061179e-17*V022*V03*V19 - 1.47494476969167388e-17*V01*V032*V19 - 
      1.59440353498617598e-17*V01*V02*V04*V19 - 4.44794287855468719e-18*V012*V05*V19 + 
      5.51181703928822303e-18*V04*V05*V19 + 3.99194592012692394e-18*V03*V06*V19 + 1.42630085136583279e-18*V02*V07*V19 + 
      4.95426857892580663e-19*V01*V08*V19 - 8.8518448452916774e-21*V11*V19 + 7.0366850616485431e-20*V014*V20 - 
      4.67942215966620425e-19*V023*V20 - 3.82845131579737685e-18*V01*V02*V03*V20 - 
      1.11099842964277723e-18*V012*V04*V20 + 6.71413490199719079e-19*V042*V20 + 
      1.3491003904533701e-18*V03*V05*V20 + 5.03159754534212754e-19*V02*V06*V20 + 2.13427398623557061e-19*V01*V07*V20 - 
      5.0076879957602313e-21*V10*V20 - 2.25062228559076418e-19*V01*V022*V21 - 
      2.40624844198066318e-19*V012*V03*V21 + 3.23029538062408962e-19*V03*V04*V21 + 1.671535265017234e-19*V02*V05*V21 + 
      7.39172201791050052e-20*V01*V06*V21 - 2.52678221472134795e-21*V09*V21 - 2.89285941423328994e-20*V012*V02*V22 + 
      3.58317988498014016e-20*V032*V22 + 3.67304310523110038e-20*V02*V04*V22 + 2.26610010716036714e-20*V01*V05*V22 - 
      1.07666005985679865e-21*V08*V22 - 1.04247186098496935e-21*V013*V23 + 8.17961680332572162e-21*V02*V03*V23 + 
      4.99297375503406491e-21*V01*V04*V23 - 4.10092299280725401e-22*V07*V23 + 4.18186987912361267e-22*V022*V24 + 
      1.00228790870808568e-21*V01*V03*V24 - 1.25138550008783256e-22*V06*V24 + 1.0677205636935544e-22*V01*V02*V25 - 
      3.46229220541556052e-23*V05*V25 + 5.77724553501522422e-24*V012*V26 - 6.79671885105076618e-24*V04*V26 - 
      1.27002769228530616e-24*V03*V27 - 1.20790677255395966e-25*V02*V28 - 1.29418582773638535e-26*V01*V29 + 
      9.80443808891201026e-30*V32) + delta8*eps12*
    (2.11565241127717922e-10*V02*V036 + 1.65171690028240725e-9*V022*V034*V04 + 
      6.86689914806456036e-10*V01*V035*V04 + 1.38805864074911309e-9*V023*V032*V042 + 
      3.76858510988269074e-9*V01*V02*V033*V042 + 8.85933436332280376e-12*V024*V043 + 
      1.76471696230472504e-9*V01*V022*V03*V043 + 
      1.03561112056353754e-9*V012*V032*V043 + 2.75037209033877212e-10*V012*V02*V044 - 
      9.02642591238259719e-10*V032*V044 - 1.2695043367275619e-10*V02*V045 + 
      1.09616111845060817e-9*V023*V033*V05 + 1.77421339320927151e-9*V01*V02*V034*V05 + 
      6.4324973752423922e-10*V024*V03*V04*V05 + 5.71344091228259897e-9*V01*V022*V032*V04*V05 + 
      1.86741308684926255e-9*V012*V033*V04*V05 + 8.32835184449467856e-10*V01*V023*V042*V05 + 
      3.18498806713256585e-9*V012*V02*V03*V042*V05 - 3.5781292071240821e-9*V033*V042*V05 + 
      1.88918926040067581e-10*V013*V043*V05 - 3.58448967695805344e-9*V02*V03*V043*V05 - 
      5.50364208970795713e-10*V01*V044*V05 + 2.9274133874502564e-11*V025*V052 + 
      9.54022580261324613e-10*V01*V023*V03*V052 + 
      1.45271116847806153e-9*V012*V02*V032*V052 - 8.30433660106480456e-10*V034*V052 + 
      8.10800334410740495e-10*V012*V022*V04*V052 + 
      4.93439900752214855e-10*V013*V03*V04*V052 - 5.51835642197186262e-9*V02*V032*V04*V052 - 
      1.31670334299521288e-9*V022*V042*V052 - 
      3.23098882822089369e-9*V01*V03*V042*V052 + 8.55819964015475075e-11*V013*V02*V053 - 
      9.36404301292205982e-10*V022*V03*V053 - 9.8734287517198592e-10*V01*V032*V053 - 
      1.11268245493696315e-9*V01*V02*V04*V053 - 7.20765262229931161e-11*V012*V054 + 
      9.23355852248475813e-11*V04*V054 + 2.39330317100315281e-10*V024*V032*V06 + 
      1.3051647236924731e-9*V01*V022*V033*V06 + 3.09561341377391052e-10*V012*V034*V06 + 
      3.48977325642452677e-12*V025*V04*V06 + 1.22416291811533812e-9*V01*V023*V03*V04*V06 + 
      2.15050441693153037e-9*V012*V02*V032*V04*V06 - 1.2540967336963881e-9*V034*V04*V06 + 
      5.75471315858418555e-10*V012*V022*V042*V06 + 
      3.76511674913909224e-10*V013*V03*V042*V06 - 3.90098211999087102e-9*V02*V032*V042*V06 - 
      4.47687665627033096e-10*V022*V043*V06 - 1.57662395238450447e-9*V01*V03*V043*V06 + 
      1.43598190260189168e-10*V01*V024*V05*V06 + 1.09951143292722396e-9*V012*V022*V03*V05*V06 + 
      3.24078789664336084e-10*V013*V032*V05*V06 - 2.59365065239942983e-9*V02*V033*V05*V06 + 
      3.90316666526930781e-10*V013*V02*V04*V05*V06 - 3.85671637616173572e-9*V022*V03*V04*V05*V06 - 
      4.50292997806951258e-9*V01*V032*V04*V05*V06 - 2.37779552204089659e-9*V01*V02*V042*V05*V06 + 
      2.04524990081220648e-11*V014*V052*V06 - 3.13399965991355314e-10*V023*V052*V06 - 
      2.3394258109460173e-9*V01*V02*V03*V052*V06 - 6.63580681882650984e-10*V012*V04*V052*V06 + 
      4.09063986133841212e-10*V042*V052*V06 + 2.63730090622421793e-10*V03*V053*V06 + 
      6.66782966486021182e-11*V012*V023*V062 + 
      1.29243357535212139e-10*V013*V02*V03*V062 - 
      7.0044339247857499e-10*V022*V032*V062 - 5.20296516473443331e-10*V01*V033*V062 + 
      1.59408858439325945e-11*V014*V04*V062 - 1.57378488160745354e-10*V023*V04*V062 - 
      1.70453294570014247e-9*V01*V02*V03*V04*V062 - 2.51569453030911035e-10*V012*V042*V062 + 
      9.18834098837043378e-11*V043*V062 - 4.26817577269560114e-10*V01*V022*V05*V062 - 
      4.56738967892153493e-10*V012*V03*V05*V062 + 5.91846382721704868e-10*V03*V04*V05*V062 + 
      1.52311401988866355e-10*V02*V052*V062 - 6.04509826524235903e-11*V012*V02*V063 + 
      7.09198988758169537e-11*V032*V063 + 6.77843207385101356e-11*V02*V04*V063 + 
      4.45704132424626415e-11*V01*V05*V063 + 2.78801274995262514e-11*V025*V03*V07 + 
      4.38809597103381844e-10*V01*V023*V032*V07 + 4.35422603833789192e-10*V012*V02*V033*V07 - 
      1.58617165714471135e-10*V035*V07 + 9.18928196463198886e-11*V01*V024*V04*V07 + 
      7.38942233429171834e-10*V012*V022*V03*V04*V07 + 
      2.19920699276369752e-10*V013*V032*V04*V07 - 1.7664033638278381e-9*V02*V033*V04*V07 + 
      1.31976714457564486e-10*V013*V02*V042*V07 - 1.27386361796512544e-9*V022*V03*V042*V07 - 
      1.54269150627059114e-9*V01*V032*V042*V07 - 5.28466126686766646e-10*V01*V02*V043*V07 + 
      1.24762180525692819e-10*V012*V023*V05*V07 + 2.28771155503092297e-10*V013*V02*V03*V05*V07 - 
      1.35112199883971345e-9*V022*V032*V05*V07 - 9.38465205954234216e-10*V01*V033*V05*V07 + 
      2.77676792983138696e-11*V014*V04*V05*V07 - 4.10747423448674162e-10*V023*V04*V05*V07 - 
      3.19278471436932968e-9*V01*V02*V03*V04*V05*V07 - 4.55811658613011584e-10*V012*V042*V05*V07 + 
      1.86665463694660622e-10*V043*V05*V07 - 4.09094681168330782e-10*V01*V022*V052*V07 - 
      4.08870225319252979e-10*V012*V03*V052*V07 + 5.49719273193079439e-10*V03*V04*V052*V07 + 
      9.56476465248094328e-11*V02*V053*V07 + 4.52017998159628711e-11*V013*V022*V06*V07 + 
      1.79896574088346691e-11*V014*V03*V06*V07 - 3.0310827457471207e-10*V023*V03*V06*V07 - 
      1.11577873665124817e-9*V01*V02*V032*V06*V07 - 5.68252949385511473e-10*V01*V022*V04*V06*V07 - 
      6.29019906495363498e-10*V012*V03*V04*V06*V07 + 4.06868983273823627e-10*V03*V042*V06*V07 - 
      3.29181431827900208e-10*V012*V02*V05*V06*V07 + 3.91643481167665928e-10*V032*V05*V06*V07 + 
      4.1601667451417486e-10*V02*V04*V05*V06*V07 + 1.22552309158309918e-10*V01*V052*V06*V07 - 
      2.05459036375128528e-11*V013*V062*V07 + 1.51330543601968553e-10*V02*V03*V062*V07 + 
      9.23677171347181746e-11*V01*V04*V062*V07 + 3.17451693919720325e-12*V014*V02*V072 - 
      1.18601173153377088e-11*V024*V072 - 1.9561645196749617e-10*V01*V022*V03*V072 - 
      9.64188505470931113e-11*V012*V032*V072 - 
      1.12705649373862715e-10*V012*V02*V04*V072 + 1.36065768023441505e-10*V032*V04*V072 + 
      7.06903374005472804e-11*V02*V042*V072 - 1.81655173837418371e-11*V013*V05*V072 + 
      1.42209629640025305e-10*V02*V03*V05*V072 + 8.52417210864674562e-11*V01*V04*V05*V072 + 
      2.61069676607456382e-11*V022*V06*V072 + 6.02627002374851982e-11*V01*V03*V06*V072 - 
      3.12491251924210466e-12*V062*V072 + 7.34232527128604452e-12*V01*V02*V073 - 
      1.92307434159209845e-12*V05*V073 + 9.33899039438782262e-14*V026*V08 + 
      5.36898446670225014e-11*V01*V024*V03*V08 + 1.87105027552625145e-10*V012*V022*V032*V08 + 
      3.5535647133409023e-11*V013*V033*V08 - 2.39015346507024879e-10*V02*V034*V08 + 
      6.78449176370001325e-11*V012*V023*V04*V08 + 1.30249691643408376e-10*V013*V02*V03*V04*V08 - 
      7.32106839125128782e-10*V022*V032*V04*V08 - 5.47258162504973128e-10*V01*V033*V04*V08 + 
      7.99919562132077166e-12*V014*V042*V08 - 8.10150432776255557e-11*V023*V042*V08 - 
      8.92060173335578148e-10*V01*V02*V03*V042*V08 - 8.78861131794236595e-11*V012*V043*V08 + 
      2.45634439070379662e-11*V044*V08 + 3.3680102907807188e-11*V013*V022*V05*V08 + 
      1.3260963424348544e-11*V014*V03*V05*V08 - 2.39777671233591518e-10*V023*V03*V05*V08 - 
      8.56336569042266343e-10*V01*V02*V032*V05*V08 - 4.45979580078837503e-10*V01*V022*V04*V05*V08 - 
      4.79942155427837879e-10*V012*V03*V04*V05*V08 + 3.18777285542879122e-10*V03*V042*V05*V08 - 
      1.25880495810415435e-10*V012*V02*V052*V08 + 1.51976211089163639e-10*V032*V052*V08 + 
      1.63688124948446059e-10*V02*V04*V052*V08 + 3.16367014179809657e-11*V01*V053*V08 + 
      5.39224161534457042e-12*V014*V02*V06*V08 - 1.41750190832167476e-11*V024*V06*V08 - 
      3.20178509616809358e-10*V01*V022*V03*V06*V08 - 1.64320036339773029e-10*V012*V032*V06*V08 - 
      1.89843943138212606e-10*V012*V02*V04*V06*V08 + 2.29316143204970521e-10*V032*V04*V06*V08 + 
      1.08531575888440868e-10*V02*V042*V06*V08 - 3.11484139606328914e-11*V013*V05*V06*V08 + 
      2.3727014010970781e-10*V02*V03*V05*V06*V08 + 1.43964229244591958e-10*V01*V04*V05*V06*V08 + 
      1.99122421911040609e-11*V022*V062*V08 + 5.12191263133403411e-11*V01*V03*V062*V08 - 
      1.72600891797293642e-12*V063*V08 + 2.73169840919134062e-13*V015*V07*V08 - 
      3.52875350509699961e-11*V01*V023*V07*V08 - 1.19056232548406994e-10*V012*V02*V03*V07*V08 + 
      4.99902156869209214e-11*V033*V07*V08 - 2.15452724095297597e-11*V013*V04*V07*V08 + 
      1.62491163306568752e-10*V02*V03*V04*V07*V08 + 4.96549282666049462e-11*V01*V042*V07*V08 + 
      4.1244746339553127e-11*V022*V05*V07*V08 + 9.32363518019342652e-11*V01*V03*V05*V07*V08 + 
      3.68800466262529626e-11*V01*V02*V06*V07*V08 - 9.79663515522813358e-12*V05*V06*V07*V08 + 
      3.48053732398600019e-12*V012*V072*V08 - 3.41200177100048083e-12*V04*V072*V08 - 
      8.9014842370156752e-12*V012*V022*V082 - 5.51185694124867139e-12*V013*V03*V082 + 
      2.29549714896332041e-11*V02*V032*V082 + 1.05963505154423349e-11*V022*V04*V082 + 
      2.7554415634859315e-11*V01*V03*V04*V082 + 1.43805891122775009e-11*V01*V02*V05*V082 - 
      1.91695324165125744e-12*V052*V082 + 2.98555011525104552e-12*V012*V06*V082 - 
      2.82096528228637575e-12*V04*V06*V082 - 1.93324877614192731e-12*V03*V07*V082 - 
      1.9350678485850944e-13*V02*V083 + 2.32334395829385428e-12*V01*V025*V09 + 
      3.20750163091827084e-11*V012*V023*V03*V09 + 2.84063060734221734e-11*V013*V02*V032*V09 - 
      1.27451402748070915e-10*V022*V033*V09 - 6.53203540288510474e-11*V01*V034*V09 + 
      1.7157321453101102e-11*V013*V022*V04*V09 + 6.80036076588052531e-12*V014*V03*V04*V09 - 
      1.17617197101646543e-10*V023*V03*V04*V09 - 4.48063471216427861e-10*V01*V02*V032*V04*V09 - 
      1.11120410037133987e-10*V01*V022*V042*V09 - 1.26804432487348757e-10*V012*V03*V042*V09 + 
      5.61876405754966581e-11*V03*V043*V09 + 3.53568774626835455e-12*V014*V02*V05*V09 - 
      1.40447766577962634e-11*V024*V05*V09 - 2.30190516477929056e-10*V01*V022*V03*V05*V09 - 
      1.12950925991023589e-10*V012*V032*V05*V09 - 1.32272563402436007e-10*V012*V02*V04*V05*V09 + 
      1.64243262359489933e-10*V032*V04*V05*V09 + 8.55971026152041424e-11*V02*V042*V05*V09 - 
      1.06125407792588808e-11*V013*V052*V09 + 8.58495928842687739e-11*V02*V03*V052*V09 + 
      5.13421228081671382e-11*V01*V04*V052*V09 + 2.06410622579155605e-13*V015*V06*V09 - 
      2.64170520031527579e-11*V01*V023*V06*V09 - 9.13674565074522247e-11*V012*V02*V03*V06*V09 + 
      3.88736980485894685e-11*V033*V06*V09 - 1.65966151998362668e-11*V013*V04*V06*V09 + 
      1.24993087622714682e-10*V02*V03*V04*V06*V09 + 3.83498824297580126e-11*V01*V042*V06*V09 + 
      3.15874205059106237e-11*V022*V05*V06*V09 + 7.2512193034044794e-11*V01*V03*V05*V06*V09 + 
      1.42226540451068014e-11*V01*V02*V062*V09 - 3.816095382756888e-12*V05*V062*V09 - 
      1.62197452894669368e-11*V012*V022*V07*V09 - 9.90975700474691904e-12*V013*V03*V07*V09 + 
      4.24024936280090997e-11*V02*V032*V07*V09 + 2.13122349695748975e-11*V022*V04*V07*V09 + 
      5.04392021761214844e-11*V01*V03*V04*V07*V09 + 2.65078091269298211e-11*V01*V02*V05*V07*V09 - 
      3.51880541311691857e-12*V052*V07*V09 + 5.41602918842199384e-12*V012*V06*V07*V09 - 
      5.30725063759252805e-12*V04*V06*V07*V09 - 1.77277488312182913e-12*V03*V072*V09 - 
      3.11624408895051199e-12*V013*V02*V08*V09 + 1.23525685228935338e-11*V022*V03*V08*V09 + 
      1.37205569954248304e-11*V01*V032*V08*V09 + 1.52354434673470733e-11*V01*V02*V04*V08*V09 + 
      4.17111144051216047e-12*V012*V05*V08*V09 - 4.16587199946322352e-12*V04*V05*V08*V09 - 
      3.0153477853378167e-12*V03*V06*V08*V09 - 1.09639205734423692e-12*V02*V07*V08*V09 - 
      1.90216358700110283e-13*V01*V082*V09 - 9.05362137174969968e-14*V014*V092 + 
      5.27174469924945277e-13*V023*V092 + 3.90596557221585395e-12*V01*V02*V03*V092 + 
      1.1306835924901323e-12*V012*V04*V092 - 5.61505141000528238e-13*V042*V092 - 
      1.08014467389071212e-12*V03*V05*V092 - 4.25065391033742532e-13*V02*V06*V092 - 
      1.73923801996343946e-13*V01*V07*V092 + 1.80204750757133097e-12*V012*V024*V10 + 
      6.6754075772133836e-12*V013*V022*V03*V10 + 1.27289035464315201e-12*V014*V032*V10 - 
      2.8182928186279854e-11*V023*V032*V10 - 6.45684737602794604e-11*V01*V02*V033*V10 + 
      1.60898588880435859e-12*V014*V02*V04*V10 - 4.45586359623285591e-12*V024*V04*V10 - 
      1.03634195138969052e-10*V01*V022*V03*V04*V10 - 5.36316695781623018e-11*V012*V032*V04*V10 - 
      3.07895100297339906e-11*V012*V02*V042*V10 + 3.91409558305249101e-11*V032*V042*V10 + 
      1.21490706789575671e-11*V02*V043*V10 + 1.19030688053496982e-13*V015*V05*V10 - 
      1.71538098636217616e-11*V01*V023*V05*V10 - 5.64226522852279638e-11*V012*V02*V03*V05*V10 + 
      2.46015300577810465e-11*V033*V05*V10 - 1.01466292237250705e-11*V013*V04*V05*V10 + 
      8.07046332883337161e-11*V02*V03*V04*V05*V10 + 2.4528164923518728e-11*V01*V042*V05*V10 + 
      1.02745451867309303e-11*V022*V052*V10 + 2.28718856216303335e-11*V01*V03*V052*V10 - 
      1.10329441033408518e-11*V012*V022*V06*V10 - 6.84933658942219803e-12*V013*V03*V06*V10 + 
      2.90846049241629619e-11*V02*V032*V06*V10 + 1.33360211355181273e-11*V022*V04*V06*V10 + 
      3.49307369582445036e-11*V01*V03*V04*V06*V10 + 1.82067196026489306e-11*V01*V02*V05*V06*V10 - 
      2.45290667983252177e-12*V052*V06*V10 + 1.89149491028716843e-12*V012*V062*V10 - 
      1.80105123076651693e-12*V04*V062*V10 - 2.51311522921836783e-12*V013*V02*V07*V10 + 
      1.01747257982938607e-11*V022*V03*V07*V10 + 1.11889968578439228e-11*V01*V032*V07*V10 + 
      1.25048991749510642e-11*V01*V02*V04*V07*V10 + 3.3971497589202656e-12*V012*V05*V07*V10 - 
      3.42121342347917974e-12*V04*V05*V07*V10 - 2.47315595448135342e-12*V03*V06*V07*V10 - 
      4.50892257805768417e-13*V02*V072*V10 - 1.62588390006639376e-13*V014*V08*V10 + 
      8.59499561964646982e-13*V023*V08*V10 + 6.95588461777906527e-12*V01*V02*V03*V08*V10 + 
      2.03021315588309362e-12*V012*V04*V08*V10 - 9.79842131694492942e-13*V042*V08*V10 - 
      1.93208350279529558e-12*V03*V05*V08*V10 - 7.40293769613125126e-13*V02*V06*V08*V10 - 
      3.11511131111510033e-13*V01*V07*V08*V10 + 9.47758744988983046e-13*V01*V022*V09*V10 + 
      9.86274402564482025e-13*V012*V03*V09*V10 - 1.05186250479343965e-12*V03*V04*V09*V10 - 
      5.50099709147661638e-13*V02*V05*V09*V10 - 2.43125269058403076e-13*V01*V06*V09*V10 + 
      3.45189681029132362e-15*V092*V10 + 1.27201107034834102e-13*V012*V02*V102 - 
      1.21093493406528216e-13*V032*V102 - 1.27970167265699324e-13*V02*V04*V102 - 
      7.74812828034231128e-14*V01*V05*V102 + 3.07202744047901961e-15*V08*V102 + 
      4.66750200453430365e-13*V013*V023*V11 + 5.42370796507721746e-13*V014*V02*V03*V11 - 
      2.66703564136419506e-12*V024*V03*V11 - 2.13059097056447515e-11*V01*V022*V032*V11 - 
      6.82976327923866823e-12*V012*V033*V11 + 4.88120769356436138e-14*V015*V04*V11 - 
      6.79955881515809613e-12*V01*V023*V04*V11 - 2.42237763853084244e-11*V012*V02*V03*V04*V11 + 
      1.09544496770453688e-11*V033*V04*V11 - 2.20585234394790884e-12*V013*V042*V11 + 
      1.73194020880645824e-11*V02*V03*V042*V11 + 3.55871308433789742e-12*V01*V043*V11 - 
      6.27773061253633616e-12*V012*V022*V05*V11 - 3.80976620701538267e-12*V013*V03*V05*V11 + 
      1.72016917343696099e-11*V02*V032*V05*V11 + 8.69399362817637592e-12*V022*V04*V05*V11 + 
      2.03930402881128102e-11*V01*V03*V04*V05*V11 + 5.3601529741255157e-12*V01*V02*V052*V11 - 
      4.8408032750926247e-13*V053*V11 - 1.57999691929495994e-12*V013*V02*V06*V11 + 
      6.3774308803590843e-12*V022*V03*V06*V11 + 7.17086151700619201e-12*V01*V032*V06*V11 + 
      7.89137369416447332e-12*V01*V02*V04*V06*V11 + 2.1786338776490303e-12*V012*V05*V06*V11 - 
      2.1948985742278733e-12*V04*V05*V06*V11 - 7.95425404155999254e-13*V03*V062*V11 - 
      1.19129491031840952e-13*V014*V07*V11 + 7.11190437305240347e-13*V023*V07*V11 + 
      5.25078827852685582e-12*V01*V02*V03*V07*V11 + 1.51817855758664337e-12*V012*V04*V07*V11 - 
      7.6082824039735212e-13*V042*V07*V11 - 1.46176680935142483e-12*V03*V05*V07*V11 - 
      5.75877537811953966e-13*V02*V06*V07*V11 - 1.1757563085783203e-13*V01*V072*V11 + 
      7.7554313589238595e-13*V01*V022*V08*V11 + 8.12999497213678129e-13*V012*V03*V08*V11 - 
      8.67601644012943141e-13*V03*V04*V08*V11 - 4.53037785871116828e-13*V02*V05*V08*V11 - 
      2.00709512347576198e-13*V01*V06*V08*V11 + 2.33554036863628865e-13*V012*V02*V09*V11 - 
      2.23426021833423486e-13*V032*V09*V11 - 2.421526232633391e-13*V02*V04*V09*V11 - 
      1.4285317101964436e-13*V01*V05*V09*V11 + 5.70595511638944445e-15*V08*V09*V11 + 
      1.86274770782752983e-14*V013*V10*V11 - 1.14236985058244151e-13*V02*V03*V10*V11 - 
      6.98171286704933682e-14*V01*V04*V10*V11 + 4.68375957413181823e-15*V07*V10*V11 - 
      6.43954982350461098e-15*V022*V112 - 1.4602310028890657e-14*V01*V03*V112 + 
      1.51372590659393389e-15*V06*V112 + 5.22431645717034434e-14*V014*V022*V12 - 
      6.57217855442747685e-14*V025*V12 + 1.46306755801796508e-14*V015*V03*V12 - 
      2.71939234770633937e-12*V01*V023*V03*V12 - 4.29677451809475364e-12*V012*V02*V032*V12 + 
      1.0330317940464957e-12*V034*V12 - 2.43842661783255919e-12*V012*V022*V04*V12 - 
      1.52423875771479026e-12*V013*V03*V04*V12 + 6.8645872335942034e-12*V02*V032*V04*V12 + 
      1.54051768008388797e-12*V022*V042*V12 + 4.13024414267126726e-12*V01*V03*V042*V12 - 
      8.0839600778865117e-13*V013*V02*V05*V12 + 3.50780059491054455e-12*V022*V03*V05*V12 + 
      3.80986187474230955e-12*V01*V032*V05*V12 + 4.28793473543833178e-12*V01*V02*V04*V05*V12 + 
      5.7602928447429103e-13*V012*V052*V12 - 5.98818735288428096e-13*V04*V052*V12 - 
      6.90320401992348523e-14*V014*V06*V12 + 3.7321417263518253e-13*V023*V06*V12 + 
      3.05832467602295418e-12*V01*V02*V03*V06*V12 + 8.93420165366179107e-13*V012*V04*V06*V12 - 
      4.36442316544916737e-13*V042*V06*V12 - 8.64026530790864853e-13*V03*V05*V06*V12 - 
      1.64662162941884957e-13*V02*V062*V12 + 5.40451934513128061e-13*V01*V022*V07*V12 + 
      5.58198669033631988e-13*V012*V03*V07*V12 - 6.0318700912628082e-13*V03*V04*V07*V12 - 
      3.15829576008743453e-13*V02*V05*V07*V12 - 1.39145649346753406e-13*V01*V06*V07*V12 + 
      1.76734768373571843e-13*V012*V02*V08*V12 - 1.69315230776424095e-13*V032*V08*V12 - 
      1.7856793078242808e-13*V02*V04*V08*V12 - 1.08309224778875102e-13*V01*V05*V08*V12 + 
      2.1506540682560739e-15*V082*V12 + 1.56987163742290443e-14*V013*V09*V12 - 
      9.68292325181963708e-14*V02*V03*V09*V12 - 5.91101433663662984e-14*V01*V04*V09*V12 + 3.96754019856724787e-15*V07*V09*V12 - 
      1.15265254280716767e-14*V022*V10*V12 - 2.68246320444907719e-14*V01*V03*V10*V12 + 
      2.76121289853093939e-15*V06*V10*V12 - 6.3861679185112356e-15*V01*V02*V11*V12 + 1.65050392776819855e-15*V05*V11*V12 - 
      3.58419591865898841e-16*V012*V122 + 3.41028946379174518e-16*V04*V122 + 
      2.58950010268666386e-15*V015*V02*V13 - 1.09850081424343276e-13*V01*V024*V13 - 
      8.13748530819934345e-13*V012*V022*V03*V13 - 2.41130510066692234e-13*V013*V032*V13 + 
      8.22332189207356192e-13*V02*V033*V13 - 2.96942078157229963e-13*V013*V02*V04*V13 + 
      1.2638334897962086e-12*V022*V03*V04*V13 + 1.44847505401729767e-12*V01*V032*V04*V13 + 
      7.85344983807370767e-13*V01*V02*V042*V13 - 3.22736890192028368e-14*V014*V05*V13 + 
      2.09019379269443467e-13*V023*V05*V13 + 1.52521533953256487e-12*V01*V02*V03*V05*V13 + 
      4.39118436195342929e-13*V012*V04*V05*V13 - 2.27633508924967209e-13*V042*V05*V13 - 
      2.17778790902937634e-13*V03*V052*V13 + 2.88288117752141297e-13*V01*V022*V06*V13 + 
      3.05349264555693289e-13*V012*V03*V06*V13 - 3.30632631205406418e-13*V03*V04*V06*V13 - 
      1.72181414944930764e-13*V02*V05*V06*V13 - 3.8255480537344902e-14*V01*V062*V13 + 
      1.12778191787630349e-13*V012*V02*V07*V13 - 1.09260484377106008e-13*V032*V07*V13 - 
      1.18701140944617636e-13*V02*V04*V07*V13 - 6.97930098512891936e-14*V01*V05*V07*V13 + 
      1.10478559955210139e-14*V013*V08*V13 - 6.80655901877191312e-14*V02*V03*V08*V13 - 
      4.16452299968607051e-14*V01*V04*V08*V13 + 2.8020716062433473e-15*V07*V08*V13 - 
      9.31985174971273256e-15*V022*V09*V13 - 2.11056434780531011e-14*V01*V03*V09*V13 + 
      2.19137817815699156e-15*V06*V09*V13 - 5.4502716511860758e-15*V01*V02*V10*V13 + 1.41035705767413631e-15*V05*V10*V13 - 
      6.65707849928832573e-16*V012*V11*V13 + 6.39061426001479399e-16*V04*V11*V13 + 
      2.52801041778552297e-16*V03*V12*V13 + 2.57926127768524185e-17*V02*V132 + 
      4.62410732622618547e-17*V016*V14 - 4.64266742077688608e-14*V012*V023*V14 - 
      8.78229227890374873e-14*V013*V02*V03*V14 + 2.18986707714845588e-13*V022*V032*V14 + 
      1.54927629419260848e-13*V01*V033*V14 - 1.11135058301989874e-14*V014*V04*V14 + 
      6.28934153347653924e-14*V023*V04*V14 + 5.29799725035523053e-13*V01*V02*V03*V04*V14 + 
      7.75494233196318679e-14*V012*V042*V14 - 2.60048530426178278e-14*V043*V14 + 
      1.36353083619310579e-13*V01*V022*V05*V14 + 1.39202726516384512e-13*V012*V03*V05*V14 - 
      1.55998600726292586e-13*V03*V04*V05*V14 - 4.08950718528632656e-14*V02*V052*V14 + 
      5.71862002559481535e-14*V012*V02*V06*V14 - 5.60444193844106971e-14*V032*V06*V14 - 
      5.86789049118273296e-14*V02*V04*V06*V14 - 3.58172282858980172e-14*V01*V05*V06*V14 + 
      6.53284368801179545e-15*V013*V07*V14 - 4.11073930825690663e-14*V02*V03*V07*V14 - 
      2.50461755064385383e-14*V01*V04*V07*V14 + 8.44616400886231065e-16*V072*V14 - 
      5.94088722559848644e-15*V022*V08*V14 - 1.38794379503494743e-14*V01*V03*V08*V14 + 
      1.43192703654689982e-15*V06*V08*V14 - 4.00273982181643707e-15*V01*V02*V09*V14 + 1.03578235953022005e-15*V05*V09*V14 - 
      5.30646576258819308e-16*V012*V10*V14 + 5.05220993342412293e-16*V04*V10*V14 + 2.1917107047179425e-16*V03*V11*V14 + 
      4.7720572861647374e-17*V02*V12*V14 + 1.08749680718856481e-17*V01*V13*V14 - 
      7.37394332424612684e-15*V013*V022*V15 - 2.9820466050543433e-15*V014*V03*V15 + 
      2.28585299444413014e-14*V023*V03*V15 + 8.12600104725178516e-14*V01*V02*V032*V15 + 
      4.29690750230386677e-14*V01*V022*V04*V15 + 4.62867692716653729e-14*V012*V03*V04*V15 - 
      2.59520107413750305e-14*V03*V042*V15 + 2.45375072003902738e-14*V012*V02*V05*V15 - 
      2.46155995453615031e-14*V032*V05*V15 - 2.68891515513532826e-14*V02*V04*V05*V15 - 
      7.83903760415543155e-15*V01*V052*V15 + 3.1231098018576612e-15*V013*V06*V15 - 
      1.9594933789074624e-14*V02*V03*V06*V15 - 1.20086681997827743e-14*V01*V04*V06*V15 - 
      3.4618108242359122e-15*V022*V07*V15 - 7.80396387108720409e-15*V01*V03*V07*V15 + 
      8.15742589427790721e-16*V06*V07*V15 - 2.45930942200419554e-15*V01*V02*V08*V15 + 6.39569809340514948e-16*V05*V08*V15 - 
      3.64051837137481534e-16*V012*V09*V15 + 3.50617706073352386e-16*V04*V09*V15 + 
      1.63725927627113307e-16*V03*V10*V15 + 3.90961486919211966e-17*V02*V11*V15 + 9.50627247036134867e-18*V01*V12*V15 - 
      2.94654087338811119e-20*V152 - 4.77489343469008282e-16*V014*V02*V16 + 
      7.26535871058317459e-16*V024*V16 + 1.28743022347801229e-14*V01*V022*V03*V16 + 
      6.4100403335553211e-15*V012*V032*V16 + 7.57457261856336804e-15*V012*V02*V04*V16 - 
      7.79229585851794524e-15*V032*V04*V16 - 4.01457158249064096e-15*V02*V042*V16 + 
      1.24134943026437688e-15*V013*V05*V16 - 8.18940865357343808e-15*V02*V03*V05*V16 - 
      4.96954818182556857e-15*V01*V04*V05*V16 - 1.49942046655474542e-15*V022*V06*V16 - 
      3.53759209286139809e-15*V01*V03*V06*V16 + 1.8384284867523702e-16*V062*V16 - 
      1.30742879622852254e-15*V01*V02*V07*V16 + 3.40247927044035842e-16*V05*V07*V16 - 
      2.11616016953575468e-16*V012*V08*V16 + 2.02073999477768511e-16*V04*V08*V16 + 
      1.06105889737457533e-16*V03*V09*V16 + 2.72593643679791138e-17*V02*V10*V16 + 7.27235157781215875e-18*V01*V11*V16 - 
      5.53254507285150897e-20*V14*V16 - 1.05550275924728147e-17*V015*V17 + 
      6.03130472178879788e-16*V01*V023*V17 + 2.00591597790125225e-15*V012*V02*V03*V17 - 
      7.23327045603310504e-16*V033*V17 + 3.67457369320492075e-16*V013*V04*V17 - 
      2.39675187569321659e-15*V02*V03*V04*V17 - 7.36639843415224813e-16*V01*V042*V17 - 
      6.14465399032351983e-16*V022*V05*V17 - 1.37150047973024232e-15*V01*V03*V05*V17 - 
      5.54395324879716279e-16*V01*V02*V06*V17 + 1.46140331824485412e-16*V05*V06*V17 - 
      1.05302276655860408e-16*V012*V07*V17 + 1.0243805050847984e-16*V04*V07*V17 + 5.82637435987304793e-17*V03*V08*V17 + 
      1.68312061391460624e-17*V02*V09*V17 + 4.82984981109450236e-18*V01*V10*V17 - 4.62198742967122348e-20*V13*V17 + 
      1.44503353944568296e-16*V012*V022*V18 + 8.87543788430551359e-17*V013*V03*V18 - 
      3.24024188697059251e-16*V02*V032*V18 - 1.61829395836158025e-16*V022*V04*V18 - 
      3.89525893611553126e-16*V01*V03*V04*V18 - 2.05918236743127053e-16*V01*V02*V05*V18 + 
      2.72609762436915104e-17*V052*V18 - 4.28114671595534402e-17*V012*V06*V18 + 
      4.1251457668053768e-17*V04*V06*V18 + 2.77256956549154024e-17*V03*V07*V18 + 8.6666533576628542e-18*V02*V08*V18 + 
      2.79975827398951377e-18*V01*V09*V18 - 3.39474875653093372e-20*V12*V18 + 1.26073940687869731e-17*V013*V02*V19 - 
      4.39632257070873312e-17*V022*V03*V19 - 4.80112144165172634e-17*V01*V032*V19 - 
      5.44097511262739552e-17*V01*V02*V04*V19 - 1.48112646826529521e-17*V012*V05*V19 + 
      1.47988454044105047e-17*V04*V05*V19 + 1.07335518730035352e-17*V03*V06*V19 + 3.964825259953388e-18*V02*V07*V19 + 
      1.38510344336724517e-18*V01*V08*V19 - 2.21359819726175189e-20*V11*V19 + 3.51834253082427155e-19*V014*V20 - 
      1.74316187611843803e-18*V023*V20 - 1.30815326098456725e-17*V01*V02*V03*V20 - 
      3.82159014895722067e-18*V012*V04*V20 + 1.88197014979782243e-18*V042*V20 + 
      3.61755067498389409e-18*V03*V05*V20 + 1.4388440920268599e-18*V02*V06*V20 + 5.9556340388130832e-19*V01*V07*V20 - 
      1.2582356312765773e-20*V10*V20 - 8.15082686307622909e-19*V01*V022*V21 - 
      8.39515620549458128e-19*V012*V03*V21 + 8.9490263517029832e-19*V03*V04*V21 + 4.71688427275203759e-19*V02*V05*V21 + 
      2.09996857233704426e-19*V01*V06*V21 - 6.32332539619169525e-21*V09*V21 - 1.05550275924728147e-19*V012*V02*V22 + 
      9.93416856486759721e-20*V032*V22 + 1.08502723500051165e-19*V02*V04*V22 + 6.43287120092937256e-20*V01*V05*V22 - 
      2.71852237765752868e-21*V08*V22 - 3.90926947869363506e-21*V013*V23 + 2.38568144787600898e-20*V02*V03*V23 + 
      1.46369725210463492e-20*V01*V04*V23 - 1.02952297712739778e-21*V07*V23 + 1.30373174240176893e-21*V022*V24 + 
      2.94832097136943609e-21*V01*V03*V24 - 3.19773350595175745e-22*V06*V24 + 3.29784432623785716e-22*V01*V02*V25 - 
      8.78577461946261243e-23*V05*V25 + 1.80538922969225757e-23*V012*V26 - 1.78243900101373234e-23*V04*V26 - 
      3.31203723081536619e-24*V03*V27 - 3.32174362452338908e-25*V02*V28 - 3.55901102627505972e-26*V01*V29 + 
      2.45110952222800256e-29*V32) + eps16*(4.50155213123768602e-9*V012*V027 + 
      3.38153489550767212e-8*V013*V025*V03 + 4.52779596012409971e-8*V014*V023*V032 - 
      1.11947206624759587e-8*V026*V032 + 9.68341366023876528e-9*V015*V02*V033 - 
      9.55704894542685233e-8*V01*V024*V033 - 1.0723884103616799e-7*V012*V022*V034 - 
      9.93836585227746956e-9*V013*V035 + 4.8703063054938864e-9*V02*V036 + 
      1.56114022070560936e-8*V014*V024*V04 - 1.89909954985575877e-9*V027*V04 + 
      2.00192681482072238e-8*V015*V022*V03*V04 - 8.38895469248809872e-8*V01*V025*V03*V04 + 
      1.77987173566655359e-9*V016*V032*V04 - 
      3.23285224281612877e-7*V012*V023*V032*V04 - 
      1.50270666980011994e-7*V013*V02*V033*V04 + 5.31274783400119321e-8*V022*V034*V04 + 
      1.73049890542628694e-8*V01*V035*V04 + 1.22542987345158214e-9*V016*V02*V042 - 
      6.17890385970812357e-8*V012*V024*V042 - 
      1.71284630285987134e-7*V013*V022*V03*V042 - 
      2.80878156156928347e-8*V014*V032*V042 + 
      7.57110438728137147e-8*V023*V032*V042 + 1.2806515617322688e-7*V01*V02*V033*V042 - 
      1.41225680290847202e-8*V014*V02*V043 + 8.35603474047208798e-9*V024*V043 + 
      9.38046625149027808e-8*V01*V022*V03*V043 + 
      3.70617082155040555e-8*V012*V032*V043 + 1.38979980604841815e-8*V012*V02*V044 - 
      4.13660814142975407e-9*V032*V044 - 1.15966243496214952e-9*V02*V045 + 
      3.51628958800994282e-9*V015*V023*V05 - 8.34998774432908832e-9*V01*V026*V05 + 
      1.87401197609968618e-9*V016*V02*V03*V05 - 9.89783807104100307e-8*V012*V024*V03*V05 - 
      1.37976642238229e-7*V013*V022*V032*V05 - 1.50967085425387661e-8*V014*V033*V05 + 
      4.29759057373092835e-8*V023*V033*V05 + 5.31546973976214333e-8*V01*V02*V034*V05 + 
      9.79863139570772624e-11*V017*V04*V05 - 7.02630735920893175e-8*V013*V023*V04*V05 - 
      6.84088766161044771e-8*V014*V02*V03*V04*V05 + 4.53671004867412281e-8*V024*V03*V04*V05 + 
      2.35184910615567518e-7*V01*V022*V032*V04*V05 + 6.09721325863324832e-8*V012*V033*V04*V05 - 
      3.20564150558353558e-9*V015*V042*V05 + 5.69609941188923212e-8*V01*V023*V042*V05 + 
      1.37028218012317002e-7*V012*V02*V03*V042*V05 - 1.39859961076650692e-8*V033*V042*V05 + 
      8.47853021505922014e-9*V013*V043*V05 - 2.01552936055205755e-8*V02*V03*V043*V05 - 
      3.13366648763871686e-9*V01*V044*V05 - 1.04166163720639294e-8*V014*V022*V052 + 
      2.69956015954098336e-9*V025*V052 - 2.58330085793726129e-9*V015*V03*V052 + 
      4.78715917087998313e-8*V01*V023*V03*V052 + 
      5.63793174436091888e-8*V012*V02*V032*V052 - 2.9383600776356961e-9*V034*V052 + 
      4.21731239654223595e-8*V012*V022*V04*V052 + 
      2.07681524916358218e-8*V013*V03*V04*V052 - 2.56786380613002093e-8*V02*V032*V04*V052 - 
      9.16729710029869223e-9*V022*V042*V052 - 
      1.57633187250810967e-8*V01*V03*V042*V052 + 4.27637441860138442e-9*V013*V02*V053 - 
      5.2224404359218289e-9*V022*V03*V053 - 4.38614696068655363e-9*V01*V032*V053 - 
      6.46673965168430089e-9*V01*V02*V04*V053 - 3.99494997353534177e-10*V012*V054 + 
      1.81955734434333532e-10*V04*V054 + 3.99409674838596407e-10*V016*V022*V06 - 
      1.0431003301698729e-8*V012*V025*V06 + 6.06642189056404743e-11*V017*V03*V06 - 
      4.77855954696384765e-8*V013*V023*V03*V06 - 2.32250277878423828e-8*V014*V02*V032*V06 + 
      1.62111803779034047e-8*V024*V032*V06 + 5.505287244419457e-8*V01*V022*V033*V06 + 
      1.06149438820031458e-8*V012*V034*V06 - 1.75099645862543264e-8*V014*V022*V04*V06 + 
      4.27154927977053744e-9*V025*V04*V06 - 4.33978855684080629e-9*V015*V03*V04*V06 + 
      8.05531790027669879e-8*V01*V023*V03*V04*V06 + 9.55327526277752113e-8*V012*V02*V032*V04*V06 - 
      4.95394613466162565e-9*V034*V04*V06 + 3.5829790696304398e-8*V012*V022*V042*V06 + 
      1.76203335311519717e-8*V013*V03*V042*V06 - 2.15354949650039887e-8*V02*V032*V042*V06 - 
      5.01445669080670866e-9*V022*V043*V06 - 8.86629346376300445e-9*V01*V03*V043*V06 - 
      2.60040365527975868e-9*V015*V02*V05*V06 + 1.22131022473066407e-8*V01*V024*V05*V06 + 
      5.88410442621935707e-8*V012*V022*V03*V05*V06 + 1.438783155986732e-8*V013*V032*V05*V06 - 
      1.21485717698657798e-8*V02*V033*V05*V06 + 2.17858954336371354e-8*V013*V02*V04*V05*V06 - 
      2.6199364758221157e-8*V022*V03*V04*V05*V06 - 2.22420204075089984e-8*V01*V032*V04*V05*V06 - 
      1.63375073043803933e-8*V01*V02*V042*V05*V06 + 1.16915374751430838e-9*V014*V052*V06 - 
      2.64403009653177083e-9*V023*V052*V06 - 1.37060208691884838e-8*V01*V02*V03*V052*V06 - 
      4.06210394333847301e-9*V012*V04*V052*V06 + 9.17023430737715776e-10*V042*V052*V06 + 
      5.17886507555759963e-10*V03*V053*V06 - 6.42642714234006087e-11*V016*V062 + 
      5.12713356558674322e-9*V012*V023*V062 + 
      7.53888501579919807e-9*V013*V02*V03*V062 - 
      4.66939828194458353e-9*V022*V032*V062 - 2.61285420173900206e-9*V01*V033*V062 + 
      9.90653896153716564e-10*V014*V04*V062 - 2.16684695625398566e-9*V023*V04*V062 - 
      1.15611782037778741e-8*V01*V02*V03*V04*V062 - 1.72204643614713198e-9*V012*V042*V062 + 
      2.55070338699924464e-10*V043*V062 - 3.54744395378099167e-9*V01*V022*V05*V062 - 
      2.85028450632095188e-9*V012*V03*V05*V062 + 1.30721071936814918e-9*V03*V04*V05*V062 + 
      4.00958262218441905e-10*V02*V052*V062 - 4.99176324286125821e-10*V012*V02*V063 + 
      1.55082715158648328e-10*V032*V063 + 2.22898033937020115e-10*V02*V04*V063 + 
      1.18699873853344444e-10*V01*V05*V063 + 2.16974213604115565e-11*V017*V02*V07 - 
      5.40417943501709903e-9*V013*V024*V07 - 1.03049112194985457e-8*V014*V022*V03*V07 + 
      2.82992660824091027e-9*V025*V03*V07 - 1.27011289999134534e-9*V015*V032*V07 + 
      2.47771140186421124e-8*V01*V023*V032*V07 + 1.92950447738465075e-8*V012*V02*V033*V07 - 
      6.13010334700889407e-10*V035*V07 - 1.88736808123289415e-9*V015*V02*V04*V07 + 
      8.95773284077813425e-9*V01*V024*V04*V07 + 4.33723866450780321e-8*V012*V022*V03*V04*V07 + 
      1.06028313287208905e-8*V013*V032*V04*V07 - 8.94937589581309056e-9*V02*V033*V04*V07 + 
      8.03387532568988885e-9*V013*V02*V042*V07 - 9.621186763472098e-9*V022*V03*V042*V07 - 
      8.20690596717339089e-9*V01*V032*V042*V07 - 4.01205446008562674e-9*V01*V02*V043*V07 - 
      1.1092641589878862e-10*V016*V05*V07 + 8.8934321039206044e-9*V012*V023*V05*V07 + 
      1.30957189103950361e-8*V013*V02*V03*V05*V07 - 8.20115748229856891e-9*V022*V032*V05*V07 - 
      4.56210569349975515e-9*V01*V033*V05*V07 + 1.72149800460836351e-9*V014*V04*V05*V07 - 
      3.87726377417136624e-9*V023*V04*V05*V07 - 2.0220579831841648e-8*V01*V02*V03*V04*V05*V07 - 
      3.00090315187239149e-9*V012*V042*V05*V07 + 4.50375403320601873e-10*V043*V05*V07 - 
      3.10658623103392034e-9*V01*V022*V052*V07 - 2.48456136955212915e-9*V012*V03*V052*V07 + 
      1.1463487571858541e-9*V03*V04*V052*V07 + 2.34762535554733894e-10*V02*V053*V07 + 
      3.43582729184104372e-9*V013*V022*V06*V07 + 1.18547425301235247e-9*V014*V03*V06*V07 - 
      2.77688806343057068e-9*V023*V03*V06*V07 - 7.13756199864560057e-9*V01*V02*V032*V06*V07 - 
      5.22631608043287862e-9*V01*V022*V04*V06*V07 - 4.21196840253792297e-9*V012*V03*V04*V06*V07 + 
      9.63797203854577068e-10*V03*V042*V06*V07 - 2.60957934744077695e-9*V012*V02*V05*V06*V07 + 
      8.15287997197083928e-10*V032*V05*V06*V07 + 1.18134096926053866e-9*V02*V04*V05*V06*V07 + 
      3.11502052229857582e-10*V01*V052*V06*V07 - 1.73037279549798118e-10*V013*V062*V07 + 
      4.2170922907670697e-10*V02*V03*V062*V07 + 2.63085966705188891e-10*V01*V04*V062*V07 + 
      2.68806747356288684e-10*V014*V02*V072 - 1.53382266455400331e-10*V024*V072 - 
      1.62010119740437514e-9*V01*V022*V03*V072 - 
      6.43604471608058537e-10*V012*V032*V072 - 
      9.63982153176219188e-10*V012*V02*V04*V072 + 3.00899320568292916e-10*V032*V04*V072 + 
      2.1745032775758309e-10*V02*V042*V072 - 1.50608906579658684e-10*V013*V05*V072 + 
      3.70176753059612665e-10*V02*V03*V05*V072 + 2.30215797641579889e-10*V01*V04*V05*V072 + 
      9.50090308519678681e-11*V022*V06*V072 + 1.63048557832402032e-10*V01*V03*V06*V072 - 
      5.138954014836295e-12*V062*V072 + 2.48758897967770192e-11*V01*V02*V073 - 
      3.00509695241274037e-12*V05*V073 + 4.4280451755941952e-13*V018*V08 - 
      1.33785560990982633e-9*V014*V023*V08 + 1.71387124331217675e-10*V026*V08 - 
      9.72559639495437938e-10*V015*V02*V03*V08 + 4.90763991641420131e-9*V01*V024*V03*V08 + 
      1.16433214611755886e-8*V012*V022*V032*V08 + 
      1.88309459978729282e-9*V013*V033*V08 - 1.22793674589569673e-9*V02*V034*V08 - 
      7.07254256117606282e-11*V016*V04*V08 + 5.82652721404267178e-9*V012*V023*V04*V08 + 
      8.55277833732601659e-9*V013*V02*V03*V04*V08 - 5.32380451144272764e-9*V022*V032*V04*V08 - 
      2.98194255700710898e-9*V01*V033*V04*V08 + 5.60749206582992815e-10*V014*V042*V08 - 
      1.23328439825600782e-9*V023*V042*V08 - 6.59565558837579339e-9*V01*V02*V03*V042*V08 - 
      6.55152654160803027e-10*V012*V043*V08 + 7.28332603021255111e-11*V044*V08 + 
      2.64280373985464114e-9*V013*V022*V05*V08 + 9.11425348972455468e-10*V014*V03*V05*V08 - 
      2.15521557145600725e-9*V023*V03*V05*V08 - 5.51903945128006319e-9*V01*V02*V032*V05*V08 - 
      4.04697466248475442e-9*V01*V022*V04*V05*V08 - 3.25295878393494051e-9*V012*V03*V04*V05*V08 + 
      7.47076599382134866e-10*V03*V042*V05*V08 - 1.00786502381453251e-9*V012*V02*V052*V08 + 
      3.15720426761199488e-10*V032*V052*V08 + 4.58193083897235425e-10*V02*V04*V052*V08 + 
      8.03678118090333361e-11*V01*V053*V08 + 4.75674311049722304e-10*V014*V02*V06*V08 - 
      2.66251567035031895e-10*V024*V06*V08 - 2.86575931143258801e-9*V01*V022*V03*V06*V08 - 
      1.1405073000981351e-9*V012*V032*V06*V08 - 1.7093371675997801e-9*V012*V02*V04*V06*V08 + 
      5.31967452811226141e-10*V032*V04*V06*V08 + 3.8193060278998328e-10*V02*V042*V06*V08 - 
      2.67013151961746173e-10*V013*V05*V06*V08 + 6.53952866707836784e-10*V02*V03*V05*V06*V08 + 
      4.07408200906976433e-10*V01*V04*V05*V06*V08 + 8.34171470929242389e-11*V022*V062*V08 + 
      1.44333265687358107e-10*V01*V03*V062*V08 - 3.02352892775963599e-12*V063*V08 + 
      2.80843619891727921e-11*V015*V07*V08 - 4.31285614236730667e-10*V01*V023*V07*V08 - 
      1.04509203264779033e-9*V012*V02*V03*V07*V08 + 1.10440712149519286e-10*V033*V07*V08 - 
      1.97415456281569499e-10*V013*V04*V07*V08 + 4.82111985939425843e-10*V02*V03*V04*V07*V08 + 
      1.50508180552319371e-10*V01*V042*V07*V08 + 1.47509606412665845e-10*V022*V05*V07*V08 + 
      2.52396595079484571e-10*V01*V03*V05*V07*V08 + 1.32037118195992703e-10*V01*V02*V06*V07*V08 - 
      1.59401386961235955e-11*V05*V06*V07*V08 + 1.22610005641182252e-11*V012*V072*V08 - 
      5.88715567119459272e-12*V04*V072*V08 - 1.06017459721247339e-10*V012*V022*V082 - 
      5.31162892578734228e-11*V013*V03*V082 + 6.66308582882360057e-11*V02*V032*V082 + 
      4.76588941899221501e-11*V022*V04*V082 + 8.26043690320186853e-11*V01*V03*V04*V082 + 
      5.11355523444654607e-11*V01*V02*V05*V082 - 3.09000590688509293e-12*V052*V082 + 
      1.08677798685781691e-11*V012*V06*V082 - 5.19528406826160834e-12*V04*V06*V082 - 
      3.25890629124482404e-12*V03*V07*V082 - 4.37517170068740584e-13*V02*V083 - 
      1.64835146936540125e-10*V015*V022*V09 + 3.45793764136157995e-10*V01*V025*V09 - 
      3.22388878534335621e-11*V016*V03*V09 + 2.80189943889264182e-9*V012*V023*V03*V09 + 
      2.04261026487676869e-9*V013*V02*V032*V09 - 8.81090672931405571e-10*V022*V033*V09 - 
      3.64752964761148189e-10*V01*V034*V09 + 1.5505707999704561e-9*V013*V022*V04*V09 + 
      5.32960300910522433e-10*V014*V03*V04*V09 - 1.25661330718114231e-9*V023*V03*V04*V09 - 
      3.24117955720727906e-9*V01*V02*V032*V04*V09 - 1.1852681129762065e-9*V01*V022*V042*V09 - 
      9.56761259908936263e-10*V012*V03*V042*V09 + 1.46022401287343066e-10*V03*V043*V09 + 
      3.28335028654464705e-10*V014*V02*V05*V09 - 1.8930956914288632e-10*V024*V05*V09 - 
      1.99457179397421526e-9*V01*V022*V03*V05*V09 - 7.91311708211819611e-10*V012*V032*V05*V09 - 
      1.18559187946897823e-9*V012*V02*V04*V05*V09 + 3.70961374605005304e-10*V032*V04*V05*V09 + 
      2.68297756745542815e-10*V02*V042*V05*V09 - 9.2515876682457129e-11*V013*V052*V09 + 
      2.28259826003975527e-10*V02*V03*V052*V09 + 1.41866770162645143e-10*V01*V04*V052*V09 + 
      2.22907557048817969e-11*V015*V06*V09 - 3.42941566153143681e-10*V01*V023*V06*V09 - 
      8.32001507167224823e-10*V012*V02*V03*V06*V09 + 8.78991395633895806e-11*V033*V06*V09 - 
      1.57180213138673668e-10*V013*V04*V06*V09 + 3.83419071477615378e-10*V02*V03*V04*V06*V09 + 
      1.19789530206304927e-10*V01*V042*V06*V09 + 1.17264278886932301e-10*V022*V05*V06*V09 + 
      2.00949046477051353e-10*V01*V03*V05*V06*V09 + 5.2546656638601498e-11*V01*V02*V062*V09 - 
      6.34219856721068642e-12*V05*V062*V09 - 1.90369660472981793e-10*V012*V022*V07*V09 - 
      9.54136549574522074e-11*V013*V03*V07*V09 + 1.19975271832697301e-10*V02*V032*V07*V09 + 
      8.63018727139487998e-11*V022*V04*V07*V09 + 1.48586651263142707e-10*V01*V03*V04*V07*V09 + 
      9.20144466841806688e-11*V01*V02*V05*V07*V09 - 5.56267504588345565e-12*V052*V07*V09 + 
      1.95324553613661958e-11*V012*V06*V07*V09 - 9.36876349615123451e-12*V04*V06*V07*V09 - 
      2.93308400276163431e-12*V03*V072*V09 - 3.88925566461286497e-11*V013*V02*V08*V09 + 
      4.79600290517914413e-11*V022*V03*V08*V09 + 4.07079363187643114e-11*V01*V032*V08*V09 + 
      6.01510731299387967e-11*V01*V02*V04*V08*V09 + 1.51079218591616224e-11*V012*V05*V08*V09 - 
      7.2674559114300349e-12*V04*V05*V08*V09 - 5.18826488998689133e-12*V03*V06*V08*V09 - 
      2.36764234511997115e-12*V02*V07*V08*V09 - 4.11387566330200618e-13*V01*V082*V09 - 
      1.26219942002800907e-12*V014*V092 + 2.8537383922813534e-12*V023*V092 + 
      1.48692305322023273e-11*V01*V02*V03*V092 + 4.45607965803086444e-12*V012*V04*V092 - 
      1.06786407528361483e-12*V042*V092 - 1.81045474064775228e-12*V03*V05*V092 - 
      9.42014522604963244e-13*V02*V06*V092 - 3.70069521128519166e-13*V01*V07*V092 - 
      9.62517188168632957e-12*V016*V02*V10 + 2.3015694245723401e-10*V012*V024*V10 + 
      6.70941372490118359e-10*V013*V022*V03*V10 + 1.1480421542309853e-10*V014*V032*V10 - 
      2.84804471273139971e-10*V023*V032*V10 - 4.80920728760762741e-10*V01*V02*V033*V10 + 
      1.74125454837983133e-10*V014*V02*V04*V10 - 9.83217365320966071e-11*V024*V04*V10 - 
      1.06220212320912648e-9*V01*V022*V03*V04*V10 - 4.22803348972879228e-10*V012*V032*V04*V10 - 
      3.16914658687702337e-10*V012*V02*V042*V10 + 9.88235079573683299e-11*V032*V042*V10 + 
      4.72330580222764217e-11*V02*V043*V10 + 1.39388397625663201e-11*V015*V05*V10 - 
      2.16987041210307743e-10*V01*V023*V05*V10 - 5.24340665172594658e-10*V012*V02*V03*V05*V10 + 
      5.5583436465140527e-11*V033*V05*V10 - 9.89222489362033276e-11*V013*V04*V05*V10 + 
      2.42914382497724878e-10*V02*V03*V04*V05*V10 + 7.57467217293811935e-11*V01*V042*V05*V10 + 
      3.71890626271298429e-11*V022*V052*V10 + 6.34857888806340332e-11*V01*V03*V052*V10 - 
      1.37749948542499838e-10*V012*V022*V06*V10 - 6.89898336794149189e-11*V013*V03*V06*V10 + 
      8.65967464965198305e-11*V02*V032*V06*V10 + 6.19103788007259522e-11*V022*V04*V06*V10 + 
      1.07380768914807285e-10*V01*V03*V04*V06*V10 + 6.64736463478337488e-11*V01*V02*V05*V06*V10 - 
      4.01637749845117034e-12*V052*V06*V10 + 7.06554901187338597e-12*V012*V062*V10 - 
      3.37610521518621009e-12*V04*V062*V10 - 3.17235160864232235e-11*V013*V02*V07*V10 + 
      3.91851771834627581e-11*V022*V03*V07*V10 + 3.32316178961705747e-11*V01*V032*V07*V10 + 
      4.9119851375945882e-11*V01*V02*V04*V07*V10 + 1.23311190808217009e-11*V012*V05*V07*V10 - 
      5.93534045393409334e-12*V04*V05*V07*V10 - 4.23691167642956704e-12*V03*V06*V07*V10 - 
      9.67072738309773911e-13*V02*V072*V10 - 2.29204394137746031e-12*V014*V08*V10 + 
      5.15098812636614658e-12*V023*V08*V10 + 2.69936407681061786e-11*V01*V02*V03*V08*V10 + 
      8.0947205339313216e-12*V012*V04*V08*V10 - 1.9344749182416599e-12*V042*V08*V10 - 
      3.28543930568488374e-12*V03*V05*V08*V10 - 1.70642818407691646e-12*V02*V06*V08*V10 - 
      6.71842057153603506e-13*V01*V07*V08*V10 + 4.91113619404217309e-12*V01*V022*V09*V10 + 
      3.96519467929314528e-12*V012*V03*V09*V10 - 1.93399244403559764e-12*V03*V04*V09*V10 - 
      1.19473241718193766e-12*V02*V05*V09*V10 - 5.35191368162743611e-13*V01*V06*V09*V10 + 
      5.21656558096304811e-15*V092*V10 + 6.62793960794148948e-13*V012*V02*V102 - 
      2.18496203813111231e-13*V032*V102 - 3.18021774161830446e-13*V02*V04*V102 - 
      1.69362231608752155e-13*V01*V05*V102 + 4.73160579050964191e-15*V08*V102 - 
      2.09749508317619773e-13*V017*V11 + 6.74347906116275928e-11*V013*V023*V11 + 
      6.85939155950927107e-11*V014*V02*V03*V11 - 4.17902267206677153e-11*V024*V03*V11 - 
      2.1731857822775088e-10*V01*V022*V032*V11 - 5.70112786775786726e-11*V012*V033*V11 + 
      6.74024218603440095e-12*V015*V04*V11 - 1.05682023547627407e-10*V01*V023*V04*V11 - 
      2.56702414596368128e-10*V012*V02*V03*V04*V11 + 2.71858135636246717e-11*V033*V04*V11 - 
      2.42303319909972094e-11*V013*V042*V11 + 5.92167081153328239e-11*V02*V03*V042*V11 + 
      1.23522296638299964e-11*V01*V043*V11 - 7.94956886745053048e-11*V012*V022*V05*V11 - 
      3.97772402002834055e-11*V013*V03*V05*V11 + 5.02621728512514009e-11*V02*V032*V05*V11 + 
      3.61986982432801641e-11*V022*V04*V05*V11 + 6.21999968838437168e-11*V01*V03*V04*V05*V11 + 
      1.92660745764212173e-11*V01*V02*V052*V11 - 7.77042349317061748e-13*V053*V11 - 
      2.10177571695828281e-11*V013*V02*V06*V11 + 2.59130886755391951e-11*V022*V03*V06*V11 + 
      2.2015955039070288e-11*V01*V032*V06*V11 + 3.25214247925367166e-11*V01*V02*V04*V06*V11 + 
      8.17252685214397471e-12*V012*V05*V06*V11 - 3.92761700397486609e-12*V04*V05*V06*V11 - 
      1.40240130202731491e-12*V03*V062*V11 - 1.71253420193648365e-12*V014*V07*V11 + 
      3.87870661715828861e-12*V023*V07*V11 + 2.0199387345982931e-11*V01*V02*V03*V07*V11 + 
      6.05239548847634198e-12*V012*V04*V07*V11 - 1.45056681582134048e-12*V042*V07*V11 - 
      2.45910908171086762e-12*V03*V05*V07*V11 - 1.27980794636312446e-12*V02*V06*V07*V11 - 
      2.51363104325421768e-13*V01*V072*V11 + 4.08499083403384318e-12*V01*V022*V08*V11 + 
      3.2991768979620935e-12*V012*V03*V08*V11 - 1.60836022410102871e-12*V03*V04*V08*V11 - 
      9.93469854243646799e-13*V02*V05*V08*V11 - 4.45185772967880226e-13*V01*V06*V08*V11 + 
      1.21426182645472652e-12*V012*V02*V09*V11 - 4.0051438766072584e-13*V032*V09*V11 - 
      5.83938956032071275e-13*V02*V04*V09*V11 - 3.10400016127577045e-13*V01*V05*V09*V11 + 8.67699638375433282e-15*V08*V09*V11 + 
      1.03298080509654978e-13*V013*V10*V11 - 2.65102496788914234e-13*V02*V03*V10*V11 - 
      1.66321564985940782e-13*V01*V04*V10*V11 + 7.08823676269778083e-15*V07*V10*V11 - 
      1.99819749783849114e-14*V022*V112 - 3.42902957155963818e-14*V01*V03*V112 + 
      2.34800551587704945e-15*V06*V112 + 9.44164106190841227e-12*V014*V022*V12 - 
      2.20259071248210634e-12*V025*V12 + 2.43348272149979236e-12*V015*V03*V12 - 
      4.01197114898756025e-11*V01*V023*V03*V12 - 4.79568788669085877e-11*V012*V02*V032*V12 + 
      2.58259556211249994e-12*V034*V12 - 3.59532582927353745e-11*V012*V022*V04*V12 - 
      1.79803376393198365e-11*V013*V03*V04*V12 + 2.26496295114767611e-11*V02*V032*V04*V12 + 
      8.08120012644868402e-12*V022*V042*V12 + 1.40567432330032326e-11*V01*V03*V042*V12 - 
      1.11822403404674748e-11*V013*V02*V05*V12 + 1.3899103160912314e-11*V022*V03*V05*V12 + 
      1.17643124604792878e-11*V01*V032*V05*V12 + 1.74021877459451961e-11*V01*V02*V04*V05*V12 + 
      2.18142417638262221e-12*V012*V052*V12 - 1.05202575182152533e-12*V04*V052*V12 - 
      1.04626071311744807e-12*V014*V06*V12 + 2.35324325374413554e-12*V023*V06*V12 + 
      1.23461144964908204e-11*V01*V02*V03*V06*V12 + 3.7028396294601924e-12*V012*V04*V06*V12 - 
      8.83999537823541165e-13*V042*V06*V12 - 1.50196887543533255e-12*V03*V05*V06*V12 - 
      3.89979751854518848e-13*V02*V062*V12 + 2.82167606968812044e-12*V01*V022*V07*V12 + 
      2.27691962382878011e-12*V012*V03*V07*V12 - 1.11068146333201862e-12*V03*V04*V07*V12 - 
      6.86263413349139655e-13*V02*V05*V07*V12 - 3.07346788275866606e-13*V01*V06*V07*V12 + 
      9.32570483214821455e-13*V012*V02*V08*V12 - 3.07306872467709447e-13*V032*V08*V12 - 
      4.47217470105025973e-13*V02*V04*V08*V12 - 2.38219660370896245e-13*V01*V05*V08*V12 + 
      3.32670968361744601e-15*V082*V12 + 8.73314695623281342e-14*V013*V09*V12 - 
      2.24162502890405889e-13*V02*V03*V09*V12 - 1.40618575675959814e-13*V01*V04*V09*V12 + 5.99226672839614513e-15*V07*V09*V12 - 
      3.68080854296587473e-14*V022*V10*V12 - 6.32743623508256207e-14*V01*V03*V10*V12 + 
      4.32961025146162615e-15*V06*V10*V12 - 1.93832637864596879e-14*V01*V02*V11*V12 + 2.51819033148391868e-15*V05*V11*V12 - 
      1.11518782684456822e-15*V012*V122 + 5.69886352327506205e-16*V04*V122 + 
      6.11769399259724337e-13*V015*V02*V13 - 2.56113606960536598e-12*V01*V024*V13 - 
      1.24784542270071951e-11*V012*V022*V03*V13 - 3.0965624319925974e-12*V013*V032*V13 + 
      2.67495038092800385e-12*V02*V033*V13 - 4.69686589583308908e-12*V013*V02*V04*V13 + 
      5.80522964060048673e-12*V022*V03*V04*V13 + 4.94295042028504447e-12*V01*V032*V04*V13 + 
      3.64847196686029732e-12*V01*V02*V042*V13 - 5.16479665657639014e-13*V014*V05*V13 + 
      1.18035900158523292e-12*V023*V05*V13 + 6.13205893736154949e-12*V01*V02*V03*V05*V13 + 
      1.83560342669867429e-12*V012*V04*V05*V13 - 4.40724623962071141e-13*V042*V05*V13 - 
      3.73436056829920745e-13*V03*V052*V13 + 1.60100402980824299e-12*V01*V022*V06*V13 + 
      1.29351957874461575e-12*V012*V03*V06*V13 - 6.2993047449704062e-13*V03*V04*V06*V13 - 
      3.89057578485850009e-13*V02*V05*V06*V13 - 8.72403249893440794e-14*V01*V062*V13 + 
      5.97596999217374583e-13*V012*V02*V07*V13 - 1.97053423762792739e-13*V032*V07*V13 - 
      2.87367076260369194e-13*V02*V04*V07*V13 - 1.52715129066380491e-13*V01*V05*V07*V13 + 
      6.22716935277264714e-14*V013*V08*V13 - 1.59696879544224903e-13*V02*V03*V08*V13 - 
      1.00209677832945464e-13*V01*V04*V08*V13 + 4.26820099280462187e-15*V07*V08*V13 - 
      2.89484172101587523e-14*V022*V09*V13 - 4.96724712995905341e-14*V01*V03*V09*V13 + 
      3.39999950690605464e-15*V06*V09*V13 - 1.66048795816438788e-14*V01*V02*V10*V13 + 2.15667455498179201e-15*V05*V10*V13 - 
      2.07068718034353406e-15*V012*V11*V13 + 1.05874818066517205e-15*V04*V11*V13 + 
      4.06691627314171604e-16*V03*V12*V13 + 5.32310427834168199e-17*V02*V132 + 
      1.45659380776124842e-14*V016*V14 - 1.01032372280896699e-12*V012*V023*V14 - 
      1.50915784517176304e-12*V013*V02*V03*V14 + 9.65111899530613654e-13*V022*V032*V14 + 
      5.40200388116406428e-13*V01*V033*V14 - 2.02118223368261928e-13*V014*V04*V14 + 
      4.56641952201875545e-13*V023*V04*V14 + 2.4038413774659864e-12*V01*V02*V03*V04*V14 + 
      3.60647266127065417e-13*V012*V042*V14 - 5.73261971211986072e-14*V043*V14 + 
      7.43303685708072962e-13*V01*V022*V05*V14 + 5.98739331928716999e-13*V012*V03*V05*V14 - 
      2.92528783395445379e-13*V03*V04*V05*V14 - 9.04206954985800713e-14*V02*V052*V14 + 
      3.17037274293073352e-13*V012*V02*V06*V14 - 1.04370806006241768e-13*V032*V06*V14 - 
      1.51802857255092993e-13*V02*V04*V06*V14 - 8.09320559072438323e-14*V01*V05*V06*V14 + 
      3.72465173984538715e-14*V013*V07*V14 - 9.5617863329913746e-14*V02*V03*V07*V14 - 
      5.99685041663519115e-14*V01*V04*V07*V14 + 1.27699020344254614e-15*V072*V14 - 
      1.92155649275381042e-14*V022*V08*V14 - 3.30439977799119423e-14*V01*V03*V08*V14 + 
      2.25891019744841029e-15*V06*V08*V14 - 1.2167497565016697e-14*V01*V02*V09*V14 + 1.57972960475843609e-15*V05*V09*V14 - 
      1.65587580125235231e-15*V012*V10*V14 + 8.45759601392870242e-16*V04*V10*V14 + 
      3.52368370073695409e-16*V03*V11*V14 + 9.92999683375833231e-17*V02*V12*V14 + 2.24013315456489625e-17*V01*V13*V14 - 
      1.72619032252818905e-13*V013*V022*V15 - 6.05499712869795485e-14*V014*V03*V15 + 
      1.4410021890658404e-13*V023*V03*V15 + 3.70558310772070201e-13*V01*V02*V032*V15 + 
      2.72933612395391299e-13*V01*V022*V04*V15 + 2.20711675156957162e-13*V012*V03*V04*V15 - 
      5.37076333235959859e-14*V03*V042*V15 + 1.37656207021258872e-13*V012*V02*V05*V15 - 
      4.54363618080454486e-14*V032*V05*V15 - 6.63188309520237084e-14*V02*V04*V05*V15 - 
      1.76018844155561038e-14*V01*V052*V15 + 1.8532735249020438e-14*V013*V06*V15 - 
      4.74740349160641406e-14*V02*V03*V06*V15 - 2.98027690632205116e-14*V01*V04*V06*V15 - 
      1.08112031383457453e-14*V022*V07*V15 - 1.85425990974611844e-14*V01*V03*V07*V15 + 
      1.26801589164715782e-15*V06*V07*V15 - 7.58950805876131731e-15*V01*V02*V08*V15 + 9.8458763702524588e-16*V05*V08*V15 - 
      1.13749039570165188e-15*V012*V09*V15 + 5.81144411006753204e-16*V04*V09*V15 + 
      2.64050499632967369e-16*V03*V10*V15 + 8.07028559738939966e-17*V02*V11*V15 + 1.95990185006105907e-17*V01*V12*V15 - 
      4.41994159530723578e-20*V152 - 1.2982683938741562e-14*V014*V02*V16 + 
      7.48285110418598444e-15*V024*V16 + 7.95515240028311156e-14*V01*V022*V03*V16 + 
      3.17835101870059889e-14*V012*V032*V16 + 4.78014581746824191e-14*V012*V02*V04*V16 - 
      1.57335308346834706e-14*V032*V04*V16 - 1.14248443741623141e-14*V02*V042*V16 + 
      7.56916107267071928e-15*V013*V05*V16 - 1.94858055016765833e-14*V02*V03*V05*V16 - 
      1.22111977484107791e-14*V01*V04*V05*V16 - 5.04266971960898918e-15*V022*V06*V16 - 
      8.68031514418432773e-15*V01*V03*V06*V16 + 2.96178628245633222e-16*V062*V16 - 
      4.01106926748115807e-15*V01*V02*V07*V16 + 5.20043795174939865e-16*V05*V07*V16 - 
      6.68262100187125589e-16*V012*V08*V16 + 3.40796007356322708e-16*V04*V08*V16 + 
      1.70710912079832186e-16*V03*V09*V16 + 5.68961989730199889e-17*V02*V10*V16 + 1.49855395947664554e-17*V01*V11*V16 - 
      8.31855677458577055e-20*V14*V16 - 3.48315910551602883e-16*V015*V17 + 
      5.3532084226852838e-15*V01*V023*V17 + 1.30229815262285386e-14*V012*V02*V03*V17 - 
      1.44935168659944404e-15*V033*V17 + 2.4857843910815798e-15*V013*V04*V17 - 
      6.36720910065059732e-15*V02*V03*V04*V17 - 2.00106485371172764e-15*V01*V042*V17 - 
      1.9623831906871225e-15*V022*V05*V17 - 3.36002286116988272e-15*V01*V03*V05*V17 - 
      1.77386214055104692e-15*V01*V02*V06*V17 + 2.29685692478969508e-16*V05*V06*V17 - 
      3.33522536760390687e-16*V012*V07*V17 + 1.70175681633904587e-16*V04*V07*V17 + 
      9.46420694940513625e-17*V03*V08*V17 + 3.47703530548843402e-17*V02*V09*V17 + 9.98650490727623037e-18*V01*V10*V17 - 
      6.93324171495697322e-20*V13*V17 + 1.26377607156303968e-15*V012*V022*V18 + 
      6.37636756166705928e-16*V013*V03*V18 - 8.37476717118542532e-16*V02*V032*V18 - 
      6.05509142985150212e-16*V022*V04*V18 - 1.04512085644600794e-15*V01*V03*V04*V18 - 
      6.51538098487688052e-16*V01*V02*V05*V18 + 4.2183745764120426e-17*V052*V18 - 
      1.39965489889902678e-16*V012*V06*V18 + 7.11959618138135748e-17*V04*V06*V18 + 
      4.47664484815287733e-17*V03*V07*V18 + 1.82573230342884465e-17*V02*V08*V18 + 5.78002813219706081e-18*V01*V09*V18 - 
      5.10765182941887713e-20*V12*V18 + 1.1817861250857955e-16*V013*V02*V19 - 
      1.52524337214245058e-16*V022*V03*V19 - 1.2956485849658582e-16*V01*V032*V19 - 
      1.92509582047974981e-16*V01*V02*V04*V19 - 4.87852597459248243e-17*V012*V05*V19 + 
      2.48851940330947306e-17*V04*V05*V19 + 1.78217883626003739e-17*V03*V06*V19 + 8.21580161786003365e-18*V02*V07*V19 + 
      2.88732953567971446e-18*V01*V08*V19 - 3.32065786634276583e-20*V11*V19 + 3.73195618448145947e-18*V014*V20 - 
      8.74080743031989095e-18*V023*V20 - 4.56292526435938585e-17*V01*V02*V03*V20 - 
      1.37812519560269486e-17*V012*V04*V20 + 3.49442732489956827e-18*V042*V20 + 
      5.93123291381005684e-18*V03*V05*V20 + 3.11377394730746575e-18*V02*V06*V20 + 1.23683100985051744e-18*V01*V07*V20 - 
      1.89686718341444172e-20*V10*V20 - 3.82410325076495229e-18*V01*V022*V21 - 
      3.09537353490632986e-18*V012*V03*V21 + 1.59461380838318852e-18*V03*V04*V21 + 
      9.91763693091799611e-19*V02*V05*V21 + 4.48611712885502124e-19*V01*V06*V21 - 9.48759379878892284e-21*V09*V21 - 
      5.02201511245035903e-19*V012*V02*V22 + 1.73751375889880365e-19*V032*V22 + 
      2.54695096442820697e-19*V02*V04*V22 + 1.36438307714898283e-19*V01*V05*V22 - 4.1219245473965876e-21*V08*V22 - 
      1.9965197694756779e-20*V013*V23 + 5.34956888638145832e-20*V02*V03*V23 + 3.37705678168462146e-20*V01*V04*V23 - 
      1.54689017019247663e-21*V07*V23 + 3.93045271232202421e-21*V022*V24 + 6.75311859330487918e-21*V01*V03*V24 - 
      4.93883128139586493e-22*V06*V24 + 9.70095812754639734e-22*V01*V02*V25 - 1.33270403343438952e-22*V05*V25 + 
      5.47634733006651463e-23*V012*V26 - 2.93249566706787557e-23*V04*V26 - 5.28836683858780465e-24*V03*V27 - 
      6.79447559561602311e-25*V02*V28 - 7.27979528101716762e-26*V01*V29 + 3.67666428334200385e-29*V32) + 
   delta6*eps13*(1.65299241725011838e-9*V02*V036 + 
      1.38412330601961887e-8*V022*V034*V04 + 5.44985440544305925e-9*V01*V035*V04 + 
      1.34108770484555025e-8*V023*V032*V042 + 
      3.18295977223590002e-8*V01*V02*V033*V042 + 5.22929181665348026e-10*V024*V043 + 
      1.6771240568429414e-8*V01*V022*V03*V043 + 8.82209927607268162e-9*V012*V032*V043 + 
      2.55159137891897729e-9*V012*V02*V044 - 3.04874291577266786e-9*V032*V044 - 
      5.49761548927799316e-10*V02*V045 + 9.27592964607305442e-9*V023*V033*V05 + 
      1.42449846252839573e-8*V01*V02*V034*V05 + 6.32078107755077287e-9*V024*V03*V04*V05 + 
      4.87597195028540828e-8*V01*V022*V032*V04*V05 + 1.5278029055829683e-8*V012*V033*V04*V05 + 
      8.04652622907330149e-9*V01*V023*V042*V05 + 2.74580639339109597e-8*V012*V02*V03*V042*V05 - 
      1.14040427858186809e-8*V033*V042*V05 + 1.64853912404816738e-9*V013*V043*V05 - 
      1.2479363034687977e-8*V02*V03*V043*V05 - 1.91923884678694495e-9*V01*V044*V05 + 
      2.9349207013615954e-10*V025*V052 + 8.22023171581799581e-9*V01*V023*V03*V052 + 
      1.20398180259875802e-8*V012*V02*V032*V052 - 2.56494314147887139e-9*V034*V052 + 
      7.06303846403804599e-9*V012*V022*V04*V052 + 
      4.18353977355287542e-9*V013*V03*V04*V052 - 1.79914303949588447e-8*V02*V032*V04*V052 - 
      4.71917437360211881e-9*V022*V042*V052 - 
      1.06534111489100329e-8*V01*V03*V042*V052 + 7.36504127000701428e-10*V013*V02*V053 - 
      3.12083860944690878e-9*V022*V03*V053 - 3.16201102910204584e-9*V01*V032*V053 - 
      3.74837088702614391e-9*V01*V02*V04*V053 - 2.3914641759682513e-10*V012*V054 + 
      2.12529819577118637e-10*V04*V054 + 2.3403743687526164e-9*V024*V032*V06 + 
      1.12394919004888551e-8*V01*V022*V033*V06 + 2.56518364779073092e-9*V012*V034*V06 + 
      2.1377417119212198e-10*V025*V04*V06 + 1.17542155193462181e-8*V01*V023*V03*V04*V06 + 
      1.87010797223958528e-8*V012*V02*V032*V04*V06 - 4.03012757585034298e-9*V034*V04*V06 + 
      5.38293469895076735e-9*V012*V022*V042*V06 + 
      3.31276694633665213e-9*V013*V03*V042*V06 - 1.3574649187066326e-8*V02*V032*V042*V06 - 
      1.99586494018127562e-9*V022*V043*V06 - 5.49299091591485691e-9*V01*V03*V043*V06 + 
      1.40422462125156984e-9*V01*V024*V05*V06 + 9.68273918898508652e-9*V012*V022*V03*V05*V06 + 
      2.78594595573925018e-9*V013*V032*V05*V06 - 8.52255311341051862e-9*V02*V033*V05*V06 + 
      3.48673243138275131e-9*V013*V02*V04*V05*V06 - 1.38163939439206244e-8*V022*V03*V04*V05*V06 - 
      1.49673481909401681e-8*V01*V032*V04*V05*V06 - 8.52864204194506626e-9*V01*V02*V042*V05*V06 + 
      1.83541696398988688e-10*V014*V052*V06 - 1.1546996614304574e-9*V023*V052*V06 - 
      7.94167223625297521e-9*V01*V02*V03*V052*V06 - 2.2779988712378314e-9*V012*V04*V052*V06 + 
      9.86116932394093112e-10*V042*V052*V06 + 6.09706888293184372e-10*V03*V053*V06 + 
      6.29177335853046002e-10*V012*V023*V062 + 
      1.16582633588763194e-9*V013*V02*V03*V062 - 
      2.50823135561480131e-9*V022*V032*V062 - 1.74412443265324682e-9*V01*V033*V062 + 
      1.46860320781447579e-10*V014*V04*V062 - 7.21851358968479499e-10*V023*V04*V062 - 
      6.10906542412836727e-9*V01*V02*V03*V04*V062 - 9.00272927503056589e-10*V012*V042*V062 + 
      2.42019645270423787e-10*V043*V062 - 1.57299965738742328e-9*V01*V022*V05*V062 - 
      1.58127715231108352e-9*V012*V03*V05*V062 + 1.42717552482394683e-9*V03*V04*V05*V062 + 
      3.77289117736286565e-10*V02*V052*V062 - 2.22244165314694417e-10*V012*V02*V063 + 
      1.71217461009421345e-10*V032*V063 + 1.8376217005164125e-10*V02*V04*V063 + 
      1.11043789513201989e-10*V01*V05*V063 + 2.79516257272532895e-10*V025*V03*V07 + 
      3.8533936905572584e-9*V01*V023*V032*V07 + 3.70476943251936423e-9*V012*V02*V033*V07 - 
      5.05255432851904134e-10*V035*V07 + 9.02968725364396125e-10*V01*V024*V04*V07 + 
      6.57402908281925381e-9*V012*V022*V03*V04*V07 + 1.91690834821799661e-9*V013*V032*V04*V07 - 
      5.9296575144261533e-9*V02*V033*V04*V07 + 1.19432932864222279e-9*V013*V02*V042*V07 - 
      4.69393644944482768e-9*V022*V03*V042*V07 - 5.23488341843352904e-9*V01*V032*V042*V07 - 
      1.94897289818485358e-9*V01*V02*V043*V07 + 1.12020856186591881e-9*V012*V023*V05*V07 + 
      2.02571821434843784e-9*V013*V02*V03*V05*V07 - 4.6315986801641047e-9*V022*V032*V05*V07 - 
      3.09548282291966115e-9*V01*V033*V05*V07 + 2.53045001191738788e-10*V014*V04*V05*V07 - 
      1.55477731533542296e-9*V023*V04*V05*V07 - 1.10580407043791035e-8*V01*V02*V03*V04*V05*V07 - 
      1.59533627447735581e-9*V012*V042*V05*V07 + 4.6010699649585559e-10*V043*V05*V07 - 
      1.44539453478443201e-9*V01*V022*V052*V07 - 1.39581069686466409e-9*V012*V03*V052*V07 + 
      1.29320714327156034e-9*V03*V04*V052*V07 + 2.30126800350706285e-10*V02*V053*V07 + 
      4.1986343552739621e-10*V013*V022*V06*V07 + 1.66509009891878224e-10*V014*V03*V06*V07 - 
      1.146638864482204e-9*V023*V03*V06*V07 - 3.8936520003242313e-9*V01*V02*V032*V06*V07 - 
      2.15038070746904231e-9*V01*V022*V04*V06*V07 - 2.21904170570482477e-9*V012*V03*V04*V06*V07 + 
      1.00232344719667175e-9*V03*V042*V06*V07 - 1.18377161000727918e-9*V012*V02*V05*V06*V07 + 
      9.25557775202590192e-10*V032*V05*V06*V07 + 1.05328385412173983e-9*V02*V04*V05*V06*V07 + 
      2.9907676006314363e-10*V01*V052*V06*V07 - 7.53615391876591318e-11*V013*V062*V07 + 
      3.82992829091679056e-10*V02*V03*V062*V07 + 2.3478771488804818e-10*V01*V04*V062*V07 + 
      3.04398763759249049e-11*V014*V02*V072 - 4.72117729854580865e-11*V024*V072 - 
      7.09141258981743529e-10*V01*V022*V03*V072 - 
      3.38383710927741947e-10*V012*V032*V072 - 
      4.12616644891592206e-10*V012*V02*V04*V072 + 3.27213086168344336e-10*V032*V04*V072 + 
      1.83077374400438577e-10*V02*V042*V072 - 6.59478496412861828e-11*V013*V05*V072 + 
      3.49640824354352004e-10*V02*V03*V05*V072 + 2.11561836854160121e-10*V01*V04*V05*V072 + 
      6.93726837337295552e-11*V022*V06*V072 + 1.50274837672879364e-10*V01*V03*V06*V072 - 
      6.54887605391839151e-12*V062*V072 + 1.90111202989630991e-11*V01*V02*V073 - 
      3.94746966512298185e-12*V05*V073 + 6.09093335156147408e-12*V026*V08 + 
      5.2636774648695792e-10*V01*V024*V03*V08 + 1.69671234867504089e-9*V012*V022*V032*V08 + 
      3.17818017383597536e-10*V013*V033*V08 - 8.12629790789238875e-10*V02*V034*V08 + 
      6.46012362497035845e-10*V012*V023*V04*V08 + 1.2000954023108889e-9*V013*V02*V03*V04*V08 - 
      2.68755864066184612e-9*V022*V032*V04*V08 - 1.8824518802405811e-9*V01*V033*V04*V08 + 
      7.54756663349645166e-11*V014*V042*V08 - 3.80801989155679947e-10*V023*V042*V08 - 
      3.27743942129616699e-9*V01*V02*V03*V042*V08 - 3.22435599953217546e-10*V012*V043*V08 + 
      6.61017147773208875e-11*V044*V08 + 3.15343087900677837e-10*V013*V022*V05*V08 + 
      1.24181582093794721e-10*V014*V03*V05*V08 - 9.04188065492352925e-10*V023*V03*V05*V08 - 
      3.0040038302645991e-9*V01*V02*V032*V05*V08 - 1.68283731729362183e-9*V01*V022*V04*V05*V08 - 
      1.70326664562076568e-9*V012*V03*V04*V05*V08 + 7.83578748184026923e-10*V03*V042*V05*V08 - 
      4.55175440631117712e-10*V012*V02*V052*V08 + 3.59658347646397295e-10*V032*V052*V08 + 
      4.13180586387259782e-10*V02*V04*V052*V08 + 7.73362743234710884e-11*V01*V053*V08 + 
      5.27013155206073566e-11*V014*V02*V06*V08 - 6.84689576973796727e-11*V024*V06*V08 - 
      1.20759245000073034e-9*V01*V022*V03*V06*V08 - 5.88427834527953767e-10*V012*V032*V06*V08 - 
      7.14790921362060381e-10*V012*V02*V04*V06*V08 + 5.64389926867821916e-10*V032*V04*V06*V08 + 
      3.00471476871286937e-10*V02*V042*V06*V08 - 1.15057682150711465e-10*V013*V05*V06*V08 + 
      5.9924804299535571e-10*V02*V03*V05*V06*V08 + 3.65540311783518363e-10*V01*V04*V05*V06*V08 + 
      5.66735473171518737e-11*V022*V062*V08 + 1.30295249697215972e-10*V01*V03*V062*V08 - 
      3.72739486227765171e-12*V063*V08 + 2.7861087387299354e-12*V015*V07*V08 - 
      1.39897526666398188e-10*V01*V023*V07*V08 - 4.41644533093685594e-10*V012*V02*V03*V07*V08 + 
      1.20985720716827986e-10*V033*V07*V08 - 8.08821159417478177e-11*V013*V04*V07*V08 + 
      4.19120793516952112e-10*V02*V03*V04*V07*V08 + 1.28639294701972478e-10*V01*V042*V07*V08 + 
      1.09201923531750455e-10*V022*V05*V07*V08 + 2.32953001308419315e-10*V01*V03*V05*V07*V08 + 
      9.80448459763113357e-11*V01*V02*V06*V07*V08 - 2.04810538021669969e-11*V05*V06*V07*V08 + 
      9.15890383820060886e-12*V012*V072*V08 - 7.25760393961260053e-12*V04*V072*V08 - 
      3.51318043592475557e-11*V012*V022*V082 - 2.10479658012154364e-11*V013*V03*V082 + 
      5.91740926179955156e-11*V02*V032*V082 + 3.07807752589410277e-11*V022*V04*V082 + 
      7.14457374773428863e-11*V01*V03*V04*V082 + 3.81938013880300072e-11*V01*V02*V05*V082 - 
      3.99999100841150985e-12*V052*V082 + 7.98556074491788708e-12*V012*V06*V082 - 
      6.18936358597806188e-12*V04*V06*V082 - 4.10446024429829721e-12*V03*V07*V082 - 
      4.4264013459104522e-13*V02*V083 + 2.32930214393777413e-11*V01*V025*V09 + 
      3.01001984197060529e-10*V012*V023*V03*V09 + 2.65919375151097257e-10*V013*V02*V032*V09 - 
      4.59107130935074397e-10*V022*V033*V09 - 2.26789990403583351e-10*V01*V034*V09 + 
      1.65094806537096671e-10*V013*V022*V04*V09 + 6.5706048470292913e-11*V014*V03*V04*V09 - 
      4.67023676442611738e-10*V023*V03*V04*V09 - 1.62966619665228934e-9*V01*V02*V032*V04*V09 - 
      4.41032537052533317e-10*V01*V022*V042*V09 - 4.65827675810928194e-10*V012*V03*V042*V09 + 
      1.43191814352310845e-10*V03*V043*V09 + 3.48370016871977343e-11*V014*V02*V05*V09 - 
      5.71502821587498283e-11*V024*V05*V09 - 8.52801947297938122e-10*V01*V022*V03*V05*V09 - 
      4.05242381352773127e-10*V012*V032*V05*V09 - 4.94777597563136522e-10*V012*V02*V04*V05*V09 + 
      3.99696083639422689e-10*V032*V04*V05*V09 + 2.24305200835768743e-10*V02*V042*V05*V09 - 
      3.93635658807944627e-11*V013*V052*V09 + 2.13611591267920048e-10*V02*V03*V052*V09 + 
      1.28977256490297231e-10*V01*V04*V052*V09 + 2.13933456676174998e-12*V015*V06*V09 - 
      1.0728446401062576e-10*V01*V023*V06*V09 - 3.44335379363673659e-10*V012*V02*V03*V06*V09 + 
      9.50727055507617348e-11*V033*V06*V09 - 6.32319716824539363e-11*V013*V04*V06*V09 + 
      3.27194317878730776e-10*V02*V03*V04*V06*V09 + 1.00727965507211103e-10*V01*V042*V06*V09 + 
      8.49487432258145688e-11*V022*V05*V06*V09 + 1.8306385170324319e-10*V01*V03*V05*V06*V09 + 
      3.83371866924847836e-11*V01*V02*V062*V09 - 8.05142885260554459e-12*V05*V062*V09 - 
      6.32147404439010862e-11*V012*V022*V07*V09 - 3.77302972743653795e-11*V013*V03*V07*V09 + 
      1.07864467949808638e-10*V02*V032*V07*V09 + 5.86489794023665398e-11*V022*V04*V07*V09 + 
      1.29511233389587309e-10*V01*V03*V04*V07*V09 + 6.94983132104084442e-11*V01*V02*V05*V07*V09 - 
      7.27413456031828447e-12*V052*V07*V09 + 1.4398916765634708e-11*V012*V06*V07*V09 - 
      1.14009159878492438e-11*V04*V06*V07*V09 - 3.72953572398336686e-12*V03*V072*V09 - 
      1.24441331666442167e-11*V013*V02*V08*V09 + 3.38241438168341798e-11*V022*V03*V08*V09 + 
      3.5494255410949495e-11*V01*V032*V08*V09 + 4.18527523327728124e-11*V01*V02*V04*V08*V09 + 
      1.11198562619915316e-11*V012*V05*V08*V09 - 8.92348142246957211e-12*V04*V05*V08*V09 - 
      6.45934970280348913e-12*V03*V06*V08*V09 - 2.45147201272742749e-12*V02*V07*V08*V09 - 
      4.26697537204433116e-13*V01*V082*V09 - 3.73561556533191765e-13*V014*V092 + 
      1.54100891636445927e-12*V023*V092 + 1.05995837611610948e-11*V01*V02*V03*V092 + 
      3.09508263999952405e-12*V012*V04*V092 - 1.23807203005564158e-12*V042*V092 - 
      2.28977255887157722e-12*V03*V05*V092 - 9.60872322161001938e-13*V02*V06*V092 - 
      3.86873773776280376e-13*V01*V07*V092 + 1.76543177060346038e-11*V012*V024*V10 + 
      6.60977299782492912e-11*V013*V022*V03*V10 + 1.27976794360635909e-11*V014*V032*V10 - 
      1.10886969017901137e-10*V023*V032*V10 - 2.38657295244777428e-10*V01*V02*V033*V10 + 
      1.6521491562302843e-11*V014*V02*V04*V10 - 2.24750668084651807e-11*V024*V04*V10 - 
      4.07899374485312101e-10*V01*V022*V03*V04*V10 - 2.0065333486758887e-10*V012*V032*V04*V10 - 
      1.20994451673556809e-10*V012*V02*V042*V10 + 9.93497937618841779e-11*V032*V042*V10 + 
      3.48253665458840755e-11*V02*V043*V10 + 1.26415695727301949e-12*V015*V05*V10 - 
      6.91511024819220775e-11*V01*V023*V05*V10 - 2.14675076789942065e-10*V012*V02*V03*V05*V10 + 
      6.02966023636317714e-11*V033*V05*V10 - 3.91078294783204656e-11*V013*V04*V05*V10 + 
      2.10156217323340596e-10*V02*V03*V04*V05*V10 + 6.4212814221649726e-11*V01*V042*V05*V10 + 
      2.74443153231186192e-11*V022*V052*V10 + 5.78983944070356525e-11*V01*V03*V052*V10 - 
      4.43843017738000093e-11*V012*V022*V06*V10 - 2.66638453083691919e-11*V013*V03*V06*V10 + 
      7.58467396739671493e-11*V02*V032*V06*V10 + 3.92782790449251503e-11*V022*V04*V06*V10 + 
      9.16216212725406214e-11*V01*V03*V04*V06*V10 + 4.89204024853496746e-11*V01*V02*V05*V06*V10 - 
      5.15412808464114329e-12*V052*V06*V10 + 5.11793677411109471e-12*V012*V062*V10 - 
      3.9831139026908763e-12*V04*V062*V10 - 1.00826225007017522e-11*V013*V02*V07*V10 + 
      2.77706129958863272e-11*V022*V03*V07*V10 + 2.89663880439119737e-11*V01*V032*V07*V10 + 
      3.42743461473933231e-11*V01*V02*V04*V07*V10 + 9.0663344942816703e-12*V012*V05*V07*V10 - 
      7.31217987621410814e-12*V04*V05*V07*V10 - 5.28878991680736179e-12*V03*V06*V07*V10 - 
      1.00545023316655181e-12*V02*V072*V10 - 6.75599333947874778e-13*V014*V08*V10 + 
      2.65138718611331927e-12*V023*V08*V10 + 1.90862565125946774e-11*V01*V02*V03*V08*V10 + 
      5.59844233423207949e-12*V012*V04*V08*V10 - 2.20267929978936099e-12*V042*V08*V10 - 
      4.12661434034899481e-12*V03*V05*V08*V10 - 1.70768450714704698e-12*V02*V06*V08*V10 - 
      6.97996635475576539e-13*V01*V07*V08*V10 + 2.75209601676780638e-12*V01*V022*V09*V10 + 
      2.72714820635076047e-12*V012*V03*V09*V10 - 2.30579147262046494e-12*V03*V04*V09*V10 - 
      1.23621169925226518e-12*V02*V05*V09*V10 - 5.49654018379800766e-13*V01*V06*V09*V10 + 
      6.93234108059802744e-15*V092*V10 + 3.70779160585071918e-13*V012*V02*V102 - 
      2.65199736154683223e-13*V032*V102 - 3.02745049527519678e-13*V02*V04*V102 - 
      1.74910018079406859e-13*V01*V05*V102 + 6.22937299983295429e-15*V08*V102 + 
      4.92619511995151302e-12*V013*V023*V11 + 5.84117237448891748e-12*V014*V02*V03*V11 - 
      1.15199860337992746e-11*V024*V03*V11 - 8.38856473565990139e-11*V01*V022*V032*V11 - 
      2.61062454682639616e-11*V012*V033*V11 + 5.44904807322493695e-13*V015*V04*V11 - 
      2.93075920440812251e-11*V01*V023*V04*V11 - 9.62561139242604334e-11*V012*V02*V03*V04*V11 + 
      2.77608797962469534e-11*V033*V04*V11 - 8.85382794057684124e-12*V013*V042*V11 + 
      4.71999151016865312e-11*V02*V03*V042*V11 + 9.72342153979441691e-12*V01*V043*V11 - 
      2.5356992658294002e-11*V012*V022*V05*V11 - 1.50405889015284077e-11*V013*V03*V05*V11 + 
      4.45583421763271917e-11*V02*V032*V05*V11 + 2.43512976285366689e-11*V022*V04*V05*V11 + 
      5.33386073504539976e-11*V01*V03*V04*V05*V11 + 1.4316658309772099e-11*V01*V02*V052*V11 - 
      1.01021636929364818e-12*V053*V11 - 6.49685464857254091e-12*V013*V02*V06*V11 + 
      1.78382540774898195e-11*V022*V03*V06*V11 + 1.88587598327407302e-11*V01*V032*V06*V11 + 
      2.21255655820517824e-11*V01*V02*V04*V06*V11 + 5.90492053889309544e-12*V012*V05*V06*V11 - 
      4.75764534560466503e-12*V04*V05*V06*V11 - 1.72358754274224914e-12*V03*V062*V11 - 
      4.99038274568920124e-13*V014*V07*V11 + 2.09049524630359461e-12*V023*V07*V11 + 
      1.43348991085224613e-11*V01*V02*V03*V07*V11 + 4.18177895602112244e-12*V012*V04*V07*V11 - 
      1.68078951637572008e-12*V042*V07*V11 - 3.10613935406968052e-12*V03*V05*V07*V11 - 
      1.3045500217260653e-12*V02*V06*V07*V11 - 2.62270407632081227e-13*V01*V072*V11 + 
      2.27200606071684525e-12*V01*V022*V08*V11 + 2.25965573310121448e-12*V012*V03*V08*V11 - 
      1.90994914268068194e-12*V03*V04*V08*V11 - 1.0230395414821402e-12*V02*V05*V08*V11 - 
      4.55581045664504838e-13*V01*V06*V08*V11 + 6.79235858264315972e-13*V012*V02*V09*V11 - 
      4.8758101962009306e-13*V032*V09*V11 - 5.63941891229075089e-13*V02*V04*V09*V11 - 
      3.2140172408927778e-13*V01*V05*V09*V11 + 1.14947568913065291e-14*V08*V09*V11 + 
      5.53458873809205168e-14*V013*V10*V11 - 2.6424886314235551e-13*V02*V03*V10*V11 - 
      1.62353246889028885e-13*V01*V04*V10*V11 + 9.41722501530556753e-15*V07*V10*V11 - 
      1.58644176989628236e-14*V022*V112 - 3.3886677205576281e-14*V01*V03*V112 + 
      3.07721381670551646e-15*V06*V112 + 6.05295649003007677e-13*V014*V022*V12 - 
      3.59882482437278407e-13*V025*V12 + 1.72849131854334813e-13*V015*V03*V12 - 
      1.15677929465048907e-11*V01*V023*V03*V12 - 1.7430281941978008e-11*V012*V02*V032*V12 + 
      2.64161000697906492e-12*V034*V12 - 1.0352793416110236e-11*V012*V022*V04*V12 - 
      6.27041153403228283e-12*V013*V03*V04*V12 + 1.8589111159799671e-11*V02*V032*V04*V12 + 
      4.73601963449950958e-12*V022*V042*V12 + 1.12480953815030756e-11*V01*V03*V042*V12 - 
      3.37383115323102257e-12*V013*V02*V05*V12 + 9.73511167772091757e-12*V022*V03*V05*V12 + 
      1.00616014982849948e-11*V01*V032*V05*V12 + 1.19601379146819554e-11*V01*V02*V04*V05*V12 + 
      1.56919078215588999e-12*V012*V052*V12 - 1.29061398334504037e-12*V04*V052*V12 - 
      2.96284601985383221e-13*V014*V06*V12 + 1.17749372433879194e-12*V023*V06*V12 + 
      8.54757581958902108e-12*V01*V02*V03*V06*V12 + 2.5090117192617549e-12*V012*V04*V06*V12 - 
      9.92923634472563931e-13*V042*V06*V12 - 1.86450149477329525e-12*V03*V05*V06*V12 - 
      3.84555095029679187e-13*V02*V062*V12 + 1.57632075026051422e-12*V01*V022*V07*V12 + 
      1.55499848102630278e-12*V012*V03*V07*V12 - 1.32395278817595673e-12*V03*V04*V07*V12 - 
      7.10410700110342782e-13*V02*V05*V07*V12 - 3.15226102723702595e-13*V01*V06*V07*V12 + 
      5.18571513178147662e-13*V012*V02*V08*V12 - 3.71940966196554748e-13*V032*V08*V12 - 
      4.24103808869650398e-13*V02*V04*V08*V12 - 2.45286362640797059e-13*V01*V05*V08*V12 + 
      4.37046007815720245e-15*V082*V12 + 4.67025512767729883e-14*V013*V09*V12 - 
      2.23698521828772384e-13*V02*V03*V09*V12 - 1.37341650884344593e-13*V01*V04*V09*V12 + 7.96939068301365903e-15*V07*V09*V12 - 
      2.8828104171663083e-14*V022*V10*V12 - 6.24104150070226499e-14*V01*V03*V10*V12 + 
      5.64485047550917638e-15*V06*V10*V12 - 1.56651786986489161e-14*V01*V02*V11*V12 + 3.33769492201838502e-15*V05*V11*V12 - 
      8.86411283607056922e-16*V012*V122 + 7.13077267517012585e-16*V04*V122 + 
      3.30161263092549642e-14*V015*V02*V13 - 5.15449824460184014e-13*V01*V024*V13 - 
      3.51332919429006389e-12*V012*V022*V03*V13 - 1.02163371969250649e-12*V013*V032*V13 + 
      2.22821348731493627e-12*V02*V033*V13 - 1.295000356283382e-12*V013*V02*V04*V13 + 
      3.69516336877554542e-12*V022*V03*V04*V13 + 3.96383473765864382e-12*V01*V032*V04*V13 + 
      2.30015305704597514e-12*V01*V02*V042*V13 - 1.41421754999903677e-13*V014*V05*V13 + 
      6.27629052363046747e-13*V023*V05*V13 + 4.25993246488590678e-12*V01*V02*V03*V05*V13 + 
      1.23802976767318278e-12*V012*V04*V05*V13 - 5.08004011562133792e-13*V042*V05*V13 - 
      4.68030384143614972e-13*V03*V052*V13 + 8.65588902541657253e-13*V01*V022*V06*V13 + 
      8.66212342176475281e-13*V012*V03*V06*V13 - 7.37424793181618753e-13*V03*V04*V06*V13 - 
      3.94239422684769086e-13*V02*V05*V06*V13 - 8.79823054201386731e-14*V01*V062*V13 + 
      3.31268813459478383e-13*V012*V02*V07*V13 - 2.39306139916671814e-13*V032*V07*V13 - 
      2.77215501314080526e-13*V02*V04*V07*V13 - 1.57652963731614308e-13*V01*V05*V07*V13 + 
      3.31086536408422936e-14*V013*V08*V13 - 1.58340795847096209e-13*V02*V03*V08*V13 - 
      9.73560685348212048e-14*V01*V04*V08*V13 + 5.65249270251123747e-15*V07*V08*V13 - 
      2.29730119703463972e-14*V022*V09*V13 - 4.90344059398011104e-14*V01*V03*V09*V13 + 
      4.4556374302116013e-15*V06*V09*V13 - 1.33967851141879037e-14*V01*V02*V10*V13 + 2.85541599075351329e-15*V05*V10*V13 - 
      1.64574873419930638e-15*V012*V11*V13 + 1.33023257104290608e-15*V04*V11*V13 + 
      5.23451871006887793e-16*V03*V12*V13 + 5.6436363957087508e-17*V02*V132 + 
      6.47375025671665965e-16*V016*V14 - 2.13778959909429818e-13*V012*V023*V14 - 
      3.93970593392060693e-13*V013*V02*V03*V14 + 6.35112634788320403e-13*V022*V032*V14 + 
      4.2922246645499399e-13*V01*V033*V14 - 5.07780597258200105e-14*V014*V04*V14 + 
      2.08209138357232785e-13*V023*V04*V14 + 1.54459401947502601e-12*V01*V02*V03*V04*V14 + 
      2.27121801799059415e-13*V012*V042*V14 - 6.10564288218587202e-14*V043*V14 + 
      4.06708557569133368e-13*V01*V022*V05*V14 + 3.97770290108845224e-13*V012*V03*V05*V14 - 
      3.46205304889671238e-13*V03*V04*V05*V14 - 9.29924265977742453e-14*V02*V052*V14 + 
      1.71681630555312298e-13*V012*V02*V06*V14 - 1.24636098548669414e-13*V032*V06*V14 - 
      1.41471832885866306e-13*V02*V04*V06*V14 - 8.2148492228427167e-14*V01*V05*V06*V14 + 
      1.96728193688666029e-14*V013*V07*V14 - 9.52557824363161538e-14*V02*V03*V07*V14 - 
      5.84072292155915883e-14*V01*V04*V07*V14 + 1.69830746360725112e-15*V072*V14 - 
      1.49536476563454537e-14*V022*V08*V14 - 3.24484221727777839e-14*V01*V03*V08*V14 + 
      2.93637275808941573e-15*V06*V08*V14 - 9.82497677004151241e-15*V01*V02*V09*V14 + 2.09432703016534729e-15*V05*V09*V14 - 
      1.31435421765251645e-15*V012*V10*V14 + 1.05736133262327091e-15*V04*V10*V14 + 
      4.53666218671016393e-16*V03*V11*V14 + 1.04868532788085482e-16*V02*V12*V14 + 2.38011479809086447e-17*V01*V13*V14 - 
      3.50426916070097446e-14*V013*V022*V15 - 1.41085535486053289e-14*V014*V03*V15 + 
      7.18702737494876399e-14*V023*V03*V15 + 2.38385906905103058e-13*V01*V02*V032*V15 + 
      1.35223172637121579e-13*V01*V022*V04*V15 + 1.3711886117740038e-13*V012*V03*V04*V15 - 
      5.97081709776533282e-14*V03*V042*V15 + 7.4062172478214984e-14*V012*V02*V05*V15 - 
      5.4631535073360603e-14*V032*V05*V15 - 6.35464205981655164e-14*V02*V04*V05*V15 - 
      1.79549661021444243e-14*V01*V052*V15 + 9.5857733703327457e-15*V013*V06*V15 - 
      4.62756549791944176e-14*V02*V03*V06*V15 - 2.84891950863623848e-14*V01*V04*V06*V15 - 
      8.56441975538305829e-15*V022*V07*V15 - 1.82256686723030509e-14*V01*V03*V07*V15 + 
      1.66107264157847099e-15*V06*V07*V15 - 6.0853444830426526e-15*V01*V02*V08*V15 + 1.29933548936433682e-15*V05*V08*V15 - 
      9.01979908299631121e-16*V012*V09*V15 + 7.30040739768721734e-16*V04*V09*V15 + 
      3.39459924769725797e-16*V03*V10*V15 + 8.55532142115370918e-17*V02*V11*V15 + 2.08154976382726338e-17*V01*V12*V15 - 
      5.8932250686124597e-20*V152 - 2.39247292096050465e-15*V014*V02*V16 + 
      2.59662614247925397e-15*V024*V16 + 4.02867476411792183e-14*V01*V022*V03*V16 + 
      1.93037883916566029e-14*V012*V032*V16 + 2.38003641781464343e-14*V012*V02*V04*V16 - 
      1.78645657745856546e-14*V032*V04*V16 - 1.00205655274990807e-14*V02*V042*V16 + 
      3.85289669587673607e-15*V013*V05*V16 - 1.92300298182246161e-14*V02*V03*V05*V16 - 
      1.17524656383676113e-14*V01*V04*V05*V16 - 3.8415350242529435e-15*V022*V06*V16 - 
      8.38983065265123518e-15*V01*V03*V06*V16 + 3.80700548231161266e-16*V062*V16 - 
      3.22539964549769187e-15*V01*V02*V07*V16 + 6.89080303128354176e-16*V05*V07*V16 - 
      5.27400509995494606e-16*V012*V08*V16 + 4.24512688171965718e-16*V04*V08*V16 + 
      2.19720871288794942e-16*V03*V09*V16 + 5.99959411638146868e-17*V02*V10*V16 + 1.59187463593250527e-17*V01*V11*V16 - 
      1.1079025536347802e-19*V14*V16 - 5.62934804931883448e-17*V015*V17 + 
      2.04276642740862361e-15*V01*V023*V17 + 6.38351314780704286e-15*V012*V02*V03*V17 - 
      1.6628606276813098e-15*V033*V17 + 1.18147617586284193e-15*V013*V04*V17 - 
      5.85428921019558605e-15*V02*V03*V04*V17 - 1.80686407381866393e-15*V01*V042*V17 - 
      1.54122167343600823e-15*V022*V05*V17 - 3.25469848517431622e-15*V01*V03*V05*V17 - 
      1.39506948536253869e-15*V01*V02*V06*V17 + 2.99777897313207931e-16*V05*V06*V17 - 
      2.62729715387494746e-16*V012*V07*V17 + 2.13653736186709851e-16*V04*V07*V17 + 
      1.21250528707195404e-16*V03*V08*V17 + 3.68465004390900903e-17*V02*V09*V17 + 1.05918722822414556e-17*V01*V10*V17 - 
      9.24426150301492161e-20*V13*V17 + 4.87994109025326464e-16*V012*V022*V18 + 
      2.91553317720971302e-16*V013*V03*V18 - 7.88222015938509173e-16*V02*V032*V18 - 
      4.30496733094720018e-16*V022*V04*V18 - 9.54780431128739958e-16*V01*V03*V04*V18 - 
      5.16302645159732691e-16*V01*V02*V05*V18 + 5.56489828859292094e-17*V052*V18 - 
      1.08446565922381515e-16*V012*V06*V18 + 8.76006319476780833e-17*V04*V06*V18 + 
      5.75451859511967202e-17*V03*V07*V18 + 1.91629901378329376e-17*V02*V08*V18 + 6.13421501533908222e-18*V01*V09*V18 - 
      6.80043879121880758e-20*V12*V18 + 4.36274473822209672e-17*V013*V02*V19 - 
      1.14258173688518219e-16*V022*V03*V19 - 1.18417157727789631e-16*V01*V032*V19 - 
      1.41925031161350305e-16*V01*V02*V04*V19 - 3.76612240191514414e-17*V012*V05*V19 + 
      3.11138533138566719e-17*V04*V05*V19 + 2.25695577670570253e-17*V03*V06*V19 + 8.69796924638006314e-18*V02*V07*V19 + 
      3.05035150630311125e-18*V01*V08*V19 - 4.42748303819597842e-20*V11*V19 + 1.26660331109673776e-18*V014*V20 - 
      4.95237958775675847e-18*V023*V20 - 3.40857981758372659e-17*V01*V02*V03*V20 - 
      1.00284729279957128e-17*V012*V04*V20 + 4.10538734031304488e-18*V042*V20 + 
      7.57818685878495806e-18*V03*V05*V20 + 3.22087545950950052e-18*V02*V06*V20 + 1.30919575577112974e-18*V01*V07*V20 - 
      2.52313523715603196e-20*V10*V20 - 2.26514242936876911e-18*V01*V022*V21 - 
      2.22604973458183276e-18*V012*V03*V21 + 1.93141229852361064e-18*V03*V04*V21 + 
      1.04437000710130713e-18*V02*V05*V21 + 4.6781280108152058e-19*V01*V06*V21 - 1.26495172291081369e-20*V09*V21 - 
      2.94870612107177044e-19*V012*V02*V22 + 2.1406494365066718e-19*V032*V22 + 
      2.50058077431335303e-19*V02*V04*V22 + 1.43024264459716799e-19*V01*V05*V22 - 5.46742040599416839e-21*V08*V22 - 
      1.11693413676961002e-20*V013*V23 + 5.43349942568181838e-20*V02*V03*V23 + 3.35293678157593289e-20*V01*V04*V23 - 
      2.06191239097954198e-21*V07*V23 + 3.18069462511115956e-21*V022*V24 + 6.76178446160740201e-21*V01*V03*V24 - 
      6.48647415930993752e-22*V06*V24 + 7.98383237130576125e-22*V01*V02*V25 - 1.77086035180825081e-22*V05*V25 + 
      4.41317367258107406e-23*V012*V26 - 3.6993007700016839e-23*V04*V26 - 6.83114419406855403e-24*V03*V27 - 
      7.24744063532375798e-25*V02*V28 - 7.76511496641831212e-26*V01*V29 + 4.90221904445600513e-29*V32) + 
   delta2*eps15*(-7.34513519595647598e-9*V026*V032 - 
      7.66733214743714631e-8*V01*V024*V033 - 9.50223719492931198e-8*V012*V022*V034 - 
      9.30118813003874923e-9*V013*V035 + 7.92541135303655303e-9*V02*V036 - 
      6.94677964495491896e-10*V027*V04 - 5.60732557136975995e-8*V01*V025*V03*V04 - 
      2.55281843345728439e-7*V012*V023*V032*V04 - 
      1.28759511348895787e-7*V013*V02*V033*V04 + 7.8784237823039034e-8*V022*V034*V04 + 
      2.74095856384940716e-8*V01*V035*V04 - 4.30239563261992811e-8*V012*V024*V042 - 
      1.33756322321729296e-7*V013*V022*V03*V042 - 
      2.33303376863546728e-8*V014*V032*V042 + 
      9.9392095205150115e-8*V023*V032*V042 + 1.86446426462638602e-7*V01*V02*V033*V042 - 
      1.08661788982903174e-8*V014*V02*V043 + 8.85485037384606633e-9*V024*V043 + 
      1.22862106534274762e-7*V01*V022*V03*V043 + 
      5.30366946500021783e-8*V012*V032*V043 + 1.82367247328506246e-8*V012*V02*V044 - 
      7.62523189444241833e-9*V032*V044 - 1.89784940868103996e-9*V02*V045 - 
      4.40708111757388559e-9*V01*V026*V05 - 6.77071712216627273e-8*V012*V024*V03*V05 - 
      1.05625519079117807e-7*V013*V022*V032*V05 - 
      1.22790162972445681e-8*V014*V033*V05 + 5.83393132196211667e-8*V023*V033*V05 + 
      7.82712175252762983e-8*V01*V02*V034*V05 - 4.87468976537895407e-8*V013*V023*V04*V05 - 
      5.14051989668392114e-8*V014*V02*V03*V04*V05 + 5.32272774181542503e-8*V024*V03*V04*V05 + 
      3.14664911623860674e-7*V01*V022*V032*V04*V05 + 8.76826166470720832e-8*V012*V033*V04*V05 - 
      2.36033928939316606e-9*V015*V042*V05 + 6.71136227616780994e-8*V01*V023*V042*V05 + 
      1.81191927409187312e-7*V012*V02*V03*V042*V05 - 2.63392400894021651e-8*V033*V042*V05 + 
      1.10969263107718122e-8*V013*V043*V05 - 3.46037844026564338e-8*V02*V03*V043*V05 - 
      5.35425046541173307e-9*V01*V044*V05 - 7.04521275513515611e-9*V014*V022*V052 + 
      2.77576346498354624e-9*V025*V052 - 1.85314363868643768e-9*V015*V03*V052 + 
      5.82041716418391508e-8*V01*V023*V03*V052 + 
      7.50689503172054512e-8*V012*V02*V032*V052 - 5.62337837306412398e-9*V034*V052 + 
      5.10318316615263682e-8*V012*V022*V04*V052 + 
      2.71615916129108854e-8*V013*V03*V04*V052 - 4.52814334226117655e-8*V02*V032*V04*V052 - 
      1.45327752816043505e-8*V022*V042*V052 - 
      2.74621234695733417e-8*V01*V03*V042*V052 + 5.16846854743267365e-9*V013*V02*V053 - 
      8.56178385130490555e-9*V022*V03*V053 - 7.75101010166097229e-9*V01*V032*V053 - 
      1.05080847658167175e-8*V01*V02*V04*V053 - 6.51990468618928513e-10*V012*V054 + 
      3.57149883234819747e-10*V04*V054 - 6.00714401602766817e-9*V012*V025*V06 - 
      3.1984522590089561e-8*V013*V023*V03*V06 - 1.6831526268782988e-8*V014*V02*V032*V06 + 
      1.9331071480799861e-8*V024*V032*V06 + 7.37181143191700339e-8*V01*V022*V033*V06 + 
      1.51727132927482365e-8*V012*V034*V06 - 1.17097119917916548e-8*V014*V022*V04*V06 + 
      4.01048218684418898e-9*V025*V04*V06 - 3.07582745825769643e-9*V015*V03*V04*V06 + 
      9.59460788216942072e-8*V01*V023*V03*V04*V06 + 1.25830110112474634e-7*V012*V02*V032*V04*V06 - 
      9.36979489735362674e-9*V034*V04*V06 + 4.28832324436438457e-8*V012*V022*V042*V06 + 
      2.2856691881741515e-8*V013*V03*V042*V06 - 3.73228480331830138e-8*V02*V032*V042*V06 - 
      7.64165341227448942e-9*V022*V043*V06 - 1.52415075299584514e-8*V01*V03*V043*V06 - 
      1.67666987255979651e-9*V015*V02*V05*V06 + 1.29208613803010814e-8*V01*V024*V05*V06 + 
      7.10384242638056369e-8*V012*V022*V03*V05*V06 + 1.8639489455271313e-8*V013*V032*V05*V06 - 
      2.15473376627685792e-8*V02*V033*V05*V06 + 2.61136077773585444e-8*V013*V02*V04*V05*V06 - 
      4.20451053616803543e-8*V022*V03*V04*V05*V06 - 3.88651879948861813e-8*V01*V032*V04*V05*V06 - 
      2.611037687324363e-8*V01*V02*V042*V05*V06 + 1.38036619399501211e-9*V014*V052*V06 - 
      3.89065652237962201e-9*V023*V052*V06 - 2.23737718204443371e-8*V01*V02*V03*V052*V06 - 
      6.56188115383649758e-9*V012*V04*V052*V06 + 1.77257493552073986e-9*V042*V052*V06 + 
      1.02343274054048332e-9*V03*V053*V06 - 3.92579313424881184e-11*V016*V062 + 
      5.53896626105372376e-9*V012*V023*V062 + 
      8.94612554318519055e-9*V013*V02*V03*V062 - 
      7.57018784023038801e-9*V022*V032*V062 - 4.57423988753967457e-9*V01*V033*V062 + 
      1.16097640437488421e-9*V014*V04*V062 - 3.05490152697411129e-9*V023*V04*V062 - 
      1.85996384776467165e-8*V01*V02*V03*V04*V062 - 2.75370580576689454e-9*V012*V042*V062 + 
      4.82553039614528773e-10*V043*V062 - 5.27207344384687974e-9*V01*V022*V05*V062 - 
      4.60414303651161596e-9*V012*V03*V05*V062 + 2.54771016133387209e-9*V03*V04*V05*V062 + 
      7.32918329149337008e-10*V02*V052*V062 - 7.43797998421722055e-10*V012*V02*V063 + 
      3.0438303047085905e-10*V032*V063 + 3.98131923878671738e-10*V02*V04*V063 + 
      2.17150728211414912e-10*V01*V05*V063 - 3.10045404814854993e-9*V013*V024*V07 - 
      6.54361911268731014e-9*V014*V022*V03*V07 + 2.89657308748128819e-9*V025*V03*V07 - 
      8.5619408960953181e-10*V015*V032*V07 + 2.97425306382492934e-8*V01*V023*V032*V07 + 
      2.52333281303459248e-8*V012*V02*V033*V07 - 1.16601553487689853e-9*V035*V07 - 
      1.18979665036711759e-9*V015*V02*V04*V07 + 9.25633803761605614e-9*V01*V024*V04*V07 + 
      5.16423382847674271e-8*V012*V022*V03*V04*V07 + 1.35789635420893226e-8*V013*V032*V04*V07 - 
      1.57072117980715576e-8*V02*V033*V04*V07 + 9.51817763058136525e-9*V013*V02*V042*V07 - 
      1.52211800623303508e-8*V022*V03*V042*V07 - 1.42045024774269449e-8*V01*V032*V042*V07 - 
      6.33229443401291315e-9*V01*V02*V043*V07 - 6.71627543776257063e-11*V016*V05*V07 + 
      9.57319667608703312e-9*V012*V023*V05*V07 + 1.54846937154151709e-8*V013*V02*V03*V05*V07 - 
      1.33875761956695592e-8*V022*V032*V05*V07 - 7.99951097235749514e-9*V01*V033*V05*V07 + 
      2.0095486361703746e-9*V014*V04*V05*V07 - 5.60933165501704436e-9*V023*V04*V05*V07 - 
      3.26535369779595175e-8*V01*V02*V03*V04*V05*V07 - 4.80157924678221344e-9*V012*V042*V05*V07 + 
      8.61880298416276305e-10*V043*V05*V07 - 4.64372218274195496e-9*V01*V022*V052*V07 - 
      4.01555119610890494e-9*V012*V03*V052*V07 + 2.24598005365667107e-9*V03*V04*V052*V07 + 
      4.32051689154240787e-10*V02*V053*V07 + 3.68970496282504369e-9*V013*V022*V06*V07 + 
      1.36300731511013964e-9*V014*V03*V06*V07 - 4.07651751182822467e-9*V023*V03*V06*V07 - 
      1.15678326592981273e-8*V01*V02*V032*V06*V07 - 7.66091299332580027e-9*V01*V022*V04*V06*V07 - 
      6.74051561116660225e-9*V012*V03*V04*V06*V07 + 1.86082412105481978e-9*V03*V042*V06*V07 - 
      3.89091480242436439e-9*V012*V02*V05*V06*V07 + 1.60720976683344328e-9*V032*V05*V06*V07 + 
      2.13604869253278858e-9*V02*V04*V05*V06*V07 + 5.71960251543224737e-10*V01*V052*V06*V07 - 
      2.55372414563206963e-10*V013*V062*V07 + 7.69818695305583881e-10*V02*V03*V062*V07 + 
      4.76964607089161981e-10*V01*V04*V062*V07 + 2.82151763039381577e-10*V014*V02*V072 - 
      2.00129525632151865e-10*V024*V072 - 2.4056036538132887e-9*V01*V022*V03*V072 - 
      1.02920453151944644e-9*V012*V032*V072 - 
      1.42202040397659846e-9*V012*V02*V04*V072 + 5.88167349435319928e-10*V032*V04*V072 + 
      3.88733334581949205e-10*V02*V042*V072 - 2.22010298539190358e-10*V013*V05*V072 + 
      6.79971755260556443e-10*V02*V03*V05*V072 + 4.19067719551377918e-10*V01*V04*V05*V072 + 
      1.59623433551773797e-10*V022*V06*V072 + 2.98128726367052495e-10*V01*V03*V06*V072 - 
      1.02099467098193178e-11*V062*V072 + 4.2253935331163418e-11*V01*V02*V073 - 
      6.00164403998919045e-12*V05*V073 - 7.35154270081124595e-10*V014*V023*V08 + 
      1.36064413237870857e-10*V026*V08 - 5.75792364547340222e-10*V015*V02*V03*V08 + 
      5.14862181924762414e-9*V01*V024*V03*V08 + 1.37457019311333921e-8*V012*V022*V032*V08 + 
      2.37349856114670404e-9*V013*V033*V08 - 2.16635350918576091e-9*V02*V034*V08 - 
      4.14629276727844225e-11*V016*V04*V08 + 6.17172074238420181e-9*V012*V023*V04*V08 + 
      9.97039015032322844e-9*V013*V02*V03*V04*V08 - 8.53399623295600594e-9*V022*V032*V04*V08 - 
      5.16890231327213456e-9*V01*V033*V04*V08 + 6.45684343456755518e-10*V014*V042*V08 - 
      1.71461107248036818e-9*V023*V042*V08 - 1.04943045204417926e-8*V01*V02*V03*V042*V08 - 
      1.03645064374222073e-9*V012*V043*V08 + 1.36661593658713027e-10*V044*V08 + 
      2.82017506202823854e-9*V013*V022*V05*V08 + 1.04117352450820565e-9*V014*V03*V05*V08 - 
      3.17341019365007678e-9*V023*V03*V05*V08 - 8.94100733202998584e-9*V01*V02*V032*V05*V08 - 
      5.94072564741481163e-9*V01*V022*V04*V05*V08 - 5.19856938577017285e-9*V012*V03*V04*V05*V08 + 
      1.44496123662651443e-9*V03*V042*V05*V08 - 1.50089626953262736e-9*V012*V02*V052*V08 + 
      6.22975547569562934e-10*V032*V052*V08 + 8.30479860600869428e-10*V02*V04*V052*V08 + 
      1.47645429692195384e-10*V01*V053*V08 + 4.98080323050083682e-10*V014*V02*V06*V08 - 
      3.39306898612751522e-10*V024*V06*V08 - 4.23790767418172289e-9*V01*V022*V03*V06*V08 - 
      1.82041666175492764e-9*V012*V032*V06*V08 - 2.5170466032238677e-9*V012*V02*V04*V06*V08 + 
      1.03627799478401073e-9*V032*V04*V06*V08 + 6.76107766667069964e-10*V02*V042*V06*V08 - 
      3.93053587082477803e-10*V013*V05*V06*V08 + 1.19603345297181466e-9*V02*V03*V05*V06*V08 + 
      7.39314927968770367e-10*V01*V04*V05*V06*V08 + 1.38685241610305423e-10*V022*V062*V08 + 
      2.63216266739460886e-10*V01*V03*V062*V08 - 5.97685901741455127e-12*V063*V08 + 
      2.84171068671405223e-11*V015*V07*V08 - 5.74870667308410316e-10*V01*V023*V07*V08 - 
      1.53994277202974889e-9*V012*V02*V03*V07*V08 + 2.17239850847743862e-10*V033*V07*V08 - 
      2.87942096311750344e-10*V013*V04*V07*V08 + 8.72628179962686229e-10*V02*V03*V04*V07*V08 + 
      2.70622355331621154e-10*V01*V042*V07*V08 + 2.48549334649299092e-10*V022*V05*V07*V08 + 
      4.61650946365056781e-10*V01*V03*V05*V07*V08 + 2.23446917972226198e-10*V01*V02*V06*V07*V08 - 
      3.17268330207259314e-11*V05*V06*V07*V08 + 2.07331873524847868e-11*V012*V072*V08 - 
      1.16187132998922594e-11*V04*V072*V08 - 1.42431959775928683e-10*V012*V022*V082 - 
      7.68644377918929679e-11*V013*V03*V082 + 1.21778641118872184e-10*V02*V032*V082 + 
      7.84460664087754784e-11*V022*V04*V082 + 1.49415686061474116e-10*V01*V03*V04*V082 + 
      8.66242901321840204e-11*V01*V02*V05*V082 - 6.16060965419676862e-12*V052*V082 + 
      1.83448453918262831e-11*V012*V06*V082 - 1.02004709800498674e-11*V04*V06*V082 - 
      6.49118474262601466e-12*V03*V07*V082 - 8.08599383298439738e-13*V02*V083 - 
      8.50977060745507598e-11*V015*V022*V09 + 3.04628299402442197e-10*V01*V025*V09 - 
      1.76313882991729569e-11*V016*V03*V09 + 2.9372440748394431e-9*V012*V023*V03*V09 + 
      2.33562886383595467e-9*V013*V02*V032*V09 - 1.42777583671319421e-9*V022*V033*V09 - 
      6.32132575155134399e-10*V01*V034*V09 + 1.62751893431331275e-9*V013*V022*V04*V09 + 
      5.99092792405409933e-10*V014*V03*V04*V09 - 1.81213329742511883e-9*V023*V03*V04*V09 - 
      5.18188038049620332e-9*V01*V02*V032*V04*V09 - 1.70891156100274428e-9*V01*V022*V042*V09 - 
      1.51114982455198454e-9*V012*V03*V042*V09 + 2.79057038501507986e-10*V03*V043*V09 + 
      3.40712895895715053e-10*V014*V02*V05*V09 - 2.46769809181573898e-10*V024*V05*V09 - 
      2.95287771491705013e-9*V01*V022*V03*V05*V09 - 1.26043557682878922e-9*V012*V032*V05*V09 - 
      1.7424144888868091e-9*V012*V02*V04*V05*V09 + 7.24489737645632959e-10*V032*V04*V05*V09 + 
      4.7950747324922868e-10*V02*V042*V05*V09 - 1.35725551914962019e-10*V013*V052*V09 + 
      4.18954689478680718e-10*V02*V03*V052*V09 + 2.57914691933666174e-10*V01*V04*V052*V09 + 
      2.24476298070442001e-11*V015*V06*V09 - 4.55134757164848017e-10*V01*V023*V06*V09 - 
      1.22291026612467966e-9*V012*V02*V03*V06*V09 + 1.7258996461164631e-10*V033*V06*V09 - 
      2.28761566089720646e-10*V013*V04*V06*V09 + 6.92151443527869975e-10*V02*V03*V04*V06*V09 + 
      2.14919704029951069e-10*V01*V042*V06*V09 + 1.96946368925808796e-10*V022*V05*V06*V09 + 
      3.66889162191042186e-10*V01*V03*V05*V06*V09 + 8.87118400372520684e-11*V01*V02*V062*V09 - 
      1.25997636002352934e-11*V05*V062*V09 - 2.55532122476566379e-10*V012*V022*V07*V09 - 
      1.37960292880996678e-10*V013*V03*V07*V09 + 2.19627954296440864e-10*V02*V032*V07*V09 + 
      1.43081975173106543e-10*V022*V04*V07*V09 + 2.68983581686812141e-10*V01*V03*V04*V07*V09 + 
      1.56072852427624416e-10*V01*V02*V05*V07*V09 - 1.11073735200707149e-11*V052*V07*V09 + 
      3.29717536236600114e-11*V012*V06*V07*V09 - 1.84529804458333143e-11*V04*V06*V07*V09 - 
      5.8503001373335711e-12*V03*V072*V09 - 5.17561968317334986e-11*V013*V02*V08*V09 + 
      8.0649042247388488e-11*V022*V03*V08*V09 + 7.39597998211291722e-11*V01*V032*V08*V09 + 
      1.00611239217036138e-10*V01*V02*V04*V08*V09 + 2.54896286156840285e-11*V012*V05*V08*V09 - 
      1.43417788640921348e-11*V04*V05*V08*V09 - 1.03161068685397302e-11*V03*V06*V08*V09 - 
      4.39076407601100194e-12*V02*V07*V08*V09 - 7.64262708926076255e-13*V01*V082*V09 - 
      1.64301507843724227e-12*V014*V092 + 4.35126481161723717e-12*V023*V092 + 
      2.50632734694209118e-11*V01*V02*V03*V092 + 7.44187477585637925e-12*V012*V04*V092 - 
      2.08452198348972177e-12*V042*V092 - 3.60983922172055736e-12*V03*V05*V092 - 
      1.74290785666765095e-12*V02*V06*V092 - 6.88168070545415153e-13*V01*V07*V092 - 
      4.62225768329569499e-12*V016*V02*V10 + 2.10055716704762471e-10*V012*V024*V10 + 
      6.88054777534822111e-10*V013*V022*V03*V10 + 1.25603147587937483e-10*V014*V032*V10 - 
      4.17193941583865808e-10*V023*V032*V10 - 7.69547846416703342e-10*V01*V02*V033*V10 + 
      1.77396109070359545e-10*V014*V02*V04*V10 - 1.22707896049382729e-10*V024*V04*V10 - 
      1.54580578198860123e-9*V01*V022*V03*V04*V10 - 6.65286737270804129e-10*V012*V032*V04*V10 - 
      4.59487775884533935e-10*V012*V02*V042*V10 + 1.9069364260462636e-10*V032*V042*V10 + 
      8.26569288746720253e-11*V02*V043*V10 + 1.3878610764642224e-11*V015*V05*V10 - 
      2.88522259469541449e-10*V01*V023*V05*V10 - 7.68673032968939211e-10*V012*V02*V03*V05*V10 + 
      1.09219894475263005e-10*V033*V05*V10 - 1.4339992201261797e-10*V013*V04*V05*V10 + 
      4.39622301634039777e-10*V02*V03*V04*V05*V10 + 1.36061191625661983e-10*V01*V042*V05*V10 + 
      6.26805369561973959e-11*V022*V052*V10 + 1.15931529500259652e-10*V01*V03*V052*V10 - 
      1.84361690446033944e-10*V012*V022*V06*V10 - 9.94777426884189774e-11*V013*V03*V06*V10 + 
      1.57952539687302153e-10*V02*V032*V06*V10 + 1.01636822911617773e-10*V022*V04*V06*V10 + 
      1.93856767980880931e-10*V01*V03*V04*V06*V10 + 1.12362998927409006e-10*V01*V02*V05*V06*V10 - 
      7.99681409737515064e-12*V052*V06*V10 + 1.19019576481725833e-11*V012*V062*V10 - 
      6.6188898182145276e-12*V04*V062*V10 - 4.21544740054389746e-11*V013*V02*V07*V10 + 
      6.59349710921910917e-11*V022*V03*V07*V10 + 6.0366896315075862e-11*V01*V032*V07*V10 + 
      8.2178251812432052e-11*V01*V02*V04*V07*V10 + 2.07973663538860204e-11*V012*V05*V07*V10 - 
      1.17191046172199895e-11*V04*V05*V07*V10 - 8.42784231988716758e-12*V03*V06*V07*V10 - 
      1.79456129125924123e-12*V02*V072*V10 - 2.98175992258485331e-12*V014*V08*V10 + 
      7.80139595339535172e-12*V023*V08*V10 + 4.54567760157179871e-11*V01*V02*V03*V08*V10 + 
      1.35137765018882454e-11*V012*V04*V08*V10 - 3.7662573011057891e-12*V042*V08*V10 - 
      6.54436921465917419e-12*V03*V05*V08*V10 - 3.14842445842757806e-12*V02*V06*V08*V10 - 
      1.24834023220356032e-12*V01*V07*V08*V10 + 7.58457149592909557e-12*V01*V022*V09*V10 + 
      6.61959784733087023e-12*V012*V03*V09*V10 - 3.81451074325811585e-12*V03*V04*V09*V10 - 
      2.21668527268540445e-12*V02*V05*V09*V10 - 9.92796652435151234e-13*V01*V06*V09*V10 + 
      1.04283059959667998e-14*V092*V10 + 1.02375643064170076e-12*V012*V02*V102 - 
      4.34442917246633889e-13*V032*V102 - 5.81222524485248035e-13*V02*V04*V102 - 
      3.1446474236005332e-13*V01*V05*V102 + 9.44582682284715888e-15*V08*V102 - 
      9.3222003696719899e-14*V017*V11 + 6.12666476081012217e-11*V013*V023*V11 + 
      6.76955440237534874e-11*V014*V02*V03*V11 - 5.42203183875842145e-11*V024*V03*V11 - 
      3.17539260827802005e-10*V01*V022*V032*V11 - 8.91832034059885633e-11*V012*V033*V11 + 
      6.57226223919458231e-12*V015*V04*V11 - 1.37403786372382197e-10*V01*V023*V04*V11 - 
      3.71031403009845362e-10*V012*V02*V03*V04*V11 + 5.28521255406003329e-11*V033*V04*V11 - 
      3.46908330210094506e-11*V013*V042*V11 + 1.0563382833473224e-10*V02*V03*V042*V11 + 
      2.19130439912233479e-11*V01*V043*V11 - 1.06029520363668362e-10*V012*V022*V05*V11 - 
      5.70864550847669276e-11*V013*V03*V05*V11 + 9.18692282914882692e-11*V02*V032*V05*V11 + 
      5.99780132436198432e-11*V022*V04*V05*V11 + 1.12355393626640223e-10*V01*V03*V04*V05*V11 + 
      3.26081158947309791e-11*V01*V02*V052*V11 - 1.55102554111744242e-12*V053*V11 - 
      2.78352412592487337e-11*V013*V02*V06*V11 + 4.34233314864072005e-11*V022*V03*V06*V11 + 
      3.9900219701852198e-11*V01*V032*V06*V11 + 5.42274939330945657e-11*V01*V02*V04*V06*V11 + 
      1.37521919021622801e-11*V012*V05*V06*V11 - 7.73507630461656551e-12*V04*V05*V06*V11 - 
      2.78315638096537635e-12*V03*V062*V11 - 2.22320717375796222e-12*V014*V07*V11 + 
      5.91223051814089438e-12*V023*V07*V11 + 3.40224515494449457e-11*V01*V02*V03*V07*V11 + 
      1.00987213690088394e-11*V012*V04*V07*V11 - 2.831446579732376e-12*V042*V07*V11 - 
      4.90239865640390091e-12*V03*V05*V07*V11 - 2.36770398504686622e-12*V02*V06*V07*V11 - 
      4.6728033142998948e-13*V01*V072*V11 + 6.30256262614238701e-12*V01*V022*V08*V11 + 
      5.50477420372722586e-12*V012*V03*V08*V11 - 3.17047326932478175e-12*V03*V04*V08*V11 - 
      1.84195802305630204e-12*V02*V05*V08*V11 - 8.25436857531729495e-13*V01*V06*V08*V11 + 
      1.87513090029284766e-12*V012*V02*V09*V11 - 7.96677217510591365e-13*V032*V09*V11 - 
      1.06942940642916119e-12*V02*V04*V09*V11 - 5.76514283863079468e-13*V01*V05*V09*V11 + 1.73378815765002234e-14*V08*V09*V11 + 
      1.57617748318863376e-13*V013*V10*V11 - 4.91156026791636878e-13*V02*V03*V10*V11 - 
      3.05682548270651004e-13*V01*V04*V10*V11 + 1.41698573630039782e-14*V07*V10*V11 - 
      3.41155936015299704e-14*V022*V112 - 6.33727158852221694e-14*V01*V03*V112 + 
      4.68392629563206402e-15*V06*V112 + 8.33365870547135597e-12*V014*V022*V12 - 
      2.42284263957588348e-12*V025*V12 + 2.28393909056963753e-12*V015*V03*V12 - 
      5.27138236407577518e-11*V01*V023*V03*V12 - 6.89414642803365036e-11*V012*V02*V032*V12 + 
      5.04512957420392336e-12*V034*V12 - 4.71898197491503617e-11*V012*V022*V04*V12 - 
      2.54655447170499812e-11*V013*V03*V04*V12 + 4.08443206688732217e-11*V02*V032*V04*V12 + 
      1.30807655878756663e-11*V022*V042*V12 + 2.50962918273578771e-11*V01*V03*V042*V12 - 
      1.47260301929318597e-11*V013*V02*V05*V12 + 2.336109331956536e-11*V022*V03*V05*V12 + 
      2.1313341965054303e-11*V01*V032*V05*V12 + 2.90546005596401007e-11*V01*V02*V04*V05*V12 + 
      3.66632963859994052e-12*V012*V052*V12 - 2.07702023754800014e-12*V04*V052*V12 - 
      1.35280078400600651e-12*V014*V06*V12 + 3.54899056870801882e-12*V023*V06*V12 + 
      2.07277037926471394e-11*V01*V02*V03*V06*V12 + 6.16371813226697242e-12*V012*V04*V06*V12 - 
      1.71758022428398171e-12*V042*V06*V12 - 2.9866055130156944e-12*V03*V05*V06*V12 - 
      7.17900922943567351e-13*V02*V062*V12 + 4.35453524384673569e-12*V01*V022*V07*V12 + 
      3.79646612573851643e-12*V012*V03*V07*V12 - 2.19063924301719898e-12*V03*V04*V07*V12 - 
      1.2733722261507823e-12*V02*V05*V07*V12 - 5.69987681594097395e-13*V01*V06*V07*V12 + 
      1.43918328377225742e-12*V012*V02*V08*V12 - 6.10787246625266118e-13*V032*V08*V12 - 
      8.16870940089851135e-13*V02*V04*V08*V12 - 4.42124983472621766e-13*V01*V05*V08*V12 + 
      6.63911307079913218e-15*V082*V12 + 1.33206708719863722e-13*V013*V09*V12 - 
      4.1536730485126651e-13*V02*V03*V09*V12 - 2.58454105653264138e-13*V01*V04*V09*V12 + 1.19807996847481632e-14*V07*V09*V12 - 
      6.27204475261856285e-14*V022*V10*V12 - 1.16911852920432403e-13*V01*V03*V10*V12 + 
      8.63039588272299124e-15*V06*V10*V12 - 3.32890966157486106e-14*V01*V02*V11*V12 + 5.03461684630547786e-15*V05*V11*V12 - 
      1.90638852522379706e-15*V012*V122 + 1.12720530030948256e-15*V04*V122 + 
      5.1660527048598944e-13*V015*V02*V13 - 2.95501982360216111e-12*V01*V024*V13 - 
      1.63029636084274865e-11*V012*V022*V03*V13 - 4.33112798741864457e-12*V013*V032*V13 + 
      4.86142020009076464e-12*V02*V033*V13 - 6.09634509221649093e-12*V013*V02*V04*V13 + 
      9.5939290837826703e-12*V022*V03*V04*V13 + 8.8567416679761702e-12*V01*V032*V04*V13 + 
      6.00367802922400712e-12*V01*V02*V042*V13 - 6.63050347411283497e-13*V014*V05*V13 + 
      1.79722614409188059e-12*V023*V05*V13 + 1.02973013911991893e-11*V01*V02*V03*V05*V13 + 
      3.05120322229944382e-12*V012*V04*V05*V13 - 8.60120558745828219e-13*V042*V05*V13 - 
      7.43964154628784579e-13*V03*V052*V13 + 2.46006945517001994e-12*V01*V022*V06*V13 + 
      2.15126479138368802e-12*V012*V03*V06*V13 - 1.23915903311821046e-12*V03*V04*V06*V13 - 
      7.19560638782095533e-13*V02*V05*V06*V13 - 1.6141143197692674e-13*V01*V062*V13 + 
      9.21353951340793197e-13*V012*V02*V07*V13 - 3.91837733769804848e-13*V032*V07*V13 - 
      5.26200783482104312e-13*V02*V04*V07*V13 - 2.83503923804952085e-13*V01*V05*V07*V13 + 
      9.49076370339617934e-14*V013*V08*V13 - 2.95642191097327827e-13*V02*V03*V08*V13 - 
      1.84053848271840166e-13*V01*V04*V08*V13 + 8.52840996078281124e-15*V07*V08*V13 - 
      4.94189778982346936e-14*V022*V09*V13 - 9.17846986619673058e-14*V01*V03*V09*V13 + 
      6.78246713863473319e-15*V06*V09*V13 - 2.85107866708969911e-14*V01*V02*V10*V13 + 4.31115767533966442e-15*V05*V10*V13 - 
      3.53958913706548344e-15*V012*V11*V13 + 2.0953977529960337e-15*V04*V11*V13 + 8.12348509384368895e-16*V03*V12*V13 + 
      9.91934982586311262e-17*V02*V132 + 1.16527504620899874e-14*V016*V14 - 
      1.18270772978072684e-12*V012*V023*V14 - 1.93186699753212665e-12*V013*V02*V03*V14 + 
      1.61434358577918168e-12*V022*V032*V14 + 9.69279177494868392e-13*V01*V033*V14 - 
      2.55689210411098451e-13*V014*V04*V14 + 6.77129129994328435e-13*V023*V04*V14 + 
      3.9832343084325807e-12*V01*V02*V03*V04*V14 + 5.92744222168406489e-13*V012*V042*V14 - 
      1.10326633806913225e-13*V043*V14 + 1.14366613940136318e-12*V01*V022*V05*V14 + 
      9.93939280198426234e-13*V012*V03*V05*V14 - 5.76640661733708373e-13*V03*V04*V05*V14 - 
      1.67705121975493764e-13*V02*V052*V14 + 4.87373576973145381e-13*V012*V02*V06*V14 - 
      2.07039304650626256e-13*V032*V06*V14 - 2.76544423968569762e-13*V02*V04*V06*V14 - 
      1.49888816630556507e-13*V01*V05*V06*V14 + 5.66886010210439433e-14*V013*V07*V14 - 
      1.7712846891103538e-13*V02*V03*V07*V14 - 1.10167768454567253e-13*V01*V04*V07*V14 + 
      2.55327618906084782e-15*V072*V14 - 3.27099271262744115e-14*V022*V08*V14 - 
      6.10165550339409747e-14*V01*V03*V08*V14 + 4.5008161434460858e-15*V06*V08*V14 - 2.08923848928948841e-14*V01*V02*V09*V14 + 
      3.15847824670863287e-15*V05*V09*V14 - 2.83008551897952341e-15*V012*V10*V14 + 
      1.67265861727876768e-15*V04*V10*V14 + 7.03869511170910609e-16*V03*V11*V14 + 1.8493620106918799e-16*V02*V12*V14 + 
      4.17805191735717951e-17*V01*V13*V14 - 2.00317535660986066e-13*V013*V022*V15 - 
      7.50589122155926795e-14*V014*V03*V15 + 2.18639136850132944e-13*V023*V03*V15 + 
      6.16202946452876259e-13*V01*V02*V032*V15 + 4.12907844209658433e-13*V01*V022*V04*V15 + 
      3.62269660379654355e-13*V012*V03*V04*V15 - 1.04682301101607333e-13*V03*V042*V15 + 
      2.11196602600547796e-13*V012*V02*V05*V15 - 9.02564643809443884e-14*V032*V05*V15 - 
      1.21387582752822401e-13*V02*V04*V05*V15 - 3.26248396940879228e-14*V01*V052*V15 + 
      2.81285788975302985e-14*V013*V06*V15 - 8.7663472662365173e-14*V02*V03*V06*V15 - 
      5.46101692692696134e-14*V01*V04*V06*V15 - 1.84498690677128981e-14*V022*V07*V15 - 
      3.42392401651051056e-14*V01*V03*V07*V15 + 2.52944968389254273e-15*V06*V07*V15 - 1.3019213777381947e-14*V01*V02*V08*V15 + 
      1.96723903639933734e-15*V05*V08*V15 - 1.9436240533962762e-15*V012*V09*V15 + 1.15013409053837597e-15*V04*V09*V15 + 
      5.2734350937139453e-16*V03*V10*V15 + 1.50381675526854445e-16*V02*V11*V15 + 3.65519835025927311e-17*V01*V12*V15 - 
      8.83988270529478617e-20*V152 - 1.4692598408722158e-14*V014*V02*V16 + 
      1.00467510764578888e-14*V024*V16 + 1.21270823444477616e-13*V01*V022*V03*V16 + 
      5.2007965048919046e-14*V012*V032*V16 + 7.23939687966379124e-14*V012*V02*V04*V16 - 
      3.09321632711715506e-14*V032*V04*V16 - 2.05848535483716615e-14*V02*V042*V16 + 
      1.1446357787627015e-14*V013*V05*V16 - 3.6063358079001518e-14*V02*V03*V05*V16 - 
      2.23978727706109381e-14*V01*V04*V05*V16 - 8.55537298052745423e-15*V022*V06*V16 - 
      1.59914553906222964e-14*V01*V03*V06*V16 + 5.8911944963537396e-16*V062*V16 - 
      6.88193396392344736e-15*V01*V02*V07*V16 + 1.03972318572288697e-15*V05*V07*V16 - 
      1.14115993049880796e-15*V012*V08*V16 + 6.73632318508629738e-16*V04*V08*V16 + 
      3.40989021759908309e-16*V03*V09*V16 + 1.05937427597508265e-16*V02*V10*V16 + 2.79481866813596067e-17*V01*V11*V16 - 
      1.66344478883764259e-19*V14*V16 - 3.79980993329021327e-16*V015*V17 + 
      7.36524799199137543e-15*V01*V023*V17 + 1.96814070692863565e-14*V012*V02*V03*V17 - 
      2.86772041805499679e-15*V033*V17 + 3.71582207087582245e-15*V013*V04*V17 - 
      1.16336933717389292e-14*V02*V03*V04*V17 - 3.62979608289536128e-15*V01*V042*V17 - 
      3.34647903749892908e-15*V022*V05*V17 - 6.1918064419508808e-15*V01*V03*V05*V17 - 
      3.0341144843651029e-15*V01*V02*V06*V17 + 4.58150065966977901e-16*V05*V06*V17 - 
      5.69230124960251162e-16*V012*V07*V17 + 3.3677539849001866e-16*V04*V07*V17 + 1.88920650517688056e-16*V03*V08*V17 + 
      6.47852073697767715e-17*V02*V09*V17 + 1.86209967121073254e-17*V01*V10*V17 - 1.38664824592745756e-19*V13*V17 + 
      1.74565077768653965e-15*V012*V022*V18 + 9.44825755634780809e-16*V013*V03*V18 - 
      1.54469996589992834e-15*V02*V032*V18 - 1.01421943749410083e-15*V022*V04*V18 - 
      1.90615868087687968e-15*V01*V03*V04*V18 - 1.11552879428252454e-15*V01*V02*V05*V18 + 
      8.43223181731107831e-17*V052*V18 - 2.38359130004794202e-16*V012*V06*V18 + 
      1.40467719441213164e-16*V04*V06*V18 + 8.94058719652069809e-17*V03*V07*V18 + 3.39691929363352318e-17*V02*V08*V18 + 
      1.07779951318553318e-17*V01*V09*V18 - 1.02131993941341098e-19*V12*V18 + 1.61341136056370167e-16*V013*V02*V19 - 
      2.59473573145277141e-16*V022*V03*V19 - 2.37076650272753382e-16*V01*V032*V19 - 
      3.25438905452792616e-16*V01*V02*V04*V19 - 8.29904003397506788e-17*V012*V05*V19 + 
      4.92415784877586569e-17*V04*V05*V19 + 3.55143593439512367e-17*V03*V06*V19 + 1.53052497815427429e-17*V02*V07*V19 + 
      5.38066674451987935e-18*V01*V08*V19 - 6.64131476204616085e-20*V11*V19 + 4.97594157930861262e-18*V014*V20 - 
      1.34965534226653519e-17*V023*V20 - 7.75926166712871152e-17*V01*V02*V03*V20 - 
      2.32055034065351869e-17*V012*V04*V20 + 6.83621748435512729e-18*V042*V20 + 
      1.18401684109242573e-17*V03*V05*V20 + 5.78015662484870134e-18*V02*V06*V20 + 2.30528866907063254e-18*V01*V07*V20 - 
      3.79243209654162573e-20*V10*V20 - 5.9769937993883756e-18*V01*V022*V21 - 
      5.2077054126883067e-18*V012*V03*V21 + 3.15194608845466797e-18*V03*V04*V21 + 1.84692682269380383e-18*V02*V05*V21 + 
      8.34390722322771706e-19*V01*V06*V21 - 1.89751778911841376e-20*V09*V21 - 7.83250063409689024e-19*V012*V02*V22 + 
      3.46074774869989855e-19*V032*V22 + 4.68200908183354995e-19*V02*V04*V22 + 2.53974362136750028e-19*V01*V05*V22 - 
      8.23762590979865995e-21*V08*V22 - 3.07156887611642754e-20*V013*V23 + 9.94689226039114265e-20*V02*V03*V23 + 
      6.22511044721301555e-20*V01*V04*V23 - 3.09377063399124523e-21*V07*V23 + 6.74589703638611015e-21*V022*V24 + 
      1.25082180204358784e-20*V01*V03*V24 - 9.85532121773120632e-22*V06*V24 + 1.67299401951482535e-21*V01*V02*V25 - 
      2.66531100293169882e-22*V05*V25 + 9.38802399439973936e-23*V012*V26 - 5.80778832054980291e-23*V04*V26 - 
      1.05670272834675864e-23*V03*V27 - 1.26830211118165765e-24*V02*V28 - 1.35889511912320462e-25*V01*V29 + 
      7.35332856668400769e-29*V32) + delta4*eps14*
    (-1.23083020897627674e-9*V026*V032 - 1.65720926455890215e-8*V01*V024*V033 - 
      2.27414063075033116e-8*V012*V022*V034 - 2.33881814428872433e-9*V013*V035 + 
      5.22454832312341654e-9*V02*V036 - 1.97753534590218582e-12*V027*V04 - 
      9.86598382550702319e-9*V01*V025*V03*V04 - 5.48376340540336987e-8*V012*V023*V032*V04 - 
      2.99539857915443774e-8*V013*V02*V033*V04 + 4.74911610452370361e-8*V022*V034*V04 + 
      1.76096755706160509e-8*V01*V035*V04 - 8.10430070227350799e-9*V012*V024*V042 - 
      2.86021258085385271e-8*V013*V022*V03*V042 - 
      5.28412388659160065e-9*V014*V032*V042 + 
      5.26904219089508856e-8*V023*V032*V042 + 
      1.10595294450472584e-7*V01*V02*V033*V042 - 2.30072831001908773e-9*V014*V02*V043 + 
      3.46651613447685113e-9*V024*V043 + 6.53121766150544046e-8*V01*V022*V03*V043 + 
      3.10088733561170214e-8*V012*V032*V043 + 9.77896255642706859e-9*V012*V02*V044 - 
      6.3327266710902895e-9*V032*V044 - 1.3675698718070872e-9*V02*V045 - 
      7.38498125385766041e-10*V01*V026*V05 - 1.37946918550321735e-8*V012*V024*V03*V05 - 
      2.3134408182248895e-8*V013*V022*V032*V05 - 2.78677748352112981e-9*V014*V033*V05 + 
      3.29951922095088513e-8*V023*V033*V05 + 4.76056823797601118e-8*V01*V02*V034*V05 - 
      9.79047533707409354e-9*V013*V023*V04*V05 - 1.09337137973024284e-8*V014*V02*V03*V04*V05 + 
      2.60259872774085781e-8*V024*V03*V04*V05 + 1.75569565323015808e-7*V01*V022*V032*V04*V05 + 
      5.21435011337984776e-8*V012*V033*V04*V05 - 4.89598290552782364e-10*V015*V042*V05 + 
      3.2934948266341763e-8*V01*V023*V042*V05 + 9.99676649873531407e-8*V012*V02*V03*V042*V05 - 
      2.26197059557923488e-8*V033*V042*V05 + 6.06447005308406843e-9*V013*V043*V05 - 
      2.71059106497756439e-8*V02*V03*V043*V05 - 4.17960800511999671e-9*V01*V044*V05 - 
      1.41095727179438807e-9*V014*V022*V052 + 1.26228757571918856e-9*V025*V052 - 
      3.82662489845915117e-10*V015*V03*V052 + 3.05989667212234895e-8*V01*V023*V03*V052 + 
      4.23893789175455697e-8*V012*V02*V032*V052 - 4.9435814437887819e-9*V034*V052 + 
      2.6567303227109088e-8*V012*V022*V04*V052 + 
      1.50401722679105051e-8*V013*V03*V04*V052 - 3.69827762972224178e-8*V02*V032*V04*V052 - 
      1.0710174761278686e-8*V022*V042*V052 - 2.21611076812180129e-8*V01*V03*V042*V052 + 
      2.72604272119853197e-9*V013*V02*V053 - 6.64348520102057389e-9*V022*V03*V053 - 
      6.3987666726280336e-9*V01*V032*V053 - 8.06829384769643841e-9*V01*V02*V04*V053 - 
      5.06918781251540621e-10*V012*V054 + 3.43957776882379446e-10*V04*V054 - 
      1.11189530071841464e-9*V012*V025*V06 - 6.37536715735813357e-9*V013*V023*V03*V06 - 
      3.48080095767883115e-9*V014*V02*V032*V06 + 9.56109781009974108e-9*V024*V032*V06 + 
      4.087558058540725e-8*V01*V022*V033*V06 + 8.90129195979451267e-9*V012*V034*V06 - 
      2.27155513926426604e-9*V014*V022*V04*V06 + 1.45481257294304808e-9*V025*V04*V06 - 
      6.16103852503035714e-10*V015*V03*V04*V06 + 4.76001329783781991e-8*V01*V023*V03*V04*V06 + 
      6.88068829020047773e-8*V012*V02*V032*V04*V06 - 8.03810866830133342e-9*V034*V04*V06 + 
      2.14680994036823617e-8*V012*V022*V042*V06 + 
      1.23355233214193484e-8*V013*V03*V042*V06 - 2.94042865508187802e-8*V02*V032*V042*V06 - 
      5.19095959248134237e-9*V022*V043*V06 - 1.19392081038589253e-8*V01*V03*V043*V06 - 
      3.18230449643242587e-10*V015*V02*V05*V06 + 5.96608248739836308e-9*V01*V024*V05*V06 + 
      3.67884464104577234e-8*V012*V022*V03*V05*V06 + 1.01775912042126525e-8*V013*V032*V05*V06 - 
      1.76004767716552408e-8*V02*V033*V05*V06 + 1.33895162200711009e-8*V013*V02*V04*V05*V06 - 
      3.12359714763980088e-8*V022*V03*V04*V05*V06 - 3.13076733649312107e-8*V01*V032*V04*V05*V06 - 
      1.93308686409280644e-8*V01*V02*V042*V05*V06 + 7.05544034747197757e-10*V014*V052*V06 - 
      2.72265358892293609e-9*V023*V052*V06 - 1.71741819914063159e-8*V01*V02*V03*V052*V06 - 
      4.98155510493677834e-9*V012*V04*V052*V06 + 1.65905201265862902e-9*V042*V052*V06 + 
      9.88056106856857375e-10*V03*V053*V06 - 7.04307035072162761e-12*V016*V062 + 
      2.6076548409405678e-9*V012*V023*V062 + 4.53428072823133368e-9*V013*V02*V03*V062 - 
      5.65657673726306991e-9*V022*V032*V062 - 3.6728840586847907e-9*V01*V033*V062 + 
      5.8011973742157058e-10*V014*V04*V062 - 1.95805686285051041e-9*V023*V04*V062 - 
      1.38213527009044916e-8*V01*V02*V03*V04*V062 - 2.03895922901186537e-9*V012*V042*V062 + 
      4.3349519478626339e-10*V043*V062 - 3.70525792482090506e-9*V01*V022*V05*V062 - 
      3.48158803071492217e-9*V012*V03*V05*V062 + 2.39620528927537535e-9*V03*V04*V05*V062 + 
      6.56938698937138254e-10*V02*V052*V062 - 5.23054073706164849e-10*V012*V02*V063 + 
      2.87265719003188194e-10*V032*V063 + 3.41513030907064747e-10*V02*V04*V063 + 
      1.94196130726893642e-10*V01*V05*V063 - 5.50205181096965808e-10*V013*V024*V07 - 
      1.2113898258519667e-9*V014*V022*V03*V07 + 1.24834810137028935e-9*V025*V03*V07 - 
      1.62298916550251587e-10*V015*V032*V07 + 1.49640561846129793e-8*V01*V023*V032*V07 + 
      1.36513310355933784e-8*V012*V02*V033*V07 - 1.00363995743917084e-9*V035*V07 - 
      2.14598606209910819e-10*V015*V02*V04*V07 + 4.01491721564693395e-9*V01*V024*V04*V07 + 
      2.57861546773648022e-8*V012*V022*V03*V04*V07 + 7.20677428257744977e-9*V013*V032*V04*V07 - 
      1.25587919031859e-8*V02*V033*V04*V07 + 4.72935795429197701e-9*V013*V02*V042*V07 - 
      1.09807351357235457e-8*V022*V03*V042*V07 - 1.12154350801135205e-8*V01*V032*V042*V07 - 
      4.56332362184435567e-9*V01*V02*V043*V07 - 1.18007218965292253e-11*V016*V05*V07 + 
      4.5168996730885781e-9*V012*V023*V05*V07 + 7.8262642721709172e-9*V013*V02*V03*V05*V07 - 
      1.01558580334969456e-8*V022*V032*V05*V07 - 6.45426015987889039e-9*V01*V033*V05*V07 + 
      9.98968803303268848e-10*V014*V04*V05*V07 - 3.79460026050486257e-9*V023*V04*V05*V07 - 
      2.45077031426954608e-8*V01*V02*V03*V04*V05*V07 - 3.57066855453061759e-9*V012*V042*V05*V07 + 
      7.91779633111647078e-10*V043*V05*V07 - 3.31076782433456615e-9*V01*V022*V052*V07 - 
      3.04706419956226199e-9*V012*V03*V052*V07 + 2.13434882718075157e-9*V03*V04*V052*V07 + 
      3.92347012426840491e-10*V02*V053*V07 + 1.72580697566399282e-9*V013*V022*V06*V07 + 
      6.67195213594540565e-10*V014*V03*V06*V07 - 2.78517517133533836e-9*V023*V03*V06*V07 - 
      8.67160195090646296e-9*V01*V02*V032*V06*V07 - 5.2280941150228981e-9*V01*V022*V04*V06*V07 - 
      4.99569214617229949e-9*V012*V03*V04*V06*V07 + 1.7194966872332067e-9*V03*V042*V06*V07 - 
      2.7497146324773924e-9*V012*V02*V05*V06*V07 + 1.53021795231366437e-9*V032*V05*V06*V07 + 
      1.87657245644626741e-9*V02*V04*V05*V06*V07 + 5.15665798155523937e-10*V01*V052*V06*V07 - 
      1.78001582169589989e-10*V013*V062*V07 + 6.80355686229752422e-10*V02*V03*V062*V07 + 
      4.19124557024304363e-10*V01*V04*V062*V07 + 1.28362854075079312e-10*V014*V02*V072 - 
      1.23605022006401984e-10*V024*V072 - 1.67242894460050537e-9*V01*V022*V03*V072 - 
      7.61195608246722452e-10*V012*V032*V072 - 
      9.81573740820518966e-10*V012*V02*V04*V072 + 5.51156116660494219e-10*V032*V04*V072 + 
      3.34309627912877796e-10*V02*V042*V072 - 1.54879529755990491e-10*V013*V05*V072 + 
      6.08451106064456907e-10*V02*V03*V05*V072 + 3.71602656457531987e-10*V01*V04*V05*V072 + 
      1.31070900834882877e-10*V022*V06*V072 + 2.64557637863480296e-10*V01*V03*V06*V072 - 
      1.0076637652846212e-11*V062*V072 + 3.51988382581282913e-11*V01*V02*V073 - 
      5.98146550924216446e-12*V05*V073 - 1.20679213142678792e-10*V014*V023*V08 + 
      4.34508373963109502e-11*V026*V08 - 9.7298246786934806e-11*V015*V02*V03*V08 + 
      2.2886637937773482e-9*V01*V024*V03*V08 + 6.77480635260199307e-9*V012*V022*V032*V08 + 
      1.22999280770531757e-9*V013*V033*V08 - 1.73227794476631344e-9*V02*V034*V08 - 
      6.84970867876815344e-12*V016*V04*V08 + 2.7703722060810885e-9*V012*V023*V04*V08 + 
      4.85589699594030352e-9*V013*V02*V03*V04*V08 - 6.23126406017349287e-9*V022*V032*V04*V08 - 
      4.06819537331349929e-9*V01*V033*V04*V08 + 3.1054892691231753e-10*V014*V042*V08 - 
      1.06702161531254501e-9*V023*V042*V08 - 7.62253363251082295e-9*V01*V02*V03*V042*V08 - 
      7.50537523760239793e-10*V012*V043*V08 + 1.20843758095306063e-10*V044*V08 + 
      1.30806078389470818e-9*V013*V022*V05*V08 + 5.04551551066440582e-10*V014*V03*V05*V08 - 
      2.18239900037469672e-9*V023*V03*V05*V08 - 6.7036088977941448e-9*V01*V02*V032*V05*V08 - 
      4.07194747485407657e-9*V01*V022*V04*V05*V08 - 3.84771521604920608e-9*V012*V03*V04*V05*V08 + 
      1.33965937383941864e-9*V03*V042*V05*V08 - 1.0599810065057773e-9*V012*V02*V052*V08 + 
      5.94155029111328308e-10*V032*V052*V08 + 7.32820052850915188e-10*V02*V04*V052*V08 + 
      1.33292503714675831e-10*V01*V053*V08 + 2.25576600204983589e-10*V014*V02*V06*V08 - 
      1.99343495171366373e-10*V024*V06*V08 - 2.91701282451571851e-9*V01*V022*V03*V06*V08 - 
      1.33993551825662362e-9*V012*V032*V06*V08 - 1.72781485683667997e-9*V012*V02*V04*V06*V08 + 
      9.64200365004229906e-10*V032*V04*V06*V08 + 5.70146087770967936e-10*V02*V042*V06*V08 - 
      2.73145873824467593e-10*V013*V05*V06*V08 + 1.06083045210178932e-9*V02*V03*V05*V06*V08 + 
      6.51136598325184319e-10*V01*V04*V05*V06*V08 + 1.11516053855078373e-10*V022*V062*V08 + 
      2.32216172474786105e-10*V01*V03*V062*V08 - 5.84118071787167106e-12*V063*V08 + 
      1.23781467895568879e-11*V015*V07*V08 - 3.61985178875995186e-10*V01*V023*V07*V08 - 
      1.05902815499704187e-9*V012*V02*V03*V07*V08 + 2.04131158294757994e-10*V033*V07*V08 - 
      1.9604526964524142e-10*V013*V04*V07*V08 + 7.58934586265512337e-10*V02*V03*V04*V07*V08 + 
      2.34069625693895776e-10*V01*V042*V07*V08 + 2.05197058801413467e-10*V022*V05*V07*V08 + 
      4.10096368857404071e-10*V01*V03*V05*V07*V08 + 1.84618520403177604e-10*V01*V02*V06*V07*V08 - 
      3.14115442412135748e-11*V05*V06*V07*V08 + 1.71502659130912139e-11*V012*V072*V08 - 
      1.13296476403873147e-11*V04*V072*V08 - 9.03852837416208366e-11*V012*V022*V082 - 
      5.17576908594873142e-11*V013*V03*V082 + 1.067029732811515e-10*V02*V032*V082 + 
      6.18872150443019913e-11*V022*V04*V082 + 1.29771776509316575e-10*V01*V03*V04*V082 + 
      7.17550890769260581e-11*V01*V02*V05*V082 - 6.11719591211462514e-12*V052*V082 + 
      1.51072386032336263e-11*V012*V06*V082 - 9.84661374629752751e-12*V04*V06*V082 - 
      6.37649123886734803e-12*V03*V07*V082 - 7.38987198410308162e-13*V02*V083 - 
      1.27786651067381488e-11*V015*V022*V09 + 1.15571372904575366e-10*V01*V025*V09 - 
      2.70576865729729507e-12*V016*V03*V09 + 1.30515076365257969e-9*V012*V023*V03*V09 + 
      1.10840813246920019e-9*V013*V02*V032*V09 - 1.052782178063311e-9*V022*V033*V09 - 
      4.94831817675165216e-10*V01*V034*V09 + 7.21644868503580076e-10*V013*V022*V04*V09 + 
      2.79543369674906739e-10*V014*V03*V04*V09 - 1.19274516531780409e-9*V023*V03*V04*V09 - 
      3.77603580627585762e-9*V01*V02*V032*V04*V09 - 1.12556830809645511e-9*V01*V022*V042*V09 - 
      1.08974860368980038e-9*V012*V03*V042*V09 + 2.52782192073265841e-10*V03*V043*V09 + 
      1.5200374430611976e-10*V014*V02*V05*V09 - 1.52058710971210249e-10*V024*V05*V09 - 
      2.04194760603183097e-9*V01*V022*V03*V05*V09 - 9.25762037049638174e-10*V012*V032*V05*V09 - 
      1.19511823963564727e-9*V012*V02*V04*V05*V09 + 6.77567852847413353e-10*V032*V04*V05*V09 + 
      4.11985177098247078e-10*V02*V042*V05*V09 - 9.3940996437556709e-11*V013*V052*V09 + 
      3.74205335481882409e-10*V02*V03*V052*V09 + 2.28147777115509968e-10*V01*V04*V052*V09 + 
      9.69401138782525209e-12*V015*V06*V09 - 2.83735239320670168e-10*V01*V023*V06*V09 - 
      8.36251702327767415e-10*V012*V02*V03*V06*V09 + 1.61573427937811628e-10*V033*V06*V09 - 
      1.54995313015193545e-10*V013*V04*V06*V09 + 5.98704974196801246e-10*V02*V03*V04*V06*V09 + 
      1.85020446570367922e-10*V01*V042*V06*V09 + 1.61547985954117473e-10*V022*V05*V06*V09 + 
      3.24682722261078725e-10*V01*V03*V05*V06*V09 + 7.29227584242278138e-11*V01*V02*V062*V09 - 
      1.24293351437775697e-11*V05*V062*V09 - 1.62100266944318696e-10*V012*V022*V07*V09 - 
      9.27996976056798666e-11*V013*V03*V07*V09 + 1.93102209023206723e-10*V02*V032*V07*V09 + 
      1.14539949135674849e-10*V022*V04*V07*V09 + 2.34096073404997454e-10*V01*V03*V04*V07*V09 + 
      1.29676643912387054e-10*V01*V02*V05*V07*V09 - 1.10621114988217525e-11*V052*V07*V09 + 
      2.71705574881141094e-11*V012*V06*V07*V09 - 1.79236865374404376e-11*V04*V06*V07*V09 - 
      5.76296452638156642e-12*V03*V072*V09 - 3.24556712321388057e-11*V013*V02*V08*V09 + 
      6.54108211903389926e-11*V022*V03*V08*V09 + 6.43873857934932674e-11*V01*V032*V08*V09 + 
      8.1240227343306506e-11*V01*V02*V04*V08*V09 + 2.10050592745838378e-11*V012*V05*V08*V09 - 
      1.39778673365567756e-11*V04*V05*V08*V09 - 1.00987870674326629e-11*V03*V06*V08*V09 - 
      4.04003085847495002e-12*V02*V07*V08*V09 - 7.0384068199720649e-13*V01*V082*V09 - 
      1.00400339970225036e-12*V014*V092 + 3.22667309016817989e-12*V023*V092 + 
      2.03935153351722987e-11*V01*V02*V03*V092 + 6.00429697232133354e-12*V012*V04*V092 - 
      1.9912141812008445e-12*V042*V092 - 3.55247567981326924e-12*V03*V05*V092 - 
      1.59644359157180678e-12*V02*V06*V092 - 6.35162169965079895e-13*V01*V07*V092 - 
      6.33132775106889314e-13*V016*V02*V10 + 8.32899483082212424e-11*V012*V024*V10 + 
      2.97351775808750856e-10*V013*V022*V03*V10 + 5.66260599633643661e-11*V014*V032*V10 - 
      2.79007152620933182e-10*V023*V032*V10 - 5.58415483380781159e-10*V01*V02*V033*V10 + 
      7.58005868630162207e-11*V014*V02*V04*V10 - 6.89620683485173357e-11*V024*V04*V10 - 
      1.02905883280274499e-9*V01*V022*V03*V04*V10 - 4.75680433558513346e-10*V012*V032*V04*V10 - 
      3.05334986408896146e-10*V012*V02*V042*V10 + 1.74199026813605896e-10*V032*V042*V10 + 
      6.81549627138978716e-11*V02*V043*V10 + 5.87798026880567792e-12*V015*V05*V10 - 
      1.81091035793284139e-10*V01*V023*V05*V10 - 5.2412646595533704e-10*V012*V02*V03*V05*V10 + 
      1.02404028092258437e-10*V033*V05*V10 - 9.66442082337426395e-11*V013*V04*V05*V10 + 
      3.82175835350397204e-10*V02*V03*V04*V05*V10 + 1.1748726617374537e-10*V01*V042*V05*V10 + 
      5.17647797809666795e-11*V022*V052*V10 + 1.02688501499668206e-10*V01*V03*V052*V10 - 
      1.16069884063401726e-10*V012*V022*V06*V10 - 6.65089774063467926e-11*V013*V03*V06*V10 + 
      1.37837351862502029e-10*V02*V032*V06*V10 + 7.97638748698947631e-11*V022*V04*V06*V10 + 
      1.67704602811361538e-10*V01*V03*V04*V06*V10 + 9.26716539001144295e-11*V01*V02*V05*V06*V10 - 
      7.91976989664513997e-12*V052*V06*V10 + 9.76056744301488485e-12*V012*V062*V10 - 
      6.37073455247836032e-12*V04*V062*V10 - 2.63738555116070788e-11*V013*V02*V07*V10 + 
      5.35529032708496911e-11*V022*V03*V07*V10 + 5.25462817458546304e-11*V01*V032*V07*V10 + 
      6.64061577994341819e-11*V01*V02*V04*V07*V10 + 1.71314595452956681e-11*V012*V05*V07*V10 - 
      1.14333769345132069e-11*V04*V05*V07*V10 - 8.25685448490179709e-12*V03*V06*V07*V10 - 
      1.65329390033687367e-12*V02*V072*V10 - 1.82011142850124376e-12*V014*V08*V10 + 
      5.7067289308947108e-12*V023*V08*V10 + 3.69069606548844603e-11*V01*V02*V03*V08*V10 + 
      1.08920539323054365e-11*V012*V04*V08*V10 - 3.57896719559537757e-12*V042*V08*V10 - 
      6.42761433482527368e-12*V03*V05*V08*V10 - 2.86797474460883325e-12*V02*V06*V08*V10 - 
      1.15018902470406406e-12*V01*V07*V08*V10 + 5.69762325771199204e-12*V01*V022*V09*V10 + 
      5.32381535016997291e-12*V012*V03*V09*V10 - 3.67836276063556685e-12*V03*V04*V09*V10 - 
      2.04091113324051795e-12*V02*V05*V09*V10 - 9.11621428639660907e-13*V01*V06*V09*V10 + 
      1.0418565338820255e-14*V092*V10 + 7.6877729382681738e-13*V012*V02*V102 - 
      4.2148125428939307e-13*V032*V102 - 5.20204246617781007e-13*V02*V04*V102 - 
      2.89392542850321528e-13*V01*V05*V102 + 9.41138159148547301e-15*V08*V102 - 
      1.16527504620899874e-14*V017*V11 + 2.39815916563475053e-11*V013*V023*V11 + 
      2.79105569282221083e-11*V014*V02*V03*V11 - 3.22904798900808943e-11*V024*V03*V11 - 
      2.11721063857746594e-10*V01*V022*V032*V11 - 6.29985591972812124e-11*V012*V033*V11 + 
      2.66592734857453025e-12*V015*V04*V11 - 8.19913816076394164e-11*V01*V023*V04*V11 - 
      2.45071771235951194e-10*V012*V02*V03*V04*V11 + 4.85301005770072349e-11*V033*V04*V11 - 
      2.27283520397930333e-11*V013*V042*V11 + 8.92713896678584498e-11*V02*V03*V042*V11 + 
      1.84456576164992886e-11*V01*V043*V11 - 6.65548657619626093e-11*V012*V022*V05*V11 - 
      3.79128472919391166e-11*V013*V03*V05*V11 + 8.05161274173344189e-11*V02*V032*V05*V11 + 
      4.79406653732000083e-11*V022*V04*V05*V11 + 9.73872425588332163e-11*V01*V03*V04*V05*V11 + 
      2.69883135307704975e-11*V01*V02*V052*V11 - 1.54309000216690953e-12*V053*V11 - 
      1.7287583311934528e-11*V013*V02*V06*V11 + 3.49716412686530775e-11*V022*V03*V06*V11 + 
      3.45586697497600319e-11*V01*V032*V06*V11 + 4.35049265200639374e-11*V01*V02*V04*V06*V11 + 
      1.12723113498003417e-11*V012*V05*V06*V11 - 7.50857385543800848e-12*V04*V05*V06*V11 - 
      2.71416669302036425e-12*V03*V062*V11 - 1.35211118582378094e-12*V014*V07*V11 + 
      4.38224324222050243e-12*V023*V07*V11 + 2.76474890812399871e-11*V01*V02*V03*V07*V11 + 
      8.13516113690048536e-12*V012*V04*V07*V11 - 2.7043810468975504e-12*V042*V07*V11 - 
      4.82287299668780267e-12*V03*V05*V07*V11 - 2.16843509660284847e-12*V02*V06*V07*V11 - 
      4.31053509995438997e-13*V01*V072*V11 + 4.72472535150458627e-12*V01*V022*V08*V11 + 
      4.42216126381697544e-12*V012*V03*V08*V11 - 3.05382126155922135e-12*V03*V04*V08*V11 - 
      1.69353406177846534e-12*V02*V05*V08*V11 - 7.57178708588871928e-13*V01*V06*V08*V11 + 
      1.40785108312120479e-12*V012*V02*V09*V11 - 7.73555851049561324e-13*V032*V09*V11 - 
      9.6112432913581759e-13*V02*V04*V09*V11 - 5.30923806822417581e-13*V01*V05*V09*V11 + 1.73057581211014067e-14*V08*V09*V11 + 
      1.16684261308602601e-13*V013*V10*V11 - 4.46175926076727951e-13*V02*V03*V10*V11 - 
      2.75778029327522626e-13*V01*V04*V10*V11 + 1.41561613701348896e-14*V07*V10*V11 - 
      2.87269631484814765e-14*V022*V112 - 5.74017530166169687e-14*V01*V03*V112 + 
      4.66022949176908057e-15*V06*V112 + 3.13070562414817661e-12*V014*V022*V12 - 
      1.21799579150969147e-12*V025*V12 + 8.87551160195854038e-13*V015*V03*V12 - 
      3.18775481232743551e-11*V01*V023*V03*V12 - 4.50665226040214233e-11*V012*V02*V032*V12 + 
      4.63602556995200807e-12*V034*V12 - 2.85210152681613032e-11*V012*V022*V04*V12 - 
      1.64248370453559468e-11*V013*V03*V04*V12 + 3.48584345036547296e-11*V02*V032*V04*V12 + 
      9.98598002216247929e-12*V022*V042*V12 + 2.12395791975100846e-11*V01*V03*V042*V12 - 
      9.07646181176116889e-12*V013*V02*V05*V12 + 1.89316580882731494e-11*V022*V03*V05*V12 + 
      1.84607924790912189e-11*V01*V032*V05*V12 + 2.33956677329314359e-11*V01*V02*V04*V05*V12 + 
      3.0023223409846485e-12*V012*V052*V12 - 2.02530611708025931e-12*V04*V052*V12 - 
      8.16322726894157926e-13*V014*V06*V12 + 2.57466116908841119e-12*V023*V06*V12 + 
      1.67264551829486578e-11*V01*V02*V03*V06*V12 + 4.93860956886462368e-12*V012*V04*V06*V12 - 
      1.62559781945479911e-12*V042*V06*V12 - 2.923150128019417e-12*V03*V05*V06*V12 - 
      6.51093323138616902e-13*V02*V062*V12 + 3.26804943289264566e-12*V01*V022*V07*V12 + 
      3.0467969867703406e-12*V012*V03*V07*V12 - 2.11240040033415363e-12*V03*V04*V07*V12 - 
      1.17261617330729371e-12*V02*V05*V07*V12 - 5.23176903067724153e-13*V01*V06*V07*V12 + 
      1.07888896807477056e-12*V012*V02*V08*V12 - 5.92082274867088116e-13*V032*V08*V12 - 
      7.30297344320266281e-13*V02*V04*V08*V12 - 4.06524117723246949e-13*V01*V05*V08*V12 + 
      6.61080309535047683e-15*V082*V12 + 9.85531740325456897e-14*V013*V09*V12 - 
      3.77450186445678748e-13*V02*V03*V09*V12 - 2.33203077160212118e-13*V01*V04*V09*V12 + 1.19728703472553745e-14*V07*V09*V12 - 
      5.26077856664303583e-14*V022*V10*V12 - 1.05841802147032891e-13*V01*V03*V10*V12 + 
      8.5738722136240769e-15*V06*V10*V12 - 2.82029359172431111e-14*V01*V02*V11*V12 + 5.02921233142613493e-15*V05*V11*V12 - 
      1.60635046712624788e-15*V012*V122 + 1.10400147925909941e-15*V04*V122 + 
      1.83530819777917301e-13*V015*V02*V13 - 1.58576057258185731e-12*V01*V024*V13 - 
      9.78487635181340849e-12*V012*V022*V03*V13 - 2.74191935873732163e-12*V013*V032*V13 + 
      4.16971479849957847e-12*V02*V033*V13 - 3.63443074524917994e-12*V013*V02*V04*V13 + 
      7.51988250819285384e-12*V022*V03*V04*V13 + 7.50094311499404231e-12*V01*V032*V04*V13 + 
      4.69146186599332558e-12*V01*V02*V042*V13 - 3.95817220600381889e-13*V014*V05*V13 + 
      1.32927467538968383e-12*V023*V05*V13 + 8.32268801261682502e-12*V01*V02*V03*V05*V13 + 
      2.4419692647486601e-12*V012*V04*V05*V13 - 8.20891503892504953e-13*V042*V05*V13 - 
      7.306954501309534e-13*V03*V052*V13 + 1.82915516876284333e-12*V01*V022*V06*V13 + 
      1.7169515067241884e-12*V012*V03*V06*V13 - 1.18855749472952992e-12*V03*V04*V06*V13 - 
      6.58428479538001534e-13*V02*V05*V06*V13 - 1.47431211630936634e-13*V01*V062*V13 + 
      6.89873451151270801e-13*V012*V02*V07*V13 - 3.80208009195057129e-13*V032*V07*V13 - 
      4.7278303066790696e-13*V02*V04*V07*V13 - 2.6086033657266639e-13*V01*V05*V07*V13 + 
      7.01058025469803099e-14*V013*V08*V13 - 2.68157094752310663e-13*V02*V03*V08*V13 - 
      1.65824026644450188e-13*V01*V04*V08*V13 + 8.51224143817787461e-15*V07*V08*V13 - 
      4.16077104613113278e-14*V022*V09*V13 - 8.31099109588426592e-14*V01*V03*V09*V13 + 
      6.74806685323250018e-15*V06*V09*V13 - 2.41431235561626347e-14*V01*V02*V10*V13 + 4.30517715778522478e-15*V05*V10*V13 - 
      2.98233876046204982e-15*V012*V11*V13 + 2.0546943470689051e-15*V04*V11*V13 + 8.03021364910364086e-16*V03*V12*V13 + 
      9.19247023276731815e-17*V02*V132 + 3.88425015402999579e-15*V016*V14 - 
      6.45414303641273753e-13*V012*V023*V14 - 1.13117828612241918e-12*V013*V02*V03*V14 + 
      1.27956809362745091e-12*V022*V032*V14 + 8.184400418212819e-13*V01*V033*V14 - 
      1.47885486357413513e-13*V014*V04*V14 + 4.75293607733056244e-13*V023*V04*V14 + 
      3.1323206689741456e-12*V01*V02*V03*V04*V14 + 4.63082745184558011e-13*V012*V042*V14 - 
      1.02549076509573579e-13*V043*V14 + 8.54069429991588632e-13*V01*V022*V05*V14 + 
      7.91618722129729418e-13*V012*V03*V05*V14 - 5.55252743250623582e-13*V03*V04*V05*V14 - 
      1.54268046837207386e-13*V02*V052*V14 + 3.62568841291365059e-13*V012*V02*V06*V14 - 
      1.99907684423277587e-13*V032*V06*V14 - 2.45964209446922916e-13*V02*V04*V06*V14 - 
      1.37240790798272797e-13*V01*V05*V06*V14 + 4.1783496246552004e-14*V013*V07*V14 - 
      1.60883468635804432e-13*V02*V03*V07*V14 - 9.93228881761834839e-14*V01*V04*V07*V14 + 
      2.55169784912412626e-15*V072*V14 - 2.73847426617915356e-14*V022*V08*V14 - 
      5.51686627384737422e-14*V01*V03*V08*V14 + 4.46747815069143399e-15*V06*V08*V14 - 1.76953326208434678e-14*V01*V02*V09*V14 + 
      3.15532593186514953e-15*V05*V09*V14 - 2.38372010662769178e-15*V012*V10*V14 + 
      1.63781918949552886e-15*V04*V10*V14 + 6.95845763369166618e-16*V03*V11*V14 + 1.71191823532273526e-16*V02*V12*V14 + 
      3.87493022898067072e-17*V01*V13*V14 - 1.07911083762911233e-13*V013*V022*V15 - 
      4.23362156734084596e-14*V014*V03*V15 + 1.57976360800010349e-13*V023*V03*V15 + 
      4.84783546072895084e-13*V01*V02*V032*V15 + 2.97691652656416048e-13*V01*V022*V04*V15 + 
      2.81750654170691155e-13*V012*V03*V04*V15 - 9.86634376299344775e-14*V03*V042*V15 + 
      1.56854922626334215e-13*V012*V02*V05*V15 - 8.73762098676233302e-14*V032*V05*V15 - 
      1.08948115223871687e-13*V02*V04*V05*V15 - 2.99315659025737346e-14*V01*V052*V15 + 
      2.06122851098882268e-14*V013*V06*V15 - 7.91151427022368249e-14*V02*V03*V06*V15 - 
      4.89688576513780108e-14*V01*V04*V06*V15 - 1.5526503110635554e-14*V022*V07*V15 - 
      3.09642224213674957e-14*V01*V03*V07*V15 + 2.51646277396746904e-15*V06*V07*V15 - 1.10051342801842462e-14*V01*V02*V08*V15 + 
      1.96265605549587988e-15*V05*V08*V15 - 1.63650010264923478e-15*V012*V09*V15 + 
      1.12774157607100467e-15*V04*V09*V15 + 5.21113250099988471e-16*V03*V10*V15 + 1.39357196183763212e-16*V02*V11*V15 + 
      3.38963493882852479e-17*V01*V12*V15 - 8.83987720500501829e-20*V152 - 
      7.66998671719691198e-15*V014*V02*V16 + 6.44142841666682068e-15*V024*V16 + 
      8.80805793895757745e-14*V01*V022*V03*V16 + 4.01438895312181116e-14*V012*V032*V16 + 
      5.2287026575254386e-14*V012*V02*V04*V16 - 2.93601512194435959e-14*V032*V04*V16 - 
      1.79309004712099445e-14*V02*V042*V16 + 8.34738493246494506e-15*V013*V05*V16 - 
      3.26913593049608102e-14*V02*V03*V05*V16 - 2.01348936504653864e-14*V01*V04*V05*V16 - 
      7.11740808206424194e-15*V022*V06*V16 - 1.43918384241227764e-14*V01*V03*V06*V16 + 
      5.82802887230197417e-16*V062*V16 - 5.82167788837820886e-15*V01*V02*V07*V16 + 
      1.03857548499295498e-15*V05*V07*V16 - 9.59591371074207605e-16*V012*V08*V16 + 
      6.58902749314492699e-16*V04*V08*V16 + 3.370730703827716e-16*V03*V09*V16 + 9.80207295800078063e-17*V02*V10*V16 + 
      2.59188621619350082e-17*V01*V11*V16 - 1.66291256260869896e-19*V14*V16 - 1.89990496664510664e-16*V015*V17 + 
      4.86956197978733304e-15*V01*V023*V17 + 1.41433851396604892e-14*V012*V02*V03*V17 - 
      2.73162648117141933e-15*V033*V17 + 2.64350666053481643e-15*V013*V04*V17 - 
      1.02907079213416284e-14*V02*V03*V04*V17 - 3.19182275225112503e-15*V01*V042*V17 - 
      2.81216818292357462e-15*V022*V05*V17 - 5.57868684882707399e-15*V01*V03*V05*V17 - 
      2.55022002225303197e-15*V01*V02*V06*V17 + 4.55583332407079884e-16*V05*V06*V17 - 
      4.78337515329117704e-16*V012*V07*V17 + 3.30177520261485175e-16*V04*V07*V17 + 
      1.86502278342547543e-16*V03*V08*V17 + 6.00291886776867114e-17*V02*V09*V17 + 1.72613654871455534e-17*V01*V10*V17 - 
      1.38664714586950399e-19*V13*V17 + 1.15882475156915424e-15*V012*V022*V18 + 
      6.63559401313457614e-16*V013*V03*V18 - 1.37711696309173586e-15*V02*V032*V18 - 
      8.23668559016970901e-16*V022*V04*V18 - 1.68264145146248983e-15*V01*V03*V04*V18 - 
      9.40293795374838116e-16*V01*V02*V05*V18 + 8.41705171441197212e-17*V052*V18 - 
      1.99357485295257017e-16*V012*V06*V18 + 1.36894629564189941e-16*V04*V06*V18 + 
      8.83494081553293481e-17*V03*V07*V18 + 3.13880353012497346e-17*V02*V08*V18 + 9.99259205972608792e-18*V01*V09*V18 - 
      1.0208999924027615e-19*V12*V18 + 1.05550275924728147e-16*V013*V02*V19 - 
      2.14364791864165478e-16*V022*V03*V19 - 2.09312061062953955e-16*V01*V032*V19 - 
      2.67448482881812156e-16*V01*V02*V04*V19 - 6.93553271388734529e-17*V012*V05*V19 + 
      4.82485543922659681e-17*V04*V05*V19 + 3.49398029906350771e-17*V03*V06*V19 + 1.41782479920331556e-17*V02*V07*V19 + 
      4.98215762039735876e-18*V01*V08*V19 - 6.64130376146662509e-20*V11*V19 + 3.1665082777418444e-18*V014*V20 - 
      1.01648984547011437e-17*V023*V20 - 6.40481946427602086e-17*V01*V02*V03*V20 - 
      1.89900743028520249e-17*V012*V04*V20 + 6.55790918062027298e-18*V042*V20 + 
      1.16860936283651301e-17*V03*V05*V20 + 5.31774039008747801e-18*V02*V06*V20 + 2.13568501732262469e-18*V01*V07*V20 - 
      3.78983661526790449e-20*V10*V20 - 4.56756253555222396e-18*V01*V022*V21 - 
      4.24504780355999907e-18*V012*V03*V21 + 3.05408693112747148e-18*V03*V04*V21 + 1.7094981873439896e-18*V02*V05*V21 + 
      7.69634849490338413e-19*V01*V06*V21 - 1.89750678853887801e-20*V09*V21 - 5.96861679336260352e-19*V012*V02*V22 + 
      3.37245848397356718e-19*V032*V22 + 4.23042288989272819e-19*V02*V04*V22 + 2.34738599004732721e-19*V01*V05*V22 - 
      8.225270132817571e-21*V08*V22 - 2.30367665708732066e-20*V013*V23 + 9.08873057987742288e-20*V02*V03*V23 + 
      5.64547619310408531e-20*V01*V04*V23 - 3.09366062819588764e-21*V07*V23 + 5.71594254072700712e-21*V022*V24 + 
      1.13753964584449765e-20*V01*V03*V24 - 9.8115444576895747e-22*V06*V24 + 1.42545509624368692e-21*V01*V02*V25 - 
      2.66421094497812289e-22*V05*V25 + 7.9437126106459333e-23*V012*V26 - 5.70244159417206115e-23*V04*V26 - 
      1.04570214881099937e-23*V03*V27 - 1.17770910324011067e-24*V02*V28 - 1.26183118204297572e-25*V01*V29 + 
      7.35332856668400769e-29*V32) + 1.15163356207719503e-37*delta32*V32 + 
   9.21306849661756022e-37*delta30*eps*V32 + 
   delta30*eps2*(-7.66476789625411319e-30*V162 - 1.62876317795399905e-29*V15*V17 - 
      1.20014128901873614e-29*V14*V18 - 1.00011774084894679e-29*V13*V19 - 5.71495851913683878e-30*V12*V20 - 
      3.71472303743894521e-30*V11*V21 - 1.6150969727995414e-30*V10*V22 - 8.07548486399770698e-31*V09*V23 - 
      2.58415515647926623e-31*V08*V24 - 9.69058183679724837e-32*V07*V25 - 2.15346263039938853e-32*V06*V26 - 
      5.79778400492143065e-33*V05*V27 - 7.99694345506404227e-34*V04*V28 - 1.42802561697572183e-34*V03*V29 - 
      9.21306849661756022e-36*V02*V30 - 9.21306849661756022e-37*V01*V31 + 6.58076321186968587e-39*V34) + 
   delta28*eps3*(-1.14971518443811698e-28*V162 - 2.44314476693099858e-28*V15*V17 - 
      1.80021193352810422e-28*V14*V18 - 1.50017661127342018e-28*V13*V19 - 8.57243777870525817e-29*V12*V20 - 
      5.57208455615841781e-29*V11*V21 - 2.42264545919931209e-29*V10*V22 - 1.21132272959965605e-29*V09*V23 - 
      3.87623273471889935e-30*V08*V24 - 1.45358727551958726e-30*V07*V25 - 3.23019394559908279e-31*V06*V26 - 
      8.69667600738214597e-32*V05*V27 - 1.19954151825960634e-32*V04*V28 - 2.14203842546358275e-33*V03*V29 - 
      1.38196027449263403e-34*V02*V30 - 1.38196027449263403e-35*V01*V31 + 4.93557240890226441e-38*V34) + 
   delta26*eps4*(1.35854611265666302e-23*V103 + 9.96267149281552879e-23*V09*V10*V11 + 
      4.00239498233110809e-23*V08*V112 + 4.19279231448653529e-23*V092*V12 + 
      5.51217550364685268e-23*V08*V10*V12 + 5.48874630260055529e-23*V07*V11*V12 + 1.14278512761837203e-23*V06*V122 + 
      5.64440318021053705e-23*V08*V09*V13 + 4.59815607360716713e-23*V07*V10*V13 + 2.78096479331761468e-23*V06*V11*V13 + 
      1.47773938916168796e-23*V05*V12*V13 + 2.50344052896390211e-24*V04*V132 + 
      1.34419298551894429e-23*V082*V14 + 3.33231075452001759e-23*V07*V09*V14 + 1.64841190441126585e-23*V06*V10*V14 + 
      1.27233683354400672e-23*V05*V11*V14 + 3.5419003320954393e-24*V04*V12*V14 + 1.63120106864616246e-24*V03*V13*V14 + 
      9.79658113066229752e-26*V02*V142 + 1.93522394750075556e-23*V07*V08*V15 + 1.45669584411875055e-23*V06*V09*V15 + 
      9.19631214721433427e-24*V05*V10*V15 + 3.71939735731779741e-24*V04*V11*V15 + 1.4073708468206552e-24*V03*V12*V15 + 
      2.39055329025730705e-25*V02*V13*V15 + 4.66057448184617845e-26*V01*V14*V15 + 4.99846613178002639e-24*V072*V16 + 
      6.06853113804515005e-24*V06*V08*V16 + 5.83154382041003079e-24*V05*V09*V16 + 1.92822022014794669e-24*V04*V10*V16 + 
      1.0602806946200056e-24*V03*V11*V16 + 1.47894999664392795e-25*V02*V12*V16 + 4.07800267161540615e-26*V01*V13*V16 - 
      1.10724989778709621e-27*V162 + 3.85595958737316321e-24*V06*V07*V17 + 2.98821344834675491e-24*V05*V08*V17 + 
      1.50416804891528572e-24*V04*V09*V17 + 6.76199422589289284e-25*V03*V10*V17 + 1.37105262235345551e-25*V02*V11*V17 + 
      3.10449451504556295e-26*V01*V12*V17 - 2.32256375101472671e-27*V15*V17 + 5.34682655334132956e-25*V062*V18 + 
      1.3659775866200477e-24*V05*V07*V18 + 5.54146808862024479e-25*V04*V08*V18 + 3.79438218505568805e-25*V03*V09*V18 + 
      6.2852656088224041e-26*V02*V10*V18 + 2.0696630100303753e-26*V01*V11*V18 - 1.73691415909114829e-27*V14*V18 + 
      4.73538896694949868e-25*V05*V06*V19 + 3.16666957666375941e-25*V04*V07*V19 + 1.74749324464722509e-25*V03*V08*V19 + 
      4.40981837599064639e-26*V02*V09*V19 + 1.18631477647243734e-26*V01*V10*V19 - 1.43145884391831513e-27*V13*V19 + 
      7.47378309177635525e-26*V052*V20 + 7.81765620164983242e-26*V04*V06*V20 + 7.11788865883462405e-26*V03*V07*V20 + 
      1.44610644816170373e-26*V02*V08*V20 + 5.9315738823621867e-27*V01*V09*V20 - 8.31664729659873031e-28*V12*V20 + 
      3.16666957666375941e-26*V04*V05*V21 + 2.2549471271188089e-26*V03*V06*V21 + 7.55968864455539381e-27*V02*V07*V21 + 
      2.49641892092460727e-27*V01*V08*V21 - 5.35639096043615648e-28*V11*V21 + 2.32999099286296679e-27*V042*V22 + 
      6.35452088962627306e-27*V03*V05*V22 + 1.66344453238788251e-27*V02*V06*V22 + 9.07788698518039009e-28*V01*V07*V22 - 
      2.3718480544096491e-28*V10*V22 + 1.25164805401729621e-27*V03*V04*V23 + 6.27484037690368656e-28*V02*V05*V23 + 
      2.67385034836222399e-28*V01*V06*V23 - 1.17732754331734312e-28*V09*V23 + 1.11410431181759333e-28*V032*V24 + 
      8.16914970912993933e-29*V02*V04*V24 + 6.68462587090555997e-29*V01*V05*V24 - 3.84309719682533456e-29*V08*V24 + 
      2.09161345896789552e-29*V02*V03*V25 + 1.25164805401729621e-29*V01*V04*V25 - 1.43342461331076717e-29*V07*V25 + 
      5.86537107541261707e-31*V022*V26 + 1.92561239079584032e-30*V01*V03*V26 - 3.25415990067933405e-30*V06*V26 + 
      1.78770381108367139e-31*V01*V02*V27 - 8.73034055966878654e-31*V05*V27 + 6.38465646815596924e-33*V012*V28 - 
      1.23185174947724412e-31*V04*V28 - 2.19593487616879548e-32*V03*V29 - 1.45105828821726574e-33*V02*V30 - 
      1.45105828821726574e-34*V01*V31 + 3.45490068623158508e-37*V34) + 
   delta24*eps5*(2.41519308916740092e-22*V103 + 1.71108882889106707e-21*V09*V10*V11 + 
      6.86471381818002175e-22*V08*V112 + 7.21315566695924313e-22*V092*V12 + 
      9.80280577669423613e-22*V08*V10*V12 + 9.44267650947391827e-22*V07*V11*V12 + 2.03355704893272539e-22*V06*V122 + 
      9.68100666666413324e-22*V08*V09*V13 + 7.89733305642030955e-22*V07*V10*V13 + 4.76433343410733015e-22*V06*V11*V13 + 
      2.542259060242978e-22*V05*V12*V13 + 4.28473475149590937e-23*V04*V132 + 2.3924488726292268e-22*V082*V14 + 
      5.744764894511072e-22*V07*V09*V14 + 2.93468385565599264e-22*V06*V10*V14 + 2.19345568699513658e-22*V05*V11*V14 + 
      6.31084029815346022e-23*V04*V12*V14 + 2.81212267563479049e-23*V03*V13*V14 + 1.74807256283651969e-24*V02*V142 + 
      3.31920228571341711e-22*V07*V08*V15 + 2.49560322738955389e-22*V06*V09*V15 + 1.57946661128406191e-22*V05*V10*V15 + 
      6.3658916307939225e-23*V04*V11*V15 + 2.42119910499331238e-23*V03*V12*V15 + 4.08813071601740664e-24*V02*V13*V15 + 
      8.03463621609940139e-25*V01*V14*V15 + 8.64020574207690276e-23*V072*V16 + 1.08198681368502136e-22*V06*V08*V16 + 
      1.00802400324230532e-22*V05*V09*V16 + 3.43954095628884356e-23*V04*V10*V16 + 1.83277091498600968e-23*V03*V11*V16 + 
      2.64075255191431242e-24*V02*V12*V16 + 7.04911890379234491e-25*V01*V13*V16 - 8.51336278386479539e-27*V162 + 
      6.60600854308999559e-23*V06*V07*V17 + 5.12523882352807054e-23*V05*V08*V17 + 2.57444146833577748e-23*V04*V09*V17 + 
      1.16137250829710435e-23*V03*V10*V17 + 2.3446632047746891e-24*V02*V11*V17 + 5.34088037866171848e-25*V01*V12*V17 - 
      1.74992214209470621e-26*V15*V17 + 9.55924124427058141e-24*V062*V18 + 2.36959167456727719e-23*V05*V07*V18 + 
      9.90930504985643715e-24*V04*V08*V18 + 6.58219909602021441e-24*V03*V09*V18 + 1.12466416877841084e-24*V02*V10*V18 + 
      3.59029041601102604e-25*V01*V11*V18 - 1.33924153583952063e-26*V14*V18 + 8.11264207046139809e-24*V05*V06*V19 + 
      5.41987677544374206e-24*V04*V07*V19 + 2.99721568627372546e-24*V03*V08*V19 + 7.54131440132209945e-25*V02*V09*V19 + 
      2.03749562859141113e-25*V01*V10*V19 - 1.08489385031719904e-26*V13*V19 + 1.30292951899967793e-24*V052*V20 + 
      1.40401461022637667e-24*V04*V06*V20 + 1.24088525619016946e-24*V03*V07*V20 + 2.59813805165022662e-25*V02*V08*V20 + 
      1.03407104682514122e-25*V01*V09*V20 - 6.46631425509029293e-27*V12*V20 + 5.41987677544374206e-25*V04*V05*V21 + 
      3.86316289069590385e-25*V03*V06*V21 + 1.29279675451235991e-25*V02*V07*V21 + 4.28173669467675066e-26*V01*V08*V21 - 
      4.10671619022030487e-27*V11*V21 + 4.21516552345209446e-26*V042*V22 + 1.11601273124061421e-25*V03*V05*V22 + 
      3.0098516875829823e-26*V02*V06*V22 + 1.59430390177230601e-26*V01*V07*V22 - 1.86934449625959823e-27*V10*V22 + 
      2.14224378476037236e-26*V03*V04*V23 + 1.07307240493120783e-26*V02*V05*V23 + 4.58082556209000457e-27*V01*V06*V23 - 
      9.17909104549210329e-28*V09*V23 + 1.98062988767572147e-27*V032*V24 + 1.49712094785480732e-27*V02*V04*V24 + 
      1.18837793260543288e-27*V01*V05*V24 - 3.08482479806665439e-28*V08*V24 + 3.57690801643735942e-28*V02*V03*V25 + 
      2.14224378476037236e-28*V01*V04*V25 - 1.14172247005246549e-28*V07*V25 + 1.1037226577128648e-29*V022*V26 + 
      3.50621922824075925e-29*V01*V03*V26 - 2.67126619320574472e-29*V06*V26 + 3.05718633883534994e-30*V01*V02*V27 - 
      7.13169513295694271e-30*V05*V27 + 1.245008011290414e-31*V012*V28 - 1.03763243446032383e-30*V04*V28 - 
      1.8455042995643258e-31*V03*V29 - 1.25758384978829697e-32*V02*V30 - 1.25758384978829697e-33*V01*V31 + 
      2.2456854460505303e-36*V34) + delta22*eps6*
    (-4.00812373053833039e-19*V074 - 3.49726544829660921e-18*V06*V072*V08 - 
      8.64445679709959123e-19*V062*V082 - 2.70617202604429337e-18*V05*V07*V082 - 
      2.9749513416244502e-19*V04*V083 - 2.62853235255092774e-18*V062*V07*V09 - 
      2.79545974967120934e-18*V05*V072*V09 - 4.08014302301271075e-18*V05*V06*V08*V09 - 
      2.72386052248094652e-18*V04*V07*V08*V09 - 7.51714451678970381e-19*V03*V082*V09 - 
      8.12017065854686979e-19*V052*V092 - 1.02005917448534291e-18*V04*V06*V092 - 
      7.70508791610044998e-19*V03*V07*V092 - 1.88648217281916666e-19*V02*V08*V092 - 
      2.11481659857383429e-20*V01*V093 - 3.519969591811684e-19*V063*V10 - 
      3.3180041620857579e-18*V05*V06*V07*V10 - 1.1108639573752765e-18*V04*V072*V10 - 
      1.27957782633264032e-18*V052*V08*V10 - 1.08977927390381499e-18*V04*V06*V08*V10 - 
      1.21864554888822888e-18*V03*V07*V08*V10 - 9.99769019598000041e-20*V02*V082*V10 - 
      1.29600795027115591e-18*V04*V05*V09*V10 - 9.21667822801599418e-19*V03*V06*V09*V10 - 
      3.08817774945004323e-19*V02*V07*V09*V10 - 1.0155379574068574e-19*V01*V08*V09*V10 - 
      8.56950366174159031e-20*V042*V102 - 2.86853880374272774e-19*V03*V05*V102 - 
      6.09433865536669912e-20*V02*V06*V102 - 4.09791257677532534e-20*V01*V07*V102 + 
      2.47555373950046052e-21*V103 - 1.00362144370126332e-18*V05*V062*V11 - 
      1.05909935719489822e-18*V052*V07*V11 - 1.3353501920535398e-18*V04*V06*V07*V11 - 
      5.02260074841224833e-19*V03*V072*V11 - 1.04001947221999776e-18*V04*V05*V08*V11 - 
      7.41844186002311045e-19*V03*V06*V08*V11 - 2.46957666259963636e-19*V02*V07*V08*V11 - 
      4.10026064552165662e-20*V01*V082*V11 - 2.57817723127360337e-19*V042*V09*V11 - 
      5.82646147197305077e-19*V03*V05*V09*V11 - 1.84046858177384574e-19*V02*V06*V09*V11 - 
      8.25797669194187712e-20*V01*V07*V09*V11 - 2.35637809140210166e-19*V03*V04*V10*V11 - 
      1.17912241342638014e-19*V02*V05*V10*V11 - 5.02727903346326955e-20*V01*V06*V10*V11 + 1.67428751596384005e-20*V09*V10*V11 - 
      2.59692449955761322e-20*V032*V112 - 2.30573249011165112e-20*V02*V04*V112 - 
      1.5522383334585883e-20*V01*V05*V112 + 6.71944950419909536e-21*V08*V112 - 
      5.30316476641187492e-19*V052*V06*V12 - 2.24068957103656314e-19*V04*V062*V12 - 
      7.12496848387961882e-19*V04*V05*V07*V12 - 5.05063311086845231e-19*V03*V06*V07*V12 - 
      8.51431060402916546e-20*V02*V072*V12 - 1.15438433606636211e-19*V042*V08*V12 - 
      3.87856075251527312e-19*V03*V05*V08*V12 - 8.20603833491245814e-20*V02*V06*V08*V12 - 
      5.54080107502181874e-20*V01*V07*V08*V12 - 1.97915791218878301e-19*V03*V04*V09*V12 - 
      9.9333623713673597e-20*V02*V05*V09*V12 - 4.20886092572371025e-20*V01*V06*V09*V12 + 
      7.07577722506606023e-21*V092*V12 - 4.3157191266873829e-20*V032*V10*V12 - 
      2.56683059798138929e-20*V02*V04*V10*V12 - 2.58943147601242974e-20*V01*V05*V10*V12 + 1.00745856732102069e-20*V08*V10*V12 - 
      1.80606588570315631e-20*V02*V03*V11*V12 - 1.07954067937569982e-20*V01*V04*V11*V12 + 9.28712285796816863e-21*V07*V11*V12 - 
      4.72266958345693077e-22*V022*V122 - 1.91756179114575899e-21*V01*V03*V122 + 
      2.10089050876714474e-21*V06*V122 - 9.39156036893935474e-20*V053*V13 - 
      3.59517359399029947e-19*V04*V05*V06*V13 - 1.28669415859136323e-19*V03*V062*V13 - 
      1.18992795289550925e-19*V042*V07*V13 - 2.66796170047352953e-19*V03*V05*V07*V13 - 
      8.49447037741774957e-20*V02*V06*V07*V13 - 1.88675599074162535e-20*V01*V072*V13 - 
      1.33335829771794585e-19*V03*V04*V08*V13 - 6.64886024546055942e-20*V02*V05*V08*V13 - 
      2.85324686923965786e-20*V01*V06*V08*V13 - 3.64842343334283575e-20*V032*V09*V13 - 
      3.25167402451643106e-20*V02*V04*V09*V13 - 2.17975235054346627e-20*V01*V05*V09*V13 + 9.50117820573796748e-21*V08*V09*V13 - 
      1.51169540182869249e-20*V02*V03*V10*V13 - 9.06299265923885253e-21*V01*V04*V10*V13 + 7.768225846593129e-21*V07*V10*V13 - 
      1.42646386642505068e-21*V022*V11*V13 - 3.81901181559831086e-21*V01*V03*V11*V13 + 
      4.69067498599230351e-21*V06*V11*V13 - 6.94640725270444734e-22*V01*V02*V12*V13 + 2.51999583004971792e-21*V05*V12*V13 - 
      3.28541707191029232e-23*V012*V132 + 4.2546602630193112e-22*V04*V132 - 
      8.20962930210004819e-20*V04*V052*V14 - 3.40785762391412531e-20*V042*V06*V14 - 
      1.15886002537218364e-19*V03*V05*V06*V14 - 1.20933274245232833e-20*V02*V062*V14 - 
      7.81869457342861732e-20*V03*V04*V07*V14 - 3.93683346878662317e-20*V02*V05*V07*V14 - 
      1.65551432196026234e-20*V01*V06*V07*V14 - 2.10347923334380714e-20*V032*V08*V14 - 
      1.24110732586668831e-20*V02*V04*V08*V14 - 1.26208754000628429e-20*V01*V05*V08*V14 + 
      2.47208325017685066e-21*V082*V14 - 1.09356485244072866e-20*V02*V03*V09*V14 - 
      6.51557881119051444e-21*V01*V04*V09*V14 + 5.68074000145817123e-21*V07*V09*V14 - 
      6.78334500594629911e-22*V022*V10*V14 - 2.76503925083144851e-21*V01*V03*V10*V14 + 
      3.04015417883098928e-21*V06*V10*V14 - 5.96489919513124723e-22*V01*V02*V11*V14 + 2.18024940345826757e-21*V05*V11*V14 - 
      5.84865268219324485e-23*V012*V12*V14 + 6.5879287790568701e-22*V04*V12*V14 + 2.82401099089442793e-22*V03*V13*V14 + 
      1.84807997956750185e-23*V02*V142 - 2.3798559057910185e-20*V042*V05*V15 - 
      2.62028402352424313e-20*V03*V052*V15 - 3.42397485141933283e-20*V03*V04*V06*V15 - 
      1.69889407548354991e-20*V02*V05*V06*V15 - 3.67626902454675208e-21*V01*V062*V15 - 
      1.23548974149434626e-20*V032*V07*V15 - 1.11485966554849065e-20*V02*V04*V07*V15 - 
      7.36910627159301524e-21*V01*V05*V07*V15 - 6.3322478528195804e-21*V02*V03*V08*V15 - 
      3.80959513633698815e-21*V01*V04*V08*V15 + 3.28329346727272258e-21*V07*V08*V15 - 
      7.47195358603597975e-22*V022*V09*V15 - 1.98362971014353397e-21*V01*V03*V09*V15 + 
      2.46994952868298608e-21*V06*V09*V15 - 4.31912971951054997e-22*V01*V02*V10*V15 + 1.569943170791865e-21*V05*V10*V15 - 
      4.85951940692613529e-23*V012*V11*V15 + 6.33772484178823997e-22*V04*V11*V15 + 
      2.43113348744145818e-22*V03*V12*V15 + 4.1156726725757944e-23*V02*V13*V15 + 8.19211475112356447e-24*V01*V14*V15 - 
      1.29551756675992026e-21*V043*V16 - 1.35322399644681519e-20*V03*V04*V05*V16 - 
      3.42152491340750472e-21*V02*V052*V16 - 4.74109004853112273e-21*V032*V06*V16 - 
      2.74730095666439821e-21*V02*V04*V06*V16 - 2.84465402911867364e-21*V01*V05*V06*V16 - 
      3.25859515562619497e-21*V02*V03*V07*V16 - 1.93317713778116455e-21*V01*V04*V07*V16 + 
      8.63772923792104737e-22*V072*V16 - 2.46311702117969774e-22*V022*V08*V16 - 
      1.01676364796578368e-21*V01*V03*V08*V16 + 1.13008989640707247e-21*V06*V08*V16 - 2.71549596302182914e-22*V01*V02*V09*V16 + 
      1.01030391811032656e-21*V05*V09*V16 - 3.18230291879855675e-23*V012*V10*V16 + 
      3.61045188577497026e-22*V04*V10*V16 + 1.85092807121625394e-22*V03*V11*V16 + 2.79962494002036427e-23*V02*V12*V16 + 
      7.20877371282024363e-24*V01*V13*V16 - 5.6041114596689983e-26*V162 - 
      1.74989404837574889e-21*V03*V042*V17 - 1.86140405743255068e-21*V032*V05*V17 - 
      1.72147448356752233e-21*V02*V04*V05*V17 - 5.52739842291651387e-22*V01*V052*V17 - 
      1.24918682020849258e-21*V02*V03*V06*V17 - 7.552885701660293e-22*V01*V04*V06*V17 - 
      1.97787006689187699e-22*V022*V07*V17 - 5.15062133998228234e-22*V01*V03*V07*V17 + 
      6.60655091788203094e-22*V06*V07*V17 - 1.39681937929843685e-22*V01*V02*V08*V17 + 5.13605115429535696e-22*V05*V08*V17 - 
      1.93694113369324223e-23*V012*V09*V17 + 2.58308744224028524e-22*V04*V09*V17 + 
      1.17234571544244396e-22*V03*V10*V17 + 2.37264041613382399e-23*V02*V11*V17 + 5.45895425689678472e-24*V01*V12*V17 - 
      1.12668406492524784e-25*V15*V17 - 4.31692792986570499e-22*V032*V04*V18 - 
      1.20910782348239812e-22*V02*V042*V18 - 4.39714635244959621e-22*V02*V03*V05*V18 - 
      2.59015675791942299e-22*V01*V04*V05*V18 - 4.22478626618183358e-23*V022*V06*V18 - 
      1.78740473937091797e-22*V01*V03*V06*V18 + 1.01211812860896262e-22*V062*V18 - 
      6.28163764635656602e-23*V01*V02*V07*V18 + 2.40803625970934142e-22*V05*V07*V18 - 
      9.13306929740652778e-24*V012*V08*V18 + 1.05173362611291638e-22*V04*V08*V18 + 6.7222780120056036e-23*V03*V09*V18 + 
      1.20236173793543005e-23*V02*V10*V18 + 3.70301171749601372e-24*V01*V11*V18 - 8.84242675422320975e-26*V14*V18 - 
      3.46430949189625438e-23*V033*V19 - 1.00671022430849259e-22*V02*V03*V04*V19 - 
      3.06998955855394543e-23*V01*V042*V19 - 2.42896324004265596e-23*V022*V05*V19 - 
      6.09628806092774045e-23*V01*V03*V05*V19 - 2.19155582492717997e-23*V01*V02*V06*V19 + 8.23939882112686568e-23*V05*V06*V19 - 
      3.96163683492057662e-24*V012*V07*V19 + 5.50838393016338671e-23*V04*V07*V19 + 
      3.05778645245882384e-23*V03*V08*V19 + 7.7096574678976154e-24*V02*V09*V19 + 2.09879537661016794e-24*V01*V10*V19 - 
      7.02914175772732108e-26*V13*V19 - 1.12040168091089179e-23*V02*V032*V20 - 
      2.93920944924782268e-24*V022*V04*V20 - 1.30048819773043469e-23*V01*V03*V04*V20 - 
      6.72241008546535077e-24*V01*V02*V05*V20 + 1.3499666271707695e-23*V052*V20 - 
      1.28456013722623718e-24*V012*V06*V20 + 1.51517066990846694e-23*V04*V06*V20 + 
      1.28878237439519341e-23*V03*V07*V20 + 2.81695552158632922e-24*V02*V08*V20 + 1.0817349928154792e-24*V01*V09*V20 - 
      4.30769289366591523e-26*V12*V20 - 1.15664916192507427e-24*V022*V03*V21 - 
      1.34793662263680984e-24*V01*V032*V21 - 1.43815746329784656e-24*V01*V02*V04*V21 - 
      3.75057596251513255e-25*V012*V05*V21 + 5.60681107631549794e-24*V04*V05*V21 + 
      4.00358082044737049e-24*V03*V06*V21 + 1.34180473605596571e-24*V02*V07*V21 + 4.46790511404883729e-25*V01*V08*V21 - 
      2.69384566209160438e-26*V11*V21 - 1.89032910090025309e-26*V023*V22 - 2.73916579264947352e-25*V01*V02*V03*V22 - 
      7.60304338067427257e-26*V012*V04*V22 + 4.65216926402460735e-25*V042*V22 + 
      1.18558964823500434e-24*V03*V05*V22 + 3.32928618343867167e-25*V02*V06*V22 + 1.70149731296153738e-25*V01*V07*V22 - 
      1.26354569551047192e-26*V10*V22 - 1.37152074536570071e-26*V01*V022*V23 - 
      1.32026625555689695e-26*V012*V03*V23 + 2.2661503020653578e-25*V03*V04*V23 + 1.13605044351121604e-25*V02*V05*V23 + 
      4.86599144562690201e-26*V01*V06*V23 - 6.13035477185315229e-27*V09*V23 - 1.30709241078676265e-27*V012*V02*V24 + 
      2.16602580921985029e-26*V032*V24 + 1.70096614906745066e-26*V02*V04*V24 + 1.30239434341311038e-26*V01*V05*V24 - 
      2.12660238800831116e-27*V08*V24 - 3.08761986800022672e-29*V013*V25 + 3.87974929847257879e-27*V02*V03*V25 + 
      2.32728517545176229e-27*V01*V04*V25 - 7.80281445575759432e-28*V07*V25 + 1.30045236805988044e-28*V022*V26 + 
      3.98103761690222781e-28*V01*V03*V26 - 1.88679832285597432e-28*V06*V26 + 3.41132195093573436e-29*V01*V02*V27 - 
      5.00961041730867675e-29*V05*V27 + 1.4940096135484968e-30*V012*V28 - 7.539466696250798e-30*V04*V28 - 
      1.33744042424985383e-30*V03*V29 - 9.43187887341222728e-32*V02*V30 - 9.43187887341222728e-33*V01*V31 + 
      1.34741126763031818e-35*V34) + delta20*eps7*
    (-6.8806124040908005e-18*V074 - 6.07772906840591224e-17*V06*V072*V08 - 
      1.6804681025869992e-17*V062*V082 - 4.7141802172589777e-17*V05*V07*V082 - 
      5.79167647039782578e-18*V04*V083 - 4.56007363364874785e-17*V062*V07*V09 - 
      4.80313376264625183e-17*V05*V072*V09 - 7.09068391314023095e-17*V05*V06*V08*V09 - 
      4.72744658958646757e-17*V04*V07*V08*V09 - 1.30949450479416047e-17*V03*V082*V09 - 
      1.39659104463258298e-17*V052*V092 - 1.76872339069042297e-17*V04*V06*V092 - 
      1.32639367578019175e-17*V03*V07*V092 - 3.27352646262625609e-18*V02*V08*V092 - 
      3.65129559672135471e-19*V01*V093 - 6.8535770329607871e-18*V063*V10 - 
      5.78317959150047557e-17*V05*V06*V07*V10 - 1.93239614418073861e-17*V04*V072*V10 - 
      2.23709301861946398e-17*V052*V08*V10 - 2.12519185296997752e-17*V04*V06*V08*V10 - 
      2.13056477963758474e-17*V03*V07*V08*V10 - 1.95546556492267008e-18*V02*V082*V10 - 
      2.25446216821086172e-17*V04*V05*V09*V10 - 1.60643877541679877e-17*V03*V06*V09*V10 - 
      5.36675967313952978e-18*V02*V07*V09*V10 - 1.77547064969798728e-18*V01*V08*V09*V10 - 
      1.67731150173420976e-18*V042*V102 - 5.03754022091824041e-18*V03*V05*V102 - 
      1.19452496543992954e-18*V02*V06*V102 - 7.19648602988320059e-19*V01*V07*V102 + 
      1.87409997973777257e-20*V103 - 1.74111902375679463e-17*V05*V062*V11 - 
      1.82318839798149993e-17*V052*V07*V11 - 2.31541971144928098e-17*V04*V06*V07*V11 - 
      8.65490113306988592e-18*V03*V072*V11 - 1.80502506147846943e-17*V04*V05*V08*V11 - 
      1.28921525693458744e-17*V03*V06*V08*V11 - 4.28534373289255343e-18*V02*V07*V08*V11 - 
      7.14269729887723894e-19*V01*V082*V11 - 4.47343270739305379e-18*V042*V09*V11 - 
      1.00541734337212563e-17*V03*V05*V09*V11 - 3.1944941391431352e-18*V02*V06*V09*V11 - 
      1.42779032997477121e-18*V01*V07*V09*V11 - 4.09902212401974857e-18*V03*V04*V10*V11 - 
      2.04912642065327501e-18*V02*V05*V10*V11 - 8.76239332045526602e-19*V01*V06*V10*V11 + 1.20724724016033249e-19*V09*V10*V11 - 
      4.50317163131412003e-19*V032*V112 - 4.01339341318224116e-19*V02*V04*V112 - 
      2.6942117026296985e-19*V01*V05*V112 + 4.85455216315177919e-20*V08*V112 - 
      9.28353673165345401e-18*V052*V06*V12 - 4.38485774862640686e-18*V04*V062*V12 - 
      1.24399526058491295e-17*V04*V05*V07*V12 - 8.84146355395567049e-18*V03*V06*V07*V12 - 
      1.48414881541701913e-18*V02*V072*V12 - 2.26353881461301804e-18*V042*V08*V12 - 
      6.81630484736776447e-18*V03*V05*V08*V12 - 1.61150741857024841e-18*V02*V06*V08*V12 - 
      9.73757835338252067e-19*V01*V07*V08*V12 - 3.45554239051364708e-18*V03*V04*V09*V12 - 
      1.73150695131985566e-18*V02*V05*V09*V12 - 7.36788629496305874e-19*V01*V06*V09*V12 + 
      5.11512913686496637e-20*V092*V12 - 7.62927789424342721e-19*V032*V10*V12 - 
      5.06698951927917361e-19*V02*V04*V10*V12 - 4.57756673654605633e-19*V01*V05*V10*V12 + 7.65977393150576483e-20*V08*V10*V12 - 
      3.1481944569451921e-19*V02*V03*V11*V12 - 1.88484130391653477e-19*V01*V04*V11*V12 + 6.74431846134640597e-20*V07*V11*V12 - 
      9.4477493446154428e-21*V022*V122 - 3.42265712385233325e-20*V01*V03*V122 + 
      1.61096263135735036e-20*V06*V122 - 1.62148164737197839e-18*V053*V13 - 
      6.23382230005575648e-18*V04*V05*V06*V13 - 2.23220387661127517e-18*V03*V062*V13 - 
      2.06466124956602482e-18*V042*V07*V13 - 4.61286106607233774e-18*V03*V05*V07*V13 - 
      1.47438191037375471e-18*V02*V06*V07*V13 - 3.27029054186179106e-19*V01*V072*V13 - 
      2.31413469420316594e-18*V03*V04*V08*V13 - 1.15374638962491823e-18*V02*V05*V08*V13 - 
      4.95852021897918248e-19*V01*V06*V08*V13 - 6.3325488737022828e-19*V032*V09*V13 - 
      5.65991378782110932e-19*V02*V04*V09*V13 - 3.78743710192046394e-19*V01*V05*V09*V13 + 6.89542523809328857e-20*V08*V09*V13 - 
      2.62708515468368591e-19*V02*V03*V10*V13 - 1.57654697077682637e-19*V01*V04*V10*V13 + 5.65235908536249583e-20*V07*V10*V13 - 
      2.50308763017485368e-20*V022*V11*V13 - 6.69882271703045465e-20*V01*V03*V11*V13 + 
      3.42587712458782707e-20*V06*V11*V13 - 1.21084402190199696e-20*V01*V02*V12*V13 + 1.8546679549186266e-20*V05*V12*V13 - 
      5.93845311343785169e-22*V012*V132 + 3.15397316328807492e-21*V04*V132 - 
      1.44112535538887772e-18*V04*V052*V14 - 6.72068886054086452e-19*V042*V06*V14 - 
      2.04136030392353062e-18*V03*V05*V06*V14 - 2.38960503254437743e-19*V02*V062*V14 - 
      1.37250033846559783e-18*V03*V04*V07*V14 - 6.89497301433408704e-19*V02*V05*V07*V14 - 
      2.91622900560504374e-19*V01*V06*V07*V14 - 3.72504827129704604e-19*V032*V08*V14 - 
      2.45995287719801078e-19*V02*V04*V08*V14 - 2.23502896277822763e-19*V01*V05*V08*V14 + 
      1.89556842059043217e-20*V082*V14 - 1.91527028175946862e-19*V02*V03*V09*V14 - 
      1.14375028205466486e-19*V01*V04*V09*V14 + 4.15428552843776348e-20*V07*V09*V14 - 
      1.35994911069011887e-20*V022*V10*V14 - 4.94025889883571771e-20*V01*V03*V10*V14 + 
      2.34097877536784348e-20*V06*V10*V14 - 1.04469288095971016e-20*V01*V02*V11*V14 + 1.60858063391307991e-20*V05*V11*V14 - 
      1.06547194514737808e-21*V012*V12*V14 + 5.13614972135705994e-21*V04*V12*V14 + 2.1197159067895599e-21*V03*V13*V14 + 
      1.46995434308547988e-22*V02*V142 - 4.12932249913204965e-19*V042*V05*V15 - 
      4.55088008603826542e-19*V03*V052*V15 - 5.93697361910072046e-19*V03*V04*V06*V15 - 
      2.94876382074750942e-19*V02*V05*V06*V15 - 6.37772536174650048e-20*V01*V062*V15 - 
      2.15114183320776888e-19*V032*V07*V15 - 1.94054187011009463e-19*V02*V04*V07*V15 - 
      1.28498691686616322e-19*V01*V05*V07*V15 - 1.09880608535706498e-19*V02*V03*V08*V15 - 
      6.61181341200904555e-20*V01*V04*V08*V15 + 2.41481521074733583e-20*V07*V08*V15 - 
      1.31114113961539955e-20*V022*V09*V15 - 3.48706057196179206e-20*V01*V03*V09*V15 + 
      1.81988375091512542e-20*V06*V09*V15 - 7.50595758481053116e-21*V01*V02*V10*V15 + 1.16265131553688367e-20*V05*V10*V15 - 
      8.79467145293633379e-22*V012*V11*V15 + 4.71824546393568535e-21*V04*V11*V15 + 
      1.82808044537179639e-21*V03*V12*V15 + 3.12052106965673026e-22*V02*V13*V15 + 6.30247277424916457e-23*V01*V14*V15 - 
      2.5831436559558207e-20*V043*V16 - 2.39399480309322067e-19*V03*V04*V05*V16 - 
      6.03422417972526764e-20*V02*V052*V16 - 8.42815777587801839e-20*V032*V06*V16 - 
      5.49465561484217533e-20*V02*V04*V06*V16 - 5.05689466552681104e-20*V01*V05*V06*V16 - 
      5.74688017116692156e-20*V02*V03*V07*V16 - 3.4199925758474581e-20*V01*V04*V07*V16 + 
      6.41608387676488055e-21*V072*V16 - 4.97248402233957802e-21*V022*V08*V16 - 
      1.82244749455697456e-20*V01*V03*V08*V16 + 8.8102785830923894e-21*V06*V08*V16 - 4.78906680930576797e-21*V01*V02*V09*V16 + 
      7.53697925263997274e-21*V05*V09*V16 - 5.81055026547601897e-22*V012*V10*V16 + 
      2.83766860240221783e-21*V04*V10*V16 + 1.39847698943323801e-21*V03*V11*V16 + 2.23552576253702192e-22*V02*V12*V16 + 
      5.55899563446680853e-23*V01*V13*V16 - 3.24649367279895418e-25*V162 - 
      3.03626654347944827e-20*V03*V042*V17 - 3.26137737426286688e-20*V032*V05*V17 - 
      2.99642494649352847e-20*V02*V04*V05*V17 - 9.71027424859312102e-21*V01*V052*V17 - 
      2.16820869172610987e-20*V02*V03*V06*V17 - 1.30962653362515893e-20*V01*V04*V06*V17 - 
      3.47066772251135174e-21*V022*V07*V17 - 9.1002423122642556e-21*V01*V03*V07*V17 + 
      4.95168650000681164e-21*V06*V07*V17 - 2.4238369529935257e-21*V01*V02*V08*V17 + 3.85915801064201055e-21*V05*V08*V17 - 
      3.51987121142091846e-22*V012*V09*V17 + 1.94735301077586016e-21*V04*V09*V17 + 
      8.90382767083426782e-22*V03*V10*V17 + 1.81351995786129813e-22*V02*V11*V17 + 4.22316719632531442e-23*V01*V12*V17 - 
      6.3978061310397304e-25*V15*V17 - 7.72537774692003327e-21*V032*V04*V18 - 
      2.4581282797918125e-21*V02*V042*V18 - 7.83429662538360927e-21*V02*V03*V05*V18 - 
      4.63522664815201996e-21*V01*V04*V05*V18 - 8.64318791730753807e-22*V022*V06*V18 - 
      3.22322582306313542e-21*V01*V03*V06*V18 + 8.05008860125783341e-22*V062*V18 - 
      1.11918523219765847e-21*V01*V02*V07*V18 + 1.83120292057985055e-21*V05*V07*V18 - 
      1.67608687730938736e-22*V012*V08*V18 + 8.39805005542868034e-22*V04*V08*V18 + 
      5.15411708123647746e-22*V03*V09*V18 + 9.7126559159009247e-23*V02*V10*V18 + 2.88491000996317356e-23*V01*V11*V18 - 
      5.13606171647815692e-25*V14*V18 - 6.14405477533365115e-22*V033*V19 - 1.75229529034709267e-21*V02*V03*V04*V19 - 
      5.32678340961306714e-22*V01*V042*V19 - 4.26222351887358985e-22*V022*V05*V19 - 
      1.08779888637693994e-21*V01*V03*V05*V19 - 3.80387489776510503e-22*V01*V02*V06*V19 + 6.32850011810763366e-22*V05*V06*V19 - 
      7.25928101722770447e-23*V012*V07*V19 + 4.23737137844077598e-22*V04*V07*V19 + 
      2.36357715305226828e-22*V03*V08*V19 + 5.98611845405606483e-23*V02*V09*V19 + 1.64509747182950133e-23*V01*V10*V19 - 
      4.01261532971166871e-25*V13*V19 - 2.02751866796379174e-22*V02*V032*V20 - 
      6.15647971055332612e-23*V022*V04*V20 - 2.36993819906445338e-22*V01*V03*V04*V20 - 
      1.21651120077827504e-22*V01*V02*V05*V20 + 1.05411639850442439e-22*V052*V20 - 
      2.37928678863953185e-23*V012*V06*V20 + 1.23795157063040923e-22*V04*V06*V20 + 
      1.01029061716163965e-22*V03*V07*V20 + 2.31872722752653509e-23*V02*V08*V20 + 8.57834441718740755e-24*V01*V09*V20 - 
      2.52215398899534959e-25*V12*V20 - 2.02963024708266183e-23*V022*V03*V21 - 
      2.45536865337150441e-23*V01*V032*V21 - 2.50327898621013239e-23*V01*V02*V04*V21 - 
      6.98490188310062718e-24*V012*V05*V21 + 4.43012453965532713e-23*V04*V05*V21 + 
      3.17070266533845328e-23*V03*V06*V21 + 1.06557561290566091e-23*V02*V07*V21 + 3.57262785675283031e-24*V01*V08*V21 - 
      1.55429734791236183e-25*V11*V21 - 4.13621086225730943e-25*V023*V22 - 5.08605271571890375e-24*V01*V02*V03*V22 - 
      1.43206014920613373e-24*V012*V04*V22 + 3.9143767813863204e-24*V042*V22 + 
      9.56649446995192159e-24*V03*V05*V22 + 2.81123232014954937e-24*V02*V06*V22 + 1.38304347236848082e-24*V01*V07*V22 - 
      7.49783842513735932e-26*V10*V22 - 2.40667618231145672e-25*V01*V022*V23 - 
      2.55000349658402725e-25*V012*V03*V23 + 1.84899210776500566e-24*V03*V04*V23 + 
      9.28056776794793416e-25*V02*V05*V23 + 3.99262842805739677e-25*V01*V06*V23 - 3.59484947117149093e-26*V09*V23 - 
      2.54728639110018705e-26*V012*V02*V24 + 1.81006414584550941e-25*V032*V24 + 
      1.48280397230036363e-25*V02*V04*V24 + 1.09215197484594609e-25*V01*V05*V24 - 1.28593320320440318e-26*V08*V24 - 
      6.79276370960049879e-28*V013*V25 + 3.27513467460738028e-26*V02*V03*V25 + 1.96871456814671445e-26*V01*V04*V25 - 
      4.67630878364161296e-27*V07*V25 + 1.17887318573066721e-27*V022*V26 + 3.46814411657102886e-27*V01*V03*V26 - 
      1.16890482158693529e-27*V06*V26 + 2.98552921107441277e-28*V01*V02*V27 - 3.08521285251173192e-28*V05*V27 + 
      1.3695088124194554e-29*V012*V28 - 4.80988095028529942e-29*V04*V28 - 8.50755474381782901e-30*V03*V29 - 
      6.22504005645207e-31*V02*V30 - 6.22504005645207e-32*V01*V31 + 7.41076197196675001e-35*V34) + 
   delta18*eps8*(2.23431572412370774e-15*V054*V06 + 
      8.27871088014895646e-15*V04*V052*V062 + 8.49274511565083019e-16*V042*V063 + 
      3.93810727613714611e-15*V03*V05*V063 + 1.49450576412521073e-16*V02*V064 + 
      6.04023312096675522e-15*V04*V053*V07 + 1.0978563060153788e-14*V042*V05*V06*V07 + 
      1.26552507026618497e-14*V03*V052*V06*V07 + 7.88448655252281567e-15*V03*V04*V062*V07 + 
      3.90289172422093983e-15*V02*V05*V062*V07 + 5.62586753733878016e-16*V01*V063*V07 + 
      1.20593125022134378e-15*V043*V072 + 8.56190628126394775e-15*V03*V04*V05*V072 + 
      2.17754272844450535e-15*V02*V052*V072 + 2.98142198076362949e-15*V032*V06*V072 + 
      2.56561169283198234e-15*V02*V04*V06*V072 + 1.77281494261500704e-15*V01*V05*V06*V072 + 
      6.86563315837419169e-16*V02*V03*V073 + 4.01329044130665294e-16*V01*V04*V073 - 
      6.28957592521203578e-17*V074 + 4.27233115371887033e-15*V042*V052*V08 + 
      3.21829306743627275e-15*V03*V053*V08 + 8.68955298932018206e-16*V043*V06*V08 + 
      1.22058602179396734e-14*V03*V04*V05*V06*V08 + 3.04062054012852086e-15*V02*V052*V06*V08 + 
      2.16231483869807119e-15*V032*V062*V08 + 9.15802935027882375e-16*V02*V04*V062*V08 + 
      1.29738890321884272e-15*V01*V05*V062*V08 + 4.06888681306559079e-15*V03*V042*V07*V08 + 
      4.54369399496807069e-15*V032*V05*V07*V08 + 4.01790345371482213e-15*V02*V04*V05*V07*V08 + 
      1.34694793950815409e-15*V01*V052*V07*V08 + 2.89582908583668653e-15*V02*V03*V06*V07*V08 + 
      1.74369431684852478e-15*V01*V04*V06*V07*V08 + 2.32436830519880973e-16*V022*V072*V08 + 
      6.2947663481599158e-16*V01*V03*V072*V08 - 5.67019015053075171e-16*V06*V072*V08 + 
      1.11721223057509143e-15*V032*V04*V082 + 2.33605491671732399e-16*V02*V042*V082 + 
      1.12205074310359995e-15*V02*V03*V05*V082 + 6.70327338345054857e-16*V01*V04*V05*V082 + 
      8.14842625159686236e-17*V022*V06*V082 + 4.6977781743939151e-16*V01*V03*V06*V082 - 
      1.74803352990062511e-16*V062*V082 + 1.60292963300514278e-16*V01*V02*V07*V082 - 
      4.411873832510041e-16*V05*V07*V082 + 8.27977694199797183e-18*V012*V083 - 
      6.04910432453409128e-17*V04*V083 + 1.40691979192490108e-15*V043*V05*V09 + 
      4.95536306066897635e-15*V03*V04*V052*V09 + 8.41040061900838482e-16*V02*V053*V09 + 
      3.04960085004271889e-15*V03*V042*V06*V09 + 3.44714016619584703e-15*V032*V05*V06*V09 + 
      2.99321364163731273e-15*V02*V04*V05*V06*V09 + 1.02303551790420363e-15*V01*V052*V06*V09 + 
      1.08413659006137218e-15*V02*V03*V062*V09 + 6.57040546043567973e-16*V01*V04*V062*V09 + 
      2.33515828575444429e-15*V032*V04*V07*V09 + 9.77719972508739597e-16*V02*V042*V07*V09 + 
      2.38434343517659722e-15*V02*V03*V05*V07*V09 + 1.38992860857600186e-15*V01*V04*V05*V07*V09 + 
      3.44162440266562191e-16*V022*V06*V07*V09 + 9.56601470283933261e-16*V01*V03*V06*V07*V09 - 
      4.25909086631241355e-16*V062*V07*V09 + 1.67799639275664257e-16*V01*V02*V072*V09 - 
      4.41140200602681811e-16*V05*V072*V09 + 4.10736938433915735e-16*V033*V08*V09 + 
      1.1160842926985617e-15*V02*V03*V04*V08*V09 + 3.39073901088799233e-16*V01*V042*V08*V09 + 
      2.71176302273194469e-16*V022*V05*V08*V09 + 7.25411485628508447e-16*V01*V03*V05*V08*V09 + 
      2.41319090486390544e-16*V01*V02*V06*V08*V09 - 6.64110547107152393e-16*V05*V06*V08*V09 + 
      4.83292614119624098e-17*V012*V07*V08*V09 - 4.4337314348152416e-16*V04*V07*V08*V09 - 
      1.23504268444759487e-16*V03*V082*V09 + 1.62445479221500999e-16*V02*V032*V092 + 
      6.49519340817043555e-17*V022*V04*V092 + 1.87439508726646023e-16*V01*V03*V04*V092 + 
      9.67789410719452769e-17*V01*V02*V05*V092 - 1.28882977242259049e-16*V052*V092 + 
      1.84058385503280947e-17*V012*V06*V092 - 1.66145907627527511e-16*V04*V06*V092 - 
      1.22975575873139173e-16*V03*V07*V092 - 3.1001626401369933e-17*V02*V08*V092 - 
      3.43274762289914875e-18*V01*V093 + 6.73404389738392889e-17*V044*V10 + 
      1.92486869280949337e-15*V03*V042*V05*V10 + 1.05708061003594529e-15*V032*V052*V10 + 
      9.55596083644865842e-16*V02*V04*V052*V10 + 2.08259614561075865e-16*V01*V053*V10 + 
      1.36563799820638702e-15*V032*V04*V06*V10 + 2.83088552584453044e-16*V02*V042*V06*V10 + 
      1.37017188862952027e-15*V02*V03*V05*V06*V10 + 8.19382798923832211e-16*V01*V04*V05*V06*V10 + 
      4.93241924449158602e-17*V022*V062*V10 + 2.87194219807626739e-16*V01*V03*V062*V10 - 
      7.15889149554091079e-17*V063*V10 + 3.30570816763612483e-16*V033*V07*V10 + 
      9.10091508233205564e-16*V02*V03*V04*V07*V10 + 2.74981241829927624e-16*V01*V042*V07*V10 + 
      2.22253305313254522e-16*V022*V05*V07*V10 + 5.83015930535412906e-16*V01*V03*V05*V07*V10 + 
      1.9573884123278861e-16*V01*V02*V06*V07*V10 - 5.43510238870039262e-16*V05*V06*V07*V10 + 
      1.93647339028294367e-17*V012*V072*V10 - 1.81791655209570891e-16*V04*V072*V10 + 
      2.51001482680685602e-16*V02*V032*V08*V10 + 5.01444330601433398e-17*V022*V04*V08*V10 + 
      2.96647116535674605e-16*V01*V03*V04*V08*V10 + 1.50600889608411361e-16*V01*V02*V05*V08*V10 - 
      2.10967316519526117e-16*V052*V08*V10 + 3.0365633758911167e-17*V012*V06*V08*V10 - 
      2.2290164322441146e-16*V04*V06*V08*V10 - 2.01691862869601237e-16*V03*V07*V08*V10 - 
      2.06754510894767905e-17*V02*V082*V10 + 6.17370292536818118e-17*V022*V03*V09*V10 + 
      7.80535830823809433e-17*V01*V032*V09*V10 + 7.5840959019433797e-17*V01*V02*V04*V09*V10 + 
      2.22164148573351532e-17*V012*V05*V09*V10 - 2.12911995843271347e-16*V04*V05*V09*V10 - 
      1.52142209597047011e-16*V03*V06*V09*V10 - 5.09568372489312638e-17*V02*V07*V09*V10 - 
      1.70003074995037179e-17*V01*V08*V09*V10 + 8.83822700481306048e-19*V023*V102 + 
      1.66333805245933921e-17*V01*V02*V03*V102 + 4.7876878757008335e-18*V012*V04*V102 - 
      1.77427460914434112e-17*V042*V102 - 4.80678083887486235e-17*V03*V05*V102 - 
      1.26854182749585998e-17*V02*V06*V102 - 6.91856310431249643e-18*V01*V07*V102 + 
      1.14144152015141444e-19*V103 + 2.55803598531800196e-16*V03*V043*V11 + 
      8.77394156354123638e-16*V032*V04*V05*V11 + 3.73311262230609664e-16*V02*V042*V05*V11 + 
      4.48482672245866287e-16*V02*V03*V052*V11 + 2.60407483601620182e-16*V01*V04*V052*V11 + 
      2.02540069200229683e-16*V033*V06*V11 + 5.44220662115875042e-16*V02*V03*V04*V06*V11 + 
      1.66341864547784667e-16*V01*V042*V06*V11 + 1.31407477192687382e-16*V022*V05*V06*V11 + 
      3.57807043067295719e-16*V01*V03*V05*V06*V11 + 5.91347230942566642e-17*V01*V02*V062*V11 - 
      1.63895952588529018e-16*V05*V062*V11 + 2.11154053247880604e-16*V02*V032*V07*V11 + 
      8.50279864342311563e-17*V022*V04*V07*V11 + 2.43345109082761209e-16*V01*V03*V04*V07*V11 + 
      1.25676349934853642e-16*V01*V02*V05*V07*V11 - 1.69049453436051543e-16*V052*V07*V11 + 
      2.38519121955329808e-17*V012*V06*V07*V11 - 2.18351454471035206e-16*V04*V06*V07*V11 - 
      8.06270771177000165e-17*V03*V072*V11 + 4.93047822314899035e-17*V022*V03*V08*V11 + 
      6.30491489783944042e-17*V01*V032*V08*V11 + 6.08773250562851838e-17*V01*V02*V04*V08*V11 + 
      1.7963285903286644e-17*V012*V05*V08*V11 - 1.70610046585614693e-16*V04*V05*V08*V11 - 
      1.22159206498699359e-16*V03*V06*V08*V11 - 4.07413389427913717e-17*V02*V07*V08*V11 - 
      6.84047473789991301e-18*V01*V082*V11 + 3.6962308252065037e-18*V023*V09*V11 + 
      3.37894238361914587e-17*V01*V02*V03*V09*V11 + 9.35078904682559046e-18*V012*V04*V09*V11 - 
      4.24555465024973953e-17*V042*V09*V11 - 9.41252895830664031e-17*V03*V05*V09*V11 - 
      3.04392524144496077e-17*V02*V06*V09*V11 - 1.34895053878512365e-17*V01*V07*V09*V11 + 
      3.36747432292809882e-18*V01*V022*V10*V11 + 3.78903245905063634e-18*V012*V03*V10*V11 - 
      3.91594891162885942e-17*V03*V04*V10*V11 - 1.96060405787126658e-17*V02*V05*V10*V11 - 
      8.42599069557619998e-18*V01*V06*V10*V11 + 7.03390637757046127e-19*V09*V10*V11 + 
      4.18094830297105741e-19*V012*V02*V112 - 4.27946122039823089e-18*V032*V112 - 
      3.86800440260107209e-18*V02*V04*V112 - 2.57175912024096312e-18*V01*V05*V112 + 
      2.83824935995279905e-19*V08*V112 + 1.45168483119178957e-16*V032*V042*V12 + 
      1.94883234853960911e-17*V02*V043*V12 + 1.03418980421033007e-16*V033*V05*V12 + 
      2.90190675679245847e-16*V02*V03*V04*V05*V12 + 8.71010898715073741e-17*V01*V042*V05*V12 + 
      3.5621303584927979e-17*V022*V052*V12 + 9.08740240807995596e-17*V01*V03*V052*V12 + 
      1.03282353206722632e-16*V02*V032*V06*V12 + 2.02983300889430858e-17*V022*V04*V06*V12 + 
      1.22226200365444404e-16*V01*V03*V04*V06*V12 + 6.19694119240335793e-17*V01*V02*V05*V06*V12 - 
      8.82864538732980502e-17*V052*V06*V12 + 6.25746716684000423e-18*V012*V062*V12 - 
      4.6379998470796275e-17*V04*V062*V12 + 3.39250510332647419e-17*V022*V03*V07*V12 + 
      4.22242694203187681e-17*V01*V032*V07*V12 + 4.14558108113208353e-17*V01*V02*V04*V07*V12 + 
      1.19897160287168096e-17*V012*V05*V07*V12 - 1.18382732481700275e-16*V04*V05*V07*V12 - 
      8.4401469597505379e-17*V03*V06*V07*V12 - 1.4194127141447538e-17*V02*V072*V12 + 
      1.18203197717829008e-18*V023*V08*V12 + 2.24209390198426242e-17*V01*V02*V03*V08*V12 + 
      6.45641320302662195e-18*V012*V04*V08*V12 - 2.40451074966244895e-17*V042*V08*V12 - 
      6.53146539084505102e-17*V03*V05*V08*V12 - 1.71867081870597643e-17*V02*V06*V08*V12 - 
      9.40058299936714553e-18*V01*V07*V08*V12 + 2.82708758610539516e-18*V01*V022*V09*V12 + 
      3.15563077796656246e-18*V012*V03*V09*V12 - 3.31344714101388011e-17*V03*V04*V09*V12 - 
      1.66227241479801433e-17*V02*V05*V09*V12 - 7.11323894362130488e-18*V01*V06*V09*V12 + 
      2.98593653773509986e-19*V092*V12 + 7.20522611252223968e-19*V012*V02*V10*V12 - 
      7.4001796917545768e-18*V032*V10*V12 - 5.45378375534178728e-18*V02*V04*V10*V12 - 
      4.45638457071659423e-18*V01*V05*V10*V12 + 4.69006828507491834e-19*V08*V10*V12 + 
      4.73519998883070628e-20*V013*V11*V12 - 3.0566275630643982e-18*V02*V03*V11*V12 - 
      1.83464888281967427e-18*V01*V04*V11*V12 + 3.95965351580611073e-19*V07*V11*V12 - 
      1.03711191305450539e-19*V022*V122 - 3.3908279883497875e-19*V01*V03*V122 + 
      9.97092193609694114e-20*V06*V122 + 3.60873504167967391e-17*V033*V04*V13 + 
      4.78604182346935467e-17*V02*V03*V042*V13 + 9.83859994353077678e-18*V01*V043*V13 + 
      5.55329563324655038e-17*V02*V032*V05*V13 + 2.28921501938314652e-17*V022*V04*V05*V13 + 
      6.37020720156903066e-17*V01*V03*V04*V05*V13 + 1.64653038064582274e-17*V01*V02*V052*V13 - 
      1.52497293577759558e-17*V053*V13 + 1.68471124606009464e-17*V022*V03*V06*V13 + 
      2.17668225410576304e-17*V01*V032*V06*V13 + 2.09315639275336555e-17*V01*V02*V04*V06*V13 + 
      6.20090847699582224e-18*V012*V05*V06*V13 - 5.94745647220787555e-17*V04*V05*V06*V13 - 
      2.13395117449770423e-17*V03*V062*V13 + 1.70595268855684786e-18*V023*V07*V13 + 
      1.53493250900093612e-17*V01*V02*V03*V07*V13 + 4.23766233715961018e-18*V012*V04*V07*V13 - 
      1.9747239495689163e-17*V042*V07*V13 - 4.35937360679025041e-17*V03*V05*V07*V13 - 
      1.41576424143028348e-17*V02*V06*V07*V13 - 3.11955524946603919e-18*V01*V072*V13 + 
      1.89633777813422706e-18*V01*V022*V08*V13 + 2.14289498613683124e-18*V012*V03*V08*V13 - 
      2.22120877864858034e-17*V03*V04*V08*V13 - 1.10959460510680936e-17*V02*V05*V08*V13 - 
      4.78893321773195764e-18*V01*V06*V08*V13 + 5.84807302906487193e-19*V012*V02*V09*V13 - 
      6.04604679195731065e-18*V032*V09*V13 - 5.47583730979756904e-18*V02*V04*V09*V13 - 
      3.63230740852777161e-18*V01*V05*V09*V13 + 4.05301568703960442e-19*V08*V09*V13 + 
      3.97753427912904126e-20*V013*V10*V13 - 2.55200356884027222e-18*V02*V03*V10*V13 - 
      1.53486606503576086e-18*V01*V04*V10*V13 + 3.32994895888450034e-19*V07*V10*V13 - 
      2.46532262551668484e-19*V022*V11*V13 - 6.53450317046624162e-19*V01*V03*V11*V13 + 
      2.03170980877609987e-19*V06*V11*V13 - 1.19762219195647563e-19*V01*V02*V12*V13 + 1.10737669172302386e-19*V05*V12*V13 - 
      5.99629786263627225e-21*V012*V132 + 1.90722657340430784e-20*V04*V132 + 
      2.70977590518315295e-18*V034*V14 + 1.5720673252052713e-17*V02*V032*V04*V14 + 
      1.48751160251002752e-18*V022*V042*V14 + 9.3354157052635532e-18*V01*V03*V042*V14 + 
      7.77338137677350784e-18*V022*V03*V05*V14 + 9.43020341581642709e-18*V01*V032*V05*V14 + 
      9.43240395123162782e-18*V01*V02*V04*V05*V14 + 1.33179076686947773e-18*V012*V052*V14 - 
      1.39347437148432234e-17*V04*V052*V14 + 3.40788389704839023e-19*V023*V06*V14 + 
      6.63168729055547288e-18*V01*V02*V03*V06*V14 + 1.91256024149634396e-18*V012*V04*V06*V14 - 
      7.23058793837264965e-18*V042*V06*V14 - 1.98070778498672788e-17*V03*V05*V06*V14 - 
      2.5815700698979907e-18*V02*V062*V14 + 1.11048305382478683e-18*V01*V022*V07*V14 + 
      1.22194503851718019e-18*V012*V03*V07*V14 - 1.3320502489081963e-17*V03*V04*V07*V14 - 
      6.69741424521806958e-18*V02*V05*V07*V14 - 2.85044288505442943e-18*V01*V06*V07*V14 + 
      3.49206087676430805e-19*V012*V02*V08*V14 - 3.64353929963390125e-18*V032*V08*V14 - 
      2.67034252859522119e-18*V02*V04*V08*V14 - 2.19404872071374449e-18*V01*V05*V08*V14 + 
      1.17243000793529834e-19*V082*V14 + 2.82755111907573544e-20*V013*V09*V14 - 
      1.87420050982859002e-18*V02*V03*V09*V14 - 1.12237137377893448e-18*V01*V04*V09*V14 + 2.455691338534815e-19*V07*V09*V14 - 
      1.49920443359428433e-19*V022*V10*V14 - 4.91470239812692332e-19*V01*V03*V10*V14 + 
      1.45589658265325156e-19*V06*V10*V14 - 1.03735409328979289e-19*V01*V02*V11*V14 + 9.61892136228957733e-20*V05*V11*V14 - 
      1.08732628957972253e-20*V012*V12*V14 + 3.24619318213505934e-20*V04*V12*V14 + 
      1.29605469629489611e-20*V03*V13*V14 + 9.53317848511123541e-22*V02*V142 + 
      1.67998488447406819e-18*V02*V033*V15 + 2.18020478036490144e-18*V022*V03*V04*V15 + 
      2.85296599287115141e-18*V01*V032*V04*V15 + 1.36744052099124419e-18*V01*V02*V042*V15 + 
      3.41190537711369573e-19*V023*V05*V15 + 2.95758946596791358e-18*V01*V02*V03*V05*V15 + 
      8.11323504134031989e-19*V012*V04*V05*V15 - 4.01039665079859403e-18*V042*V05*V15 - 
      4.38291226908034135e-18*V03*V052*V15 + 4.81346070302884183e-19*V01*V022*V06*V15 + 
      5.44757413706718612e-19*V012*V03*V06*V15 - 5.77339261990982776e-18*V03*V04*V06*V15 - 
      2.87503115668331176e-18*V02*V05*V06*V15 - 6.23723626902046877e-19*V01*V062*V15 + 
      1.95133067732607049e-19*V012*V02*V07*V15 - 2.08274823722224424e-18*V032*V07*V15 - 
      1.89898807823511098e-18*V02*V04*V07*V15 - 1.24990518774705528e-18*V01*V05*V07*V15 + 
      1.65603886446698032e-20*V013*V08*V15 - 1.07693518391265624e-18*V02*V03*V08*V15 - 
      6.49159860652201926e-19*V01*V04*V08*V15 + 1.44178557979096807e-19*V07*V08*V15 - 
      1.30111573588447329e-19*V022*V09*V15 - 3.43309060802498082e-19*V01*V03*V09*V15 + 
      1.09005981278996813e-19*V06*V09*V15 - 7.45604715176421593e-20*V01*V02*V10*V15 + 6.99767251881736294e-20*V05*V10*V15 - 
      8.9211362419446454e-21*V012*V11*V15 + 2.86638556212159926e-20*V04*V11*V15 + 1.12115425333876691e-20*V03*V12*V15 + 
      1.94210750127342274e-21*V02*V13*V15 + 3.97700402717793619e-22*V01*V14*V15 + 
      3.16397439603185685e-19*V022*V032*V16 + 2.43297414646889877e-19*V01*V033*V16 + 
      3.70472463103990815e-20*V023*V04*V16 + 7.58691845352729137e-19*V01*V02*V03*V04*V16 + 
      1.0976439405258339e-19*V012*V042*V16 - 2.83948181302505117e-19*V043*V16 + 
      1.89838463761911411e-19*V01*V022*V05*V16 + 2.0329108467211205e-19*V012*V03*V05*V16 - 
      2.3711898649319395e-18*V03*V04*V05*V16 - 5.97923804954621175e-19*V02*V052*V16 + 
      7.77018683025438656e-20*V012*V02*V06*V16 - 8.38153692877855333e-19*V032*V06*V16 - 
      6.06803070465679587e-19*V02*V04*V06*V16 - 5.04674134877121834e-19*V01*V05*V06*V16 + 
      8.18751941199687481e-21*V013*V07*V16 - 5.71499976165130908e-19*V02*V03*V07*V16 - 
      3.41170140642083192e-19*V01*V04*V07*V16 + 3.85682260796142374e-20*V072*V16 - 
      5.55229708725014704e-20*V022*V08*V16 - 1.83564993673113071e-19*V01*V03*V08*V16 + 
      5.55736293192178429e-20*V06*V08*V16 - 4.81371813515624038e-20*V01*V02*V09*V16 + 4.55697426645284025e-20*V05*V09*V16 - 
      5.97855251559898588e-21*V012*V10*V16 + 1.80947492177341379e-20*V04*V10*V16 + 
      8.60028947691849145e-21*V03*V11*V16 + 1.45577734941666095e-21*V02*V12*V16 + 3.51231121439745566e-22*V01*V13*V16 - 
      1.67104218740553894e-24*V162 + 2.50875395376007039e-20*V023*V03*V17 + 
      1.0080393902607452e-19*V01*V02*V032*V17 + 4.80927525080492966e-20*V01*V022*V04*V17 + 
      5.43568281401704711e-20*V012*V03*V04*V17 - 3.01604395462480601e-19*V03*V042*V17 + 
      2.84837200354767044e-20*V012*V02*V05*V17 - 3.23267205244129966e-19*V032*V05*V17 - 
      2.98774151938201372e-19*V02*V04*V05*V17 - 9.67386733979734953e-20*V01*V052*V17 + 
      3.20778756316690115e-21*V013*V06*V17 - 2.16197438780693306e-19*V02*V03*V06*V17 - 
      1.30725007165582777e-19*V01*V04*V06*V17 - 3.49578070580101897e-20*V022*V07*V17 - 
      9.12744582195726726e-20*V01*V03*V07*V17 + 3.02374131232102459e-20*V06*V07*V17 - 2.43790801745874078e-20*V01*V02*V08*V17 + 
      2.36255605334669593e-20*V05*V08*V17 - 3.62013410196554922e-21*V012*V09*V17 + 
      1.19928441245080034e-20*V04*V09*V17 + 5.52460633475018036e-21*V03*V10*V17 + 1.1381800961426224e-21*V02*V11*V17 + 
      2.68283397433151953e-22*V01*V12*V17 - 3.24191412185170787e-24*V15*V17 + 2.62137603527561534e-22*V024*V18 + 
      1.18396706984557905e-20*V01*V022*V03*V18 + 5.96577626578814692e-21*V012*V032*V18 + 
      6.90380113638207551e-21*V012*V02*V04*V18 - 7.87334225749228142e-20*V032*V04*V18 - 
      2.78764370500489387e-20*V02*V042*V18 + 1.04499052072900765e-21*V013*V05*V18 - 
      7.98220064213116742e-20*V02*V03*V05*V18 - 4.74015033867398307e-20*V01*V04*V05*V18 - 
      9.86317572806714541e-21*V022*V06*V18 - 3.31375299428384087e-20*V01*V03*V06*V18 + 
      5.19520085294113752e-21*V062*V18 - 1.14816155367989248e-20*V01*V02*V07*V18 + 
      1.12970032011332233e-20*V05*V07*V18 - 1.75289545748614903e-21*V012*V08*V18 + 
      5.44900176071489512e-21*V04*V08*V18 + 3.21587946754881343e-21*V03*V09*V18 + 6.40229649211245309e-22*V02*V10*V18 + 
      1.83981481053849886e-22*V01*V11*V18 - 2.64903190147815307e-24*V14*V18 + 4.40132272589486033e-22*V01*V023*V19 + 
      1.48375793301027181e-21*V012*V02*V03*V19 - 6.29855780323320726e-21*V033*V19 + 
      2.48559354069477966e-22*V013*V04*V19 - 1.79263990765895532e-20*V02*V03*V04*V19 - 
      5.44855170486488526e-21*V01*V042*V19 - 4.38821026594829222e-21*V022*V05*V19 - 
      1.12251571836329489e-20*V01*V03*V05*V19 - 3.90517352304298059e-21*V01*V02*V06*V19 + 3.97282872870724859e-21*V05*V06*V19 - 
      7.64232294115621065e-22*V012*V07*V19 + 2.6675628981410365e-21*V04*V07*V19 + 1.49561169371102153e-21*V03*V08*V19 + 
      3.81904739764890252e-22*V02*V09*V19 + 1.06014324573555914e-22*V01*V10*V19 - 2.04065520125757302e-24*V13*V19 + 
      8.53952289752426705e-23*V012*V022*V20 + 4.71791403450302643e-23*V013*V03*V20 - 
      2.13385873690771044e-21*V02*V032*V20 - 7.25262507918711164e-22*V022*V04*V20 - 
      2.50657441465761043e-21*V01*V03*V04*V20 - 1.28446188475115189e-21*V01*V02*V05*V20 + 
      6.69073092687208968e-22*V052*V20 - 2.54948918733172892e-22*V012*V06*V20 + 
      8.23760973844888739e-22*V04*V06*V20 + 6.44838155152286243e-22*V03*V07*V20 + 1.55906153778006592e-22*V02*V08*V20 + 
      5.5654171448138675e-23*V01*V09*V20 - 1.30912130069651704e-24*V12*V20 + 5.22023891082798332e-24*V013*V02*V21 - 
      2.15003424808990054e-22*V022*V03*V21 - 2.63801345439005828e-22*V01*V032*V21 - 
      2.64434350150505956e-22*V01*V02*V04*V21 - 7.60757997643747005e-23*V012*V05*V21 + 
      2.87184202081803778e-22*V04*V05*V21 + 2.06075627250880319e-22*V03*V06*V21 + 6.96137768675734642e-23*V02*V07*V21 + 
      2.35193737158198856e-23*V01*V08*V21 - 7.96644461906312721e-25*V11*V21 + 9.84950737892072324e-26*V014*V22 - 
      5.09990995368648877e-24*V023*V22 - 5.57757871507028861e-23*V01*V02*V03*V22 - 
      1.58490056732153047e-23*V012*V04*V22 + 2.69031474812047694e-23*V042*V22 + 
      6.29361589807623898e-23*V03*V05*V22 + 1.94195381814851333e-23*V02*V06*V22 + 9.19652557715912691e-24*V01*V07*V22 - 
      3.93570969130069318e-25*V10*V22 - 2.63898870117979378e-24*V01*V022*V23 - 
      2.91664291780971417e-24*V012*V03*V23 + 1.24192518885328395e-23*V03*V04*V23 + 
      6.24858664396800335e-24*V02*V05*V23 + 2.70197410704530372e-24*V01*V06*V23 - 1.8664656173451793e-25*V09*V23 - 
      2.93787030440221573e-25*V012*V02*V24 + 1.23596572560574694e-24*V032*V24 + 
      1.05949949359318791e-24*V02*V04*V24 + 7.49631690677537088e-25*V01*V05*V24 - 6.86491518459004595e-26*V08*V24 - 
      8.49095463700062349e-27*V013*V25 + 2.28511675410935597e-25*V02*V03*V25 + 1.37705024094651187e-25*V01*V04*V25 - 
      2.47452841935085413e-26*V07*V25 + 8.77550813469222144e-27*V022*V26 + 2.47515892697942906e-26*V01*V03*V26 - 
      6.38619448629445895e-27*V06*V26 + 2.16838895299747105e-27*V01*V02*V27 - 1.67515827919125204e-27*V05*V27 + 
      1.02713160931459155e-28*V012*V28 - 2.70685491788057511e-28*V04*V28 - 4.772530709946587e-29*V03*V29 - 
      3.6312733662637075e-30*V02*V30 - 3.6312733662637075e-31*V01*V31 + 3.705380985983375e-34*V34) + 
   delta16*eps9*(3.54230568459897081e-14*V054*V06 + 
      1.35487356966297229e-13*V04*V052*V062 + 1.83626720342466716e-14*V042*V063 + 
      6.46138235992046601e-14*V03*V05*V063 + 3.24724401218465678e-15*V02*V064 + 
      9.56108363059418441e-14*V04*V053*V07 + 1.79445381192341197e-13*V042*V05*V06*V07 + 
      2.01098709648453901e-13*V03*V052*V06*V07 + 1.29035578063140218e-13*V03*V04*V062*V07 + 
      6.38940289174400741e-14*V02*V05*V062*V07 + 9.23054622845780858e-15*V01*V063*V07 + 
      1.97142745986780557e-14*V043*V072 + 1.35828596510163487e-13*V03*V04*V05*V072 + 
      3.4472295647677036e-14*V02*V052*V072 + 4.75036518804449859e-14*V032*V06*V072 + 
      4.20298838126161278e-14*V02*V04*V06*V072 + 2.83137971221361544e-14*V01*V05*V06*V072 + 
      1.0892723374127973e-14*V02*V03*V073 + 6.39580816731017928e-15*V01*V04*V073 - 
      4.00183962629200026e-16*V074 + 7.00410197815034129e-14*V042*V052*V08 + 
      5.13212545814413857e-14*V03*V053*V08 + 1.88775115853643146e-14*V043*V06*V08 + 
      2.00580730219540525e-13*V03*V04*V05*V06*V08 + 4.99193603823908576e-14*V02*V052*V06*V08 + 
      3.56595673404115062e-14*V032*V062*V08 + 2.00025437775219335e-14*V02*V04*V062*V08 + 
      2.13957404042469037e-14*V01*V05*V062*V08 + 6.67057331252413456e-14*V03*V042*V07*V08 + 
      7.2660452021112996e-14*V032*V05*V07*V08 + 6.59243372827698823e-14*V02*V04*V05*V07*V08 + 
      2.16014478206214894e-14*V01*V052*V07*V08 + 4.75422479832293882e-14*V02*V03*V06*V07*V08 + 
      2.86543900313629322e-14*V01*V04*V06*V07*V08 + 3.83016582033478617e-15*V022*V072*V08 + 
      1.01382881335948633e-14*V01*V03*V072*V08 - 3.70234548293250895e-15*V06*V072*V08 + 
      1.84539848959245279e-14*V032*V04*V082 + 5.13049304386922149e-15*V02*V042*V082 + 
      1.84949868878869314e-14*V02*V03*V05*V082 + 1.10723909375547167e-14*V01*V04*V05*V082 + 
      1.80241855891531093e-15*V022*V06*V082 + 7.79390333328492644e-15*V01*V03*V06*V082 - 
      1.25543546016232061e-15*V062*V082 + 2.64214098398384734e-15*V01*V02*V07*V082 - 
      2.8896803124336371e-15*V05*V07*V082 + 1.38250207044420275e-16*V012*V083 - 
      4.37368119725508873e-16*V04*V083 + 2.29999870317910649e-14*V043*V05*V09 + 
      7.87909990069058653e-14*V03*V04*V052*V09 + 1.33435861333067669e-14*V02*V053*V09 + 
      4.9845939220094777e-14*V03*V042*V06*V09 + 5.50546055152647447e-14*V032*V05*V06*V09 + 
      4.90348644480521491e-14*V02*V04*V05*V06*V09 + 1.63844340086973434e-14*V01*V052*V06*V09 + 
      1.77483413659555761e-14*V02*V03*V062*V09 + 1.07529648385950181e-14*V01*V04*V062*V09 + 
      3.72364163558904961e-14*V032*V04*V07*V09 + 1.60549458256343414e-14*V02*V042*V07*V09 + 
      3.79224166013244906e-14*V02*V03*V05*V07*V09 + 2.22154643971468208e-14*V01*V04*V05*V07*V09 + 
      5.6719523673026612e-15*V022*V06*V07*V09 + 1.53876185889585219e-14*V01*V03*V06*V07*V09 - 
      2.79252898080582962e-15*V062*V07*V09 + 2.68159160592913072e-15*V01*V02*V072*V09 - 
      2.82860004463753936e-15*V05*V072*V09 + 6.60640741818181483e-15*V033*V08*V09 + 
      1.83123159118805229e-14*V02*V03*V04*V08*V09 + 5.55881109377011214e-15*V01*V042*V08*V09 + 
      4.46852679039058386e-15*V022*V05*V08*V09 + 1.17187318304648908e-14*V01*V03*V05*V08*V09 + 
      3.96185399860244902e-15*V01*V02*V06*V08*V09 - 4.36720601660342037e-15*V05*V06*V08*V09 + 
      7.92906638638071448e-16*V012*V07*V08*V09 - 2.92720290124247436e-15*V04*V07*V08*V09 - 
      8.20386969439503907e-16*V03*V082*V09 + 2.59909391701638232e-15*V02*V032*V092 + 
      1.07581829435141357e-15*V022*V04*V092 + 3.01934782022176318e-15*V01*V03*V04*V092 + 
      1.55203889561844416e-15*V01*V02*V05*V092 - 8.32741091496087819e-16*V052*V092 + 
      3.01600270563334275e-16*V012*V06*V092 - 1.10154333067294613e-15*V04*V06*V092 - 
      8.00658421837466939e-16*V03*V07*V092 - 2.08331101765147579e-16*V02*V08*V092 - 
      2.285487121790072e-17*V01*V093 + 1.47697079673354942e-15*V044*V10 + 
      3.17441219514464633e-14*V03*V042*V05*V10 + 1.70022526700544721e-14*V032*V052*V10 + 
      1.575486608699941e-14*V02*V04*V052*V10 + 3.3611151502274527e-15*V01*V053*V10 + 
      2.25982683827241556e-14*V032*V04*V06*V10 + 6.24729540308580249e-15*V02*V042*V06*V10 + 
      2.26295125866673784e-14*V02*V03*V05*V06*V10 + 1.35589610296344934e-14*V01*V04*V05*V06*V10 + 
      1.09664757742331231e-15*V022*V062*V10 + 4.7733824645636692e-15*V01*V03*V062*V10 - 
      5.1754614387928482e-16*V063*V10 + 5.33510341305944872e-15*V033*V07*V10 + 
      1.50046343685708667e-14*V02*V03*V04*V07*V10 + 4.53487456449235191e-15*V01*V042*V07*V10 + 
      3.67537080613932796e-15*V022*V05*V07*V10 + 9.45197054105715045e-15*V01*V03*V05*V07*V10 + 
      3.23278751238105406e-15*V01*V02*V06*V07*V10 - 3.58444399055651325e-15*V05*V06*V07*V10 + 
      3.18961870877840455e-16*V012*V072*V10 - 1.20349276762261678e-15*V04*V072*V10 + 
      4.16733826791483186e-15*V02*V032*V08*V10 + 1.12227409519141663e-15*V022*V04*V08*V10 + 
      4.93947647621521988e-15*V01*V03*V04*V08*V10 + 2.50040296074889912e-15*V01*V02*V05*V08*V10 - 
      1.39577732192086623e-15*V052*V08*V10 + 5.08001648140567652e-16*V012*V06*V08*V10 - 
      1.62222905396247913e-15*V04*V06*V08*V10 - 1.34375795510468675e-15*V03*V07*V08*V10 - 
      1.52472600201304211e-16*V02*V082*V10 + 1.02093633503870221e-15*V022*V03*V09*V10 + 
      1.27616223997186941e-15*V01*V032*V09*V10 + 1.25038619738090556e-15*V01*V02*V04*V09*V10 + 
      3.67439398907070802e-16*V012*V05*V09*V10 - 1.41928078932458041e-15*V04*V05*V09*V10 - 
      1.01739580474509221e-15*V03*V06*V09*V10 - 3.43277551866262605e-16*V02*V07*V09*V10 - 
      1.1559138457754648e-16*V01*V08*V09*V10 + 2.02449204922569999e-17*V023*V102 + 
      2.78617070750681358e-16*V01*V02*V03*V102 + 8.04305453061187561e-17*V012*V04*V102 - 
      1.30835368668089958e-16*V042*V102 - 3.23463058501953587e-16*V03*V05*V102 - 
      9.41571656150179025e-17*V02*V06*V102 - 4.71890652355455409e-17*V01*V07*V102 + 
      5.80323730930774183e-19*V103 + 4.18181582396201181e-15*V03*V043*V11 + 
      1.40566866241195825e-14*V032*V04*V05*V11 + 6.13007022433311218e-15*V02*V042*V05*V11 + 
      7.16716301948331301e-15*V02*V03*V052*V11 + 4.18457736944301164e-15*V01*V04*V052*V11 + 
      3.2611292644927155e-15*V033*V06*V11 + 8.91542989964584529e-15*V02*V03*V04*V06*V11 + 
      2.71886941200516966e-15*V01*V042*V06*V11 + 2.16565454024283428e-15*V022*V05*V06*V11 + 
      5.78732922507201685e-15*V01*V03*V05*V06*V11 + 9.68091347233940516e-16*V01*V02*V062*V11 - 
      1.08967605834462146e-15*V05*V062*V11 + 3.38626668134933271e-15*V02*V032*V07*V11 + 
      1.40834394896912322e-15*V022*V04*V07*V11 + 3.92962161621985782e-15*V01*V03*V04*V07*V11 + 
      2.02073554291195881e-15*V01*V02*V05*V07*V11 - 1.1003905529891647e-15*V052*V07*V11 + 
      3.91967717735473397e-16*V012*V06*V07*V11 - 1.45759479627601126e-15*V04*V06*V07*V11 - 
      5.28803070473474046e-16*V03*V072*V11 + 8.12459416434651611e-16*V022*V03*V08*V11 + 
      1.02976257491614688e-15*V01*V032*V08*V11 + 9.98853595193483065e-16*V01*V02*V04*V08*V11 + 
      2.96785935185675481e-16*V012*V05*V08*V11 - 1.14196222922079603e-15*V04*V05*V08*V11 - 
      8.2011179566361821e-16*V03*V06*V08*V11 - 2.75607905287840549e-16*V02*V07*V08*V11 - 
      4.66790703799904242e-17*V01*V082*V11 + 6.20601645858161673e-17*V023*V09*V11 + 
      5.486276714022129e-16*V01*V02*V03*V09*V11 + 1.54066167567742734e-16*V012*V04*V09*V11 - 
      2.86547049771419988e-16*V042*V09*V11 - 6.21936751943217815e-16*V03*V05*V09*V11 - 
      2.06802933278904476e-16*V02*V06*V09*V11 - 9.04554373733683397e-17*V01*V07*V09*V11 + 
      5.56874364566564843e-17*V01*V022*V10*V11 + 6.36646027125769036e-17*V012*V03*V10*V11 - 
      2.66345176476211437e-16*V03*V04*V10*V11 - 1.33830302257400457e-16*V02*V05*V10*V11 - 
      5.78634350020298385e-17*V01*V06*V10*V11 + 3.44772010468265697e-18*V09*V10*V11 + 
      6.9793384346324566e-18*V012*V02*V112 - 2.89032401174039629e-17*V032*V112 - 
      2.67458892011690925e-17*V02*V04*V112 - 1.74951554490750698e-17*V01*V05*V112 + 
      1.39780433529782171e-18*V08*V112 + 2.41610797579993174e-15*V032*V042*V12 + 
      4.36883366138734348e-16*V02*V043*V12 + 1.68324846527531923e-15*V033*V05*V12 + 
      4.82366297001586424e-15*V02*V03*V04*V05*V12 + 1.44966478547995904e-15*V01*V042*V05*V12 + 
      5.93229970333772434e-16*V022*V052*V12 + 1.48677115941159585e-15*V01*V03*V052*V12 + 
      1.72192735710314058e-15*V02*V032*V06*V12 + 4.58960513279731982e-16*V022*V04*V06*V12 + 
      2.04328505715946363e-15*V01*V03*V04*V06*V12 + 1.03315641426188435e-15*V01*V02*V05*V06*V12 - 
      5.91958968993137293e-16*V052*V06*V12 + 1.05104246892778149e-16*V012*V062*V12 - 
      3.41867322719615313e-16*V04*V062*V12 + 5.64980924127402318e-16*V022*V03*V07*V12 + 
      6.94580333369240193e-16*V01*V032*V07*V12 + 6.8909471000226632e-16*V01*V02*V04*V07*V12 + 
      1.995964645611512e-16*V012*V05*V07*V12 - 7.96561280005617774e-16*V04*V05*V07*V12 - 
      5.6976900940325286e-16*V03*V06*V07*V12 - 9.64875733667091432e-17*V02*V072*V12 + 
      2.72144944025558306e-17*V023*V08*V12 + 3.76369020017668677e-16*V01*V02*V03*V08*V12 + 
      1.08689606392801495e-16*V012*V04*V08*V12 - 1.78409450038842522e-16*V042*V08*V12 - 
      4.42378185330697579e-16*V03*V05*V08*V12 - 1.28355907814232756e-16*V02*V06*V08*V12 - 
      6.4523458007265529e-17*V01*V07*V08*V12 + 4.70817436772835265e-17*V01*V022*V09*V12 + 
      5.32091402085585516e-17*V012*V03*V09*V12 - 2.25942249657338189e-16*V03*V04*V09*V12 - 
      1.13737842569043681e-16*V02*V05*V09*V12 - 4.89803914693849313e-17*V01*V06*V09*V12 + 
      1.46477730159608929e-18*V092*V12 + 1.22249605935798653e-17*V012*V02*V10*V12 - 
      5.0964336826890606e-17*V032*V10*V12 - 4.12677438387991416e-17*V02*V04*V10*V12 - 
      3.0891951574979379e-17*V01*V05*V10*V12 + 2.39808260417402158e-18*V08*V10*V12 + 
      8.38151889097114425e-19*V013*V11*V12 - 2.13172479077623131e-17*V02*V03*V11*V12 - 
      1.28341475195154075e-17*V01*V04*V11*V12 + 1.9545785054057598e-18*V07*V11*V12 - 
      8.05758527136592065e-19*V022*V122 - 2.4049879143387869e-18*V01*V03*V122 + 
      5.16084952073073561e-19*V06*V122 + 5.84600071475320268e-16*V033*V04*V13 + 
      7.85906439017065665e-16*V02*V03*V042*V13 + 1.60839070152385069e-16*V01*V043*V13 + 
      8.97436325800063254e-16*V02*V032*V05*V13 + 3.79169524722456252e-16*V022*V04*V05*V13 + 
      1.03728662290886855e-15*V01*V03*V04*V05*V13 + 2.67076936638106887e-16*V01*V02*V052*V13 - 
      1.01440677558759088e-16*V053*V13 + 2.77648017979850548e-16*V022*V03*V06*V13 + 
      3.56968043900155461e-16*V01*V032*V06*V13 + 3.42901149986378665e-16*V01*V02*V04*V06*V13 + 
      1.02915841520805903e-16*V012*V05*V06*V13 - 4.05008720480813134e-16*V04*V05*V06*V13 - 
      1.45711730613094863e-16*V03*V062*V13 + 2.8643152885761308e-17*V023*V07*V13 + 
      2.50554490868736999e-16*V01*V02*V03*V07*V13 + 7.02236478537310737e-17*V012*V04*V07*V13 - 
      1.35031255307238071e-16*V042*V07*V13 - 2.92125664606409189e-16*V03*V05*V07*V13 - 
      9.74321631140540065e-17*V02*V06*V07*V13 - 2.12096697134348169e-17*V01*V072*V13 + 
      3.12484390936404466e-17*V01*V022*V08*V13 + 3.60769438047498248e-17*V012*V03*V08*V13 - 
      1.5263693699125273e-16*V03*V04*V08*V13 - 7.65311526394204939e-17*V02*V05*V08*V13 - 
      3.32141933011237748e-17*V01*V06*V08*V13 + 9.79078645496149312e-18*V012*V02*V09*V13 - 
      4.11109740274468992e-17*V032*V09*V13 - 3.81003513241839754e-17*V02*V04*V09*V13 - 
      2.48755914617231969e-17*V01*V05*V09*V13 + 2.00614211746479643e-18*V08*V09*V13 + 
      7.0408551226642214e-19*V013*V10*V13 - 1.78656006855199207e-17*V02*V03*V10*V13 - 
      1.07757198562480214e-17*V01*V04*V10*V13 + 1.6506776866523539e-18*V07*V10*V13 - 
      1.75767927910891473e-18*V022*V11*V13 - 4.57413479835438311e-18*V01*V03*V11*V13 + 
      1.01689078437998401e-18*V06*V11*V13 - 8.60768520038049824e-19*V01*V02*V12*V13 + 5.5676898287146704e-19*V05*V12*V13 - 
      4.36509652056081189e-20*V012*V132 + 9.76752888351527708e-20*V04*V132 + 
      4.48102052356221803e-17*V034*V14 + 2.64532403762151898e-16*V02*V032*V04*V14 + 
      3.44155965530630537e-17*V022*V042*V14 + 1.57427626428392877e-16*V01*V03*V042*V14 + 
      1.30895946525948972e-16*V022*V03*V05*V14 + 1.57084361851987751e-16*V01*V032*V05*V14 + 
      1.58719442257291139e-16*V01*V02*V04*V05*V14 + 2.24776593734593678e-17*V012*V052*V14 - 
      9.58587951849846929e-17*V04*V052*V14 + 7.97594018589640422e-18*V023*V06*V14 + 
      1.12090667279273179e-16*V01*V02*V03*V06*V14 + 3.24110847646366245e-17*V012*V04*V06*V14 - 
      5.46375744090898964e-17*V042*V06*V14 - 1.36716915212871443e-16*V03*V05*V06*V14 - 
      1.96341773271024262e-17*V02*V062*V14 + 1.86994209322784246e-17*V01*V022*V07*V14 + 
      2.0802669356211003e-17*V012*V03*V07*V14 - 9.22264695082456627e-17*V03*V04*V07*V14 - 
      4.65166824524657298e-17*V02*V05*V07*V14 - 1.99287012032171426e-17*V01*V06*V07*V14 + 
      5.9525663977457027e-18*V012*V02*V08*V14 - 2.54022302738442329e-17*V032*V08*V14 - 
      2.04445886745367291e-17*V02*V04*V08*V14 - 1.53944583787229172e-17*V01*V05*V08*V14 + 
      6.05697001677060108e-19*V082*V14 + 5.03649641955189121e-19*V013*V09*V14 - 
      1.31808054007493948e-17*V02*V03*V09*V14 - 7.91863383965696068e-18*V01*V04*V09*V14 + 1.21876374036691762e-18*V07*V09*V14 - 
      1.17131423902936725e-18*V022*V10*V14 - 3.50614391717765146e-18*V01*V03*V10*V14 + 
      7.57063494605796157e-19*V06*V10*V14 - 7.47262627623666727e-19*V01*V02*V11*V14 + 4.838114807931289e-19*V05*V11*V14 - 
      7.99964909596980643e-20*V012*V12*V14 + 1.72066239191014715e-19*V04*V12*V14 + 
      6.68971641753707293e-20*V03*V13*V14 + 5.21026808190039119e-21*V02*V142 + 
      2.75817691263653212e-17*V02*V033*V15 + 3.61113833069005954e-17*V022*V03*V04*V15 + 
      4.72995075879523804e-17*V01*V032*V04*V15 + 2.24544696862018761e-17*V01*V02*V042*V15 + 
      5.7286305771522616e-18*V023*V05*V15 + 4.88862851463274758e-17*V01*V02*V03*V05*V15 + 
      1.36303944591010629e-17*V012*V04*V05*V15 - 2.81177593803883835e-17*V042*V05*V15 - 
      3.01790447209865878e-17*V03*V052*V15 + 7.93280051371001567e-18*V01*V022*V06*V15 + 
      9.24962008761436675e-18*V012*V03*V06*V15 - 4.05689816731974822e-17*V03*V04*V06*V15 - 
      2.02802948015577314e-17*V02*V05*V06*V15 - 4.4207496682725921e-18*V01*V062*V15 + 
      3.29867430439438251e-18*V012*V02*V07*V15 - 1.44446946993515652e-17*V032*V07*V15 - 
      1.34556755022399991e-17*V02*V04*V07*V15 - 8.72958596588438028e-18*V01*V05*V07*V15 + 
      2.95151054444547769e-19*V013*V08*V15 - 7.65836759942007755e-18*V02*V03*V08*V15 - 
      4.62812061354664539e-18*V01*V04*V08*V15 + 7.24488545786200946e-19*V07*V08*V15 - 
      9.38489028192482565e-19*V022*V09*V15 - 2.43348213969074529e-18*V01*V03*V09*V15 + 
      5.50448486916837406e-19*V06*V09*V15 - 5.4078300359537644e-19*V01*V02*V10*V15 + 3.54660125483944175e-19*V05*V10*V15 - 
      6.53286460757456257e-20*V012*V11*V15 + 1.4736297697515293e-19*V04*V11*V15 + 5.80662407168307964e-20*V03*V12*V15 + 
      1.02849009704698179e-20*V02*V13*V15 + 2.12973206141177218e-21*V01*V14*V15 + 
      5.41544698831548646e-18*V022*V032*V16 + 4.14898090516051631e-18*V01*V033*V16 + 
      8.94873539188475676e-19*V023*V04*V16 + 1.29932379417294361e-17*V01*V02*V03*V04*V16 + 
      1.88377455888464202e-18*V012*V042*V16 - 2.20997739119726556e-18*V043*V16 + 
      3.24926819298929188e-18*V01*V022*V05*V16 + 3.52475264139274526e-18*V012*V03*V05*V16 - 
      1.68651420523964359e-17*V03*V04*V05*V16 - 4.26432332093489227e-18*V02*V052*V16 + 
      1.3382295734512777e-18*V012*V02*V06*V16 - 5.98316911585681925e-18*V032*V06*V16 - 
      4.75380875898720862e-18*V02*V04*V06*V16 - 3.62460653111123294e-18*V01*V05*V06*V16 + 
      1.47909156899490781e-19*V013*V07*V16 - 4.10038312202359897e-18*V02*V03*V07*V16 - 
      2.45603860149996501e-18*V01*V04*V07*V16 + 1.94362532607944744e-19*V072*V16 - 
      4.41045688546816513e-19*V022*V08*V16 - 1.33205058539090214e-18*V01*V03*V08*V16 + 
      2.93031484236054793e-19*V06*V08*V16 - 3.51479297594796734e-19*V01*V02*V09*V16 + 2.31292505917178341e-19*V05*V09*V16 - 
      4.44634881801110105e-20*V012*V10*V16 + 9.67064071132622911e-20*V04*V10*V16 + 
      4.45717709267112497e-20*V03*V11*V16 + 7.98525436329681887e-21*V02*V12*V16 + 1.8814247010476793e-21*V01*V13*V16 - 
      7.64122637614893118e-24*V162 + 4.21222836555313353e-19*V023*V03*V17 + 
      1.70920935781806387e-18*V01*V02*V032*V17 + 7.96574631769866075e-19*V01*V022*V04*V17 + 
      9.40270108013128053e-19*V012*V03*V04*V17 - 2.19007513667643656e-18*V03*V042*V17 + 
      4.91322230834286605e-19*V012*V02*V05*V17 - 2.31394345121888326e-18*V032*V05*V17 - 
      2.17877656055317827e-18*V02*V04*V05*V17 - 6.97283903328341688e-19*V01*V052*V17 + 
      5.81071687819428068e-20*V013*V06*V17 - 1.57875647571162694e-18*V02*V03*V06*V17 - 
      9.5656749893159278e-19*V01*V04*V06*V17 - 2.57847033223490892e-19*V022*V07*V17 - 
      6.62919858883000458e-19*V01*V03*V07*V17 + 1.55440681022232688e-19*V06*V07*V17 - 1.80351365147473241e-19*V01*V02*V08*V17 + 
      1.21714042799970376e-19*V05*V08*V17 - 2.69762283404460819e-20*V012*V09*V17 + 
      6.23807562343217406e-20*V04*V09*V17 + 2.89217812041133028e-20*V03*V10*V17 + 6.06795445128586217e-21*V02*V11*V17 + 
      1.4455070475485413e-21*V01*V12*V17 - 1.46629966058377701e-23*V15*V17 + 6.6985655440550217e-21*V024*V18 + 
      2.07516864872535296e-19*V01*V022*V03*V18 + 1.07095114874212554e-19*V012*V032*V18 + 
      1.21122769212546621e-19*V012*V02*V04*V18 - 5.81141504969611151e-19*V032*V04*V18 - 
      2.25844666808929592e-19*V02*V042*V18 + 1.93836194608435779e-20*V013*V05*V18 - 
      5.90383070847301023e-19*V02*V03*V05*V18 - 3.51875404659483586e-19*V01*V04*V05*V18 - 
      8.04908132790609475e-20*V022*V06*V18 - 2.47079272805837783e-19*V01*V03*V06*V18 + 
      2.80338127953583151e-20*V062*V18 - 8.58744984616867039e-20*V01*V02*V07*V18 + 
      5.83866609334371303e-20*V05*V07*V18 - 1.33123628224034258e-20*V012*V08*V18 + 
      2.96092484947269207e-20*V04*V08*V18 + 1.68662957227770477e-20*V03*V09*V18 + 3.55051842028132318e-21*V02*V10*V18 + 
      9.92390634858589074e-22*V01*V11*V18 - 1.21303001882835853e-23*V14*V18 + 7.38987432553181321e-21*V01*V023*V19 + 
      2.66962455070749986e-20*V012*V02*V03*V19 - 4.7023070533834595e-20*V033*V19 + 
      4.6551586017744744e-21*V013*V04*V19 - 1.35687912624140615e-19*V02*V03*V04*V19 - 
      4.12900393404038644e-20*V01*V042*V19 - 3.34013269369388434e-20*V022*V05*V19 - 
      8.44330790220972064e-20*V01*V03*V05*V19 - 2.97456300660113346e-20*V01*V02*V06*V19 + 2.09788946116137518e-20*V05*V06*V19 - 
      5.85721031330269716e-21*V012*V07*V19 + 1.41531047580741835e-20*V04*V07*V19 + 
      7.97383871823323048e-21*V03*V08*V19 + 2.06414490330240603e-21*V02*V09*V19 + 5.78471225490976509e-22*V01*V10*V19 - 
      9.24842041409319923e-24*V13*V19 + 1.54775158952360245e-21*V012*V022*V20 + 
      9.21913890666979696e-22*V013*V03*V20 - 1.64161712798614264e-20*V02*V032*V20 - 
      6.14170370277427686e-21*V022*V04*V20 - 1.93691703790779235e-20*V01*V03*V04*V20 - 
      9.93382741044021772e-21*V01*V02*V05*V20 + 3.55406627464441801e-21*V052*V20 - 
      1.99491825413178763e-21*V012*V06*V20 + 4.58965982491152924e-21*V04*V06*V20 + 
      3.45128183011230384e-21*V03*V07*V20 + 8.80815073208328441e-22*V02*V08*V20 + 3.04473854173118396e-22*V01*V09*V20 - 
      6.02209430189021826e-24*V12*V20 + 1.05488224028240946e-22*V013*V02*V21 - 
      1.70075536551959163e-21*V022*V03*V21 - 2.07621104198435786e-21*V01*V032*V21 - 
      2.09037162537131732e-21*V01*V02*V04*V21 - 6.05661007250774045e-22*V012*V05*V21 + 
      1.56717781182109807e-21*V04*V05*V21 + 1.12756477402017628e-21*V03*V06*V21 + 3.8430783954015278e-22*V02*V07*V21 + 
      1.3086187876442999e-22*V01*V08*V21 - 3.62809446433511758e-24*V11*V21 + 2.21613916025716273e-24*V014*V22 - 
      4.53166615753393733e-23*V023*V22 - 4.49907035307730759e-22*V01*V02*V03*V22 - 
      1.28761688089555741e-22*V012*V04*V22 + 1.54977854864939431e-22*V042*V22 + 
      3.46762125767085872e-22*V03*V05*V22 + 1.12651468826930084e-22*V02*V06*V22 + 5.14306586647242163e-23*V01*V07*V22 - 
      1.82636005570528964e-24*V10*V22 - 2.18006958495918408e-23*V01*V022*V23 - 
      2.43882293656714108e-23*V012*V03*V23 + 7.027290381841315e-23*V03*V04*V23 + 3.55073857676908062e-23*V02*V05*V23 + 
      1.54397041286489439e-23*V01*V06*V23 - 8.57920514013664163e-25*V09*V23 - 2.4963406632781833e-24*V012*V02*V24 + 
      7.07196106919584181e-24*V032*V24 + 6.36130739272415964e-24*V02*V04*V24 + 4.32118728724494832e-24*V01*V05*V24 - 
      3.2316293666267551e-25*V08*V24 - 7.64185917330056114e-26*V013*V25 + 1.34666882920032993e-24*V02*V03*V25 + 
      8.13870327535821536e-25*V01*V04*V25 - 1.15513895327514649e-25*V07*V25 + 5.49885178362659733e-26*V022*V26 + 
      1.48356835386180974e-25*V01*V03*V26 - 3.07117153358820708e-26*V06*V26 + 1.33424396049965442e-26*V01*V02*V27 - 
      8.00476344599157569e-27*V05*V27 + 6.47092913868192677e-28*V012*V28 - 1.34059350135723554e-27*V04*V28 - 
      2.35539953136005199e-28*V03*V29 - 1.867512016935621e-29*V02*V30 - 1.867512016935621e-30*V01*V31 + 
      1.66742144369251875e-33*V34) + delta14*eps10*
    (-1.06551186196798794e-14*V046 - 1.22615892997377738e-12*V03*V044*V05 - 
      4.33652244331295628e-12*V032*V042*V052 - 1.18803762918766024e-12*V02*V043*V052 - 
      9.67520198274434802e-13*V033*V053 - 2.9295784032171682e-12*V02*V03*V04*V053 - 
      8.53014761917221758e-13*V01*V042*V053 - 1.83385813283416686e-13*V022*V054 - 
      4.20371442760744707e-13*V01*V03*V054 - 1.76638730303978693e-12*V032*V043*V06 - 
      1.10327880331966336e-13*V02*V044*V06 - 4.01437585406192717e-12*V033*V04*V05*V06 - 
      5.18809185704023208e-12*V02*V03*V042*V05*V06 - 1.05983238182387216e-12*V01*V043*V05*V06 - 
      3.06975614081388044e-12*V02*V032*V052*V06 - 1.24916044897764212e-12*V022*V04*V052*V06 - 
      3.53008527527229571e-12*V01*V03*V04*V052*V06 - 6.03335415983564145e-13*V01*V02*V053*V06 + 
      2.84483874118333337e-13*V054*V06 - 3.46708569456291063e-13*V034*V062 - 
      1.87222026386121509e-12*V02*V032*V04*V062 - 
      1.13681013828802023e-13*V022*V042*V062 - 
      1.133440147577288e-12*V01*V03*V042*V062 - 9.11342830588269911e-13*V022*V03*V05*V062 - 
      1.21138858605886229e-12*V01*V032*V05*V062 - 1.12333215831672905e-12*V01*V02*V04*V05*V062 - 
      1.73158357257677233e-13*V012*V052*V062 + 1.13235735258395956e-12*V04*V052*V062 - 
      8.63318935920672129e-15*V023*V063 - 2.67392484892644865e-13*V01*V02*V03*V063 - 
      7.94115661675345788e-14*V012*V04*V063 + 1.88784007545412907e-13*V042*V063 + 
      5.41640061498286687e-13*V03*V05*V063 + 3.36143560477466875e-14*V02*V064 - 
      1.35399168558289168e-12*V033*V042*V07 - 1.13146440875015261e-12*V02*V03*V043*V07 - 
      1.75165561424825339e-13*V01*V044*V07 - 6.74354021342948743e-13*V034*V05*V07 - 
      4.12420000461614792e-12*V02*V032*V04*V05*V07 - 8.08999080919038247e-13*V022*V042*V05*V07 - 
      2.38668323658157605e-12*V01*V03*V042*V05*V07 - 1.03511304016265511e-12*V022*V03*V052*V07 - 
      1.16577149230146174e-12*V01*V032*V052*V07 - 1.21898640139090238e-12*V01*V02*V04*V052*V07 - 
      1.09424502657809165e-13*V012*V053*V07 + 7.69894137976968135e-13*V04*V053*V07 - 
      9.57675263465974834e-13*V02*V033*V06*V07 - 1.18967661807394488e-12*V022*V03*V04*V06*V07 - 
      1.64153918185183665e-12*V01*V032*V04*V06*V07 - 7.41155979577176012e-13*V01*V02*V042*V06*V07 - 
      1.87790932752292044e-13*V023*V05*V06*V07 - 1.68622129874481741e-12*V01*V02*V03*V05*V06*V07 - 
      4.70638131727799117e-13*V012*V04*V05*V06*V07 + 1.50541899935502346e-12*V042*V05*V06*V07 + 
      1.62821930771898555e-12*V03*V052*V06*V07 - 1.30191832941181416e-13*V01*V022*V062*V07 - 
      1.59660969200104193e-13*V012*V03*V062*V07 + 1.08519939061592886e-12*V03*V04*V062*V07 + 
      5.39767600995604466e-13*V02*V05*V062*V07 + 7.8340613679328721e-14*V01*V063*V07 - 
      2.42972694961270919e-13*V022*V032*V072 - 1.79221261180408623e-13*V01*V033*V072 - 
      6.01786047917861804e-14*V023*V04*V072 - 5.68377650101449052e-13*V01*V02*V03*V04*V072 - 
      7.98669172143181038e-14*V012*V042*V072 + 1.66114464779746409e-13*V043*V072 - 
      1.43954203707413945e-13*V01*V022*V05*V072 - 1.50414659021001827e-13*V012*V03*V05*V072 + 
      1.10255989441278972e-12*V03*V04*V05*V072 + 2.8038332562744712e-13*V02*V052*V072 - 
      5.62412462704722163e-14*V012*V02*V06*V072 + 3.87805209862038471e-13*V032*V06*V072 + 
      3.56727752446445671e-13*V02*V04*V06*V072 + 2.32990911217867057e-13*V01*V05*V06*V072 - 
      2.0583479245532589e-15*V013*V073 + 8.92959749772500795e-14*V02*V03*V073 + 
      5.27440153929078861e-14*V01*V04*V073 - 1.95484137189789633e-15*V074 - 
      3.56365667149302966e-13*V034*V04*V08 - 9.60330764192442729e-13*V02*V032*V042*V08 - 
      3.8174117445761991e-14*V022*V043*V08 - 3.88385117919935962e-13*V01*V03*V043*V08 - 
      7.2959889166517381e-13*V02*V033*V05*V08 - 9.32700990202008761e-13*V022*V03*V04*V05*V08 - 
      1.24410360891050324e-12*V01*V032*V04*V05*V08 - 5.76198458515465637e-13*V01*V02*V042*V05*V08 - 
      7.41930908043865987e-14*V023*V052*V08 - 6.40317695793048718e-13*V01*V02*V03*V052*V08 - 
      1.77660695265519531e-13*V012*V04*V052*V08 + 5.8951367006286366e-13*V042*V052*V08 + 
      4.17602828924684642e-13*V03*V053*V08 - 3.37640370331701187e-13*V022*V032*V06*V08 - 
      2.83289287692937242e-13*V01*V033*V06*V08 - 2.60369447143429007e-14*V023*V04*V06*V08 - 
      8.23596403175737098e-13*V01*V02*V03*V04*V06*V08 - 1.22524168472805205e-13*V012*V042*V06*V08 + 
      1.95386258894598809e-13*V043*V06*V08 - 2.02584222199020712e-13*V01*V022*V05*V06*V08 - 
      2.40632231955574689e-13*V012*V03*V05*V06*V08 + 1.69302719430078193e-12*V03*V04*V05*V06*V08 + 
      4.2302085735691581e-13*V02*V052*V06*V08 - 4.33466631997746864e-14*V012*V02*V062*V08 + 
      3.01967767530605667e-13*V032*V062*V08 + 2.08502135307368109e-13*V02*V04*V062*V08 + 
      1.82291681630360955e-13*V01*V05*V062*V08 - 7.06600864803681892e-14*V023*V03*V07*V08 - 
      2.97141137660686194e-13*V01*V02*V032*V07*V08 - 1.33242998600286966e-13*V01*V022*V04*V07*V08 - 
      1.63655977468068016e-13*V012*V03*V04*V07*V08 + 5.64934107513067722e-13*V03*V042*V07*V08 - 
      8.49154162687546458e-14*V012*V02*V05*V07*V08 + 5.96172350872383989e-13*V032*V05*V07*V08 + 
      5.60989385496712256e-13*V02*V04*V05*V07*V08 + 1.78694288824356194e-13*V01*V052*V07*V08 - 
      1.00940941914017634e-14*V013*V06*V07*V08 + 4.05363497273448834e-13*V02*V03*V06*V07*V08 + 
      2.44847993638330131e-13*V01*V04*V06*V07*V08 + 3.3010313363418097e-14*V022*V072*V08 + 
      8.46163098984560407e-14*V01*V03*V072*V08 - 1.86064024062838575e-14*V06*V072*V08 - 
      5.53235690907154062e-16*V024*V082 - 3.7152647792104543e-14*V01*V022*V03*V082 - 
      2.07746999844606328e-14*V012*V032*V082 - 
      2.22523223252245616e-14*V012*V02*V04*V082 + 1.57331910726695047e-13*V032*V04*V082 + 
      5.38570652592179342e-14*V02*V042*V082 - 3.77763067074145333e-15*V013*V05*V082 + 
      1.58233461651944288e-13*V02*V03*V05*V082 + 9.4973249236722369e-14*V01*V04*V05*V082 + 
      1.90732197480336838e-14*V022*V06*V082 + 6.70787649313196104e-14*V01*V03*V06*V082 - 
      6.82174527399275739e-15*V062*V082 + 2.2879479669345133e-14*V01*V02*V07*V082 - 
      1.45573020924588662e-14*V05*V07*V082 + 1.20906148827913319e-15*V012*V083 - 
      2.39842183560939952e-15*V04*V083 - 3.58362897583465665e-14*V035*V09 - 
      3.70590370801530981e-13*V02*V033*V04*V09 - 2.24721966921955068e-13*V022*V03*V042*V09 - 
      3.18799117835123802e-13*V01*V032*V042*V09 - 9.4288700729179384e-14*V01*V02*V043*V09 - 
      2.79910951653304894e-13*V022*V032*V05*V09 - 2.04932466747304612e-13*V01*V033*V05*V09 - 
      7.02083722570838771e-14*V023*V04*V05*V09 - 6.52955258455056118e-13*V01*V02*V03*V04*V05*V09 - 
      9.14769121374937998e-14*V012*V042*V05*V09 + 1.95018306807010683e-13*V043*V05*V09 - 
      8.27543087188816977e-14*V01*V022*V052*V09 - 8.57831912439608151e-14*V012*V03*V052*V09 + 
      6.44730855840469779e-13*V03*V04*V052*V09 + 1.09395957787412353e-13*V02*V053*V09 - 
      5.21641479867477901e-14*V023*V03*V06*V09 - 2.24763365459760357e-13*V01*V02*V032*V06*V09 - 
      9.91397181728287398e-14*V01*V022*V04*V06*V09 - 1.24157179973322077e-13*V012*V03*V04*V06*V09 + 
      4.23423601600362636e-13*V03*V042*V06*V09 - 6.4351000151359021e-14*V012*V02*V05*V06*V09 + 
      4.53099890345955032e-13*V032*V05*V06*V09 + 4.18777377920581423e-13*V02*V04*V05*V06*V09 + 
      1.35936775532943005e-13*V01*V052*V06*V09 - 3.83676763915971827e-15*V013*V062*V09 + 
      1.51803651435061756e-13*V02*V03*V062*V09 + 9.21242367329382966e-14*V01*V04*V062*V09 - 
      3.8472213407784503e-15*V024*V07*V09 - 7.70881340803796681e-14*V01*V022*V03*V07*V09 - 
      3.91608440111307401e-14*V012*V032*V07*V09 - 4.36034663041862804e-14*V012*V02*V04*V07*V09 + 
      3.07202276215251475e-13*V032*V04*V07*V09 + 1.37855885705849234e-13*V02*V042*V07*V09 - 
      7.01348356570349863e-15*V013*V05*V07*V09 + 3.13369332023064273e-13*V02*V03*V05*V07*V09 + 
      1.84710057570448733e-13*V01*V04*V05*V07*V09 + 4.90956885325281141e-14*V022*V06*V07*V09 + 
      1.28801949153574931e-13*V01*V03*V06*V07*V09 - 1.41316200080800767e-14*V062*V07*V09 + 
      2.25037564157622906e-14*V01*V02*V072*V09 - 1.39503142976684493e-14*V05*V072*V09 - 
      5.88834054003068243e-15*V01*V023*V08*V09 - 2.22922738281772658e-14*V012*V02*V03*V08*V09 + 
      5.51095827050482599e-14*V033*V08*V09 - 3.91817897553733839e-15*V013*V04*V08*V09 + 
      1.57756029922201453e-13*V02*V03*V04*V08*V09 + 4.7950971537007417e-14*V01*V042*V08*V09 + 
      3.87481856991369855e-14*V022*V05*V08*V09 + 9.86175039035535775e-14*V01*V03*V05*V08*V09 + 
      3.44019140061696566e-14*V01*V02*V06*V08*V09 - 2.21506344914122313e-14*V05*V06*V08*V09 + 
      6.8128954820281926e-15*V012*V07*V08*V09 - 1.49478009571762997e-14*V04*V07*V08*V09 - 
      4.21174223510092973e-15*V03*V082*V09 - 1.47404957283084409e-15*V012*V022*V092 - 
      8.97014023032917549e-16*V013*V03*V092 + 2.18257470433779129e-14*V02*V032*V092 + 
      9.43093426753423801e-15*V022*V04*V092 + 2.55349003173343601e-14*V01*V03*V04*V092 + 
      1.31316027028268966e-14*V01*V02*V05*V092 - 4.14600733787741851e-15*V052*V092 + 
      2.59825990122078398e-15*V012*V06*V092 - 5.66349098432564873e-15*V04*V06*V092 - 
      4.0270712557830935e-15*V03*V07*V092 - 1.0906586437259189e-15*V02*V08*V092 - 
      1.18397450259437353e-16*V01*V093 - 3.93159853861184893e-14*V02*V034*V10 - 
      1.05063867635665914e-13*V022*V032*V04*V10 - 8.8377134947598002e-14*V01*V033*V04*V10 - 
      3.9200532436358705e-15*V023*V042*V10 - 1.2855667124745793e-13*V01*V02*V03*V042*V10 - 
      1.27863581666589638e-14*V012*V043*V10 + 1.54912648336551777e-14*V044*V10 - 
      3.36861455178073908e-14*V023*V03*V05*V10 - 1.36805077144640328e-13*V01*V02*V032*V05*V10 - 
      6.30383205813995485e-14*V01*V022*V04*V05*V10 - 7.49225909259565943e-14*V012*V03*V04*V05*V10 + 
      2.71664719876490803e-13*V03*V042*V05*V10 - 1.94520865504198122e-14*V012*V02*V052*V10 + 
      1.41259817043388159e-13*V032*V052*V10 + 1.35416343185048314e-13*V02*V04*V052*V10 + 
      2.81599465131863828e-14*V01*V053*V10 - 6.62804643701804529e-16*V024*V06*V10 - 
      4.51871809502037739e-14*V01*V022*V03*V06*V10 - 2.52419558766810243e-14*V012*V032*V06*V10 - 
      2.70918167398789118e-14*V012*V02*V04*V06*V10 + 1.93984328816821864e-13*V032*V04*V06*V10 + 
      6.60120003366064543e-14*V02*V042*V06*V10 - 4.58532662673825323e-15*V013*V05*V06*V10 + 
      1.9495083207347682e-13*V02*V03*V05*V06*V10 + 1.17092478864102288e-13*V01*V04*V05*V06*V10 + 
      1.16822615687391404e-14*V022*V062*V10 + 4.13596900888601511e-14*V01*V03*V062*V10 - 
      2.83609382119934156e-15*V063*V10 - 4.81230650254391297e-15*V01*V023*V07*V10 - 
      1.78497295367732163e-14*V012*V02*V03*V07*V10 + 4.47024312583884912e-14*V033*V07*V10 - 
      3.12804427962825617e-15*V013*V04*V07*V10 + 1.29750694021906269e-13*V02*V03*V04*V07*V10 + 
      3.92806226156294735e-14*V01*V042*V07*V10 + 3.19750972688999544e-14*V022*V05*V07*V10 + 
      7.99020411279876739e-14*V01*V03*V05*V07*V10 + 2.81857112847512785e-14*V01*V02*V06*V07*V10 - 
      1.82098004694926018e-14*V05*V06*V07*V10 + 2.75363532026623854e-15*V012*V072*V10 - 
      6.15480559875667695e-15*V04*V072*V10 - 2.44121025535655719e-15*V012*V022*V08*V10 - 
      1.5504554226197802e-15*V013*V03*V08*V10 + 3.62510371294021595e-14*V02*V032*V08*V10 + 
      1.20447274428461367e-14*V022*V04*V08*V10 + 4.30846375080211333e-14*V01*V03*V04*V08*V10 + 
      2.18796369512836569e-14*V01*V02*V05*V08*V10 - 7.10896148912683815e-15*V052*V08*V10 + 
      4.47234927967834007e-15*V012*V06*V08*V10 - 8.9705432194866546e-15*V04*V06*V08*V10 - 
      6.91097630894980225e-15*V03*V07*V08*V10 - 8.5870585316745628e-16*V02*V082*V10 - 
      4.20502524715647304e-16*V013*V02*V09*V10 + 8.98901065465886617e-15*V022*V03*V09*V10 + 
      1.09777355486993199e-14*V01*V032*V09*V10 + 1.10082448680048721e-14*V01*V02*V04*V09*V10 + 
      3.19936844035435471e-15*V012*V05*V09*V10 - 7.32360878527080561e-15*V04*V05*V09*V10 - 
      5.26594051555302994e-15*V03*V06*V09*V10 - 1.79956798306621123e-15*V02*V07*V09*V10 - 
      6.11421843484123976e-16*V01*V08*V09*V10 - 9.93230411774702645e-18*V014*V102 + 
      2.22546498750064457e-16*V023*V102 + 2.47893826965401833e-15*V01*V02*V03*V102 + 
      7.17547397444181439e-16*V012*V04*V102 - 7.36006119814956077e-16*V042*V102 - 
      1.68180676268824037e-15*V03*V05*V102 - 5.34596865761021809e-16*V02*V06*V102 - 
      2.50118047253760904e-16*V01*V07*V102 + 2.50010865541097869e-18*V103 - 
      1.62561968083471866e-14*V022*V033*V11 - 8.66846215348587269e-15*V01*V034*V11 - 
      1.27651585921970686e-14*V023*V03*V04*V11 - 5.62312590430988711e-14*V01*V02*V032*V04*V11 - 
      1.22575618321066401e-14*V01*V022*V042*V11 - 1.55576856489661935e-14*V012*V03*V042*V11 + 
      3.61222909998055089e-14*V03*V043*V11 - 1.46893905738813557e-15*V024*V05*V11 - 
      2.86023295515765554e-14*V01*V022*V03*V05*V11 - 1.43569467303507565e-14*V012*V032*V05*V11 - 
      1.60948507708728829e-14*V012*V02*V04*V05*V11 + 1.17825091338786564e-13*V032*V04*V05*V11 + 
      5.32884671190034935e-14*V02*V042*V05*V11 - 1.27963654394852363e-15*V013*V052*V11 + 
      6.0166550894149915e-14*V02*V03*V052*V11 + 3.53552769540881072e-14*V01*V04*V052*V11 - 
      2.84531716291351582e-15*V01*V023*V06*V11 - 1.09007936416980029e-14*V012*V02*V03*V06*V11 + 
      2.75005728383578954e-14*V033*V06*V11 - 1.91740564860917211e-15*V013*V04*V06*V11 + 
      7.75567960217756075e-14*V02*V03*V04*V06*V11 + 2.36687408874828719e-14*V01*V042*V06*V11 + 
      1.89760870846147681e-14*V022*V05*V06*V11 + 4.92297676101732141e-14*V01*V03*V05*V06*V11 + 
      8.48400353799178838e-15*V01*V02*V062*V11 - 5.610029796994928e-15*V05*V062*V11 - 
      1.90194651247327762e-15*V012*V022*V07*V11 - 1.15271333318426e-15*V013*V03*V07*V11 + 
      2.86583872827511808e-14*V02*V032*V07*V11 + 1.24213499633250921e-14*V022*V04*V07*V11 + 
      3.34953851622692688e-14*V01*V03*V04*V07*V11 + 1.72316564053759856e-14*V01*V02*V05*V07*V11 - 
      5.52442177733084614e-15*V052*V07*V11 + 3.40375971081883343e-15*V012*V06*V07*V11 - 
      7.55458323234464608e-15*V04*V06*V07*V11 - 2.68169431939165629e-15*V03*V072*V11 - 
      3.39066188056662846e-16*V013*V02*V08*V11 + 7.17393564083356409e-15*V022*V03*V08*V11 + 
      8.88783259037429655e-15*V01*V032*V08*V11 + 8.81494472979319973e-15*V01*V02*V04*V08*V11 + 
      2.59253083817016289e-15*V012*V05*V08*V11 - 5.93119702351185591e-15*V04*V05*V08*V11 - 
      4.27185923606146558e-15*V03*V06*V08*V11 - 1.45417997987316307e-15*V02*V07*V08*V11 - 
      2.48366198585331004e-16*V01*V082*V11 - 1.83224888505146645e-17*V014*V09*V11 + 
      5.59970014283847403e-16*V023*V09*V11 + 4.75883582594536368e-15*V01*V02*V03*V09*V11 + 
      1.35134622263474521e-15*V012*V04*V09*V11 - 1.50814787076596273e-15*V042*V09*V11 - 
      3.1829547911659653e-15*V03*V05*V09*V11 - 1.0983503831402296e-15*V02*V06*V09*V11 - 
      4.72337749277670796e-16*V01*V07*V09*V11 + 5.01986674735088572e-16*V01*V022*V10*V11 + 
      5.69444852163396221e-16*V012*V03*V10*V11 - 1.41043715022785627e-15*V03*V04*V10*V11 - 
      7.13088461566017984e-16*V02*V05*V10*V11 - 3.10257678039573508e-16*V01*V06*V10*V11 + 1.44451094331469112e-17*V09*V10*V11 + 
      6.28023085816063777e-17*V012*V02*V112 - 1.51930636504113554e-16*V032*V112 - 
      1.45291352040773905e-16*V02*V04*V112 - 9.28959207995042336e-17*V01*V05*V112 + 
      5.88920574653151414e-18*V08*V112 - 2.54812345872454069e-15*V023*V032*V12 - 
      6.48790725965456129e-15*V01*V02*V033*V12 - 1.31789556296394531e-16*V024*V04*V12 - 
      9.44390000165252454e-15*V01*V022*V03*V04*V12 - 5.25736908189679584e-15*V012*V032*V04*V12 - 
      2.84132632175981548e-15*V012*V02*V042*V12 + 2.11646518353147968e-14*V032*V042*V12 + 
      4.70970594800598737e-15*V02*V043*V12 - 1.52887407523472441e-15*V01*V023*V05*V12 - 
      5.46566593223260904e-15*V012*V02*V03*V05*V12 + 1.4385823498265622e-14*V033*V05*V12 - 
      9.51248202796851721e-16*V013*V04*V05*V12 + 4.24221543865247278e-14*V02*V03*V04*V05*V12 + 
      1.27734429006489928e-14*V01*V042*V05*V12 + 5.24649984891637354e-15*V022*V052*V12 + 
      1.28222323837068128e-14*V01*V03*V052*V12 - 9.97489710484378892e-16*V012*V022*V06*V12 - 
      6.29878994438351794e-16*V013*V03*V06*V12 + 1.51823063094257641e-14*V02*V032*V06*V12 + 
      4.99017123888030002e-15*V022*V04*V06*V12 + 1.80614029833706908e-14*V01*V03*V04*V06*V12 + 
      9.16249489219901066e-15*V01*V02*V05*V06*V12 - 3.06254894798269408e-15*V052*V06*V12 + 
      9.37604042232111739e-16*V012*V062*V12 - 1.92020981089934854e-15*V04*V062*V12 - 
      2.24703082348553181e-16*V013*V02*V07*V12 + 5.02598395348539777e-15*V022*V03*V07*V12 + 
      6.0455376361582417e-15*V01*V032*V07*V12 + 6.13149725366843852e-15*V01*V02*V04*V07*V12 + 
      1.75878378077440567e-15*V012*V05*V07*V12 - 4.14703605752856656e-15*V04*V05*V07*V12 - 
      2.97587439522681437e-15*V03*V06*V07*V12 - 5.1016581894044853e-16*V02*V072*V12 - 
      1.32896059465971708e-17*V014*V08*V12 + 3.01062739653686955e-16*V023*V08*V12 + 
      3.37079455832092501e-15*V01*V02*V03*V08*V12 + 9.76019066176421651e-16*V012*V04*V08*V12 - 
      1.01096146577464312e-15*V042*V08*V12 - 2.31683563269019869e-15*V03*V05*V08*V12 - 
      7.34034507633388322e-16*V02*V06*V08*V12 - 3.44411848824223478e-16*V01*V07*V08*V12 + 
      4.26161353800757936e-16*V01*V022*V09*V12 + 4.77818354774205109e-16*V012*V03*V09*V12 - 
      1.19759763131477675e-15*V03*V04*V09*V12 - 6.06498949880525193e-16*V02*V05*V09*V12 - 
      2.62934078975331241e-16*V01*V06*V09*V12 + 6.13555248731214618e-18*V092*V12 + 
      1.1199349642520944e-16*V012*V02*V10*V12 - 2.72359063672652455e-16*V032*V10*V12 - 
      2.39956424993083363e-16*V02*V04*V10*V12 - 1.66678750029171748e-16*V01*V05*V10*V12 + 1.0388208988504024e-17*V08*V10*V12 + 
      7.89202697500412712e-18*V013*V11*V12 - 1.165057052791236e-16*V02*V03*V11*V12 - 
      7.03821097426879375e-17*V01*V04*V11*V12 + 8.23644524733146958e-18*V07*V11*V12 - 
      4.84034573560224839e-18*V022*V122 - 1.33282670527982911e-17*V01*V03*V122 + 
      2.2643166468573696e-18*V06*V122 - 1.88325520177966098e-16*V024*V03*V13 - 
      1.70954608479439596e-15*V01*V022*V032*V13 - 5.52676475661923433e-16*V012*V033*V13 - 
      4.90967638161425714e-16*V01*V023*V04*V13 - 1.89379618984849949e-15*V012*V02*V03*V04*V13 + 
      5.05826863077221138e-15*V033*V04*V13 - 1.66275019988456055e-16*V013*V042*V13 + 
      6.99918385778533476e-15*V02*V03*V042*V13 + 1.43190972017806288e-15*V01*V043*V13 - 
      4.87551254794044012e-16*V012*V022*V05*V13 - 2.91211617106693385e-16*V013*V03*V05*V13 + 
      7.77397616711693979e-15*V02*V032*V05*V13 + 3.40510932238382793e-15*V022*V04*V05*V13 + 
      9.05274223902764908e-15*V01*V03*V04*V05*V13 + 2.33161706058240628e-15*V01*V02*V052*V13 - 
      5.21856294576601128e-16*V053*V13 - 1.15155503343078876e-16*V013*V02*V06*V13 + 
      2.49192412726166886e-15*V022*V03*V06*V13 + 3.13774237604734243e-15*V01*V032*V06*V13 + 
      3.07368796120097812e-15*V01*V02*V04*V06*V13 + 9.15480415252568465e-16*V012*V05*V06*V13 - 
      2.14879673455203454e-15*V04*V05*V06*V13 - 7.75144631962718339e-16*V03*V062*V13 - 
      8.14198567662998133e-18*V014*V07*V13 + 2.61535188520080978e-16*V023*V07*V13 + 
      2.20690156870873267e-15*V01*V02*V03*V07*V13 + 6.2557833599924391e-16*V012*V04*V07*V13 - 
      7.2109649001022126e-16*V042*V07*V13 - 1.5176108896882925e-15*V03*V05*V07*V13 - 
      5.24938995741032451e-16*V02*V06*V07*V13 - 1.12387254502748627e-16*V01*V072*V13 + 
      2.84177714920727022e-16*V01*V022*V08*V13 + 3.2619820945998524e-16*V012*V03*V08*V13 - 
      8.18798807878542713e-16*V03*V04*V08*V13 - 4.13088091934053933e-16*V02*V05*V08*V13 - 
      1.80325399712050579e-16*V01*V06*V08*V13 + 8.87682917956981836e-17*V012*V02*V09*V13 - 
      2.17571564912440851e-16*V032*V09*V13 - 2.08333984970200831e-16*V02*V04*V09*V13 - 
      1.3297390061290931e-16*V01*V05*V09*V13 + 8.4858377866208675e-18*V08*V09*V13 + 
      6.65348813114996974e-18*V013*V10*V13 - 9.81953900142440396e-17*V02*V03*V10*V13 - 
      5.94151013796158778e-17*V01*V04*V10*V13 + 6.98519757425581751e-18*V07*V10*V13 - 
      9.91217964168999333e-18*V022*V11*V13 - 2.50959563440515778e-17*V01*V03*V11*V13 + 
      4.35631570165455718e-18*V06*V11*V13 - 4.88908098117785845e-18*V01*V02*V12*V13 + 2.38916685696865678e-18*V05*V12*V13 - 
      2.50242469336948047e-19*V012*V132 + 4.29153537149113603e-19*V04*V132 - 
      1.23827605624218082e-18*V025*V14 - 1.64014886839458252e-16*V01*V023*V03*V14 - 
      2.71910639351658826e-16*V012*V02*V032*V14 + 3.96713968353032764e-16*V034*V14 - 
      1.49406425000117482e-16*V012*V022*V04*V14 - 9.29591383246045202e-17*V013*V03*V04*V14 + 
      2.39545386757149256e-15*V02*V032*V04*V14 + 3.84317366265926323e-16*V022*V042*V14 + 
      1.42852499754548655e-15*V01*V03*V042*V14 - 4.86085868151963648e-17*V013*V02*V05*V14 + 
      1.19136941902463419e-15*V022*V03*V05*V14 + 1.40447156071301066e-15*V01*V032*V05*V14 + 
      1.44536557178824077e-15*V01*V02*V04*V05*V14 + 2.0354754007535017e-16*V012*V052*V14 - 
      5.11095831949386586e-16*V04*V052*V14 - 3.83378213781377726e-18*V014*V06*V14 + 
      8.99495705274210186e-17*V023*V06*V14 + 1.02372315523250819e-15*V01*V02*V03*V06*V14 + 
      2.96751956094958866e-16*V012*V04*V06*V14 - 3.1629839424292061e-16*V042*V06*V14 - 
      7.31408801813696081e-16*V03*V05*V06*V14 - 1.14687984494807366e-16*V02*V062*V14 + 
      1.72110498015751048e-16*V01*V022*V07*V14 + 1.90349397543779618e-16*V012*V03*V07*V14 - 
      4.96203118799017596e-16*V03*V04*V07*V14 - 2.51698858257636642e-16*V02*V05*V07*V14 - 
      1.08595016470591401e-16*V01*V06*V07*V14 + 5.52322595369984406e-17*V012*V02*V08*V14 - 
      1.37543393612936272e-16*V032*V08*V14 - 1.2044639608042722e-16*V02*V04*V08*V14 - 
      8.41413381789429364e-17*V01*V05*V08*V14 + 2.64867501839094766e-18*V082*V14 + 
      4.79477954876151937e-18*V013*V09*V14 - 7.25361459822451558e-17*V02*V03*V09*V14 - 
      4.37353296969485493e-17*V01*V04*V09*V14 + 5.15396909173541851e-18*V07*V09*V14 - 
      7.07829888414054356e-18*V022*V10*V14 - 1.95455701802223465e-17*V01*V03*V10*V14 + 
      3.33469360495167414e-18*V06*V10*V14 - 4.24667502020315083e-18*V01*V02*V11*V14 + 2.07518537792927636e-18*V05*V11*V14 - 
      4.62477496542911579e-19*V012*V12*V14 + 7.74367195404895075e-19*V04*V12*V14 + 
      2.95086677406131292e-19*V03*V13*V14 + 2.42785009129719816e-20*V02*V142 - 
      5.38072914794188852e-18*V01*V024*V15 - 4.16857690788606772e-17*V012*V022*V03*V15 - 
      1.19979150227557046e-17*V013*V032*V15 + 2.48354659074398767e-16*V02*V033*V15 - 
      1.45290792510990871e-17*V013*V02*V04*V15 + 3.33962747667225869e-16*V022*V03*V04*V15 + 
      4.29581977644375772e-16*V01*V032*V04*V15 + 2.07147928748383837e-16*V01*V02*V042*V15 - 
      1.48667124844425863e-18*V014*V05*V15 + 5.35420335519536816e-17*V023*V05*V15 + 
      4.43992408995352375e-16*V01*V02*V03*V05*V15 + 1.25276051983433327e-16*V012*V04*V05*V15 - 
      1.54409564867649559e-16*V042*V05*V15 - 1.61415539577174706e-16*V03*V052*V15 + 
      7.37303657680600388e-17*V01*V022*V06*V15 + 8.57793019553663621e-17*V012*V03*V06*V15 - 
      2.23306851592900086e-16*V03*V04*V06*V15 - 1.12318732246420198e-16*V02*V05*V06*V15 - 
      2.46114276986979374e-17*V01*V062*V15 + 3.05923676279543986e-17*V012*V02*V07*V15 - 
      7.79930515155372592e-17*V032*V07*V15 - 7.50052586140408749e-17*V02*V04*V07*V15 - 
      4.76001048089897515e-17*V01*V05*V07*V15 + 2.84000570406433493e-18*V013*V08*V15 - 
      4.28455550719478702e-17*V02*V03*V08*V15 - 2.59673670838905704e-17*V01*V04*V08*V15 + 3.10307046862766255e-18*V07*V08*V15 - 
      5.35417323797334968e-18*V022*V09*V15 - 1.35119482444954776e-17*V01*V03*V09*V15 + 
      2.3734607668613851e-18*V06*V09*V15 - 3.10389352829348931e-18*V01*V02*V10*V15 + 1.53217252203333747e-18*V05*V10*V15 - 
      3.76514833046523428e-19*V012*V11*V15 + 6.49093599142644255e-19*V04*V11*V15 + 
      2.56889491029814325e-19*V03*V12*V15 + 4.68975210621292899e-20*V02*V13*V15 + 9.7861607205884644e-21*V01*V14*V15 - 
      1.94325264861973674e-18*V012*V023*V16 - 3.50015246059688076e-18*V013*V02*V03*V16 + 
      5.10217136926340173e-17*V022*V032*V16 + 3.87113702261432411e-17*V01*V033*V16 - 
      4.15499498878294926e-19*V014*V04*V16 + 1.04332431359128657e-17*V023*V04*V16 + 
      1.22530227243343096e-16*V01*V02*V03*V04*V16 + 1.78036375406639624e-17*V012*V042*V16 - 
      1.32407397217539872e-17*V043*V16 + 3.07763771737159736e-17*V01*V022*V05*V16 + 
      3.33574336135158893e-17*V012*V03*V05*V16 - 9.33396955804505158e-17*V03*V04*V05*V16 - 
      2.37234318634031038e-17*V02*V052*V16 + 1.27329843673231961e-17*V012*V02*V06*V16 - 
      3.32333674226172097e-17*V032*V06*V16 - 2.87331569389266671e-17*V02*V04*V06*V16 - 
      2.03154655193473732e-17*V01*V05*V06*V16 + 1.44453817190320657e-18*V013*V07*V16 - 
      2.30056680772099881e-17*V02*V03*V07*V16 - 1.38325487398101055e-17*V01*V04*V07*V16 + 
      8.3208244129826581e-19*V072*V16 - 2.71266667264535076e-18*V022*V08*V16 - 
      7.55622938003174571e-18*V01*V03*V08*V16 + 1.30663262792206919e-18*V06*V08*V16 - 2.02110197201380231e-18*V01*V02*V09*V16 + 
      9.98302170075891685e-19*V05*V09*V16 - 2.5975458938627178e-19*V012*V10*V16 + 4.38154096260583443e-19*V04*V10*V16 + 
      1.97051737283107586e-19*V03*V11*V16 + 3.73127276128761573e-20*V02*V12*V16 + 8.6427935339499305e-21*V01*V13*V16 - 
      3.08321795249567716e-23*V162 - 2.36151788917003261e-19*V013*V022*V17 - 
      8.99929790197228641e-20*V014*V03*V17 + 4.07312700910734637e-18*V023*V03*V17 + 
      1.62643200126761488e-17*V01*V02*V032*V17 + 7.66535334007716975e-18*V01*V022*V04*V17 + 
      9.07132571723025373e-18*V012*V03*V04*V17 - 1.25104698798292999e-17*V03*V042*V17 + 
      4.73308362665614774e-18*V012*V02*V05*V17 - 1.29066829680622123e-17*V032*V05*V17 - 
      1.25239159533136547e-17*V02*V04*V05*V17 - 3.92691431429749568e-18*V01*V052*V17 + 
      5.77497498581765316e-19*V013*V06*V17 - 9.09076580610028899e-18*V02*V03*V06*V17 - 
      5.52187707545663367e-18*V01*V04*V06*V17 - 1.50462127870478505e-18*V022*V07*V17 - 
      3.76875386262416048e-18*V01*V03*V07*V17 + 6.79858711527913207e-19*V06*V07*V17 - 1.05697650135606318e-18*V01*V02*V08*V17 + 
      5.3312982875450891e-19*V05*V08*V17 - 1.57965310308726917e-19*V012*V09*V17 + 2.7703897663671414e-19*V04*V09*V17 + 
      1.290336565724745e-19*V03*V10*V17 + 2.77851042319410559e-20*V02*V11*V17 + 6.67264847763487244e-21*V01*V12*V17 - 
      5.8754840480881479e-23*V15*V17 - 1.14884654067731316e-20*V014*V02*V18 + 
      8.21835578920235092e-20*V024*V18 + 2.04536626257126152e-18*V01*V022*V03*V18 + 
      1.06580058806064101e-18*V012*V032*V18 + 1.1957121852731972e-18*V012*V02*V04*V18 - 
      3.34838759471945799e-18*V032*V04*V18 - 1.41682675403497151e-18*V02*V042*V18 + 
      1.9713507604413287e-19*V013*V05*V18 - 3.41694521790804768e-18*V02*V03*V05*V18 - 
      2.044825154472289e-18*V01*V04*V05*V18 - 5.09509431295445512e-19*V022*V06*V18 - 
      1.44176227128256354e-18*V01*V03*V06*V18 + 1.27732454492789867e-19*V062*V18 - 
      5.05201994594371016e-19*V01*V02*V07*V18 + 2.55676270924465273e-19*V05*V07*V18 - 
      7.93902342294450505e-20*V012*V08*V18 + 1.36089303355779624e-19*V04*V08*V18 + 
      7.51942956814267584e-20*V03*V09*V18 + 1.67370434668110536e-20*V02*V10*V18 + 4.57850921653635291e-21*V01*V11*V18 - 
      4.8988653836145646e-23*V14*V18 - 1.9147442344621886e-22*V015*V19 + 7.46446323783989714e-20*V01*V023*V19 + 
      2.71825297570971417e-19*V012*V02*V03*V19 - 2.741008620115485e-19*V033*V19 + 
      4.84764611740823939e-20*V013*V04*V19 - 8.12211888722484104e-19*V02*V03*V04*V19 - 
      2.47619562352523429e-19*V01*V042*V19 - 2.01337841386302288e-19*V022*V05*V19 - 
      4.96984677304056839e-19*V01*V03*V05*V19 - 1.79718765455244445e-19*V01*V02*V06*V19 + 9.39678038422184373e-20*V05*V06*V19 - 
      3.52121552053129892e-20*V012*V07*V19 + 6.3847626415114815e-20*V04*V07*V19 + 3.61182037088944865e-20*V03*V08*V19 + 
      9.54276345025735983e-21*V02*V09*V19 + 2.6962513469856021e-21*V01*V10*V19 - 3.70920801893677133e-23*V13*V19 + 
      1.60359829636208295e-20*V012*V022*V20 + 9.94603255123414633e-21*V013*V03*V20 - 
      9.90604379387443211e-20*V02*V032*V20 - 4.04388322975849319e-20*V022*V04*V20 - 
      1.17412412961357329e-19*V01*V03*V04*V20 - 6.04242176008892358e-20*V01*V02*V05*V20 + 
      1.59494712373572282e-20*V052*V20 - 1.22621796307981259e-20*V012*V06*V20 + 
      2.15911464159160969e-20*V04*V06*V20 + 1.56399294599584636e-20*V03*V07*V20 + 4.21904360436078379e-21*V02*V08*V20 + 
      1.41914193227918129e-21*V01*V09*V20 - 2.43941584002846862e-23*V12*V20 + 1.17012147661578192e-21*V013*V02*V21 - 
      1.06807820270286487e-20*V022*V03*V21 - 1.27945552085769476e-20*V01*V032*V21 - 
      1.31346812600505442e-20*V01*V02*V04*V21 - 3.77715046714060927e-21*V012*V05*V21 + 
      7.24911445721134992e-21*V04*V05*V21 + 5.22892276352023085e-21*V03*V06*V21 + 1.8069708327693035e-21*V02*V07*V21 + 
      6.19935070485659976e-22*V01*V08*V21 - 1.45884987676579764e-23*V11*V21 + 2.65936699230859528e-23*V014*V22 - 
      3.13822772199096072e-22*V023*V22 - 2.85800292949436438e-21*V01*V02*V03*V22 - 
      8.23091551226192068e-22*V012*V04*V22 + 7.53708177130055374e-22*V042*V22 + 
      1.61303548180996623e-21*V03*V05*V22 + 5.53015856726015466e-22*V02*V06*V22 + 2.44065469373257532e-22*V01*V07*V22 - 
      7.44517702291831119e-24*V10*V22 - 1.43651668739703948e-22*V01*V022*V23 - 
      1.59592586975208919e-22*V012*V03*V23 + 3.36838074067063997e-22*V03*V04*V23 + 1.713509842123205e-22*V02*V05*V23 + 
      7.49470654701314059e-23*V01*V06*V23 - 3.47002786704959745e-24*V09*V23 - 1.67356715895282289e-23*V012*V02*V24 + 
      3.41444958891838321e-23*V032*V24 + 3.23161335404514703e-23*V02*V04*V24 + 2.10789416194410927e-23*V01*V05*V24 - 
      1.33266228453628235e-24*V08*V24 - 5.3493014213103928e-25*V013*V25 + 6.73744924866687699e-24*V02*V03*V25 + 
      4.0851489218303661e-24*V01*V04*V25 - 4.7269965280178486e-25*V07*V25 + 2.9208336147757177e-25*V022*V26 + 
      7.52008244970022316e-25*V01*V03*V26 - 1.29087659644237543e-25*V06*V26 + 6.98860346977648091e-26*V01*V02*V27 - 
      3.34292121079543902e-26*V05*V27 + 3.45116220729702761e-27*V012*V28 - 5.79899831498849033e-27*V04*V28 - 
      1.01499278120451001e-27*V03*V29 - 8.40380407621029451e-29*V02*V30 - 8.40380407621029451e-30*V01*V31 + 
      6.66968577477007501e-33*V34) + delta12*eps11*
    (-2.90595190793452012e-13*V046 - 1.77195745145617204e-11*V03*V044*V05 - 
      5.88614777929885433e-11*V032*V042*V052 - 1.72389073345638161e-11*V02*V043*V052 - 
      1.28249638500401755e-11*V033*V053 - 3.97524696718161194e-11*V02*V03*V04*V053 - 
      1.16381089576911965e-11*V01*V042*V053 - 2.4908126170632933e-12*V022*V054 - 
      5.61951866516027541e-12*V01*V03*V054 - 2.55701335251972444e-11*V032*V043*V06 - 
      3.04763212928287762e-12*V02*V044*V06 - 5.47767011981018882e-11*V033*V04*V05*V06 - 
      7.5280608413445805e-11*V02*V03*V042*V05*V06 - 1.53420801151183466e-11*V01*V043*V05*V06 - 
      4.18666904731182519e-11*V02*V032*V052*V06 - 1.82220854678926646e-11*V022*V04*V052*V06 - 
      4.84613359748920688e-11*V01*V03*V04*V052*V06 - 8.27416495174710403e-12*V01*V02*V053*V06 + 
      1.51150935932592036e-12*V054*V06 - 4.75621746276407292e-12*V034*V062 - 
      2.72006680209384402e-11*V02*V032*V04*V062 - 
      3.18481819851589684e-12*V022*V042*V062 - 
      1.64369223785167943e-11*V01*V03*V042*V062 - 1.32870214733482497e-11*V022*V03*V05*V062 - 
      1.67329208896806221e-11*V01*V032*V05*V062 - 1.63204008125630641e-11*V01*V02*V04*V05*V062 - 
      2.41529033110316866e-12*V012*V052*V062 + 6.28778566415960119e-12*V04*V052*V062 - 
      2.45630135633172784e-13*V023*V063 - 3.89013646962091539e-12*V01*V02*V03*V063 - 
      1.14916221273412521e-12*V012*V04*V063 + 1.22316616919207007e-12*V042*V063 + 
      3.01617362396948867e-12*V03*V05*V063 + 2.2028891934215122e-13*V02*V064 - 
      1.84731888217320579e-11*V033*V042*V07 - 1.64180069852988724e-11*V02*V03*V043*V07 - 
      2.53136778779453149e-12*V01*V044*V07 - 8.99972631519362601e-12*V034*V05*V07 - 
      5.62511266390048619e-11*V02*V032*V04*V05*V07 - 1.18297292705155729e-11*V022*V042*V05*V07 - 
      3.27587164397903329e-11*V01*V03*V042*V05*V07 - 1.41286182045516637e-11*V022*V03*V052*V07 - 
      1.57068379283736578e-11*V01*V032*V052*V07 - 1.67139032669102946e-11*V01*V02*V04*V052*V07 - 
      1.49498224255297789e-12*V012*V053*V07 + 4.11924524486703758e-12*V04*V053*V07 - 
      1.31335951615033397e-11*V02*V033*V06*V07 - 1.73543671122787282e-11*V022*V03*V04*V06*V07 - 
      2.26779242245202087e-11*V01*V032*V04*V06*V07 - 1.07543726304922579e-11*V01*V02*V042*V06*V07 - 
      2.76437516846411614e-12*V023*V05*V06*V07 - 2.32758672010234902e-11*V01*V02*V03*V05*V06*V07 - 
      6.56528397813460784e-12*V012*V04*V05*V06*V07 + 8.43591789824285482e-12*V042*V05*V06*V07 + 
      8.76472862478428712e-12*V03*V052*V06*V07 - 1.89814592476403568e-12*V01*V022*V062*V07 - 
      2.24463908063110724e-12*V012*V03*V062*V07 + 6.09710851076802665e-12*V03*V04*V062*V07 + 
      3.05973314557146188e-12*V02*V05*V062*V07 + 4.46510471276158973e-13*V01*V063*V07 - 
      3.33472248313485948e-12*V022*V032*V072 - 2.4350792435977345e-12*V01*V033*V072 - 
      8.9058899281035463e-13*V023*V04*V072 - 7.84522745818421876e-12*V01*V02*V03*V04*V072 - 
      1.1139301270089876e-12*V012*V042*V072 + 9.39384864591944787e-13*V043*V072 - 
      1.98589109701009761e-12*V01*V022*V05*V072 - 2.07528969018269551e-12*V012*V03*V05*V072 + 
      5.97523823502397728e-12*V03*V04*V05*V072 + 1.52860939802137154e-12*V02*V052*V072 - 
      7.90063392279891396e-13*V012*V02*V06*V072 + 2.11454803660240372e-12*V032*V06*V072 + 
      2.04069879761808021e-12*V02*V04*V06*V072 + 1.28701789453467606e-12*V01*V05*V06*V072 - 
      2.93885174803620453e-14*V013*V073 + 4.92869844944472802e-13*V02*V03*V073 + 
      2.93159129392934015e-13*V01*V04*V073 - 7.64977331613850994e-15*V074 - 
      4.91289003686096005e-12*V034*V04*V08 - 1.40077728813468158e-11*V02*V032*V042*V08 - 
      1.081896728093992e-12*V022*V043*V08 - 5.65213048897102343e-12*V01*V03*V043*V08 - 
      1.00564425551097837e-11*V02*V033*V05*V08 - 1.36597314798058693e-11*V022*V03*V04*V05*V08 - 
      1.72764085417933243e-11*V01*V032*V04*V05*V08 - 8.40466372880808951e-12*V01*V02*V042*V05*V08 - 
      1.0944292191592896e-12*V023*V052*V08 - 8.88749508436677026e-12*V01*V02*V03*V052*V08 - 
      2.49244852562956192e-12*V012*V04*V052*V08 + 3.31091310819733194e-12*V042*V052*V08 + 
      2.25935822592621382e-12*V03*V053*V08 - 4.9475574919926493e-12*V022*V032*V06*V08 - 
      3.95833307574457354e-12*V01*V033*V06*V08 - 7.49900202073305014e-13*V023*V04*V06*V08 - 
      1.20273208142840232e-11*V01*V02*V03*V04*V06*V08 - 1.77892773094438943e-12*V012*V042*V06*V08 + 
      1.27972652267384541e-12*V043*V06*V08 - 2.96853449519558958e-12*V01*V022*V05*V06*V08 - 
      3.40100881556848316e-12*V012*V03*V05*V06*V08 + 9.5346414558501748e-12*V03*V04*V05*V06*V08 + 
      2.4031035840572183e-12*V02*V052*V06*V08 - 6.31223435317128016e-13*V012*V02*V062*V08 + 
      1.70550952108206894e-12*V032*V062*V08 + 1.3812613980094606e-12*V02*V04*V062*V08 + 
      1.04155411533880302e-12*V01*V05*V062*V08 - 1.04231354205646628e-12*V023*V03*V07*V08 - 
      4.15437708054035007e-12*V01*V02*V032*V07*V08 - 1.95139021140083847e-12*V01*V022*V04*V07*V08 - 
      2.31518970189870679e-12*V012*V03*V04*V07*V08 + 3.209532620850908e-12*V03*V042*V07*V08 - 
      1.20061632641955493e-12*V012*V02*V05*V07*V08 + 3.26712871779420036e-12*V032*V05*V07*V08 + 
      3.21561036816506166e-12*V02*V04*V05*V07*V08 + 9.92166385492437881e-13*V01*V052*V07*V08 - 
      1.4657271001739129e-13*V013*V06*V07*V08 + 2.3288217508600429e-12*V02*V03*V06*V07*V08 + 
      1.41065810629555102e-12*V01*V04*V06*V07*V08 + 1.93156259747662569e-13*V022*V072*V08 + 
      4.75804893099775018e-13*V01*V03*V072*V08 - 7.4886166207675242e-14*V06*V072*V08 - 
      1.64315868093657611e-14*V024*V082 - 5.47099609247452195e-13*V01*V022*V03*V082 - 
      2.97661277588471112e-13*V012*V032*V082 - 
      3.25249140722128074e-13*V012*V02*V04*V082 + 8.98444556173748027e-13*V032*V04*V082 + 
      3.60637312192839873e-13*V02*V042*V082 - 5.51539865089048533e-14*V013*V05*V082 + 
      9.11104127001634005e-13*V02*V03*V05*V082 + 5.48520167869523443e-13*V01*V04*V05*V082 + 
      1.2921865783226018e-13*V022*V06*V082 + 3.88538914741094532e-13*V01*V03*V06*V082 - 
      2.91857543067660216e-14*V062*V082 + 1.34644834921388101e-13*V01*V02*V07*V082 - 
      5.86645228256932343e-14*V05*V07*V082 + 7.17450122454159205e-15*V012*V083 - 
      1.03776069363781464e-14*V04*V083 - 4.84694388636299341e-13*V035*V09 - 
      5.10878658707380573e-12*V02*V033*V04*V09 - 3.28603590847654802e-12*V022*V03*V042*V09 - 
      4.42809759891092236e-12*V01*V032*V042*V09 - 1.36816724877490604e-12*V01*V02*V043*V09 - 
      3.86145491085296757e-12*V022*V032*V05*V09 - 2.80297277547695921e-12*V01*V033*V05*V09 - 
      1.0390204916120804e-12*V023*V04*V05*V09 - 9.06307940966427522e-12*V01*V02*V03*V04*V05*V09 - 
      1.28361055283113884e-12*V012*V042*V05*V09 + 1.11525123467469327e-12*V043*V05*V09 - 
      1.14820449197378578e-12*V01*V022*V052*V09 - 1.19222361951962521e-12*V012*V03*V052*V09 + 
      3.53673830936390443e-12*V03*V04*V052*V09 + 6.03571741092428972e-13*V02*V053*V09 - 
      7.67881991240032262e-13*V023*V03*V06*V09 - 3.14276545479872727e-12*V01*V02*V032*V06*V09 - 
      1.44619725935656068e-12*V01*V022*V04*V06*V09 - 1.75720625556122991e-12*V012*V03*V04*V06*V09 + 
      2.42708490910096376e-12*V03*V042*V06*V09 - 9.09934297793617777e-13*V012*V02*V05*V06*V09 + 
      2.50064697168297843e-12*V032*V05*V06*V09 + 2.42203107650518099e-12*V02*V04*V05*V06*V09 + 
      7.59903041572251371e-13*V01*V052*V06*V09 - 5.57977813101668583e-14*V013*V062*V09 + 
      8.79788263159727173e-13*V02*V03*V062*V09 + 5.35277678789437174e-13*V01*V04*V062*V09 - 
      5.79013449106212626e-14*V024*V07*V09 - 1.07787658577461116e-12*V01*V022*V03*V07*V09 - 
      5.50242597587842769e-13*V012*V032*V07*V09 - 6.16484899638005322e-13*V012*V02*V04*V07*V09 + 
      1.70616937906599848e-12*V032*V04*V07*V09 + 8.04507906794255842e-13*V02*V042*V07*V09 - 
      1.0099361224018983e-13*V013*V05*V07*V09 + 1.75001012749867981e-12*V02*V03*V05*V07*V09 + 
      1.03875607956523936e-12*V01*V04*V05*V07*V09 + 2.89828241215801768e-13*V022*V06*V07*V09 + 
      7.29035340931257697e-13*V01*V03*V06*V07*V09 - 5.73896485822789713e-14*V062*V07*V09 + 
      1.28712740936397465e-13*V01*V02*V072*V09 - 5.51508501121437067e-14*V05*V072*V09 - 
      8.68594618380388569e-14*V01*V023*V08*V09 - 3.20543962479079932e-13*V012*V02*V03*V08*V09 + 
      3.09494112311760471e-13*V033*V08*V09 - 5.74450882825092299e-14*V013*V04*V08*V09 + 
      9.24087110473303651e-13*V02*V03*V04*V08*V09 + 2.81531562141414108e-13*V01*V042*V08*V09 + 
      2.29121895995233358e-13*V022*V05*V08*V09 + 5.6105226648728694e-13*V01*V03*V05*V08*V09 + 
      2.04106396939724229e-13*V01*V02*V06*V08*V09 - 9.00490867242537475e-14*V05*V06*V08*V09 + 
      3.98058232539407154e-14*V012*V07*V08*V09 - 6.13630532774544539e-14*V04*V07*V08*V09 - 
      1.73537057205651628e-14*V03*V082*V09 - 2.11850712326831304e-14*V012*V022*V092 - 
      1.32184328056637726e-14*V013*V03*V092 + 1.24749544118988933e-13*V02*V032*V092 + 
      5.67603579473663064e-14*V022*V04*V092 + 1.47023240190327336e-13*V01*V03*V04*V092 + 
      7.5949959707761596e-14*V01*V02*V05*V092 - 1.65585366654739811e-14*V052*V092 + 
      1.52700815938654888e-14*V012*V06*V092 - 2.34601922955722198e-14*V04*V06*V092 - 
      1.62847269837454516e-14*V03*V07*V092 - 4.62097006145935701e-15*V02*V08*V092 - 
      4.96299072845128054e-16*V01*V093 - 5.50870856926615277e-13*V02*V034*V10 - 
      1.5527722364769094e-12*V022*V032*V04*V10 - 1.24863362969075099e-12*V01*V033*V04*V10 - 
      1.1550257910037109e-13*V023*V042*V10 - 1.89209151665001544e-12*V01*V02*V03*V042*V10 - 
      1.86968646760236552e-13*V012*V043*V10 + 1.03582324453623614e-13*V044*V10 - 
      5.00910961956077343e-13*V023*V03*V05*V10 - 1.93373288382711014e-12*V01*V02*V032*V05*V10 - 
      9.31663341886145639e-13*V01*V022*V04*V05*V10 - 1.07172884093792675e-12*V012*V03*V04*V05*V10 + 
      1.56330601197716445e-12*V03*V042*V05*V10 - 2.78342428153320806e-13*V012*V02*V052*V10 + 
      7.86655330558895721e-13*V032*V052*V10 + 7.85957953193368738e-13*V02*V04*V052*V10 + 
      1.58861952966039074e-13*V01*V053*V10 - 1.98950881151465037e-14*V024*V06*V10 - 
      6.68103505799281803e-13*V01*V022*V03*V06*V10 - 3.63771320020942622e-13*V012*V032*V06*V10 - 
      3.97485562792206224e-13*V012*V02*V04*V06*V10 + 1.11938743099417928e-12*V032*V04*V06*V10 + 
      4.46405496344398297e-13*V02*V042*V06*V10 - 6.73696204971486524e-14*V013*V05*V06*V10 + 
      1.13417327928836874e-12*V02*V03*V05*V06*V10 + 6.83222616705886977e-13*V01*V04*V05*V06*V10 + 
      7.99240785903998132e-14*V022*V062*V10 + 2.42026597250748805e-13*V01*V03*V062*V10 - 
      1.22482962297168172e-14*V063*V10 - 7.15587088508681918e-14*V01*V023*V07*V10 - 
      2.58030569511442931e-13*V012*V02*V03*V07*V10 + 2.52052114564455858e-13*V033*V07*V10 - 
      4.60783804462108791e-14*V013*V04*V07*V10 + 7.61241408165898528e-13*V02*V03*V04*V07*V10 + 
      2.31033983145262517e-13*V01*V042*V07*V10 + 1.89335827139776751e-13*V022*V05*V07*V10 + 
      4.56420320648084873e-13*V01*V03*V05*V07*V10 + 1.67522300877232639e-13*V01*V02*V06*V07*V10 - 
      7.40391619107675595e-14*V05*V06*V07*V10 + 1.61566325476315485e-14*V012*V072*V10 - 
      2.52642968895642921e-14*V04*V072*V10 - 3.61160864951402973e-14*V012*V022*V08*V10 - 
      2.31839958455375664e-14*V013*V03*V08*V10 + 2.13692446244694972e-13*V02*V032*V08*V10 + 
      8.32816636850870626e-14*V022*V04*V08*V10 + 2.54754482561835463e-13*V01*V03*V04*V08*V10 + 
      1.30357222949023397e-13*V01*V02*V05*V08*V10 - 2.89506049609139514e-14*V052*V08*V10 + 
      2.68016795055927463e-14*V012*V06*V08*V10 - 3.91770731361302015e-14*V04*V06*V08*V10 - 
      2.84895218786783107e-14*V03*V07*V08*V10 - 3.83915284786933657e-15*V02*V082*V10 - 
      6.35150156029677035e-15*V013*V02*V09*V10 + 5.43239597758033047e-14*V022*V03*V09*V10 + 
      6.42088723627743631e-14*V01*V032*V09*V10 + 6.66142900568783812e-14*V01*V02*V04*V09*V10 + 
      1.89842415273924881e-14*V012*V05*V09*V10 - 3.03618756100015642e-14*V04*V05*V09*V10 - 
      2.18887967869969245e-14*V03*V06*V09*V10 - 7.62290374539222611e-15*V02*V07*V09*V10 - 
      2.61040645626882311e-15*V01*V08*V09*V10 - 1.58676112460290127e-16*V014*V102 + 
      1.58893278536049181e-15*V023*V102 + 1.51055927936013176e-14*V01*V02*V03*V102 + 
      4.38526426711846703e-15*V012*V04*V102 - 3.28006379030340162e-15*V042*V102 - 
      7.00805156439816736e-15*V03*V05*V102 - 2.41188218366547633e-15*V02*V06*V102 - 
      1.06887522169987317e-15*V01*V07*V102 + 9.14207691019508718e-18*V103 - 
      2.28132548454620351e-13*V022*V033*V11 - 1.21303047415730805e-13*V01*V034*V11 - 
      1.88912816656741891e-13*V023*V03*V04*V11 - 7.95542822378279404e-13*V01*V02*V032*V04*V11 - 
      1.79238322280538983e-13*V01*V022*V042*V11 - 2.23009212886274765e-13*V012*V03*V042*V11 + 
      2.13301438659448423e-13*V03*V043*V11 - 2.21077862386008457e-14*V024*V05*V11 - 
      4.04662559250882427e-13*V01*V022*V03*V05*V11 - 2.04703848077714046e-13*V012*V032*V05*V11 - 
      2.30493182140839486e-13*V012*V02*V04*V05*V11 + 6.6938585725379883e-13*V032*V04*V05*V11 + 
      3.17487273708286677e-13*V02*V042*V05*V11 - 1.87238798506310335e-14*V013*V052*V11 + 
      3.43580474477070011e-13*V02*V03*V052*V11 + 2.03312295670697371e-13*V01*V04*V052*V11 - 
      4.18844722494563052e-14*V01*V023*V06*V11 - 1.57771690385542814e-13*V012*V02*V03*V06*V11 + 
      1.57181892166940491e-13*V033*V06*V11 - 2.83354266841582726e-14*V013*V04*V06*V11 + 
      4.62850638974080586e-13*V02*V03*V04*V06*V11 + 1.41525473057646955e-13*V01*V042*V06*V11 + 
      1.1431505037335038e-13*V022*V05*V06*V11 + 2.84917281117310506e-13*V01*V03*V05*V06*V11 + 
      5.12461659239716623e-14*V01*V02*V062*V11 - 2.31826254120352504e-14*V05*V062*V11 - 
      2.7506784267166733e-14*V012*V022*V07*V11 - 1.71142856090207052e-14*V013*V03*V07*V11 + 
      1.65553213876725325e-13*V02*V032*V07*V11 + 7.54955788893130922e-14*V022*V04*V07*V11 + 
      1.94913228557554029e-13*V01*V03*V04*V07*V11 + 1.00710882632026356e-13*V01*V02*V05*V07*V11 - 
      2.22306982232099975e-14*V052*V07*V11 + 2.02138690756728178e-14*V012*V06*V07*V11 - 
      3.15262928841360421e-14*V04*V06*V07*V11 - 1.09262429107429086e-14*V03*V072*V11 - 
      5.13084145426626466e-15*V013*V02*V08*V11 + 4.37164863389298981e-14*V022*V03*V08*V11 + 
      5.23229452853965094e-14*V01*V032*V08*V11 + 5.37715160118417592e-14*V01*V02*V04*V08*V11 + 
      1.54790722930103452e-14*V012*V05*V08*V11 - 2.477365541544727e-14*V04*V05*V08*V11 - 
      1.78849054136021923e-14*V03*V06*V08*V11 - 6.2065520307388192e-15*V02*V07*V08*V11 - 
      1.06749702928144317e-15*V01*V082*V11 - 2.90963727504169379e-16*V014*V09*V11 + 
      3.50707214533027658e-15*V023*V09*V11 + 2.84374917893430262e-14*V01*V02*V03*V09*V11 + 
      8.15171070809740622e-15*V012*V04*V09*V11 - 6.41818200181575174e-15*V042*V09*V11 - 
      1.31002665804024687e-14*V03*V05*V09*V11 - 4.72973927902239277e-15*V02*V06*V09*V11 - 
      1.9948451217303451e-15*V01*V07*V09*V11 + 3.15192592877457861e-15*V01*V022*V10*V11 + 
      3.49397223437032659e-15*V012*V03*V10*V11 - 6.01984279202816973e-15*V03*V04*V10*V11 - 
      3.07246639567515387e-15*V02*V05*V10*V11 - 1.34496012736194932e-15*V01*V06*V10*V11 + 5.17878053645355038e-17*V09*V10*V11 + 
      3.92366454580907171e-16*V012*V02*V112 - 6.44205660833536906e-16*V032*V112 - 
      6.42444290022996291e-16*V02*V04*V112 - 3.9922837584864715e-16*V01*V05*V112 + 
      2.12345312439852685e-17*V08*V112 - 3.84064171652211876e-14*V023*V032*V12 - 
      9.40505054499348202e-14*V01*V02*V033*V12 - 4.09249643488451368e-15*V024*V04*V12 - 
      1.41446050260142088e-13*V01*V022*V03*V04*V12 - 7.72288419791322916e-14*V012*V032*V04*V12 - 
      4.2190829755898063e-14*V012*V02*V042*V12 + 1.25874876186291312e-13*V032*V042*V12 + 
      3.27884126758458746e-14*V02*V043*V12 - 2.30438502991327126e-14*V01*V023*V05*V12 - 
      8.04600520060931912e-14*V012*V02*V03*V05*V12 + 8.32035558594828789e-14*V033*V05*V12 - 
      1.42742211519147517e-14*V013*V04*V05*V12 + 2.54298413124247597e-13*V02*V03*V04*V05*V12 + 
      7.6768780282111254e-14*V01*V042*V05*V12 + 3.17258699566973791e-14*V022*V052*V12 + 
      7.51120186778152368e-14*V01*V03*V052*V12 - 1.48795353098640662e-14*V012*V022*V06*V12 - 
      9.54318011283601072e-15*V013*V03*V06*V12 + 9.12355114937558028e-14*V02*V032*V06*V12 + 
      3.51431392151825084e-14*V022*V04*V06*V12 + 1.0885826289156896e-13*V01*V03*V04*V06*V12 + 
      5.56286916067064811e-14*V01*V02*V05*V06*V12 - 1.26684235358598834e-14*V052*V06*V12 + 
      5.72551324868645745e-15*V012*V062*V12 - 8.52581775210741481e-15*V04*V062*V12 - 
      3.43282124801889987e-15*V013*V02*V07*V12 + 3.06971751644572955e-14*V022*V03*V07*V12 + 
      3.584390066347564e-14*V01*V032*V07*V12 + 3.75053450443787402e-14*V01*V02*V04*V07*V12 + 
      1.05788673300242669e-14*V012*V05*V07*V12 - 1.73117801830002007e-14*V04*V05*V07*V12 - 
      1.24594805090415846e-14*V03*V06*V07*V12 - 2.17539911207855514e-15*V02*V072*V12 - 
      2.13842409058411346e-16*V014*V08*V12 + 2.16809659193893376e-15*V023*V08*V12 + 
      2.07252599638628731e-14*V01*V02*V03*V08*V12 + 6.0186076259075824e-15*V012*V04*V08*V12 - 
      4.53806896125226671e-15*V042*V08*V12 - 9.71930186888395396e-15*V03*V05*V08*V12 - 
      3.33545112794844355e-15*V02*V06*V08*V12 - 1.48162074360070317e-15*V01*V07*V08*V12 + 
      2.67861316036734157e-15*V01*V022*V09*V12 + 2.94135389148521551e-15*V012*V03*V09*V12 - 
      5.10909112914692719e-15*V03*V04*V09*V12 - 2.61134638975267907e-15*V02*V05*V09*V12 - 
      1.13973775027948049e-15*V01*V06*V09*V12 + 2.19752573064356817e-17*V092*V12 + 
      7.10584019797870351e-16*V012*V02*V10*V12 - 1.16909013785125411e-15*V032*V10*V12 - 
      1.1119934617964594e-15*V02*V04*V10*V12 - 7.24934187905344272e-16*V01*V05*V10*V12 + 3.81709119254581757e-17*V08*V10*V12 + 
      5.11007891660526681e-17*V013*V11*V12 - 5.16030078861824271e-16*V02*V03*V11*V12 - 
      3.12893186084986183e-16*V01*V04*V11*V12 + 2.96505187428893643e-17*V07*V11*V12 - 
      2.33054397167997735e-17*V022*V122 - 5.96941309963432686e-17*V01*V03*V122 + 
      8.42417204249470703e-18*V06*V122 - 2.83433156905139048e-15*V024*V03*V13 - 
      2.48766340937986731e-14*V01*V022*V032*V13 - 8.16618619670232692e-15*V012*V033*V13 - 
      7.26587756372084197e-15*V01*V023*V04*V13 - 2.79950065312086397e-14*V012*V02*V03*V04*V13 + 
      2.99982073336089253e-14*V033*V04*V13 - 2.51714064157018145e-15*V013*V042*V13 + 
      4.33474780338194787e-14*V02*V03*V042*V13 + 8.87880449333861129e-15*V01*V043*V13 - 
      7.20161423692587196e-15*V012*V022*V05*V13 - 4.43353810875427657e-15*V013*V03*V05*V13 + 
      4.63102605514547704e-14*V02*V032*V05*V13 + 2.12877834077792355e-14*V022*V04*V05*V13 + 
      5.43231873602758436e-14*V01*V03*V04*V05*V13 + 1.40467089734057312e-14*V01*V02*V052*V13 - 
      2.14873232200104931e-15*V053*V13 - 1.77101076726189364e-15*V013*V02*V06*V13 + 
      1.55925342203709522e-14*V022*V03*V06*V13 + 1.89506303280017709e-14*V01*V032*V06*V13 + 
      1.92430599821296989e-14*V01*V02*V04*V06*V13 + 5.60456976517891085e-15*V012*V05*V06*V13 - 
      9.16971609742599651e-15*V04*V05*V06*V13 - 3.31489802026933394e-15*V03*V062*V13 - 
      1.3148995431706557e-16*V014*V07*V13 + 1.66755407800186044e-15*V023*V07*V13 + 
      1.34439019277869765e-14*V01*V02*V03*V07*V13 + 3.84699195728309541e-15*V012*V04*V07*V13 - 
      3.10725966469847063e-15*V042*V07*V13 - 6.3263777696378392e-15*V03*V05*V07*V13 - 
      2.28875664134825522e-15*V02*V06*V07*V13 - 4.8073756884235031e-16*V01*V072*V13 + 
      1.81332382036538165e-15*V01*V022*V08*V13 + 2.03155910719937898e-15*V012*V03*V08*V13 - 
      3.53846528572086054e-15*V03*V04*V08*V13 - 1.8024373519476791e-15*V02*V05*V08*V13 - 
      7.91171446675598773e-16*V01*V06*V08*V13 + 5.59553655672757608e-16*V012*V02*V09*V13 - 
      9.273734448702899e-16*V032*V09*V13 - 9.25912074211352958e-16*V02*V04*V09*V13 - 
      5.74472063236676506e-16*V01*V05*V09*V13 + 3.06765985420069206e-17*V08*V09*V13 + 
      4.33108475411449453e-17*V013*V10*V13 - 4.37433644996957902e-16*V02*V03*V10*V13 - 
      2.65572086469623862e-16*V01*V04*V10*V13 + 2.5236382459977642e-17*V07*V10*V13 - 
      4.57432688210227211e-17*V022*V11*V13 - 1.11645451160819337e-16*V01*V03*V11*V13 + 
      1.59575172818717453e-17*V06*V11*V13 - 2.26465249212108962e-17*V01*V02*V12*V13 + 8.74232863798130612e-18*V05*V12*V13 - 
      1.16844462209289411e-18*V012*V132 + 1.61385941746621937e-18*V04*V132 - 
      4.10763637966855792e-17*V025*V14 - 2.51848489775275857e-15*V01*V023*V03*V14 - 
      4.1553491945466938e-15*V012*V02*V032*V14 + 2.39970781394422697e-15*V034*V14 - 
      2.26912494264964364e-15*V012*V022*V04*V14 - 1.45194458634018942e-15*V013*V03*V04*V14 + 
      1.49320383171783871e-14*V02*V032*V04*V14 + 2.80557616158932653e-15*V022*V042*V14 + 
      8.92853201929087591e-15*V01*V03*V042*V14 - 7.63421278347737107e-16*V013*V02*V05*V14 + 
      7.48540666922023424e-15*V022*V03*V05*V14 + 8.60347560478289299e-15*V01*V032*V05*V14 + 
      9.0963833522252862e-15*V01*V02*V04*V05*V14 + 1.26481235432075669e-15*V012*V052*V14 - 
      2.18113225898635906e-15*V04*V052*V14 - 6.31651300745069298e-17*V014*V06*V14 + 
      6.64434790655152199e-16*V023*V06*V14 + 6.46038816272402666e-15*V01*V02*V03*V06*V14 + 
      1.87812048887447027e-15*V012*V04*V06*V14 - 1.45095007970022581e-15*V042*V06*V14 - 
      3.13153207745970782e-15*V03*V05*V06*V14 - 5.32467651465468331e-16*V02*V062*V14 + 
      1.10157131918264988e-15*V01*V022*V07*V14 + 1.19712868274301687e-15*V012*V03*V07*V14 - 
      2.14271124113885909e-15*V03*V04*V07*V14 - 1.09656684185231894e-15*V02*V05*V07*V14 - 
      4.76620134195367518e-16*V01*V06*V07*V14 + 3.56188108127101105e-16*V012*V02*V08*V14 - 
      5.97263470583267208e-16*V032*V08*V14 - 5.65154697197074163e-16*V02*V04*V08*V14 - 
      3.70175450652741857e-16*V01*V05*V08*V14 + 9.80865838743469535e-18*V082*V14 + 
      3.14058340762237076e-17*V013*V09*V14 - 3.22713901450089101e-16*V02*V03*V09*V14 - 
      1.95367042495679132e-16*V01*V04*V09*V14 + 1.85876431853439997e-17*V07*V09*V14 - 
      3.4262171944854816e-17*V022*V10*V14 - 8.79629061901705802e-17*V01*V03*V10*V14 + 
      1.24430489645100335e-17*V06*V10*V14 - 1.96596988032197738e-17*V01*V02*V11*V14 + 7.58736282152991534e-18*V05*V11*V14 - 
      2.17104384231269531e-18*V012*V12*V14 + 2.95649935064851283e-18*V04*V12*V14 + 
      1.11010870706120906e-18*V03*V13*V14 + 9.63246890546055995e-20*V02*V142 - 
      8.09809019728968708e-17*V01*V024*V15 - 6.44543672097230788e-16*V012*V022*V03*V15 - 
      1.92709412202511033e-16*V013*V032*V15 + 1.55228380685568773e-15*V02*V033*V15 - 
      2.31855421978909186e-16*V013*V02*V04*V15 + 2.18011439278647467e-15*V022*V03*V04*V15 + 
      2.70576467295308031e-15*V01*V032*V04*V15 + 1.35181286116135465e-15*V01*V02*V042*V15 - 
      2.49689881652088473e-17*V014*V05*V15 + 3.53072973817065201e-16*V023*V05*V15 + 
      2.8058343642063018e-15*V01*V02*V03*V05*V15 + 7.99320870381139741e-16*V012*V04*V05*V15 - 
      6.82610533427659768e-16*V042*V05*V15 - 6.90960635114978441e-16*V03*V052*V15 + 
      4.85647771931164829e-16*V01*V022*V06*V15 + 5.51317023695178505e-16*V012*V03*V06*V15 - 
      9.89090368279280363e-16*V03*V04*V06*V15 - 5.02321748431503004e-16*V02*V05*V06*V15 - 
      1.10620697679624665e-16*V01*V062*V15 + 1.97908181013888883e-16*V012*V02*V07*V15 - 
      3.37936020054706314e-16*V032*V07*V15 - 3.38667347920568608e-16*V02*V04*V07*V15 - 
      2.09040311120392819e-16*V01*V05*V07*V15 + 1.88878385652422559e-17*V013*V08*V15 - 
      1.93923650479491514e-16*V02*V03*V08*V15 - 1.17893386703800525e-16*V01*V04*V08*V15 + 1.13193167338919329e-17*V07*V08*V15 - 
      2.49204614139056803e-17*V022*V09*V15 - 6.06474620313341038e-17*V01*V03*V09*V15 + 
      8.72807614323375286e-18*V06*V09*V15 - 1.45074389560744105e-17*V01*V02*V10*V15 + 5.63401474683540154e-18*V05*V10*V15 - 
      1.76443911081364944e-18*V012*V11*V15 + 2.44404883864416701e-18*V04*V11*V15 + 
      9.68456847054712765e-19*V03*V12*V15 + 1.83569236626170988e-19*V02*V13*V15 + 3.84761531304417121e-20*V01*V14*V15 - 
      3.04520923048866475e-17*V012*V023*V16 - 5.81051476630286522e-17*V013*V02*V03*V16 + 
      3.34779082627576589e-16*V022*V032*V16 + 2.49279121467537986e-16*V01*V033*V16 - 
      7.18412036770213162e-18*V014*V04*V16 + 8.03235515810501768e-17*V023*V04*V16 + 
      8.05525795060203109e-16*V01*V02*V03*V04*V16 + 1.17365646194876533e-16*V012*V042*V16 - 
      6.29701119028003319e-17*V043*V16 + 2.03707415954213554e-16*V01*V022*V05*V16 + 
      2.17972579302648421e-16*V012*V03*V05*V16 - 4.13612087956030817e-16*V03*V04*V05*V16 - 
      1.06009822909882282e-16*V02*V052*V16 + 8.47090094892323099e-17*V012*V02*V06*V16 - 
      1.47788683562784511e-16*V032*V06*V16 - 1.38262390208906751e-16*V02*V04*V06*V16 - 
      9.15078584034843923e-17*V01*V05*V06*V16 + 9.72785832494578484e-18*V013*V07*V16 - 
      1.03970125582516242e-16*V02*V03*V07*V16 - 6.27871345288553543e-17*V01*V04*V07*V16 + 
      3.02720961996028608e-18*V072*V16 - 1.33451286199099775e-17*V022*V08*V16 - 
      3.45178492145219498e-17*V01*V03*V08*V16 + 4.92339253454328646e-18*V06*V08*V16 - 9.43513021112853153e-18*V01*V02*V09*V16 + 
      3.66324336856631204e-18*V05*V09*V16 - 1.22947286900301847e-18*V012*V10*V16 + 1.6810223127349019e-18*V04*V10*V16 + 
      7.42000944687580131e-19*V03*V11*V16 + 1.48316963262901088e-19*V02*V12*V16 + 3.39669000943191817e-20*V01*V13*V16 - 
      1.08414106860607694e-22*V162 - 4.06936337163061249e-18*V013*V022*V17 - 
      1.63295770795716984e-18*V014*V03*V17 + 2.81188390545665347e-17*V023*V03*V17 + 
      1.0826211222779499e-16*V01*V02*V032*V17 + 5.28066931246391429e-17*V01*V022*V04*V17 + 
      6.10140882694644323e-17*V012*V03*V04*V17 - 5.75164057112453765e-17*V03*V042*V17 + 
      3.19063511884286489e-17*V012*V02*V05*V17 - 5.75781547914209758e-17*V032*V05*V17 - 
      5.81351960019835587e-17*V02*V04*V05*V17 - 1.77535839362381307e-17*V01*V052*V17 + 
      3.98051657978457463e-18*V013*V06*V17 - 4.22649542682855194e-17*V02*V03*V06*V17 - 
      2.57436460375644467e-17*V01*V04*V06*V17 - 7.1314633209179444e-18*V022*V07*V17 - 
      1.72422550721790697e-17*V01*V03*V07*V17 + 2.52511622482320726e-18*V06*V07*V17 - 5.03006878738516483e-18*V01*V02*V08*V17 + 
      1.98122790134510562e-18*V05*V08*V17 - 7.48919157241560804e-19*V012*V09*V17 + 
      1.04812557308086724e-18*V04*V09*V17 + 4.89273591619826013e-19*V03*V10*V17 + 1.08980041334204557e-19*V02*V11*V17 + 
      2.63116927405092983e-20*V01*V12*V17 - 2.0575443830850905e-22*V15*V17 - 2.18919090806843563e-19*V014*V02*V18 + 
      6.7033068154927376e-19*V024*V18 + 1.41836780067710544e-17*V01*V022*V03*V18 + 
      7.35302385702896333e-18*V012*V032*V18 + 8.31082767816847573e-18*V012*V02*V04*V18 - 
      1.54470532504313798e-17*V032*V04*V18 - 7.0838055619170403e-18*V02*V042*V18 + 
      1.38565873906407305e-18*V013*V05*V18 - 1.58853321551998814e-17*V02*V03*V05*V18 - 
      9.55049010072567148e-18*V01*V04*V05*V18 - 2.5771488456284754e-18*V022*V06*V18 - 
      6.76035344261243714e-18*V01*V03*V06*V18 + 4.90498683064798354e-19*V062*V18 - 
      2.40288907434302142e-18*V01*V02*V07*V18 + 9.47877120289529219e-19*V05*V07*V18 - 
      3.82372331697886096e-19*V012*V08*V18 + 5.28068570560231079e-19*V04*V08*V18 + 
      2.84579955220036533e-19*V03*V09*V18 + 6.6952903423269279e-20*V02*V10*V18 + 1.80344841436370416e-20*V01*V11*V18 - 
      1.72345829297033869e-22*V14*V18 - 4.02096289237059606e-21*V015*V19 + 
      5.43782930308941048e-19*V01*V023*V19 + 1.93679038682842685e-18*V012*V02*V03*V19 - 
      1.27684877971053212e-18*V033*V19 + 3.50615376544285716e-19*V013*V04*V19 - 
      3.92484695520143063e-18*V02*V03*V04*V19 - 1.19935410976718376e-18*V01*V042*V19 - 
      9.82548547820733781e-19*V022*V05*V19 - 2.34584274307905763e-18*V01*V03*V05*V19 - 
      8.79705129476875345e-19*V01*V02*V06*V19 + 3.5593236370260905e-19*V05*V06*V19 - 
      1.70553970938679269e-19*V012*V07*V19 + 2.44219379668026081e-19*V04*V07*V19 + 
      1.38543399662842116e-19*V03*V08*V19 + 3.7640466379559635e-20*V02*V09*V19 + 1.07024168228217185e-20*V01*V10*V19 - 
      1.2993477728821087e-22*V13*V19 + 1.17743473584463056e-19*V012*V022*V20 + 
      7.41520163022046649e-20*V013*V03*V20 - 4.8012030821805611e-19*V02*V032*V20 - 
      2.12884051737732548e-19*V022*V04*V20 - 5.71883066422638208e-19*V01*V03*V04*V20 - 
      2.9628475343091466e-19*V01*V02*V05*V20 + 6.03524279827530684e-20*V052*V20 - 
      6.07269815111703984e-20*V012*V06*V20 + 8.55097958086453117e-20*V04*V06*V20 + 
      5.98944498718490738e-20*V03*V07*V20 + 1.70938767687218455e-20*V02*V08*V20 + 5.6260851248527965e-21*V01*V09*V20 - 
      8.59799417012496578e-23*V12*V20 + 8.99752499064408068e-21*V013*V02*V21 - 
      5.42973102114055258e-20*V022*V03*V21 - 6.31630701905253325e-20*V01*V032*V21 - 
      6.68634988660727841e-20*V01*V02*V04*V21 - 1.89118361844498564e-20*V012*V05*V21 + 
      2.83120837311243544e-20*V04*V05*V21 + 2.04673091618930054e-20*V03*V06*V21 + 7.21417454179992764e-21*V02*V07*V21 + 
      2.49179510466674089e-21*V01*V08*V21 - 5.11611035008880854e-23*V11*V21 + 2.17181637705201948e-22*V014*V22 - 
      1.74180590462672758e-21*V023*V22 - 1.46308396743311364e-20*V01*V02*V03*V22 - 
      4.23856737961672064e-21*V012*V04*V22 + 3.08282122615226201e-21*V042*V22 + 
      6.31568181143729104e-21*V03*V05*V22 + 2.28998883831590243e-21*V02*V06*V22 + 9.80656923760037668e-22*V01*V07*V22 - 
      2.63534003090158564e-23*V10*V22 - 7.69079763944637793e-22*V01*V022*V23 - 
      8.37251261257817439e-22*V012*V03*V23 + 1.36103642147440712e-21*V03*V04*V23 + 
      6.99349117825256533e-22*V02*V05*V23 + 3.07723079531434893e-22*V01*V06*V23 - 1.22086802494361939e-23*V09*V23 - 
      9.0617166076998054e-23*V012*V02*V24 + 1.38553829678985954e-22*V032*V24 + 
      1.38361595835513072e-22*V02*V04*V24 + 8.67332692141703517e-23*V01*V05*V24 - 4.75863519628270821e-24*V08*V24 - 
      2.99560879593381997e-24*V013*V25 + 2.84723758070510859e-23*V02*V03*V25 + 1.73271925748060649e-23*V01*V04*V25 - 
      1.67647889031402806e-24*V07*V25 + 1.31021455887694266e-24*V022*V26 + 3.21107635640939772e-24*V01*V03*V26 - 
      4.68559138551550696e-25*V06*V26 + 3.10029404955516314e-25*V01*V02*V27 - 1.20564521550145063e-25*V05*V27 + 
      1.55302299328366242e-26*V012*V28 - 2.16377412330228792e-26*V04*V28 - 3.77144051820148661e-27*V03*V29 - 
      3.26814602963733675e-28*V02*V30 - 3.26814602963733675e-29*V01*V31 + 2.33439002116952625e-32*V34) + 
   delta10*eps12*(2.22749683444943147e-11*V036*V04 + 
      1.73292491102310232e-10*V02*V034*V042 + 1.45354177117946323e-10*V022*V032*V043 + 
      1.31751524744173828e-10*V01*V033*V043 + 1.27157831390982766e-12*V023*V044 + 
      9.1275474217791114e-11*V01*V02*V03*V044 + 5.62381147292536842e-12*V012*V045 - 
      2.82877994364105943e-12*V046 + 6.88076150292916025e-11*V02*V035*V05 + 
      3.47490943412465875e-10*V022*V033*V04*V05 + 1.88622010016937578e-10*V01*V034*V04*V05 + 
      1.36514759536405017e-10*V023*V03*V042*V05 + 
      6.02882465247553759e-10*V01*V02*V032*V042*V05 + 
      8.72125062707677939e-11*V01*V022*V043*V05 + 1.12216145697541569e-10*V012*V03*V043*V05 - 
      1.23138837696583437e-10*V03*V044*V05 + 8.62240050975281002e-11*V023*V032*V052 + 
      1.94977156546874651e-10*V01*V02*V033*V052 + 1.57555709716582765e-11*V024*V04*V052 + 
      3.03947887889767357e-10*V01*V022*V03*V04*V052 + 
      1.56300807236916521e-10*V012*V032*V04*V052 + 
      8.61339462429127826e-11*V012*V02*V042*V052 - 
      3.83987752890811111e-10*V032*V042*V052 - 1.21220431716326447e-10*V02*V043*V052 + 
      1.68611033675897474e-11*V01*V023*V053 + 5.40778786173839565e-11*V012*V02*V03*V053 - 
      8.1381137821677036e-11*V033*V053 + 9.34919609101353893e-12*V013*V04*V053 - 
      2.61217197823716458e-10*V02*V03*V04*V053 - 7.70570171493270654e-11*V01*V042*V053 - 
      1.64955344498558386e-11*V022*V054 - 3.62903404272886363e-11*V01*V03*V054 + 
      6.04459891865828449e-11*V022*V034*V06 + 2.53821272099447691e-11*V01*V035*V06 + 
      1.00937341709014671e-10*V023*V032*V04*V06 + 2.76140733023829203e-10*V01*V02*V033*V04*V06 + 
      1.27027449949796009e-12*V024*V042*V06 + 1.91186248094514313e-10*V01*V022*V03*V042*V06 + 
      1.14140000786386183e-10*V012*V032*V042*V06 + 
      3.94620208946994932e-11*V012*V02*V043*V06 - 1.77898336791669556e-10*V032*V043*V06 - 
      3.00126569924297715e-11*V02*V044*V06 + 2.35620118383952506e-11*V024*V03*V05*V06 + 
      2.09934826835567113e-10*V01*V022*V032*V05*V06 + 
      6.95658153159453474e-11*V012*V033*V05*V06 + 6.05624050254088028e-11*V01*V023*V04*V05*V06 + 
      2.34580348438361818e-10*V012*V02*V03*V04*V05*V06 - 3.59829446282170513e-10*V033*V04*V05*V06 + 
      2.09690223516922011e-11*V013*V042*V05*V06 - 5.29820692861439768e-10*V02*V03*V042*V05*V06 - 
      1.079461410606446e-10*V01*V043*V05*V06 + 2.99287531765837491e-11*V012*V022*V052*V06 + 
      1.8558648108808757e-11*V013*V03*V052*V06 - 2.76995800769563952e-10*V02*V032*V052*V06 - 
      1.29843307205049466e-10*V022*V04*V052*V06 - 3.23201110183917031e-10*V01*V03*V04*V052*V06 - 
      5.5552153373563504e-11*V01*V02*V053*V06 + 5.83138189716279212e-12*V054*V06 + 
      8.42069009156108361e-14*V025*V062 + 2.2176084249925596e-11*V01*V023*V03*V062 + 
      3.971619317492692e-11*V012*V02*V032*V062 - 3.1458599927917941e-11*V034*V062 + 
      2.07035819533159167e-11*V012*V022*V04*V062 + 
      1.39898949669564178e-11*V013*V03*V04*V062 - 1.91599416114820754e-10*V02*V032*V04*V062 - 
      3.17480578302565785e-11*V022*V042*V062 - 
      1.15702035759804818e-10*V01*V03*V042*V062 + 7.26430931373054165e-12*V013*V02*V05*V062 - 
      9.47269441705209698e-11*V022*V03*V05*V062 - 1.1240066308212529e-10*V01*V032*V05*V062 - 
      1.16241818101486839e-10*V01*V02*V04*V05*V062 - 1.64928815541386254e-11*V012*V052*V062 + 
      2.53725865969608951e-11*V04*V052*V062 + 2.01175787851679834e-13*V014*V063 - 
      2.48011675294559049e-12*V023*V063 - 2.77142642235135694e-11*V01*V02*V03*V063 - 
      8.16066992755002367e-12*V012*V04*V063 + 5.54022990825782863e-12*V042*V063 + 
      1.21974075151752332e-11*V03*V05*V063 + 1.01436947559492419e-12*V02*V064 + 
      2.67636561390313451e-11*V023*V033*V07 + 4.45146419764245776e-11*V01*V02*V034*V07 + 
      1.50053056872935967e-11*V024*V03*V04*V07 + 1.40549488908721632e-10*V01*V022*V032*V04*V07 + 
      4.72418649970546082e-11*V012*V033*V04*V07 + 1.95021085052007168e-11*V01*V023*V042*V07 + 
      7.90365436521888773e-11*V012*V02*V03*V042*V07 - 1.22315998474260047e-10*V033*V042*V07 + 
      4.73789012157675317e-12*V013*V043*V07 - 1.16751413800826824e-10*V02*V03*V043*V07 - 
      1.79913012012536508e-11*V01*V044*V07 + 1.3616852513889526e-12*V025*V05*V07 + 
      4.68965943190198785e-11*V01*V023*V03*V05*V07 + 7.35741222609171521e-11*V012*V02*V032*V05*V07 - 
      5.80597263119434395e-11*V034*V05*V07 + 4.02239914595479521e-11*V012*V022*V04*V05*V07 + 
      2.52369247616439444e-11*V013*V03*V04*V05*V07 - 3.7506876436623631e-10*V02*V032*V04*V05*V07 - 
      8.52146672960118114e-11*V022*V042*V05*V07 - 2.20148558512723362e-10*V01*V03*V042*V05*V07 + 
      6.57447932502501923e-12*V013*V02*V052*V07 - 9.49142305133562536e-11*V022*V03*V052*V07 - 
      1.03137007307082244e-10*V01*V032*V052*V07 - 1.13053305374205318e-10*V01*V02*V04*V052*V07 - 
      1.00097347439058998e-11*V012*V053*V07 + 1.60680556078829638e-11*V04*V053*V07 + 
      3.36600169119932152e-12*V01*V024*V06*V07 + 2.74077552772991237e-11*V012*V022*V03*V06*V07 + 
      8.32586861056177461e-12*V013*V032*V06*V07 - 8.81817018823755844e-11*V02*V033*V06*V07 + 
      9.84227266058061372e-12*V013*V02*V04*V06*V07 - 1.25036125446928126e-10*V022*V03*V04*V06*V07 - 
      1.53530839834894819e-10*V01*V032*V04*V06*V07 - 7.73856162361412975e-11*V01*V02*V042*V06*V07 + 
      1.06516504372291707e-12*V014*V05*V06*V07 - 2.01886033293445036e-11*V023*V05*V06*V07 - 
      1.58596727551803931e-10*V01*V02*V03*V05*V06*V07 - 4.51663959704385601e-11*V012*V04*V05*V06*V07 + 
      3.45220986007291083e-11*V042*V05*V06*V07 + 3.43838099616265763e-11*V03*V052*V06*V07 - 
      1.38315018655633126e-11*V01*V022*V062*V07 - 1.55648585470633141e-11*V012*V03*V062*V07 + 
      2.49974326936422146e-11*V03*V04*V062*V07 + 1.27225895917746904e-11*V02*V05*V062*V07 + 
      1.86620966425297466e-12*V01*V063*V07 + 1.5551273428710461e-12*V012*V023*V072 + 
      2.94817611917140068e-12*V013*V02*V03*V072 - 
      2.27219138226724757e-11*V022*V032*V072 - 1.62559346100216763e-11*V01*V033*V072 + 
      3.62247984038862067e-13*V014*V04*V072 - 6.5794917300651681e-12*V023*V04*V072 - 
      5.38411630942362187e-11*V01*V02*V03*V04*V072 - 7.71711787376060855e-12*V012*V042*V072 + 
      3.89829154936873638e-12*V043*V072 - 1.3718910651857091e-11*V01*V022*V05*V072 - 
      1.41313336903572415e-11*V012*V03*V05*V072 + 2.36929812994591895e-11*V03*V04*V05*V072 + 
      6.12583596041494081e-12*V02*V052*V072 - 5.54909403113311497e-12*V012*V02*V06*V072 + 
      8.43223496406090027e-12*V032*V06*V072 + 8.60253908189920048e-12*V02*V04*V06*V072 + 
      5.22654993760904891e-12*V01*V05*V06*V072 - 2.0828403690459012e-13*V013*V073 + 
      2.00650698423283727e-12*V02*V03*V073 + 1.20246486083832847e-12*V01*V04*V073 - 
      2.43272390387416231e-14*V074 + 4.43589357347288559e-12*V024*V032*V08 + 
      2.44199258420110704e-11*V01*V022*V033*V08 + 5.86845970093331564e-12*V012*V034*V08 + 
      8.32941840379171502e-14*V025*V04*V08 + 2.25851861767948222e-11*V01*V023*V03*V04*V08 + 
      4.0345207198136212e-11*V012*V02*V032*V04*V08 - 3.29521234318622865e-11*V034*V04*V08 + 
      1.0566787942277273e-11*V012*V022*V042*V08 + 
      7.0960815638831393e-12*V013*V03*V042*V08 - 9.98742346814537664e-11*V02*V032*V042*V08 - 
      1.08992078774954743e-11*V022*V043*V08 - 4.02620237810387979e-11*V01*V03*V043*V08 + 
      2.66153614408373136e-12*V01*V024*V05*V08 + 2.06572170595783577e-11*V012*V022*V03*V05*V08 + 
      6.1901025273319589e-12*V013*V032*V05*V08 - 6.79298991890078524e-11*V02*V033*V05*V08 + 
      7.36426156856230334e-12*V013*V02*V04*V05*V08 - 9.85881026255866861e-11*V022*V03*V04*V05*V08 - 
      1.17669335170122035e-10*V01*V032*V04*V05*V08 - 6.05834847911178298e-11*V01*V02*V042*V05*V08 + 
      3.94375735865307124e-13*V014*V052*V08 - 8.00381895567361082e-12*V023*V052*V08 - 
      6.09343178683393248e-11*V01*V02*V03*V052*V08 - 1.72554041716935053e-11*V012*V04*V052*V08 + 
      1.35549735195908077e-11*V042*V052*V08 + 8.89774241794624971e-12*V03*V053*V08 + 
      2.45323343110556666e-12*V012*V023*V06*V08 + 4.89397249289638568e-12*V013*V02*V03*V06*V08 - 
      3.57216018618000045e-11*V022*V032*V06*V08 - 2.71522212905568456e-11*V01*V033*V06*V08 + 
      6.09074140522126704e-13*V014*V04*V06*V08 - 7.65354013069657337e-12*V023*V04*V06*V08 - 
      8.67071648045461203e-11*V01*V02*V03*V04*V06*V08 - 1.27816021708323676e-11*V012*V042*V06*V08 + 
      5.88312376096160235e-12*V043*V06*V08 - 2.16653700699282647e-11*V01*V022*V05*V06*V08 - 
      2.37276126624613818e-11*V012*V03*V05*V06*V08 + 3.91200880371059887e-11*V03*V04*V05*V06*V08 + 
      9.99677782522239317e-12*V02*V052*V06*V08 - 4.58913421431129618e-12*V012*V02*V062*V08 + 
      7.01458940668508906e-12*V032*V062*V08 + 6.45373135574594442e-12*V02*V04*V062*V08 + 
      4.35805636677664265e-12*V01*V05*V062*V08 + 8.57894507767387915e-13*V013*V022*V07*V08 + 
      3.48953740867378518e-13*V014*V03*V07*V08 - 7.70505934060221209e-12*V023*V03*V07*V08 - 
      2.89075165288960718e-11*V01*V02*V032*V07*V08 - 1.43908734713166523e-11*V01*V022*V04*V07*V08 - 
      1.62747358408630594e-11*V012*V03*V04*V07*V08 + 1.33461090314409295e-11*V03*V042*V07*V08 - 
      8.48889080959702884e-12*V012*V02*V05*V07*V08 + 1.30792308264499076e-11*V032*V05*V07*V08 + 
      1.35579369428690651e-11*V02*V04*V05*V07*V08 + 4.04521118072525584e-12*V01*V052*V07*V08 - 
      1.0586691607248449e-12*V013*V06*V07*V08 + 9.83607058208231697e-12*V02*V03*V06*V07*V08 + 
      5.97767982169950295e-12*V01*V04*V06*V07*V08 + 8.382204849968335e-13*V022*V072*V08 + 
      1.97085318598774865e-12*V01*V03*V072*V08 - 2.44282273920194646e-13*V06*V072*V08 + 
      5.20754904190915895e-14*V014*V02*V082 - 1.71894103455293766e-13*V024*V082 - 
      4.03969427424909435e-12*V01*V022*V03*V082 - 
      2.1216463148402431e-12*V012*V032*V082 - 
      2.3921762992463582e-12*V012*V02*V04*V082 + 3.74810390010033114e-12*V032*V04*V082 + 
      1.70932432891098722e-12*V02*V042*V082 - 4.00945604293709623e-13*V013*V05*V082 + 
      3.85138393949729925e-12*V02*V03*V05*V082 + 2.32709893298158498e-12*V01*V04*V05*V082 + 
      6.22275306778810704e-13*V022*V06*V082 + 1.65258762802313112e-12*V01*V03*V06*V082 - 
      9.96756080707849081e-14*V062*V082 + 5.86997414646288496e-13*V01*V02*V07*V082 - 
      1.91360153715975186e-13*V05*V07*V082 + 3.15069030081969638e-14*V012*V083 - 
      3.59036749336042189e-14*V04*V083 + 3.78245903163597944e-13*V025*V03*V09 + 
      6.18365674754297415e-12*V01*V023*V032*V09 + 6.26705132297496372e-12*V012*V02*V033*V09 - 
      3.22809215476187665e-12*V035*V09 + 1.25044214060779972e-12*V01*V024*V04*V09 + 
      1.04753975338861827e-11*V012*V022*V03*V04*V09 + 
      3.18788110894417446e-12*V013*V032*V04*V09 - 3.5056204372677474e-11*V02*V033*V04*V09 + 
      1.88481344810167452e-12*V013*V02*V042*V09 - 2.41955882021185472e-11*V022*V03*V042*V09 - 
      3.06373521106104911e-11*V01*V032*V042*V09 - 1.00551303821026447e-11*V01*V02*V043*V09 + 
      1.76863694145480704e-12*V012*V023*V05*V09 + 3.32023823792797618e-12*V013*V02*V03*V05*V09 - 
      2.66818654751512963e-11*V022*V032*V05*V09 - 1.90015261211833585e-11*V01*V033*V05*V09 + 
      4.06510903584277547e-13*V014*V04*V05*V09 - 7.75961726013110088e-12*V023*V04*V05*V09 - 
      6.30838348218848874e-11*V01*V02*V03*V04*V05*V09 - 9.02069349602445306e-12*V012*V042*V05*V09 + 
      4.68972556474879297e-12*V043*V05*V09 - 8.04295008814014337e-12*V01*V022*V052*V09 - 
      8.24331798763934029e-12*V012*V03*V052*V09 + 1.42147274697760471e-11*V03*V04*V052*V09 + 
      2.45116216837310884e-12*V02*V053*V09 + 6.4826960868364484e-13*V013*V022*V06*V09 + 
      2.64416306241910253e-13*V014*V03*V06*V09 - 5.73045301032915337e-12*V023*V03*V06*V09 - 
      2.20418648412081695e-11*V01*V02*V032*V06*V09 - 1.07636353382499787e-11*V01*V022*V04*V06*V09 - 
      1.2451316255600049e-11*V012*V03*V04*V06*V09 + 1.02216308638425745e-11*V03*V042*V06*V09 - 
      6.48232575349766959e-12*V012*V02*V05*V06*V09 + 1.01074029961373167e-11*V032*V05*V06*V09 + 
      1.03430224355184527e-11*V02*V04*V05*V06*V09 + 3.12705130277321364e-12*V01*V052*V06*V09 - 
      4.0621794288044824e-13*V013*V062*V09 + 3.76230403305984231e-12*V02*V03*V062*V09 + 
      2.29551725304580545e-12*V01*V04*V062*V09 + 9.36347210142029678e-14*V014*V02*V07*V09 - 
      4.44003085557858383e-13*V024*V07*V09 - 7.65641235560342064e-12*V01*V022*V03*V07*V09 - 
      3.86798496460154733e-12*V012*V032*V07*V09 - 4.41906360931733599e-12*V012*V02*V04*V07*V09 + 
      6.96691079172594937e-12*V032*V04*V07*V09 + 3.48195841533475201e-12*V02*V042*V07*V09 - 
      7.2667051887220448e-13*V013*V05*V07*V09 + 7.21821887142400422e-12*V02*V03*V05*V07*V09 + 
      4.31663555782010374e-12*V01*V04*V05*V07*V09 + 1.27353186923951184e-12*V022*V06*V07*V09 + 
      3.04711222311651776e-12*V01*V03*V06*V07*V09 - 1.8907452628926285e-13*V062*V07*V09 + 
      5.48167933948330858e-13*V01*V02*V072*V09 - 1.77083430559958377e-13*V05*V072*V09 + 
      4.10421307055738404e-15*V015*V08*V09 - 6.62681933611782404e-13*V01*V023*V08*V09 - 
      2.33361685639446493e-12*V012*V02*V03*V08*V09 + 1.27594638349972527e-12*V033*V08*V09 - 
      4.23891691667463604e-13*V013*V04*V08*V09 + 4.00502194096992461e-12*V02*V03*V04*V08*V09 + 
      1.22346194054951197e-12*V01*V042*V08*V09 + 1.00676735103873816e-12*V022*V05*V08*V09 + 
      2.35450673119894343e-12*V01*V03*V05*V08*V09 + 9.00024010225081081e-13*V01*V02*V06*V08*V09 - 
      2.96561487323976458e-13*V05*V06*V08*V09 + 1.72696385402357092e-13*V012*V07*V08*V09 - 
      2.04657290911524405e-13*V04*V07*V08*V09 - 5.79684896082063436e-14*V03*V082*V09 - 
      1.5690011124953018e-13*V012*V022*V092 - 9.81877711776517748e-14*V013*V03*V092 + 
      5.2917055616711043e-13*V02*V032*V092 + 2.55786594415443067e-13*V022*V04*V092 + 
      6.28336267315784024e-13*V01*V03*V04*V092 + 3.27539971187132558e-13*V01*V02*V05*V092 - 
      5.36894830743704179e-14*V052*V092 + 6.67984129284117039e-14*V012*V06*V092 - 
      7.90545048500523179e-14*V04*V06*V092 - 5.35638595320512922e-14*V03*V07*V092 - 
      1.60038070755565166e-14*V02*V08*V092 - 1.70220959456931541e-15*V01*V093 + 
      1.33871312051040767e-15*V026*V10 + 6.01628313686092315e-13*V01*V024*V03*V10 + 
      2.13199677290930093e-12*V012*V022*V032*V10 + 
      4.11209824377458165e-13*V013*V033*V10 - 3.84866739850521412e-12*V02*V034*V10 + 
      7.57341244892155875e-13*V012*V023*V04*V10 + 1.49091081304407357e-12*V013*V02*V03*V04*V10 - 
      1.14769483561987782e-11*V022*V032*V04*V10 - 8.79900433484753714e-12*V01*V033*V04*V10 + 
      9.22754081081756732e-14*V014*V042*V10 - 1.20295502031097831e-12*V023*V042*V10 - 
      1.39585437954771616e-11*V01*V02*V03*V042*V10 - 1.37441499498701589e-12*V012*V043*V10 + 
      4.8926553978257235e-13*V044*V10 + 3.85787338884810033e-13*V013*V022*V05*V10 + 
      1.5476095619194474e-13*V014*V03*V05*V10 - 3.75060288477556567e-12*V023*V03*V05*V10 - 
      1.37151870483471011e-11*V01*V02*V032*V05*V10 - 6.95876527996827857e-12*V01*V022*V04*V05*V10 - 
      7.68029125120983369e-12*V012*V03*V04*V05*V10 + 6.58387841259996672e-12*V03*V042*V05*V10 - 
      2.00644723689726838e-12*V012*V02*V052*V10 + 3.19985268073096672e-12*V032*V052*V10 + 
      3.35441262132503336e-12*V02*V04*V052*V10 + 6.58015884146853982e-13*V01*V053*V10 + 
      6.25313951838994503e-14*V014*V02*V06*V10 - 2.10116049994914531e-13*V024*V06*V10 - 
      4.98876499212611456e-12*V01*V022*V03*V06*V10 - 2.62729852629577297e-12*V012*V032*V06*V10 - 
      2.95624686713097178e-12*V012*V02*V04*V06*V10 + 4.72590746432026113e-12*V032*V04*V06*V10 + 
      2.14201337362565441e-12*V02*V042*V06*V10 - 4.96245870499580144e-13*V013*V05*V06*V10 + 
      4.85069460597035732e-12*V02*V03*V05*V06*V10 + 2.9325541617036918e-12*V01*V04*V05*V06*V10 + 
      3.89564517275730112e-13*V022*V062*V10 + 1.04152552318936155e-12*V01*V03*V062*V10 - 
      4.2219813203799354e-14*V063*V10 + 3.24112760123541267e-15*V015*V07*V10 - 
      5.46986773910763243e-13*V01*V023*V07*V10 - 1.88832752442836149e-12*V012*V02*V03*V07*V10 + 
      1.04173289093730835e-12*V033*V07*V10 - 3.41815709982325177e-13*V013*V04*V07*V10 + 
      3.29695130024991376e-12*V02*V03*V04*V07*V10 + 1.00374321946414321e-12*V01*V042*V07*V10 + 
      8.31123409903402573e-13*V022*V05*V07*V10 + 1.92042056717612708e-12*V01*V03*V05*V07*V10 + 
      7.38564049504890531e-13*V01*V02*V06*V07*V10 - 2.43578077689676484e-13*V05*V06*V07*V10 + 
      7.02971223516309167e-14*V012*V072*V10 - 8.41434086655142606e-14*V04*V072*V10 - 
      2.74939871057277513e-13*V012*V022*V08*V10 - 1.74712661343157951e-13*V013*V03*V08*V10 + 
      9.2857682570958759e-13*V02*V032*V08*V10 + 4.11519080314520632e-13*V022*V04*V08*V10 + 
      1.1111224769011676e-12*V01*V03*V04*V08*V10 + 5.75475872999506705e-13*V01*V02*V05*V08*V10 - 
      9.52835175922104226e-14*V052*V08*V10 + 1.19036726068356502e-13*V012*V06*V08*V10 - 
      1.36804953890871821e-13*V04*V06*V08*V10 - 9.51101591829798765e-14*V03*V07*V08*V10 - 
      1.37973183983452954e-14*V02*V082*V10 - 4.87996782533456262e-14*V013*V02*V09*V10 + 
      2.44779357487306318e-13*V022*V03*V09*V10 + 2.77906476698692051e-13*V01*V032*V09*V10 + 
      3.00792426399261113e-13*V01*V02*V04*V09*V10 + 8.36504743073629782e-14*V012*V05*V09*V10 - 
      1.02108433340623443e-13*V04*V05*V09*V10 - 7.37542972270286555e-14*V03*V06*V09*V10 - 
      2.6357953774389911e-14*V02*V07*V09*V10 - 9.08270584263137615e-15*V01*V08*V09*V10 - 
      1.27505639986404442e-15*V014*V102 + 8.17325681260883336e-15*V023*V102 + 
      6.84800323368365143e-14*V01*V02*V03*V102 + 1.99486489056840919e-14*V012*V04*V102 - 
      1.17110801694087962e-14*V042*V102 - 2.36218669323730536e-14*V03*V05*V102 - 
      8.74864195251315859e-15*V02*V06*V102 - 3.7189867181172887e-15*V01*V07*V102 + 
      2.81163663872025041e-17*V103 + 2.06315947180144333e-14*V01*V025*V11 + 
      2.93901773689154254e-13*V012*V023*V03*V11 + 2.65426279516479862e-13*V013*V02*V032*V11 - 
      1.64240953577656259e-12*V022*V033*V11 - 8.60545858849959743e-13*V01*V034*V11 + 
      1.58167476557047921e-13*V013*V022*V04*V11 + 6.40253331768262557e-14*V014*V03*V04*V11 - 
      1.45640872459933003e-12*V023*V03*V04*V11 - 5.7731525482397614e-12*V01*V02*V032*V04*V11 - 
      1.37701542410388919e-12*V01*V022*V042*V11 - 1.63533875325576729e-12*V012*V03*V042*V11 + 
      9.31612681010708492e-13*V03*V043*V11 + 3.33354638713254145e-14*V014*V02*V05*V11 - 
      1.73110467387712033e-13*V024*V05*V11 - 2.95286324651478518e-12*V01*V022*V03*V05*V11 - 
      1.48142789538492827e-12*V012*V032*V05*V11 - 1.69792602697663613e-12*V012*V02*V04*V05*V11 + 
      2.79824583367979196e-12*V032*V04*V05*V11 + 1.40561027403534417e-12*V02*V042*V05*V11 - 
      1.38686871481520062e-13*V013*V052*V11 + 1.45031184215905664e-12*V02*V03*V052*V11 + 
      8.64596215745334728e-13*V01*V04*V052*V11 + 1.97217669766211915e-15*V015*V06*V11 - 
      3.25934634134331048e-13*V01*V023*V06*V11 - 1.17255533795928272e-12*V012*V02*V03*V06*V11 + 
      6.60775885683684359e-13*V033*V06*V11 - 2.13507992052350161e-13*V013*V04*V06*V11 + 
      2.0513385979446487e-12*V02*V03*V04*V06*V11 + 6.28611997433052961e-13*V01*V042*V06*V11 + 
      5.13614312623875598e-13*V022*V05*V06*V11 + 1.21864390066318021e-12*V01*V03*V05*V06*V11 + 
      2.30865959006174119e-13*V01*V02*V062*V11 - 7.75336031803536438e-14*V05*V062*V11 - 
      2.06407752472392703e-13*V012*V022*V07*V11 - 1.289068713108202e-13*V013*V03*V07*V11 + 
      7.09362625243609346e-13*V02*V032*V07*V11 + 3.43593348975628685e-13*V022*V04*V07*V11 + 
      8.41422620982796247e-13*V01*V03*V04*V07*V11 + 4.38658193799442732e-13*V01*V02*V05*V07*V11 - 
      7.24864849143380341e-14*V052*V07*V11 + 8.93086625296611971e-14*V012*V06*V07*V11 - 
      1.06819036914544325e-13*V04*V06*V07*V11 - 3.61455599620500694e-14*V03*V072*V11 - 
      3.97235073820984772e-14*V013*V02*V08*V11 + 1.99099101351709333e-13*V022*V03*V08*V11 + 
      2.28133602768134236e-13*V01*V032*V08*V11 + 2.45293270994943009e-13*V01*V02*V04*V08*V11 + 
      6.86878948426054709e-14*V012*V05*V08*V11 - 8.38908634448676941e-14*V04*V05*V08*V11 - 
      6.06582693352870143e-14*V03*V06*V08*V11 - 2.1617397129188001e-14*V02*V07*V08*V11 - 
      3.7373375435039043e-15*V01*V082*V11 - 2.33041083494439981e-15*V014*V09*V11 + 
      1.6591934359476477e-14*V023*V09*V11 + 1.27222397526953658e-13*V01*V02*V03*V09*V11 + 
      3.67735683258596418e-14*V012*V04*V09*V11 - 2.2251910804660274e-14*V042*V09*V11 - 
      4.37755615991400669e-14*V03*V05*V09*V11 - 1.66488466392502867e-14*V02*V06*V09*V11 - 
      6.8834176462998274e-15*V01*V07*V09*V11 + 1.49122781406584791e-14*V01*V022*V10*V11 + 
      1.59807162473166057e-14*V012*V03*V10*V11 - 2.08550325888617344e-14*V03*V04*V10*V11 - 
      1.0790478270642594e-14*V02*V05*V10*V11 - 4.75030218089155165e-15*V01*V06*V10*V11 + 1.572129357798619e-16*V09*V10*V11 + 
      1.84873127504908963e-15*V012*V02*V112 - 2.2197628311036752e-15*V032*V112 - 
      2.32752088496273191e-15*V02*V04*V112 - 1.40023635994507536e-15*V01*V05*V112 + 
      6.47905459621435216e-17*V08*V112 + 1.35222152503943329e-14*V012*V024*V12 + 
      5.14035473101475392e-14*V013*V022*V03*V12 + 9.9767371770286226e-15*V014*V032*V12 - 
      2.97274956574801655e-13*V023*V032*V12 - 6.98140517373392828e-13*V01*V02*V033*V12 + 
      1.24975279593577671e-14*V014*V02*V04*V12 - 4.45053548678169788e-14*V024*V04*V12 - 
      1.09159740725652908e-12*V01*V022*V03*V04*V12 - 5.79751685170443441e-13*V012*V032*V04*V12 - 
      3.24237391103006069e-13*V012*V02*V042*V12 + 5.50219494086006972e-13*V032*V042*V12 + 
      1.63064659211535092e-13*V02*V043*V12 + 9.42603056702609285e-16*V015*V05*V12 - 
      1.80143381943543884e-13*V01*V023*V05*V12 - 6.07407415218738782e-13*V012*V02*V03*V05*V12 + 
      3.52604154995320684e-13*V033*V05*V12 - 1.09297239850715196e-13*V013*V04*V05*V12 + 
      1.12535173471944433e-12*V02*V03*V04*V05*V12 + 3.40891562320442255e-13*V01*V042*V05*V12 + 
      1.42199479116374707e-13*V022*V052*V12 + 3.23970785350965992e-13*V01*V03*V052*V12 - 
      1.15699527614723754e-13*V012*V022*V06*V12 - 7.3760794396937325e-14*V013*V03*V06*V12 + 
      4.04716693965560024e-13*V02*V032*V06*V12 + 1.77440044435642267e-13*V022*V04*V06*V12 + 
      4.84668883857915821e-13*V01*V03*V04*V06*V12 + 2.50589707940243076e-13*V01*V02*V05*V06*V12 - 
      4.2279433037884392e-14*V052*V06*V12 + 2.59493182117973732e-14*V012*V062*V12 - 
      3.02337933754670152e-14*V04*V062*V12 - 2.68398249756196224e-14*V013*V02*V07*V12 + 
      1.39493270074008252e-13*V022*V03*V07*V12 + 1.5697748836449023e-13*V01*V032*V07*V12 + 
      1.70862080061330378e-13*V01*V02*V04*V07*V12 + 4.71697182812359318e-14*V012*V05*V07*V12 - 
      5.84734114742470686e-14*V04*V05*V07*V12 - 4.21832772025097777e-14*V03*V06*V07*V12 - 
      7.55327314660873196e-15*V02*V072*V12 - 1.73983031673890977e-15*V014*V08*V12 + 
      1.12597124340662818e-14*V023*V08*V12 + 9.48025872838216582e-14*V01*V02*V03*V08*V12 + 
      2.76253676674113186e-14*V012*V04*V08*V12 - 1.63020123948615713e-14*V042*V08*V12 - 
      3.29370368524766492e-14*V03*V05*V08*V12 - 1.21731184953380937e-14*V02*V06*V08*V12 - 
      5.18335699681192263e-15*V01*V07*V08*V12 + 1.26586753509513071e-14*V01*V022*V09*V12 + 
      1.34798372259755746e-14*V012*V03*V09*V12 - 1.76789338395929214e-14*V03*V04*V09*V12 - 
      9.15699663582341643e-15*V02*V05*V09*V12 - 4.02254894740345604e-15*V01*V06*V09*V12 + 
      6.66263144109280637e-17*V092*V12 + 3.38329764357856179e-15*V012*V02*V10*V12 - 
      4.06032494015028077e-15*V032*V10*V12 - 4.14865610241330084e-15*V02*V04*V10*V12 - 
      2.5623892659868136e-15*V01*V05*V10*V12 + 1.17850923556614601e-16*V08*V10*V12 + 
      2.47618001763618212e-16*V013*V11*V12 - 1.86431969779710639e-15*V02*V03*V11*V12 - 
      1.13495028755403613e-15*V01*V04*V11*V12 + 9.02297905800475673e-17*V07*V11*V12 - 
      9.08108567209181868e-17*V022*V122 - 2.17507724119292815e-16*V01*V03*V122 + 
      2.63036856389727386e-17*V06*V122 + 3.01016877274992854e-15*V013*V023*V13 + 
      3.57050782274795942e-15*V014*V02*V03*V13 - 2.31121154441548564e-14*V024*V03*V13 - 
      1.91290431388730924e-13*V01*V022*V032*V13 - 6.25664904052573772e-14*V012*V033*V13 + 
      3.24250447640764866e-16*V015*V04*V13 - 5.89368241998019043e-14*V01*V023*V04*V13 - 
      2.17590547270108976e-13*V012*V02*V03*V04*V13 + 1.31246088615135607e-13*V033*V04*V13 - 
      1.98483751367527314e-14*V013*V042*V13 + 2.00349216992898741e-13*V02*V03*V042*V13 + 
      4.11007208258047326e-14*V01*V043*V13 - 5.61666377971959766e-14*V012*V022*V05*V13 - 
      3.47857600659586659e-14*V013*V03*V05*V13 + 2.04457987682175266e-13*V02*V032*V05*V13 + 
      9.97214632083164805e-14*V022*V04*V05*V13 + 2.41625619320238558e-13*V01*V03*V04*V05*V13 + 
      6.30161817706866753e-14*V01*V02*V052*V13 - 7.13875357778470582e-15*V053*V13 - 
      1.41561285119988056e-14*V013*V02*V06*V13 + 7.30821787199887783e-14*V022*V03*V06*V13 + 
      8.47845729002821492e-14*V01*V032*V06*V13 + 9.0292259824386639e-14*V01*V02*V04*V06*V13 + 
      2.55065504681134991e-14*V012*V05*V06*V13 - 3.16406050579614405e-14*V04*V05*V06*V13 - 
      1.14533959836346866e-14*V03*V062*V13 - 1.08098246385420377e-15*V014*V07*V13 + 
      8.02243919332404111e-15*V023*V07*V13 + 6.1178957416679346e-14*V01*V02*V03*V07*V13 + 
      1.76532891776252959e-14*V012*V04*V07*V13 - 1.08644978129260194e-14*V042*V07*V13 - 
      2.13297014125215577e-14*V03*V05*V07*V13 - 8.12633935943986226e-15*V02*V06*V07*V13 - 
      1.6743537366414291e-15*V01*V072*V13 + 8.72726622835706138e-15*V01*V022*V08*V13 + 
      9.42362603564253456e-15*V012*V03*V08*V13 - 1.23801977792277578e-14*V03*V04*V08*V13 - 
      6.39538388820295596e-15*V02*V05*V08*V13 - 2.82134560940722691e-15*V01*V06*V08*V13 + 
      2.65554750082792534e-15*V012*V02*V09*V13 - 3.20556049679519723e-15*V032*V09*V13 - 
      3.36431678260605531e-15*V02*V04*V09*V13 - 2.02144613089466401e-15*V01*V05*V09*V13 + 9.37266190278147209e-17*V08*V09*V13 + 
      2.10899091038029656e-16*V013*V10*V13 - 1.58749685578917256e-15*V02*V03*V10*V13 - 
      9.67297198240582393e-16*V01*V04*V10*V13 + 7.69986828341727686e-17*V07*V10*V13 - 
      1.73690676922869153e-16*V022*V11*V13 - 4.05227533434671577e-16*V01*V03*V11*V13 + 
      4.93644173802195677e-17*V06*V11*V13 - 8.5970312634630041e-17*V01*V02*V12*V13 + 2.69584630787616477e-17*V05*V12*V13 - 
      4.46872336704121194e-18*V012*V132 + 5.12316083005274106e-18*V04*V132 + 
      2.92846727451350511e-16*V014*V022*V14 - 4.70770138474114252e-16*V025*V14 + 
      8.33947703877661622e-17*V015*V03*V14 - 2.0502609945426675e-14*V01*V023*V03*V14 - 
      3.3190137336922047e-14*V012*V02*V032*V14 + 1.06589499847804039e-14*V034*V14 - 
      1.8383399916152844e-14*V012*V022*V04*V14 - 1.17869168342934737e-14*V013*V03*V04*V14 + 
      6.89457053312643412e-14*V02*V032*V04*V14 + 1.47697307625069425e-14*V022*V042*V14 + 
      4.13709145399218087e-14*V01*V03*V042*V14 - 6.22541457308918185e-15*V013*V02*V05*V14 + 
      3.49707665575084018e-14*V022*V03*V05*V14 + 3.88763432784733219e-14*V01*V032*V05*V14 + 
      4.26173189893410792e-14*V01*V02*V04*V05*V14 + 5.81805744875020088e-15*V012*V052*V14 - 
      7.5006919800349865e-15*V04*V052*V14 - 5.33006656276608727e-16*V014*V06*V14 + 
      3.54945839889880179e-15*V023*V06*V14 + 3.03477104588579643e-14*V01*V02*V03*V06*V14 + 
      8.85263850220524772e-15*V012*V04*V06*V14 - 5.31477661362616769e-15*V042*V06*V14 - 
      1.07994354188325529e-14*V03*V05*V06*V14 - 1.98149221660648068e-15*V02*V062*V14 + 
      5.28739978783132576e-15*V01*V022*V07*V14 + 5.58915585185767514e-15*V012*V03*V07*V14 - 
      7.47542721720777458e-15*V03*V04*V07*V14 - 3.87575668295651998e-15*V02*V05*V07*V14 - 
      1.69703163828655927e-15*V01*V06*V07*V14 + 1.7222163057574822e-15*V012*V02*V08*V14 - 
      2.09257068661927608e-15*V032*V08*V14 - 2.13005184828001923e-15*V02*V04*V08*V14 - 
      1.3200281134732167e-15*V01*V05*V08*V14 + 3.04616258762209545e-17*V082*V14 + 
      1.53555316890428859e-16*V013*V09*V14 - 1.16841147730262097e-15*V02*V03*V09*V14 - 
      7.10476792438142021e-16*V01*V04*V09*V14 + 5.6598711316278649e-17*V07*V09*V14 - 
      1.34040402813243432e-16*V022*V10*V14 - 3.21570984886861432e-16*V01*V03*V10*V14 + 
      3.89287881351678484e-17*V06*V10*V14 - 7.45665166472236098e-17*V01*V02*V11*V14 + 2.33791285531186939e-17*V05*V11*V14 - 
      8.32597014360989977e-18*V012*V12*V14 + 9.46800666744931921e-18*V04*V12*V14 + 
      3.51566762930281634e-18*V03*V13*V14 + 3.21588689522293773e-19*V02*V142 + 
      1.27330491591735542e-17*V015*V02*V15 - 6.99708974650006043e-16*V01*V024*V15 - 
      5.35153413841426615e-15*V012*V022*V03*V15 - 1.6160048816292807e-15*V013*V032*V15 + 
      7.19701627649591415e-15*V02*V033*V15 - 1.95562657686026894e-15*V013*V02*V04*V15 + 
      1.06908424806482057e-14*V022*V03*V04*V15 + 1.26403169127219994e-14*V01*V032*V04*V15 + 
      6.63187601814328303e-15*V01*V02*V042*V15 - 2.15890858975233796e-16*V014*V05*V15 + 
      1.75501206330477099e-15*V023*V05*V15 + 1.32124780665074032e-14*V01*V02*V03*V05*V15 + 
      3.79591448043184786e-15*V012*V04*V05*V15 - 2.43575119505684081e-15*V042*V05*V15 - 
      2.37983897101426178e-15*V03*V052*V15 + 2.41378853651057285e-15*V01*V022*V06*V15 + 
      2.63486830691019968e-15*V012*V03*V06*V15 - 3.53351121929619304e-15*V03*V04*V06*V15 - 
      1.82035006301599511e-15*V02*V05*V06*V15 - 4.02694229974753154e-16*V01*V062*V15 + 
      9.60055044280869663e-16*V012*V02*V07*V15 - 1.18128035839437005e-15*V032*V07*V15 - 
      1.24352323400166597e-15*V02*V04*V07*V15 - 7.44022457253361189e-16*V01*V05*V07*V15 + 
      9.37001124309374795e-17*V013*V08*V15 - 7.12330243026821422e-16*V02*V03*V08*V15 - 
      4.34497116726936266e-16*V01*V04*V08*V15 + 3.47776557433019525e-17*V07*V08*V15 - 
      9.50657752706512669e-17*V022*V09*V15 - 2.2129309166550233e-16*V01*V03*V09*V15 + 
      2.70503314390339342e-17*V06*V09*V15 - 5.5417294723040643e-17*V01*V02*V10*V15 + 1.74283471457144486e-17*V05*V10*V15 - 
      6.76134539848172088e-18*V012*V11*V15 + 7.76227322380347164e-18*V04*V11*V15 + 
      3.07103291992024162e-18*V03*V12*V15 + 6.08128663771453229e-19*V02*V13*V15 + 1.27720477892161055e-19*V01*V14*V15 + 
      2.01048144618529803e-19*V016*V16 - 2.61727825466812406e-16*V012*V023*V16 - 
      5.0679322748129577e-16*V013*V02*V03*V16 + 1.6373486649527708e-15*V022*V032*V16 + 
      1.18510445058111235e-15*V01*V033*V16 - 6.43052490562367574e-17*V014*V04*V16 + 
      4.49178631488881075e-16*V023*V04*V16 + 3.95136432562536951e-15*V01*V02*V03*V04*V16 + 
      5.77612609040266758e-16*V012*V042*V16 - 2.38955008786771412e-16*V043*V16 + 
      1.0098302112628906e-15*V01*V022*V05*V16 + 1.05480871088033097e-15*V012*V03*V05*V16 - 
      1.47373129213744841e-15*V03*V04*V05*V16 - 3.82525742785820367e-16*V02*V052*V16 + 
      4.2231109173306557e-16*V012*V02*V06*V16 - 5.28288327273463918e-16*V032*V06*V16 - 
      5.32920521544244382e-16*V02*V04*V06*V16 - 3.32915283003657404e-16*V01*V05*V06*V16 + 
      4.87018720905525657e-17*V013*V07*V16 - 3.80503487118661217e-16*V02*V03*V07*V16 - 
      2.30904634560482043e-16*V01*V04*V07*V16 + 9.26760003871316095e-18*V072*V16 - 
      5.28960458897738949e-17*V022*V08*V16 - 1.27604975875922037e-16*V01*V03*V08*V16 + 
      1.55126054093417784e-17*V06*V08*V16 - 3.59599069497925566e-17*V01*V02*V09*V16 + 1.13065752311239477e-17*V05*V09*V16 - 
      4.74097822096121075e-18*V012*V10*V16 + 5.40038752900604558e-18*V04*V10*V16 + 
      2.35049680990961217e-18*V03*V11*V16 + 4.95736791648512396e-19*V02*V12*V16 + 1.12718236863376938e-19*V01*V13*V16 - 
      3.26031222048915011e-22*V162 - 3.69023869447311453e-17*V013*V022*V17 - 
      1.51992397331608531e-17*V014*V03*V17 + 1.46506296085330399e-16*V023*V03*V17 + 
      5.36680031441462341e-16*V01*V02*V032*V17 + 2.74921681760312217e-16*V01*V022*V04*V17 + 
      3.05161819856544877e-16*V012*V03*V04*V17 - 2.12872328583188704e-16*V03*V042*V17 + 
      1.60668334822885038e-16*V012*V02*V05*V17 - 2.06083262088267604e-16*V032*V05*V17 - 
      2.18250210759552323e-16*V02*V04*V05*V17 - 6.4705876540403041e-17*V01*V052*V17 + 
      2.04039214455789049e-17*V013*V06*V17 - 1.58827713982905707e-16*V02*V03*V06*V17 - 
      9.7039007262936178e-17*V01*V04*V06*V17 - 2.75370191339749868e-17*V022*V07*V17 - 
      6.37627793687281453e-17*V01*V03*V07*V17 + 7.8732289555061698e-18*V06*V07*V17 - 1.94773802685722829e-17*V01*V02*V08*V17 + 
      6.17443945860402596e-18*V05*V08*V17 - 2.89034017754101399e-18*V012*V09*V17 + 3.3362506205073375e-18*V04*V09*V17 + 
      1.55707473634662261e-18*V03*V10*V17 + 3.61302157530117044e-19*V02*V11*V17 + 8.74854604248952092e-20*V01*V12*V17 - 
      6.17358692499256085e-22*V15*V17 - 2.13111033295641591e-18*V014*V02*V18 + 
      3.99136413774620139e-18*V024*V18 + 7.377796747017982e-17*V01*V022*V03*V18 + 
      3.7554344059730559e-17*V012*V032*V18 + 4.33548356718394131e-17*V012*V02*V04*V18 - 
      5.71766260060981307e-17*V032*V04*V18 - 2.8345954275539663e-17*V02*V042*V18 + 
      7.21668431652295037e-18*V013*V05*V18 - 5.95092644299437411e-17*V02*V03*V05*V18 - 
      3.59656004243909051e-17*V01*V04*V05*V18 - 1.04709102033242943e-17*V022*V06*V18 - 
      2.55507152923717685e-17*V01*V03*V06*V18 + 1.56976458808754471e-18*V062*V18 - 
      9.28057085149596195e-18*V01*V02*V07*V18 + 2.94430175062978124e-18*V05*V07*V18 - 
      1.49382516615594163e-18*V012*V08*V18 + 1.71039390998886452e-18*V04*V08*V18 + 
      9.03796874560947413e-19*V03*V09*V18 + 2.24712696058570686e-19*V02*V10*V18 + 5.99078403943434323e-20*V01*V11*V18 - 
      5.18439166561294642e-22*V14*V18 - 4.22201103698912586e-20*V015*V19 + 
      3.00687977402852096e-18*V01*V023*V19 + 1.02919896032635715e-17*V012*V02*V03*V19 - 
      4.75991249444578704e-18*V033*V19 + 1.8844540444197937e-18*V013*V04*V19 - 
      1.53044289465233611e-17*V02*V03*V04*V19 - 4.68949178400584818e-18*V01*V042*V19 - 
      3.88567004050345989e-18*V022*V05*V19 - 8.90287583752866863e-18*V01*V03*V05*V19 - 
      3.49002185727777755e-18*V01*V02*V06*V19 + 1.12651484231771703e-18*V05*V06*V19 - 
      6.68535740269443239e-19*V012*V07*V19 + 7.82576429172633082e-19*V04*V07*V19 + 
      4.44484183810913417e-19*V03*V08*V19 + 1.25127848439584547e-19*V02*V09*V19 + 3.5730969424710774e-20*V01*V10*V19 - 
      3.89899709438361545e-22*V13*V19 + 6.51731068805067444e-19*V012*V022*V20 + 
      4.08890971902408067e-19*V013*V03*V20 - 1.87161113589314478e-18*V02*V032*V20 - 
      8.99504603266313537e-19*V022*V04*V20 - 2.24156689185734437e-18*V01*V03*V04*V20 - 
      1.1740989955387523e-18*V01*V02*V05*V20 + 1.90449823435447421e-19*V052*V20 - 
      2.42972583815146889e-19*V012*V06*V20 + 2.81690201103204802e-19*V04*V06*V20 + 
      1.91659488557217884e-19*V03*V07*V20 + 5.79118371618265687e-20*V02*V08*V20 + 1.87550208967303183e-20*V01*V09*V20 - 
      2.58913773418535731e-22*V12*V20 + 5.14720481361328616e-20*V013*V02*V21 - 
      2.23296563241738812e-19*V022*V03*V21 - 2.50146781075875307e-19*V01*V032*V21 - 
      2.75532558869195522e-19*V01*V02*V04*V21 - 7.62472383247626929e-20*V012*V05*V21 + 
      9.21907900065666794e-20*V04*V05*V21 + 6.6756466390755203e-20*V03*V06*V21 + 2.4164870521491053e-20*V02*V07*V21 + 
      8.39369822504337072e-21*V01*V08*V21 - 1.53578688076393192e-22*V11*V21 + 1.30308982623121169e-21*V014*V22 - 
      7.78015237038794673e-21*V023*V22 - 6.04314433062458418e-20*V01*V02*V03*V22 - 
      1.76097932929253869e-20*V012*V04*V22 + 1.04692705255742426e-20*V042*V22 + 
      2.05652806026182752e-20*V03*V05*V22 + 7.90193548685542108e-21*V02*V06*V22 + 3.29861972843236093e-21*V01*V07*V22 - 
      7.95692249424796776e-23*V10*V22 - 3.34265007494275301e-21*V01*V022*V23 - 
      3.52935139314932834e-21*V012*V03*V23 + 4.57327265598230726e-21*V03*V04*V23 + 
      2.38358472303665073e-21*V02*V05*V23 + 1.05501790793389417e-21*V01*V06*V23 - 3.67025307723762352e-23*V09*V23 - 
      3.96918165461231145e-22*V012*V02*V24 + 4.6642247696771028e-22*V032*V24 + 
      4.92876974666260543e-22*V02*V04*V24 + 2.97415242746788187e-22*V01*V05*V24 - 1.44570417421603664e-23*V08*V24 - 
      1.34802395817021898e-23*V013*V25 + 1.00260863671588381e-22*V02*V03*V25 + 6.12658942944886584e-23*V01*V04*V25 - 
      5.06437408575491579e-24*V07*V25 + 4.90082289247214406e-24*V022*V26 + 1.14022948166886495e-23*V01*V03*V26 - 
      1.44276452355017828e-24*V06*V26 + 1.14923701502991019e-24*V01*V02*V27 - 3.68929239960052252e-25*V05*V27 + 
      5.82383622481373409e-26*V012*V28 - 6.83761512320723595e-26*V04*V28 - 1.18633700875835324e-26*V03*V29 - 
      1.07848818978032113e-27*V02*V30 - 1.07848818978032113e-28*V01*V31 + 7.00317006350857876e-32*V34) + 
   delta8*eps13*(2.22394334678818364e-10*V036*V04 + 
      1.82648525629828962e-9*V02*V034*V042 + 1.7220270094518011e-9*V022*V032*V043 + 
      1.39735262799609656e-9*V01*V033*V043 + 6.34254881618462429e-11*V023*V044 + 
      1.06851666092327546e-9*V01*V02*V03*V044 + 6.46807814813955819e-11*V012*V045 - 
      1.4977795563804726e-11*V046 + 6.90819740395243151e-10*V02*V035*V05 + 
      3.68336895930336777e-9*V022*V033*V04*V05 + 1.91731873043757959e-9*V01*V034*V04*V05 + 
      1.63790189523977149e-9*V023*V03*V042*V05 + 6.43098160557939878e-9*V01*V02*V032*V042*V05 + 
      1.03321620567108066e-9*V01*V022*V043*V05 + 1.20658147736265803e-9*V012*V03*V043*V05 - 
      5.29362876984010124e-10*V03*V044*V05 + 9.19460711255528151e-10*V023*V032*V052 + 
      1.99406771055546795e-9*V01*V02*V033*V052 + 1.92004825174254079e-10*V024*V04*V052 + 
      3.26014587036853121e-9*V01*V022*V03*V04*V052 + 
      1.62334299945146428e-9*V012*V032*V04*V052 + 
      9.3144890706734036e-10*V012*V02*V042*V052 - 
      1.55582653740533089e-9*V032*V042*V052 - 5.3211696073585261e-10*V02*V043*V052 + 
      1.81848082667138365e-10*V01*V023*V053 + 5.65532762472038467e-10*V012*V02*V03*V053 - 
      3.20036945007794919e-10*V033*V053 + 9.96741619101295313e-11*V013*V04*V053 - 
      1.07479274489196619e-9*V02*V03*V04*V053 - 3.19874219222528719e-10*V01*V042*V053 - 
      6.891368797624056e-11*V022*V054 - 1.46518976839734828e-10*V01*V03*V054 + 
      6.44920172298290917e-10*V022*V034*V06 + 2.6037499643597725e-10*V01*V035*V06 + 
      1.20618573979559187e-9*V023*V032*V04*V06 + 2.96548111572616059e-9*V01*V02*V033*V04*V06 + 
      6.52266535133277669e-11*V024*V042*V06 + 2.25424693671119517e-9*V01*V022*V03*V042*V06 + 
      1.23547245275571412e-9*V012*V032*V042*V06 + 
      4.56391236024895398e-10*V012*V02*V043*V06 - 7.64957967671492083e-10*V032*V043*V06 - 
      1.62266819248071573e-10*V02*V044*V06 + 2.85544376160375666e-10*V024*V03*V05*V06 + 
      2.26887620026776487e-9*V01*V022*V032*V05*V06 + 7.2979231234954459e-10*V012*V033*V05*V06 + 
      7.23711443877355124e-10*V01*V023*V04*V05*V06 + 2.55713651285726604e-9*V012*V02*V03*V04*V05*V06 - 
      1.46803818415804021e-9*V033*V04*V05*V06 + 2.31114550936411707e-10*V013*V042*V05*V06 - 
      2.3262351937615409e-9*V02*V03*V042*V05*V06 - 4.74446394727675954e-10*V01*V043*V05*V06 + 
      3.28272045740831862e-10*V012*V022*V052*V06 + 
      2.00041168473962955e-10*V013*V03*V052*V06 - 1.14733022131657352e-9*V02*V032*V052*V06 - 
      5.81930693859052832e-10*V022*V04*V052*V06 - 1.35087057322363099e-9*V01*V03*V04*V052*V06 - 
      2.35563579114648483e-10*V01*V02*V053*V06 + 1.68793539973876763e-11*V054*V06 + 
      4.45703434141323001e-12*V025*V062 + 2.63500583957490092e-10*V01*V023*V03*V062 + 
      4.3610847312994859e-10*V012*V02*V032*V062 - 1.29250992305242281e-10*V034*V062 + 
      2.40896279555929337e-10*V012*V022*V04*V062 + 
      1.55348884105790566e-10*V013*V03*V04*V062 - 8.4139210868749396e-10*V02*V032*V04*V062 - 
      1.75247152835987788e-10*V022*V042*V062 - 
      5.08465807395616202e-10*V01*V03*V042*V062 + 8.13934800011179179e-11*V013*V02*V05*V062 - 
      4.24582193484970666e-10*V022*V03*V05*V062 - 4.73102469675116297e-10*V01*V032*V05*V062 - 
      5.21340121554002184e-10*V01*V02*V04*V05*V062 - 7.10874045538428092e-11*V012*V052*V062 + 
      7.66563704484005527e-11*V04*V052*V062 + 2.31787782681454692e-12*V014*V063 - 
      1.39753773973602216e-11*V023*V063 - 1.24279181163507518e-10*V01*V02*V03*V063 - 
      3.65468250772209106e-11*V012*V04*V063 + 1.82557853709429989e-11*V042*V063 + 
      3.68920954862445296e-11*V03*V05*V063 + 3.4166521842974886e-12*V02*V064 + 
      2.88647750265298992e-10*V023*V033*V07 + 4.62726600407034665e-10*V01*V02*V034*V07 + 
      1.82861738261194361e-10*V024*V03*V04*V07 + 1.5263141320781102e-9*V01*V022*V032*V04*V07 + 
      4.99176108470081125e-10*V012*V033*V04*V07 + 2.3398598503425307e-10*V01*V023*V042*V07 + 
      8.66470580479213125e-10*V012*V02*V03*V042*V07 - 5.06821883792135369e-10*V033*V042*V07 + 
      5.25957000807143e-11*V013*V043*V07 - 5.23145797792697609e-10*V02*V03*V043*V07 - 
      8.06841374466300775e-11*V01*V044*V07 + 1.69221344745024552e-11*V025*V05*V07 + 
      5.12117626261100089e-10*V01*V023*V03*V05*V07 + 7.83315845084951599e-10*V012*V02*V032*V05*V07 - 
      2.33718021328816286e-10*V034*V05*V07 + 4.43297780179461828e-10*V012*V022*V04*V05*V07 + 
      2.74209548841787964e-10*V013*V03*V04*V05*V07 - 1.5772028967732526e-9*V02*V032*V04*V05*V07 - 
      3.89564131002165914e-10*V022*V042*V05*V07 - 9.33788954771181867e-10*V01*V03*V042*V05*V07 + 
      7.20828918694013699e-11*V013*V02*V052*V07 - 4.05010498658610053e-10*V022*V03*V052*V07 - 
      4.25954917272141195e-10*V01*V032*V052*V07 - 4.86327168608720654e-10*V01*V02*V04*V052*V07 - 
      4.2423639573872798e-11*V012*V053*V07 + 4.71801655931172137e-11*V04*V053*V07 + 
      4.07920537371965238e-11*V01*V024*V06*V07 + 3.05091983561828093e-10*V012*V022*V03*V06*V07 + 
      9.15114215693501587e-11*V013*V032*V06*V07 - 3.7324817476241997e-10*V02*V033*V06*V07 + 
      1.1112112048879567e-10*V013*V02*V04*V06*V07 - 5.71593334556057121e-10*V022*V03*V04*V06*V07 - 
      6.55642061708179882e-10*V01*V032*V04*V06*V07 - 3.53887995384687268e-10*V01*V02*V042*V06*V07 + 
      1.21243326376949775e-11*V014*V05*V06*V07 - 9.41450343061347587e-11*V023*V05*V06*V07 - 
      6.86732908025763391e-10*V01*V02*V03*V05*V06*V07 - 1.97362985679369452e-10*V012*V04*V05*V06*V07 + 
      1.06170808686289498e-10*V042*V05*V06*V07 + 1.01407379288148979e-10*V03*V052*V06*V07 - 
      6.44757982482091298e-11*V01*V022*V062*V07 - 6.84992871582634481e-11*V012*V03*V062*V07 + 
      7.69179114418788399e-11*V03*V04*V062*V07 + 3.99473669914208789e-11*V02*V05*V062*V07 + 
      5.8844960723756594e-12*V01*V063*V07 + 1.74791477465401664e-11*V012*V023*V072 + 
      3.30029238866568609e-11*V013*V02*V03*V072 - 
      9.89583351530689044e-11*V022*V032*V072 - 6.86311995035295413e-11*V01*V033*V072 + 
      4.16365758848501254e-12*V014*V04*V072 - 3.1262588277227323e-11*V023*V04*V072 - 
      2.36360092933860755e-10*V01*V02*V03*V04*V072 - 3.41741448959486168e-11*V012*V042*V072 + 
      1.22088517660940894e-11*V043*V072 - 6.10415828939006264e-11*V01*V022*V05*V072 - 
      6.12009132953483721e-11*V012*V03*V05*V072 + 7.08712507522932658e-11*V03*V04*V05*V072 + 
      1.86256058833176134e-11*V02*V052*V072 - 2.50610396748516358e-11*V012*V02*V06*V072 + 
      2.53356919803076403e-11*V032*V06*V072 + 2.74960153163471983e-11*V02*V04*V06*V072 + 
      1.60867447299989155e-11*V01*V05*V06*V072 - 9.45854522447970916e-13*V013*V073 + 
      6.21193025120276381e-12*V02*V03*V073 + 3.7511569097763079e-12*V01*V04*V073 - 
      6.25026546299077287e-14*V074 + 5.39226113664556203e-11*V024*V032*V08 + 
      2.69106277671397631e-10*V01*V022*V033*V08 + 6.31642538604680487e-11*V012*V034*V08 + 
      4.50177959481777704e-12*V025*V04*V08 + 2.70291336429073547e-10*V01*V023*V03*V04*V08 + 
      4.48755649113832851e-10*V012*V02*V032*V04*V08 - 1.38160338023542042e-10*V034*V04*V08 + 
      1.23739028878873142e-10*V012*V022*V042*V08 + 
      7.98880044771732184e-11*V013*V03*V042*V08 - 4.47020251341229655e-10*V02*V032*V042*V08 - 
      6.12718751274315607e-11*V022*V043*V08 - 1.803225829679844e-10*V01*V03*V043*V08 + 
      3.23535668198733722e-11*V01*V024*V05*V08 + 2.31594664517389349e-10*V012*V022*V03*V05*V08 + 
      6.86115460111102913e-11*V013*V032*V05*V08 - 2.88918711368720904e-10*V02*V033*V05*V08 + 
      8.3683567858207612e-11*V013*V02*V04*V05*V08 - 4.50123051159890254e-10*V022*V03*V04*V05*V08 - 
      5.05070891576142691e-10*V01*V032*V04*V05*V08 - 2.76737501842186717e-10*V01*V02*V042*V05*V08 + 
      4.52850882031609705e-12*V014*V052*V08 - 3.72744742517306646e-11*V023*V052*V08 - 
      2.65145469782902468e-10*V01*V02*V03*V052*V08 - 7.57999007301997039e-11*V012*V04*V052*V08 + 
      4.16236662994652254e-11*V042*V052*V08 + 2.62928807678054163e-11*V03*V053*V08 + 
      2.89219933710382047e-11*V012*V023*V06*V08 + 5.61260950027754743e-11*V013*V02*V03*V06*V08 - 
      1.63115084300603903e-10*V022*V032*V06*V08 - 1.17385904017989568e-10*V01*V033*V06*V08 + 
      7.1340725305036553e-12*V014*V04*V06*V08 - 4.39096782540823181e-11*V023*V04*V06*V08 - 
      3.96039717765899189e-10*V01*V02*V03*V04*V06*V08 - 5.83036822253703141e-11*V012*V042*V06*V08 + 
      1.97296069310796555e-11*V043*V06*V08 - 1.00891169429410779e-10*V01*V022*V05*V06*V08 - 
      1.05004014658216133e-10*V012*V03*V05*V06*V08 + 1.20270077510528931e-10*V03*V04*V05*V06*V08 + 
      3.1343961012456021e-11*V02*V052*V06*V08 - 2.13341183468833236e-11*V012*V02*V062*V08 + 
      2.16027798113523001e-11*V032*V062*V08 + 2.21157446926849458e-11*V02*V04*V062*V08 + 
      1.37401489670126787e-11*V01*V05*V062*V08 + 1.00186997020786814e-11*V013*V022*V07*V08 + 
      4.10043929534342726e-12*V014*V03*V07*V08 - 3.65521384810631864e-11*V023*V03*V07*V08 - 
      1.28364645564144024e-10*V01*V02*V032*V07*V08 - 6.82451433184789902e-11*V01*V022*V04*V07*V08 - 
      7.29570085811939161e-11*V012*V03*V04*V07*V08 + 4.17358161622513512e-11*V03*V042*V07*V08 - 
      3.85355775529045449e-11*V012*V02*V05*V07*V08 + 3.93805279286094362e-11*V032*V05*V07*V08 + 
      4.32493785157616068e-11*V02*V04*V05*V07*V08 + 1.2478866680119357e-11*V01*V052*V07*V08 - 
      4.89396794485662586e-12*V013*V06*V07*V08 + 3.13966531162347292e-11*V02*V03*V06*V07*V08 + 
      1.91505121022256463e-11*V01*V04*V06*V07*V08 + 2.77567733520418774e-12*V022*V072*V08 + 
      6.19098510947597622e-12*V01*V03*V072*V08 - 6.40979768120706772e-13*V06*V072*V08 + 
      6.37354633834677971e-13*V014*V02*V082 - 1.02407914453300515e-12*V024*V082 - 
      1.91398773385070101e-11*V01*V022*V03*V082 - 
      9.63797204817467837e-12*V012*V032*V082 - 
      1.13154755613692426e-11*V012*V02*V04*V082 + 1.17327100542204334e-11*V032*V04*V082 + 
      5.9580959806487732e-12*V02*V042*V082 - 1.86508438191211742e-12*V013*V05*V082 + 
      1.22850209663923981e-11*V02*V03*V05*V082 + 7.45482854217009245e-12*V01*V04*V05*V082 + 
      2.21480763485243461e-12*V022*V06*V082 + 5.30535718437220242e-12*V01*V03*V06*V082 - 
      2.7029136397153164e-13*V062*V082 + 1.94831692851992246e-12*V01*V02*V07*V082 - 
      5.01463869873301016e-13*V05*V07*V082 + 1.05253477803424944e-13*V012*V083 - 
      9.87373557257295633e-14*V04*V083 + 4.70059290958401534e-12*V025*V03*V09 + 
      6.92818238617716001e-11*V01*V023*V032*V09 + 6.9078096067410472e-11*V012*V02*V033*V09 - 
      1.35525998327247362e-11*V035*V09 + 1.52384781884328634e-11*V01*V024*V04*V09 + 
      1.18782225208223541e-10*V012*V022*V03*V04*V09 + 
      3.59303845505348074e-11*V013*V032*V04*V09 - 1.53386033607497987e-10*V02*V033*V04*V09 + 
      2.17392233968219124e-11*V013*V02*V042*V09 - 1.14770361070165767e-10*V022*V03*V042*V09 - 
      1.35173057374230096e-10*V01*V032*V042*V09 - 4.76874181366485816e-11*V01*V02*V043*V09 + 
      2.01489986109674244e-11*V012*V023*V05*V09 + 3.78044288689855158e-11*V013*V02*V03*V05*V09 - 
      1.18342777312323599e-10*V022*V032*V05*V09 - 8.17498318891662836e-11*V01*V033*V05*V09 + 
      4.75653144610541683e-12*V014*V04*V05*V09 - 3.75146216978449427e-11*V023*V04*V05*V09 - 
      2.81987535253471531e-10*V01*V02*V03*V04*V05*V09 - 4.06712511350395673e-11*V012*V042*V05*V09 + 
      1.48634678622836034e-11*V043*V05*V09 - 3.64229196604943815e-11*V01*V022*V052*V09 - 
      3.63621246163961679e-11*V012*V03*V052*V09 + 4.30361210736455366e-11*V03*V04*V052*V09 + 
      7.54260985165352741e-12*V02*V053*V09 + 7.62704632646405809e-12*V013*V022*V06*V09 + 
      3.13575770509679947e-12*V014*V03*V06*V09 - 2.76921154234908835e-11*V023*V03*V06*V09 - 
      9.9165851163648353e-11*V01*V02*V032*V06*V09 - 5.19761844093874136e-11*V01*V022*V04*V06*V09 - 
      5.65240677647489528e-11*V012*V03*V04*V06*V09 + 3.23960808342102081e-11*V03*V042*V06*V09 - 
      2.97923040609741584e-11*V012*V02*V05*V06*V09 + 3.07414761206647043e-11*V032*V05*V06*V09 + 
      3.34545986427474453e-11*V02*V04*V05*V06*V09 + 9.74213527269190872e-12*V01*V052*V06*V09 - 
      1.89951391225404803e-12*V013*V062*V09 + 1.21696364449145545e-11*V02*V03*V062*V09 + 
      7.44684362404557613e-12*V01*V04*V062*V09 + 1.13753806340442519e-12*V014*V02*V07*V09 - 
      2.22526096340661034e-12*V024*V07*V09 - 3.53262032166272511e-11*V01*V022*V03*V07*V09 - 
      1.74186204162994403e-11*V012*V032*V07*V09 - 2.0555566864796387e-11*V012*V02*V04*V07*V09 + 
      2.1487150960138617e-11*V032*V04*V07*V09 + 1.14682244893232395e-11*V02*V042*V07*V09 - 
      3.35843488358238068e-12*V013*V05*V07*V09 + 2.26187936374699135e-11*V02*V03*V05*V07*V09 + 
      1.36301845954234184e-11*V01*V04*V05*V07*V09 + 4.2775285240602101e-12*V022*V06*V07*V09 + 
      9.66621353851474279e-12*V01*V03*V06*V07*V09 - 5.00880896358795874e-13*V062*V07*V09 + 
      1.78853782919928605e-12*V01*V02*V072*V09 - 4.58618445748888429e-13*V05*V072*V09 + 
      5.27390102200129253e-14*V015*V08*V09 - 3.30917133851376104e-12*V01*V023*V08*V09 - 
      1.09859160648311399e-11*V012*V02*V03*V08*V09 + 3.96285705580366221e-12*V033*V08*V09 - 
      2.01661884998151421e-12*V013*V04*V08*V09 + 1.31611218782826282e-11*V02*V03*V04*V08*V09 + 
      4.03215528196799936e-12*V01*V042*V08*V09 + 3.37384776834229044e-12*V022*V05*V08*V09 + 
      7.48810976400511516e-12*V01*V03*V05*V08*V09 + 3.02456822210022597e-12*V01*V02*V06*V08*V09 - 
      7.84320125423407439e-13*V05*V06*V08*V09 + 5.72058431884078941e-13*V012*V07*V08*V09 - 
      5.49459850770374319e-13*V04*V07*V08*V09 - 1.55519354860853935e-13*V03*V082*V09 - 
      7.64034262324782911e-13*V012*V022*V092 - 4.71041389118609445e-13*V013*V03*V092 + 
      1.70925707511168869e-12*V02*V032*V092 + 8.8522245053830832e-13*V022*V04*V092 + 
      2.04488770214063792e-12*V01*V03*V04*V092 + 1.08184865163431235e-12*V01*V02*V05*V092 - 
      1.40191185183467147e-13*V052*V092 + 2.23369537169967895e-13*V012*V06*V092 - 
      2.14418255346581928e-13*V04*V06*V092 - 1.42068574016419847e-13*V03*V07*V092 - 
      4.48588083903120199e-14*V02*V08*V092 - 4.73366785375495536e-15*V01*V093 + 
      7.75126002833629745e-14*V026*V10 + 7.36885414454773576e-12*V01*V024*V03*V10 + 
      2.47556498853289512e-11*V012*V022*V032*V10 + 
      4.76963129803072572e-12*V013*V033*V10 - 1.70833215924100739e-11*V02*V034*V10 + 
      9.04999478756685021e-12*V012*V023*V04*V10 + 1.75926970728712389e-11*V013*V02*V03*V04*V10 - 
      5.4217512647191921e-11*V022*V032*V04*V10 - 3.94225283202298839e-11*V01*V033*V04*V10 + 
      1.11564927982457956e-12*V014*V042*V10 - 7.1345569506375561e-12*V023*V042*V10 - 
      6.59514249143471895e-11*V01*V02*V03*V042*V10 - 6.48556043912789787e-12*V012*V043*V10 + 
      1.69096929386410628e-12*V044*V10 + 4.59896350402208318e-12*V013*V022*V05*V10 + 
      1.86646284673306109e-12*V014*V03*V05*V10 - 1.80512896059993817e-11*V023*V03*V05*V10 - 
      6.22191772923744138e-11*V01*V02*V032*V05*V10 - 3.34851176533446251e-11*V01*V022*V04*V05*V10 - 
      3.51888806429786134e-11*V012*V03*V04*V05*V10 + 2.08034291778673591e-11*V03*V042*V05*V10 - 
      9.30299930234646813e-12*V012*V02*V052*V10 + 9.76074074619972294e-12*V032*V052*V10 + 
      1.08047953054476574e-11*V02*V04*V052*V10 + 2.05672922923900003e-12*V01*V053*V10 + 
      7.77149549894904636e-13*V014*V02*V06*V10 - 1.27105323598973373e-12*V024*V06*V10 - 
      2.40065531481532784e-11*V01*V022*V03*V06*V10 - 1.21304485323329022e-11*V012*V032*V06*V10 - 
      1.42032497035099351e-11*V012*V02*V04*V06*V10 + 1.49598459968604733e-11*V032*V04*V06*V10 + 
      7.56081321843459125e-12*V02*V042*V06*V10 - 2.34532638699358294e-12*V013*V05*V06*V10 + 
      1.56450131409425085e-11*V02*V03*V05*V06*V10 + 9.49907685503881357e-12*V01*V04*V05*V06*V10 + 
      1.40385508353588482e-12*V022*V062*V10 + 3.3809706491544246e-12*V01*V03*V062*V10 - 
      1.15426201204123253e-13*V063*V10 + 4.19875372669597415e-14*V015*V07*V10 - 
      2.72501460765988743e-12*V01*V023*V07*V10 - 8.92341175921214405e-12*V012*V02*V03*V07*V10 + 
      3.23810052478392476e-12*V033*V07*V10 - 1.63339892024226987e-12*V013*V04*V07*V10 + 
      1.08106366627861418e-11*V02*V03*V04*V07*V10 + 3.30322264577426398e-12*V01*V042*V07*V10 + 
      2.77759315527422251e-12*V022*V05*V07*V10 + 6.11384518388560735e-12*V01*V03*V05*V07*V10 + 
      2.47852022954158301e-12*V01*V02*V06*V07*V10 - 6.43090030796587558e-13*V05*V06*V07*V10 + 
      2.33196705963143323e-13*V012*V072*V10 - 2.2543462570070715e-13*V04*V072*V10 - 
      1.36629609794978827e-12*V012*V022*V08*V10 - 8.47445132380843219e-13*V013*V03*V08*V10 + 
      3.04864759687355253e-12*V02*V032*V08*V10 + 1.50751236648856406e-12*V022*V04*V08*V10 + 
      3.66471531197126906e-12*V01*V03*V04*V08*V10 + 1.93140236216127962e-12*V01*V02*V05*V08*V10 - 
      2.51354885134082044e-13*V052*V08*V10 + 4.02068671659144899e-13*V012*V06*V08*V10 - 
      3.79362533103627947e-13*V04*V06*V08*V10 - 2.54838216491093584e-13*V03*V07*V08*V10 - 
      3.95965158011853283e-14*V02*V082*V10 - 2.44115681705057422e-13*V013*V02*V09*V10 + 
      8.42425775343825465e-13*V022*V03*V09*V10 + 9.12479783065952808e-13*V01*V032*V09*V10 + 
      1.03792263835823726e-12*V01*V02*V04*V09*V10 + 2.81010168109900867e-13*V012*V05*V09*V10 - 
      2.75828712184180876e-13*V04*V05*V09*V10 - 1.99417746270675705e-13*V03*V06*V09*V10 - 
      7.37039686607555777e-14*V02*V07*V09*V10 - 2.55082883434524422e-14*V01*V08*V09*V10 - 
      6.61818996884761677e-15*V014*V102 + 3.14162261759926742e-14*V023*V102 + 
      2.36550696756511164e-13*V01*V02*V03*V102 + 6.91941897039592307e-14*V012*V04*V102 - 
      3.32248512490934716e-14*V042*V102 - 6.37707388265212247e-14*V03*V05*V102 - 
      2.53253087929340036e-14*V02*V06*V102 - 1.0437058648182273e-14*V01*V07*V102 + 
      7.12471773608827853e-17*V103 + 2.56395976886400837e-13*V01*V025*V11 + 
      3.50635718174572365e-12*V012*V023*V03*V11 + 3.19979262664549255e-12*V013*V02*V032*V11 - 
      7.66905721983921236e-12*V022*V033*V11 - 3.90729559182028989e-12*V01*V034*V11 + 
      1.93303698197881414e-12*V013*V022*V04*V11 + 7.95629030231981234e-13*V014*V03*V04*V11 - 
      7.38898687656075272e-12*V023*V03*V04*V11 - 2.71607989167461936e-11*V01*V02*V032*V04*V11 - 
      6.97563087202209774e-12*V01*V022*V042*V11 - 7.75915187864787855e-12*V012*V03*V042*V11 + 
      3.06323024042195822e-12*V03*V043*V11 + 4.20055904764912826e-13*V014*V02*V05*V11 - 
      8.94346052286353144e-13*V024*V05*V11 - 1.40577423243712333e-11*V01*V022*V03*V05*V11 - 
      6.88985002508664858e-12*V012*V032*V05*V11 - 8.14825152736710296e-12*V012*V02*V04*V05*V11 + 
      8.79790619580279309e-12*V032*V04*V05*V11 + 4.71716034723625953e-12*V02*V042*V05*V11 - 
      6.6157816987232337e-13*V013*V052*V11 + 4.6325200921409029e-12*V02*V03*V052*V11 + 
      2.78319696225915525e-12*V01*V04*V052*V11 + 2.60818265383454121e-14*V015*V06*V11 - 
      1.67855724183987916e-12*V01*V023*V06*V11 - 5.66483201132555183e-12*V012*V02*V03*V06*V11 + 
      2.08762897754657495e-12*V033*V06*V11 - 1.0417944712519662e-12*V013*V04*V06*V11 + 
      6.88171172452535888e-12*V02*V03*V04*V06*V11 + 2.11354032961384442e-12*V01*V042*V06*V11 + 
      1.75789131486502897e-12*V022*V05*V06*V11 + 3.94199810212296021e-12*V01*V03*V05*V06*V11 + 
      7.9145538379004642e-13*V01*V02*V062*V11 - 2.07687498555480307e-13*V05*V062*V11 - 
      1.01923579168084346e-12*V012*V022*V07*V11 - 6.272312927333192e-13*V013*V03*V07*V11 + 
      2.30745443945638305e-12*V02*V032*V07*V11 + 1.19731197076102005e-12*V022*V04*V07*V11 + 
      2.75799400664454538e-12*V01*V03*V04*V07*V11 + 1.45927220365852332e-12*V01*V02*V05*V07*V11 - 
      1.89910433079673229e-13*V052*V07*V11 + 3.00856806867567381e-13*V012*V06*V07*V11 - 
      2.90642844832045268e-13*V04*V06*V07*V11 - 9.62100169171856892e-14*V03*V072*V11 - 
      2.00608410851282181e-13*V013*V02*V08*V11 + 6.91831622380073695e-13*V022*V03*V08*V11 + 
      7.53632746231201129e-13*V01*V032*V08*V11 + 8.54012080758671847e-13*V01*V02*V04*V08*V11 + 
      2.32121658707087254e-13*V012*V05*V08*V11 - 2.27817058812744894e-13*V04*V05*V08*V11 - 
      1.64820607561245944e-13*V03*V06*V08*V11 - 6.08045531130707584e-14*V02*V07*V08*V11 - 
      1.05465844485395164e-14*V01*V082*V11 - 1.20899083878553765e-14*V014*V09*V11 + 
      6.07061567747321048e-14*V023*V09*V11 + 4.36122687632287632e-13*V01*V02*V03*V09*V11 + 
      1.27010308180101857e-13*V012*V04*V09*V11 - 6.20515158629919408e-14*V042*V09*V11 - 
      1.17540910925422305e-13*V03*V05*V09*V11 - 4.73422530760680865e-14*V02*V06*V09*V11 - 
      1.92193123767345681e-14*V01*V07*V09*V11 + 5.4300519450312012e-14*V01*V022*V10*V11 + 
      5.57758080167384659e-14*V012*V03*V10*V11 - 5.79257950416517911e-14*V03*V04*V10*V11 - 
      3.05451495636396829e-14*V02*V05*V10*V11 - 1.35155299017993354e-14*V01*V06*V10*V11 + 3.95230212201433155e-16*V09*V10*V11 + 
      6.71834157681786398e-15*V012*V02*V112 - 6.13686479653693604e-15*V032*V112 - 
      6.8129536173238793e-15*V02*V04*V112 - 3.9623256084821889e-15*V01*V05*V112 + 
      1.63519336185150235e-16*V08*V112 + 1.66335808621152406e-13*V012*V024*V12 + 
      6.48723522593670651e-13*V013*V022*V03*V12 + 1.29023350477447666e-13*V014*V032*V12 - 
      1.49594288794489304e-12*V023*V032*V12 - 3.34125286479095216e-12*V01*V02*V033*V12 + 
      1.63419370727291909e-13*V014*V02*V04*V12 - 2.81508738714305204e-13*V024*V04*V12 - 
      5.49090311804623287e-12*V01*V022*V03*V04*V12 - 2.80391931794771626e-12*V012*V032*V04*V12 - 
      1.62842929475199495e-12*V012*V02*V042*V12 + 1.80294982976722111e-12*V032*V042*V12 + 
      5.97796701487601218e-13*V02*V043*V12 + 1.28006348437894833e-14*V015*V05*V12 - 
      9.21534301641409075e-13*V01*V023*V05*V12 - 2.96899189274734953e-12*V012*V02*V03*V05*V12 + 
      1.1184095915138358e-12*V033*V05*V12 - 5.40632256085885512e-13*V013*V04*V05*V12 + 
      3.75568010846009391e-12*V02*V03*V04*V05*V12 + 1.14248366780051941e-12*V01*V042*V05*V12 + 
      4.83387006155968997e-13*V022*V052*V12 + 1.05262619541588581e-12*V01*V03*V052*V12 - 
      5.90802464949353536e-13*V012*V022*V06*V12 - 3.68031915182999834e-13*V013*V03*V06*V12 + 
      1.35323137763257968e-12*V02*V032*V06*V12 + 6.63758491774177272e-13*V022*V04*V06*V12 + 
      1.62793517472396777e-12*V01*V03*V04*V06*V12 + 8.56430182117520987e-13*V01*V02*V05*V06*V12 - 
      1.12792964795633948e-13*V052*V06*V12 + 8.92490765782059639e-14*V012*V062*V12 - 
      8.49144945601788246e-14*V04*V062*V12 - 1.36585082786026453e-13*V013*V02*V07*V12 + 
      4.82505178756065022e-13*V022*V03*V07*V12 + 5.1955385104123629e-13*V01*V032*V07*V12 + 
      5.92973558971413991e-13*V01*V02*V04*V07*V12 + 1.59781128726128815e-13*V012*V05*V07*V12 - 
      1.58274899914289276e-13*V04*V05*V07*V12 - 1.14336891385730971e-13*V03*V06*V07*V12 - 
      2.11612335574857437e-14*V02*V072*V12 - 9.14540395040037885e-15*V014*V08*V12 + 
      4.36513789377590849e-14*V023*V08*V12 + 3.29808775473445619e-13*V01*V02*V03*V08*V12 + 
      9.64999075483340518e-14*V012*V04*V08*V12 - 4.64542120180366846e-14*V042*V08*V12 - 
      8.92524779686709731e-14*V03*V05*V08*V12 - 3.53984484165353238e-14*V02*V06*V08*V12 - 
      1.46046242142143682e-14*V01*V07*V08*V12 + 4.60086911365172456e-14*V01*V022*V09*V12 + 
      4.70898459919305361e-14*V012*V03*V09*V12 - 4.90442329407386549e-14*V03*V04*V09*V12 - 
      2.58800256001095627e-14*V02*V05*V09*V12 - 1.14354321085520797e-14*V01*V06*V09*V12 + 
      1.67304941337438081e-16*V092*V12 + 1.23614587127440312e-14*V012*V02*V10*V12 - 
      1.12752719742842038e-14*V032*V10*V12 - 1.23483105179103649e-14*V02*V04*V10*V12 - 
      7.28253899063751415e-15*V01*V05*V10*V12 + 2.99466995538605696e-16*V08*V10*V12 + 
      9.19761287891000096e-16*V013*V11*V12 - 5.42327750071571153e-15*V02*V03*V11*V12 - 
      3.31594176887950092e-15*V01*V04*V11*V12 + 2.27063702679461703e-16*V07*V11*V12 - 
      2.83650935372259443e-16*V022*V122 - 6.36746260259674075e-16*V01*V03*V122 + 
      6.74678300891818865e-17*V06*V122 + 3.9976301382534789e-14*V013*V023*V13 + 
      4.89175266874960327e-14*V014*V02*V03*V13 - 1.26121534182215931e-13*V024*V03*V13 - 
      9.65245554661754847e-13*V01*V022*V032*V13 - 3.09384401799187093e-13*V012*V033*V13 + 
      4.60390198769202322e-15*V015*V04*V13 - 3.20611454730648966e-13*V01*V023*V04*V13 - 
      1.10683270603017737e-12*V012*V02*V03*V04*V13 + 4.30516052102499739e-13*V033*V04*V13 - 
      1.01936481370279414e-13*V013*V042*V13 + 7.00076174692932343e-13*V02*V03*V042*V13 + 
      1.4385443312891571e-13*V01*V043*V13 - 2.88665089014129592e-13*V012*V022*V05*V13 - 
      1.76367387568914817e-13*V013*V03*V05*V13 + 6.81004679079123795e-13*V02*V032*V05*V13 + 
      3.55505520092120169e-13*V022*V04*V05*V13 + 8.11151765580101422e-13*V01*V03*V04*V05*V13 + 
      2.14676049170278744e-13*V01*V02*V052*V13 - 1.89540431210138558e-14*V053*V13 - 
      7.39817198646526695e-14*V013*V02*V06*V13 + 2.60368659919936565e-13*V022*V03*V06*V13 + 
      2.8610881589996524e-13*V01*V032*V06*V13 + 3.22128340038525479e-13*V01*V02*V04*V06*V13 + 
      8.80400827189002382e-14*V012*V05*V06*V13 - 8.71978405747278985e-14*V04*V05*V06*V13 - 
      3.15742248835108776e-14*V03*V062*V13 - 5.74510456476696239e-15*V014*V07*V13 + 
      2.96719074278722933e-14*V023*V07*V13 + 2.1214147133610943e-13*V01*V02*V03*V07*V13 + 
      6.16889542111668482e-14*V012*V04*V07*V13 - 3.04314226877813598e-14*V042*V07*V13 - 
      5.75634046845674801e-14*V03*V05*V07*V13 - 2.32164929702007898e-14*V02*V06*V07*V13 - 
      4.7014695213560154e-15*V01*V072*V13 + 3.22071976045939323e-14*V01*V022*V08*V13 + 
      3.32273010727860078e-14*V012*V03*V08*V13 - 3.46151454979041412e-14*V03*V04*V08*V13 - 
      1.82333149657068196e-14*V02*V05*V08*V13 - 8.07976868172121293e-15*V01*V06*V08*V13 + 
      9.69111403462569307e-15*V012*V02*V09*V13 - 8.87545771300985079e-15*V032*V09*V13 - 
      9.85923876113217571e-15*V02*V04*V09*V13 - 5.72941930611747409e-15*V01*V05*V09*V13 + 2.36668517579857675e-16*V08*V09*V13 + 
      7.85838586585542426e-16*V013*V10*V13 - 4.63118661693940456e-15*V02*V03*V10*V13 - 
      2.83327755590088768e-15*V01*V04*V10*V13 + 1.94089098358819306e-16*V07*V10*V13 - 
      5.34747994933650592e-16*V022*V11*V13 - 1.18399830264103422e-15*V01*V03*V11*V13 + 
      1.25961338249916731e-16*V06*V11*V13 - 2.63802488349573982e-16*V01*V02*V12*V13 + 6.84861852535489448e-17*V05*V12*V13 - 
      1.38063162902524864e-17*V012*V132 + 1.33924380873533929e-17*V04*V132 + 
      4.26473376772056344e-15*V014*V022*V14 - 3.19974417607342883e-15*V025*V14 + 
      1.2490115984426164e-15*V015*V03*V14 - 1.10378562365037161e-13*V01*V023*V03*V14 - 
      1.72449208763539772e-13*V012*V02*V032*V14 + 3.53353815997856983e-14*V034*V14 - 
      9.87745582087084762e-14*V012*V022*V04*V14 - 6.20470542110473628e-14*V013*V03*V04*V14 + 
      2.39684321287531833e-13*V02*V032*V04*V14 + 5.76674016361060071e-14*V022*V042*V14 + 
      1.44456263934970899e-13*V01*V03*V042*V14 - 3.30670039284281572e-14*V013*V02*V05*V14 + 
      1.23723764119750044e-13*V022*V03*V05*V14 + 1.3197645652539253e-13*V01*V032*V05*V14 + 
      1.51354697162463954e-13*V01*V02*V04*V05*V14 + 2.02187336530048534e-14*V012*V052*V14 - 
      2.05641518806160233e-14*V04*V052*V14 - 2.90668553575449303e-15*V014*V06*V14 + 
      1.41298566552369442e-14*V023*V06*V14 + 1.0802070835039691e-13*V01*V02*V03*V06*V14 + 
      3.16357453003009066e-14*V012*V04*V06*V14 - 1.53834734140362349e-14*V042*V06*V14 - 
      2.96652412863963616e-14*V03*V05*V06*V14 - 5.85408791376920744e-15*V02*V062*V14 + 
      1.9420468668914513e-14*V01*V022*V07*V14 + 1.97792209799963733e-14*V012*V03*V07*V14 - 
      2.08310653264802157e-14*V03*V04*V07*V14 - 1.10004745417421942e-14*V02*V05*V07*V14 - 
      4.84961018151276382e-15*V01*V06*V07*V14 + 6.36611560985669837e-15*V012*V02*V08*V14 - 
      5.84463449973296657e-15*V032*V08*V14 - 6.38563750761872962e-15*V02*V04*V08*V14 - 
      3.77401737738169876e-15*V01*V05*V08*V14 + 7.77120610251126273e-17*V082*V14 + 
      5.73533709290183558e-16*V013*V09*V14 - 3.40118979205735017e-15*V02*V03*V09*V14 - 
      2.07801687945432342e-15*V01*V04*V09*V14 + 1.42427946754172133e-16*V07*V09*V14 - 
      4.19754454735862376e-16*V022*V10*V14 - 9.43217442397693872e-16*V01*V03*V10*V14 + 
      9.99682115573723471e-17*V06*V10*V14 - 2.2866267128259449e-16*V01*V02*V11*V14 + 5.93613340935076492e-17*V05*V11*V14 - 
      2.57529244257825513e-17*V012*V12*V14 + 2.48684411884531046e-17*V04*V12*V14 + 
      9.15120278155854706e-18*V03*V13*V14 + 8.83202182205101331e-19*V02*V142 + 
      2.03561246426261425e-16*V015*V02*V15 - 4.09469171473875801e-15*V01*V024*V15 - 
      2.92699627225537953e-14*V012*V022*V03*V15 - 8.75533674891401935e-15*V013*V032*V15 + 
      2.50869759681357287e-14*V02*V033*V15 - 1.08024927274801475e-14*V013*V02*V04*V15 + 
      3.97790131174541599e-14*V022*V03*V04*V15 + 4.44154911238667375e-14*V01*V032*V04*V15 + 
      2.46974754720833537e-14*V01*V02*V042*V15 - 1.20268340431768652e-15*V014*V05*V15 + 
      6.65940300669267592e-15*V023*V05*V15 + 4.70825996870079467e-14*V01*V02*V03*V05*V15 + 
      1.36362282721498699e-14*V012*V04*V05*V15 - 6.91924908888120564e-15*V042*V05*V15 - 
      6.52101578223697902e-15*V03*V052*V15 + 9.15584879762881452e-15*V01*V022*V06*V15 + 
      9.51969757577759039e-15*V012*V03*V06*V15 - 1.00392051987447196e-14*V03*V04*V06*V15 - 
      5.27624693459990309e-15*V02*V05*V06*V15 - 1.17183188734371519e-15*V01*V062*V15 + 
      3.55615851912314675e-15*V012*V02*V07*V15 - 3.29167501300949733e-15*V032*V07*V15 - 
      3.66432686831905488e-15*V02*V04*V07*V15 - 2.1230528758276457e-15*V01*V05*V07*V15 + 
      3.53732685726801065e-16*V013*V08*V15 - 2.09481567426887542e-15*V02*V03*V08*V15 - 
      1.28255758709462523e-15*V01*V04*V08*V15 + 8.80650959885073008e-17*V07*V08*V15 - 
      2.93209345162479819e-16*V022*V09*V15 - 6.48276852241903685e-16*V01*V03*V09*V15 + 
      6.90687106478139838e-17*V06*V09*V15 - 1.70667903123265413e-16*V01*V02*V10*V15 + 4.43564971194096355e-17*V05*V10*V15 - 
      2.09091661418311036e-17*V012*V11*V15 + 2.02941819960513407e-17*V04*V11*V15 + 
      7.99948331375185607e-18*V03*V12*V15 + 1.66316451903554112e-18*V02*V13*V15 + 3.49474520250452522e-19*V01*V14*V15 + 
      3.51834253082427155e-18*V016*V16 - 1.50831902763504906e-15*V012*V023*V16 - 
      2.87862408866016126e-15*V013*V02*V03*V16 + 6.05336188635199065e-15*V022*V032*V16 + 
      4.22031926254492107e-15*V01*V033*V16 - 3.71922313532228591e-16*V014*V04*V16 + 
      1.87260748315947443e-15*V023*V04*V16 + 1.46661625903621132e-14*V01*V02*V03*V04*V16 + 
      2.15202006527865e-15*V012*V042*V16 - 7.14627124477428683e-16*V043*V16 + 
      3.80933964072999833e-15*V01*V022*V05*V16 + 3.84448163793571359e-15*V012*V03*V05*V16 - 
      4.1695425614659382e-15*V03*V04*V05*V16 - 1.102077346314639e-15*V02*V052*V16 + 
      1.60241616300828418e-15*V012*V02*V06*V16 - 1.4984433836970569e-15*V032*V06*V16 - 
      1.62680168926496138e-15*V02*V04*V06*V16 - 9.66790272218241992e-16*V01*V05*V06*V16 + 
      1.84993409491203663e-16*V013*V07*V16 - 1.11440013489664696e-15*V02*V03*V07*V16 - 
      6.7983658724181726e-16*V01*V04*V07*V16 + 2.33852736189229427e-17*V072*V16 - 
      1.67186989258231604e-16*V022*V08*V16 - 3.77044277664306566e-16*V01*V03*V08*V16 + 
      4.00219539415658807e-17*V06*V08*V16 - 1.10527624482159593e-16*V01*V02*V09*V16 + 2.87246539546490258e-17*V05*V09*V16 - 
      1.47107543656901992e-17*V012*V10*V16 + 1.42107849706263982e-17*V04*V10*V16 + 
      6.11850192024307764e-18*V03*V11*V16 + 1.36235198421228277e-18*V02*V12*V16 + 3.08376290658021748e-19*V01*V13*V16 - 
      8.16093987447942729e-22*V162 - 2.19712114043949986e-16*V013*V022*V17 - 
      9.08988923856527871e-17*V014*V03*V17 + 5.81309401986453052e-16*V023*V03*V17 + 
      2.00695721980500327e-15*V01*V02*V032*V17 + 1.09087396910726857e-15*V01*V022*V04*V17 + 
      1.1508143392832719e-15*V012*V03*V04*V17 - 6.24523523673056162e-16*V03*V042*V17 + 
      6.1364040355558053e-16*V012*V02*V05*V17 - 5.84204785621399171e-16*V032*V05*V17 - 
      6.53349451244695463e-16*V02*V04*V05*V17 - 1.87905455736007897e-16*V01*V052*V17 + 
      7.91407272753546793e-17*V013*V06*V17 - 4.75485950049715488e-16*V02*V03*V06*V17 - 
      2.91516574787420555e-16*V01*V04*V06*V17 - 8.54953895192164887e-17*V022*V07*V17 - 
      1.88311432681518762e-16*V01*V03*V07*V17 + 2.01636861124894124e-17*V06*V07*V17 - 6.05337496018360723e-17*V01*V02*V08*V17 + 
      1.57897472518293901e-17*V05*V08*V17 - 8.97211006568833035e-18*V012*V09*V17 + 
      8.72951100618995659e-18*V04*V09*V17 + 4.06410279007934676e-18*V03*V10*V17 + 9.88353667393404911e-19*V02*V11*V17 + 
      2.39589013682437767e-19*V01*V12*V17 - 1.5434563422317208e-21*V15*V17 - 1.33697016171322319e-17*V014*V02*V18 + 
      1.7797547659326043e-17*V024*V18 + 2.91549428396745051e-16*V01*V022*V03*V18 + 
      1.44040524361644389e-16*V012*V032*V18 + 1.71907233263948466e-16*V012*V02*V04*V18 - 
      1.67385532804347518e-16*V032*V04*V18 - 8.96122550376044305e-17*V02*V042*V18 + 
      2.83348040318727555e-17*V013*V05*V18 - 1.77313890131301069e-16*V02*V03*V05*V18 - 
      1.07787929585219645e-16*V01*V04*V05*V18 - 3.37739784758552844e-17*V022*V06*V18 - 
      7.68092032412540911e-17*V01*V03*V06*V18 + 4.09875991303181505e-18*V062*V18 - 
      2.87565169833336802e-17*V01*V02*V07*V18 + 7.50476984256860474e-18*V05*V07*V18 - 
      4.67557835730033381e-18*V012*V08*V18 + 4.52500798904504722e-18*V04*V08*V18 + 
      2.35518281398418217e-18*V03*V09*V18 + 6.19057888652445335e-19*V02*V10*V18 + 1.63970887973297979e-19*V01*V11*V18 - 
      1.29790962572455848e-21*V14*V18 - 2.81467402465941724e-19*V015*V19 + 
      1.27247718794099937e-17*V01*V023*V19 + 4.13590738219565432e-17*V012*V02*V03*V19 - 
      1.39953315720472285e-17*V033*V19 + 7.64551389245019213e-18*V013*V04*V19 - 
      4.74054746926585335e-17*V02*V03*V04*V19 - 1.45716891879891268e-17*V01*V042*V19 - 
      1.22772415774788941e-17*V022*V05*V19 - 2.6813609580364461e-17*V01*V03*V05*V19 - 
      1.10589867962835127e-17*V01*V02*V06*V19 + 2.91484265964679019e-18*V05*V06*V19 - 
      2.09596573211370315e-18*V012*V07*V19 + 2.0545661741992879e-18*V04*V07*V19 + 1.16616957998382906e-18*V03*V08*V19 + 
      3.42638453399718963e-19*V02*V09*V19 + 9.80791296217238151e-20*V01*V10*V19 - 9.74808884579484448e-22*V13*V19 + 
      2.75310303036999249e-18*V012*V022*V20 + 1.6946683190136908e-18*V013*V03*V20 - 
      5.7823807497517946e-18*V02*V032*V20 - 3.01098922965011838e-18*V022*V04*V20 - 
      6.96797242900358369e-18*V01*V03*V04*V20 - 3.71043491321253936e-18*V01*V02*V05*V20 + 
      4.90791699620579875e-19*V052*V20 - 7.75020927358920314e-19*V012*V06*V20 + 
      7.55034934484592169e-19*V04*V06*V20 + 5.01489306749679763e-19*V03*V07*V20 + 1.60544588142819402e-19*V02*V08*V20 + 
      5.14196341815682151e-20*V01*V09*V20 - 6.48561479923403361e-22*V12*V20 + 2.22828360285537198e-19*V013*V02*V21 - 
      7.31306608085803184e-19*V022*V03*V21 - 7.83334142965243263e-19*V01*V032*V21 - 
      9.04748528798925536e-19*V01*V02*V04*V21 - 2.4438797458285934e-19*V012*V05*V21 + 
      2.44737987417296179e-19*V04*V05*V21 + 1.77361199702333235e-19*V03*V06*V21 + 6.64340953626921741e-20*V02*V07*V21 + 
      2.31740682244072771e-20*V01*V08*V21 - 3.84006331174563566e-22*V11*V21 + 5.86390421804045258e-21*V014*V22 - 
      2.76133996111711796e-20*V023*V22 - 1.98458700637656908e-19*V01*V02*V03*V22 - 
      5.81801638207661737e-20*V012*V04*V22 + 2.885104948567397e-20*V042*V22 + 
      5.44814526448508686e-20*V03*V05*V22 + 2.22254037591925726e-20*V02*V06*V22 + 9.09118583527632848e-21*V01*V07*V22 - 
      1.99618953359069914e-22*V10*V22 - 1.16122635253806007e-20*V01*V022*V23 - 
      1.17903952627102368e-20*V012*V03*V23 + 1.24829930444674685e-20*V03*V04*V23 + 
      6.63433821803523373e-21*V02*V05*V23 + 2.95293566826376469e-21*V01*V06*V23 - 9.1815937914521173e-23*V09*V23 - 
      1.38653892840365381e-21*V012*V02*V24 + 1.27288815110408637e-21*V032*V24 + 
      1.4277546795758848e-21*V02*V04*V24 + 8.31495166416901221e-22*V01*V05*V24 - 3.64154142458589054e-23*V08*V24 - 
      4.81437127917935352e-23*V013*V25 + 2.87383669442572391e-22*V02*V03*V25 + 1.76419529479540842e-22*V01*V04*V25 - 
      1.26997698933404636e-23*V07*V25 + 1.49435323575961296e-23*V022*V26 + 3.29079101347669386e-23*V01*V03*V26 - 
      3.67195815305932608e-24*V06*V26 + 3.47812441204153564e-24*V01*V02*V27 - 9.33456039350090217e-25*V05*V27 + 
      1.77950551313752986e-25*V012*V28 - 1.78195662265975786e-25*V04*V28 - 3.07614245039614322e-26*V03*V29 - 
      2.94133142667360308e-27*V02*V30 - 2.94133142667360308e-28*V01*V31 + 1.75079251587714469e-31*V34) + 
   eps17*(6.25217958800249802e-11*V029 + 5.21460329924242516e-9*V01*V027*V03 + 
      4.06225920945970708e-8*V012*V025*V032 + 
      5.95994333673905381e-8*V013*V023*V033 + 1.39624942109602899e-8*V014*V02*V034 - 
      1.27904119054044682e-8*V024*V034 - 2.48693774719741628e-8*V01*V022*V035 - 
      3.1060329028014276e-9*V012*V036 + 1.06823668728937659e-8*V012*V026*V04 + 
      6.83139131533307064e-8*V013*V024*V03*V04 + 
      6.27971469034988056e-8*V014*V022*V032*V04 - 
      2.16739195338582674e-8*V025*V032*V04 + 4.99651713432981605e-9*V015*V033*V04 - 
      1.22596598950903475e-7*V01*V023*V033*V04 - 7.00089456216922057e-8*V012*V02*V034*V04 + 
      1.56608811723923264e-9*V036*V04 + 1.55601197047449342e-8*V014*V023*V042 - 
      2.29312206278746533e-9*V026*V042 + 1.10216061614696041e-8*V015*V02*V03*V042 - 
      6.72307839815968607e-8*V01*V024*V03*V042 - 
      1.57722416286680781e-7*V012*V022*V032*V042 - 
      2.51750150548485499e-8*V013*V033*V042 + 1.7193024652002522e-8*V02*V034*V042 + 
      2.58374153008075656e-10*V016*V043 - 2.6435758593732076e-8*V012*V023*V043 - 
      3.81301400574972317e-8*V013*V02*V03*V043 + 
      2.47730730996561627e-8*V022*V032*V043 + 1.38240502075723025e-8*V01*V033*V043 - 
      1.23052242317200593e-9*V014*V044 + 2.8310089717477044e-9*V023*V044 + 
      1.52663119200692249e-8*V01*V02*V03*V044 + 9.04450252085365281e-10*V012*V045 - 
      6.71998649148490015e-11*V046 + 8.40590183298298363e-9*V013*V025*V05 + 
      2.51321383350022123e-8*V014*V023*V03*V05 - 4.2856022615388244e-9*V026*V03*V05 + 
      8.84216358805279108e-9*V015*V02*V032*V05 - 5.60249119523475168e-8*V01*V024*V032*V05 - 
      8.60341465206358242e-8*V012*V022*V033*V05 - 
      1.02435577706299213e-8*V013*V034*V05 + 5.7657358329666887e-9*V02*V035*V05 + 
      6.4447836091644154e-9*V015*V022*V04*V05 - 1.62115305690489908e-8*V01*V025*V04*V05 + 
      1.23390528879124628e-9*V016*V03*V04*V05 - 1.29143182151684916e-7*V012*V023*V03*V04*V05 - 
      9.29289187484598122e-8*V013*V02*V032*V04*V05 + 4.1983199565484209e-8*V022*V033*V04*V05 + 
      1.72287877082014647e-8*V01*V034*V04*V05 - 3.526200373508032e-8*V013*V022*V042*V05 - 
      1.19735669562184922e-8*V014*V03*V042*V05 + 2.99633780485777922e-8*V023*V03*V042*V05 + 
      7.65271992620178504e-8*V01*V02*V032*V042*V05 + 1.86673133612388625e-8*V01*V022*V043*V05 + 
      1.49263930466024361e-8*V012*V03*V043*V05 - 1.72920001165233684e-9*V03*V044*V05 + 
      3.52917450893756121e-10*V016*V02*V052 - 9.9018292437014247e-9*V012*V024*V052 - 
      2.85850327053454468e-8*V013*V022*V03*V052 - 
      4.85058993456562419e-9*V014*V032*V052 + 
      1.27747449201050857e-8*V023*V032*V052 + 
      2.12312123752395612e-8*V01*V02*V033*V052 - 7.34792527373400611e-9*V014*V02*V04*V052 + 
      4.50572255404291472e-9*V024*V04*V052 + 4.69761686875178592e-8*V01*V022*V03*V04*V052 + 
      1.84760187151136238e-8*V012*V032*V04*V052 + 
      1.38339568584472043e-8*V012*V02*V042*V052 - 
      4.38402051480113621e-9*V032*V042*V052 - 2.1133901413536643e-9*V02*V043*V052 - 
      1.93805630295909278e-10*V015*V053 + 3.19609069810412848e-9*V01*V023*V053 + 
      7.61613129067371416e-9*V012*V02*V03*V053 - 8.18884651824912958e-10*V033*V053 + 
      1.4234230165583747e-9*V013*V04*V053 - 3.58820034185001617e-9*V02*V03*V04*V053 - 
      1.10604891741996578e-9*V01*V042*V053 - 2.74513215501942477e-10*V022*V054 - 
      4.62042702263902793e-10*V01*V03*V054 + 3.11450438592833532e-9*V014*V024*V06 - 
      2.76233550963885337e-10*V027*V06 + 4.30915018351155544e-9*V015*V022*V03*V06 - 
      1.14490807149647928e-8*V01*V025*V03*V06 + 4.09650851801853284e-10*V016*V032*V06 - 
      4.47619544523281794e-8*V012*V023*V032*V06 - 
      2.13304635011177068e-8*V013*V02*V033*V06 + 7.42769753078757508e-9*V022*V034*V06 + 
      2.41750728342859943e-9*V01*V035*V06 + 5.88959140230183187e-10*V016*V02*V04*V06 - 
      1.6891698206477126e-8*V012*V024*V04*V06 - 4.84918735393063022e-8*V013*V022*V03*V04*V06 - 
      8.20637186649805629e-9*V014*V032*V04*V06 + 2.13561740696096514e-8*V023*V032*V04*V06 + 
      3.58780807467336936e-8*V01*V02*V033*V04*V06 - 6.21111930832424268e-9*V014*V02*V042*V06 + 
      3.64573209039694736e-9*V024*V042*V06 + 3.9575985050321896e-8*V01*V022*V03*V042*V06 + 
      1.56548985706669312e-8*V012*V032*V042*V06 + 
      7.82142174967862171e-9*V012*V02*V043*V06 - 2.45858915048717442e-9*V032*V043*V06 - 
      8.76422973489214721e-10*V02*V044*V06 + 2.66454936459131485e-11*V017*V05*V06 - 
      9.96122663522447496e-9*V013*V023*V05*V06 - 1.00593320396627165e-8*V014*V02*V03*V05*V06 + 
      6.44738436734896429e-9*V024*V03*V05*V06 + 3.30795237314614605e-8*V01*V022*V032*V05*V06 + 
      8.6053502624490764e-9*V012*V033*V05*V06 - 9.80822806006783529e-10*V015*V04*V05*V06 + 
      1.61142333468791977e-8*V01*V023*V04*V05*V06 + 3.87130587107496189e-8*V012*V02*V03*V04*V05*V06 - 
      4.14428602681015892e-9*V033*V04*V05*V06 + 3.62429421899931134e-9*V013*V042*V05*V06 - 
      9.0356717848728135e-9*V02*V03*V042*V05*V06 - 1.86670228117321432e-9*V01*V043*V05*V06 + 
      5.97712300334043037e-9*V012*V022*V052*V06 + 
      2.9698612199659946e-9*V013*V03*V052*V06 - 3.82237495075362237e-9*V02*V032*V052*V06 - 
      2.75737540907529724e-9*V022*V04*V052*V06 - 4.68767891190603062e-9*V01*V03*V04*V052*V06 - 
      9.65538289703845381e-10*V01*V02*V053*V06 + 2.90313705779298021e-11*V054*V06 - 
      1.3024692474573372e-9*V014*V022*V062 + 3.12684564465768275e-10*V025*V062 - 
      3.34360436394538699e-10*V015*V03*V062 + 5.69615685891738665e-9*V01*V023*V03*V062 + 
      6.76539862860980909e-9*V012*V02*V032*V062 - 3.66941939257599517e-10*V034*V062 + 
      5.06949346726614814e-9*V012*V022*V04*V062 + 
      2.51998318968914377e-9*V013*V03*V04*V062 - 3.21409828836954241e-9*V02*V032*V04*V062 - 
      1.1424942651270953e-9*V022*V042*V062 - 1.9801065602429236e-9*V01*V03*V042*V062 + 
      1.56226399934720183e-9*V013*V02*V05*V062 - 1.9665253235546451e-9*V022*V03*V05*V062 - 
      1.65424462157614319e-9*V01*V032*V05*V062 - 2.44372884923101719e-9*V01*V02*V04*V05*V062 - 
      3.03672370018409949e-10*V012*V052*V062 + 1.46693005886443412e-10*V04*V052*V062 + 
      4.83111728746744609e-11*V014*V063 - 1.10261623396711803e-10*V023*V063 - 
      5.76282937577413328e-10*V01*V02*V03*V063 - 1.71664032556611196e-10*V012*V04*V063 + 
      4.10067886233213659e-11*V042*V063 + 6.96157596747433627e-11*V03*V05*V063 + 
      8.99385796115546754e-12*V02*V064 + 5.91855348123603781e-10*V015*V023*V07 - 
      8.39470188623126695e-10*V01*V026*V07 + 3.33572855492122102e-10*V016*V02*V03*V07 - 
      1.01076333486928667e-8*V012*V024*V03*V07 - 
      1.44575772043763784e-8*V013*V022*V032*V07 - 
      1.62554825873654545e-9*V014*V033*V07 + 4.44033867280284692e-9*V023*V033*V07 + 
      5.49587002047559689e-9*V01*V02*V034*V07 + 1.89898215566130759e-11*V017*V04*V07 - 
      7.33356643613840155e-9*V013*V023*V04*V07 - 7.38038767572874876e-9*V014*V02*V03*V04*V07 + 
      4.72124705725639456e-9*V024*V03*V04*V07 + 2.43721384242946689e-8*V01*V022*V032*V04*V07 + 
      6.34949336323987246e-9*V012*V033*V04*V07 - 3.58711834548540219e-10*V015*V042*V07 + 
      5.92287945592841199e-9*V01*V023*V042*V07 + 1.42813843590052571e-8*V012*V02*V03*V042*V07 - 
      1.52827555980420777e-9*V033*V042*V07 + 8.91804111228698377e-10*V013*V043*V07 - 
      2.21656690755728284e-9*V02*V03*V043*V07 - 3.44264486232852612e-10*V01*V044*V07 - 
      2.2617453271974169e-9*V014*V022*V05*V07 + 5.65569065124989267e-10*V025*V05*V07 - 
      5.79942054856457939e-10*V015*V03*V05*V07 + 9.96033863165800775e-9*V01*V023*V03*V05*V07 + 
      1.17816757742744326e-8*V012*V02*V032*V05*V07 - 6.41630147088408431e-10*V034*V05*V07 + 
      8.81874589814799716e-9*V012*V022*V04*V05*V07 + 4.38312159674681856e-9*V013*V03*V04*V05*V07 - 
      5.63500759562669437e-9*V02*V032*V04*V05*V07 - 2.02677068397080957e-9*V022*V042*V05*V07 - 
      3.46120390535372909e-9*V01*V03*V042*V05*V07 + 1.35822920011842013e-9*V013*V02*V052*V07 - 
      1.72657092585744622e-9*V022*V03*V052*V07 - 1.44449604397210845e-9*V01*V032*V052*V07 - 
      2.13785624540183415e-9*V01*V02*V04*V052*V07 - 1.76546723303474283e-10*V012*V053*V07 + 
      8.57207334082235027e-11*V04*V053*V07 - 2.96473224142283089e-10*V015*V02*V06*V07 + 
      1.27701130257302887e-9*V01*V024*V06*V07 + 6.1688530474233967e-9*V012*V022*V03*V06*V07 + 
      1.52334473868234138e-9*V013*V032*V06*V07 - 1.33316918802663421e-9*V02*V033*V06*V07 + 
      2.30646348850187464e-9*V013*V02*V04*V06*V07 - 2.89394849262719912e-9*V022*V03*V04*V06*V07 - 
      2.44366746737013675e-9*V01*V032*V04*V06*V07 - 1.80262507477819381e-9*V01*V02*V042*V06*V07 + 
      2.52001559143364636e-10*V014*V05*V06*V07 - 5.87199253868119502e-10*V023*V05*V06*V07 - 
      3.02254684622403879e-9*V01*V02*V03*V05*V06*V07 - 8.97993116088297765e-10*V012*V04*V05*V06*V07 + 
      2.16423159490416931e-10*V042*V05*V06*V07 + 1.82922434640969395e-10*V03*V052*V06*V07 - 
      3.93138399374219116e-10*V01*V022*V062*V07 - 3.15483861877075647e-10*V012*V03*V062*V07 + 
      1.541612040791784e-10*V03*V04*V062*V07 + 9.49768480212710592e-11*V02*V05*V062*V07 + 
      1.40319674401066144e-11*V01*V063*V07 - 6.67433352319351925e-12*V016*V072 + 
      4.68119739679706491e-10*V012*V023*V072 + 
      6.96536833755630426e-10*V013*V02*V03*V072 - 
      4.52366956785083763e-10*V022*V032*V072 - 2.50847130563253705e-10*V01*V033*V072 + 
      9.29144944053638204e-11*V014*V04*V072 - 2.15623899892797133e-10*V023*V04*V072 - 
      1.11578638084818601e-9*V01*V02*V03*V04*V072 - 1.65972394540607654e-10*V012*V042*V072 + 
      2.66015627059490537e-11*V043*V072 - 3.44168828501578135e-10*V01*V022*V05*V072 - 
      2.75089909423818342e-10*V012*V03*V05*V072 + 1.35081996886893752e-10*V03*V04*V05*V072 + 
      4.16637030314234614e-11*V02*V052*V072 - 1.44985566349800077e-10*V012*V02*V06*V072 + 
      4.80232984077666035e-11*V032*V06*V072 + 7.00353521918086302e-11*V02*V04*V06*V072 + 
      3.68103576803470648e-11*V01*V05*V06*V072 - 5.62096178863145967e-12*V013*V073 + 
      1.46059473559258666e-11*V02*V03*V073 + 9.07475147155517216e-12*V01*V04*V073 - 
      9.5333289695796225e-14*V074 + 5.85730680977158589e-11*V016*V022*V08 - 
      8.13378434734331522e-10*V012*V025*V08 + 9.28879581834733194e-12*V017*V03*V08 - 
      3.85910585160513838e-9*V013*V023*V03*V08 - 1.93543477000348155e-9*V014*V02*V032*V08 + 
      1.30761251805902701e-9*V024*V032*V08 + 4.41426565424957284e-9*V01*V022*V033*V08 + 
      8.54735952539530986e-10*V012*V034*V08 - 1.46492713156924979e-9*V014*V022*V04*V08 + 
      3.54829073300207166e-10*V025*V04*V08 - 3.74649560065337595e-10*V015*V03*V04*V08 + 
      6.48299097265539626e-9*V01*V023*V03*V04*V08 + 7.70030849966701762e-9*V012*V02*V032*V04*V08 - 
      4.1894328385578419e-10*V034*V04*V08 + 2.88565702652034469e-9*V012*V022*V042*V08 + 
      1.43303713330201758e-9*V013*V03*V042*V08 - 1.83387992964094575e-9*V02*V032*V042*V08 - 
      4.34073866752261839e-10*V022*V043*V08 - 7.53699490860911749e-10*V01*V03*V043*V08 - 
      2.27098777867077168e-10*V015*V02*V05*V08 + 9.88525055809407175e-10*V01*V024*V05*V08 + 
      4.75838090260309246e-9*V012*V022*V03*V05*V08 + 1.17376170627362714e-9*V013*V032*V05*V08 - 
      1.03184867644043272e-9*V02*V033*V05*V08 + 1.77689664086652921e-9*V013*V02*V04*V05*V08 - 
      2.24353942429317817e-9*V022*V03*V04*V05*V08 - 1.88936508705028677e-9*V01*V032*V04*V05*V08 - 
      1.39512023322237727e-9*V01*V02*V042*V05*V08 + 9.70048087888572839e-11*V014*V052*V08 - 
      2.27833680374323428e-10*V023*V052*V08 - 1.16882536800255138e-9*V01*V02*V03*V052*V08 - 
      3.46892875155937239e-10*V012*V04*V052*V08 + 8.38557917874070341e-11*V042*V052*V08 + 
      4.72156223519573041e-11*V03*V053*V08 - 1.17882687551263049e-11*V016*V06*V08 + 
      8.30619857103425369e-10*V012*V023*V06*V08 + 1.23440215233389514e-9*V013*V02*V03*V06*V08 - 
      7.98948153331468531e-10*V022*V032*V06*V08 - 4.44235410095508924e-10*V01*V033*V06*V08 + 
      1.64560801986622462e-10*V014*V04*V06*V08 - 3.77046107613907149e-10*V023*V04*V06*V08 - 
      1.97445974899615695e-9*V01*V02*V03*V04*V06*V08 - 2.9416699109403249e-10*V012*V042*V06*V08 + 
      4.68710155000857439e-11*V043*V06*V08 - 6.08648356586315841e-10*V01*V022*V05*V06*V08 - 
      4.87447277259323692e-10*V012*V03*V05*V06*V08 + 2.38854976640415346e-10*V03*V04*V05*V06*V08 + 
      7.36209866584940369e-11*V02*V052*V06*V08 - 1.28492414393759719e-10*V012*V02*V062*V08 + 
      4.2477498375898144e-11*V032*V062*V08 + 6.16901649343956522e-11*V02*V04*V062*V08 + 
      3.25842303891974507e-11*V01*V05*V062*V08 + 2.82361150702873144e-10*V013*V022*V07*V08 + 
      9.89205637462599268e-11*V014*V03*V07*V08 - 2.3937993020667713e-10*V023*V03*V07*V08 - 
      6.09642324026631687e-10*V01*V02*V032*V07*V08 - 4.48958644307427093e-10*V01*V022*V04*V07*V08 - 
      3.60451783960605287e-10*V012*V03*V04*V07*V08 + 8.8160698646272407e-11*V03*V042*V07*V08 - 
      2.24062822598173939e-10*V012*V02*V05*V07*V08 + 7.43745377831746402e-11*V032*V05*V07*V08 + 
      1.08608389474597358e-10*V02*V04*V05*V07*V08 + 2.84891125797776135e-11*V01*V052*V07*V08 - 
      2.98954157468648261e-11*V013*V06*V07*V08 + 7.74538271107998589e-11*V02*V03*V06*V07*V08 + 
      4.81917124698400386e-11*V01*V04*V06*V07*V08 + 8.78424163332413206e-12*V022*V072*V08 + 
      1.492558099501873e-11*V01*V03*V072*V08 - 1.01184214750575244e-12*V06*V072*V08 + 
      1.99760477249626661e-11*V014*V02*V082 - 1.16603532660160478e-11*V024*V082 - 
      1.23061936586956314e-10*V01*V022*V03*V082 - 
      4.88911305120578969e-11*V012*V032*V082 - 
      7.3418665956766893e-11*V012*V02*V04*V082 + 2.43037852619659205e-11*V032*V04*V082 + 
      1.76345638255005475e-11*V02*V042*V082 - 1.1539750653114504e-11*V013*V05*V082 + 
      3.00145804404645824e-11*V02*V03*V05*V082 + 1.8654037672410373e-11*V01*V04*V05*V082 + 
      7.7353246852272538e-12*V022*V06*V082 + 1.32164002103809836e-11*V01*V03*V06*V082 - 
      4.47079529606547657e-13*V062*V082 + 6.07468628372015167e-12*V01*V02*V07*V082 - 
      7.84309956067134683e-13*V05*V07*V082 + 3.3321393101337754e-13*V012*V083 - 
      1.70827850978975007e-13*V04*V083 + 2.83550261244189693e-12*V017*V02*V09 - 
      3.47701550311919508e-10*V013*V024*V09 - 6.88273798378328814e-10*V014*V022*V03*V09 + 
      1.82882493120976459e-10*V025*V03*V09 - 8.75942569958729511e-11*V015*V032*V09 + 
      1.58831367795939532e-9*V01*V023*V032*V09 + 1.24169199320257811e-9*V012*V02*V033*V09 - 
      4.12526797055413064e-11*V035*V09 - 1.3131947368872562e-10*V015*V02*V04*V09 + 
      5.77115370620781484e-10*V01*V024*V04*V09 + 2.79327089226766114e-9*V012*V022*V03*V04*V09 + 
      6.88928727757572682e-10*V013*V032*V04*V09 - 6.05346448095323926e-10*V02*V033*V04*V09 + 
      5.2185572209010303e-10*V013*V02*V042*V09 - 6.55892989905916645e-10*V022*V03*V042*V09 - 
      5.55318229700878994e-10*V01*V032*V042*V09 - 2.72865445185831921e-10*V01*V02*V043*V09 - 
      8.07302089602861703e-12*V016*V05*V09 + 5.74659160286879746e-10*V012*V023*V05*V09 + 
      8.53790438371114728e-10*V013*V02*V03*V05*V09 - 5.5728438508343481e-10*V022*V032*V05*V09 - 
      3.0867547386690874e-10*V01*V033*V05*V09 + 1.13762246333938145e-10*V014*V04*V05*V09 - 
      2.65917865221501366e-10*V023*V04*V05*V09 - 1.37355760085647454e-9*V01*V02*V03*V04*V05*V09 - 
      2.04166548369035985e-10*V012*V042*V05*V09 + 3.27959555209060227e-11*V043*V05*V09 - 
      2.11899277111199132e-10*V01*V022*V052*V09 - 1.6917840269893338e-10*V012*V03*V052*V09 + 
      8.32430094377811309e-11*V03*V04*V052*V09 + 1.71219345810712357e-11*V02*V053*V09 + 
      2.24668200465914997e-10*V013*V022*V06*V09 + 7.86561948032019762e-11*V014*V03*V06*V09 - 
      1.902169001110536e-10*V023*V03*V06*V09 - 4.85180194200980499e-10*V01*V02*V032*V06*V09 - 
      3.57108556653966247e-10*V01*V022*V04*V06*V09 - 2.86952146224708911e-10*V012*V03*V04*V06*V09 + 
      7.01293734819105985e-11*V03*V042*V06*V09 - 1.78375062677351323e-10*V012*V02*V05*V06*V09 + 
      5.91880960569288584e-11*V032*V05*V06*V09 + 8.63711114989073914e-11*V02*V04*V05*V06*V09 + 
      2.26792690115107483e-11*V01*V052*V06*V09 - 1.19017400811913611e-11*V013*V062*V09 + 
      3.08071455304501023e-11*V02*V03*V062*V09 + 1.91797164115980435e-11*V01*V04*V062*V09 + 
      3.58758662457402319e-11*V014*V02*V07*V09 - 2.11893353253071622e-11*V024*V07*V09 - 
      2.21363428616652058e-10*V01*V022*V03*V07*V09 - 8.7856899484514988e-11*V012*V032*V07*V09 - 
      1.31898052726596567e-10*V012*V02*V04*V07*V09 + 4.37323817717026595e-11*V032*V04*V07*V09 + 
      3.18416720262621891e-11*V02*V042*V07*V09 - 2.0730826258580542e-11*V013*V05*V07*V09 + 
      5.40301416467807654e-11*V02*V03*V05*V07*V09 + 3.35514435740144165e-11*V01*V04*V05*V07*V09 + 
      1.39697828349622167e-11*V022*V06*V07*V09 + 2.37671357275883016e-11*V01*V03*V06*V07*V09 - 
      8.05251664931596082e-13*V062*V07*V09 + 5.46418033077163014e-12*V01*V02*V072*V09 - 
      7.05698928866150331e-13*V05*V072*V09 + 1.92331403477942124e-12*V015*V08*V09 - 
      2.96472091058435434e-11*V01*V023*V08*V09 - 7.16331933278997916e-11*V012*V02*V03*V08*V09 + 
      8.02375728406389966e-12*V033*V08*V09 - 1.35982834522099655e-11*V013*V04*V08*V09 + 
      3.52521476148210387e-11*V02*V03*V04*V08*V09 + 1.09819821587418427e-11*V01*V042*V08*V09 + 
      1.08393747578490735e-11*V022*V05*V08*V09 + 1.83960298562759464e-11*V01*V03*V05*V08*V09 + 
      9.67191968090106168e-12*V01*V02*V06*V08*V09 - 1.24848698321318035e-12*V05*V06*V08*V09 + 
      1.79674961600924864e-12*V012*V07*V08*V09 - 9.23147643677301279e-13*V04*V07*V08*V09 - 
      2.55264659612331162e-13*V03*V082*V09 - 6.55278484244954175e-12*V012*V022*V092 - 
      3.29607850858004624e-12*V013*V03*V092 + 4.38104144771132214e-12*V02*V032*V092 + 
      3.17692428342772668e-12*V022*V04*V092 + 5.42010666756547432e-12*V01*V03*V04*V092 + 
      3.36900726031306845e-12*V01*V02*V05*V092 - 2.17700363789892943e-13*V052*V092 + 
      7.15639541233808199e-13*V012*V06*V092 - 3.67356170562764885e-13*V04*V06*V092 - 
      2.29664910250554026e-13*V03*V07*V092 - 9.3228902348140207e-14*V02*V08*V092 - 
      9.6803401273559701e-15*V01*V093 + 5.24373770794049432e-14*V018*V10 - 
      7.38106793436302189e-11*V014*V023*V10 + 9.30780807820173272e-12*V026*V10 - 
      5.55603142032450598e-11*V015*V02*V03*V10 + 2.58209917430039932e-10*V01*V024*V03*V10 + 
      6.13792723870704225e-10*V012*V022*V032*V10 + 
      1.00193032566304441e-10*V013*V033*V10 - 6.78143787217560688e-11*V02*V034*V10 - 
      4.21246929204553044e-12*V016*V04*V10 + 3.06807623115474111e-10*V012*V023*V04*V10 + 
      4.55170101876548038e-10*V013*V02*V03*V04*V10 - 2.96075436754576627e-10*V022*V032*V04*V10 - 
      1.64824266003051312e-10*V01*V033*V04*V10 + 3.02728095893227744e-11*V014*V042*V10 - 
      6.97295981134493693e-11*V023*V042*V10 - 3.66190937043207167e-10*V01*V02*V03*V042*V10 - 
      3.63866246680599772e-11*V012*V043*V10 + 4.34912851294683331e-12*V044*V10 + 
      1.41052636750537203e-10*V013*V022*V05*V10 + 4.93487945934049035e-11*V014*V03*V05*V10 - 
      1.20545538621757182e-10*V023*V03*V05*V10 - 3.06222873465289124e-10*V01*V02*V032*V05*V10 - 
      2.25733766310917337e-10*V01*V022*V04*V05*V10 - 1.8088183370091895e-10*V012*V03*V04*V05*V10 + 
      4.43666565825676507e-11*V03*V042*V05*V10 - 5.62308782333052644e-11*V012*V02*V052*V10 + 
      1.87061391991870827e-11*V032*V052*V10 + 2.73440275485312675e-11*V02*V04*V052*V10 + 
      4.77538466289459359e-12*V01*V053*V10 + 2.58900461070031787e-11*V014*V02*V06*V10 - 
      1.51336025069472042e-11*V024*V06*V10 - 1.59861933378489889e-10*V01*V022*V03*V06*V10 - 
      6.35144825160909707e-11*V012*V032*V06*V10 - 9.5383940163144455e-11*V012*V02*V04*V06*V10 + 
      3.15755317611839195e-11*V032*V04*V06*V10 + 2.29033452163022798e-11*V02*V042*V06*V10 - 
      1.49902314462338746e-11*V013*V05*V06*V10 + 3.89944414211196012e-11*V02*V03*V05*V06*V10 + 
      2.42408129758295985e-11*V01*V04*V05*V06*V10 + 5.02385967125436126e-12*V022*V062*V10 + 
      8.58840656090410771e-12*V01*V03*V062*V10 - 1.9364479054841699e-13*V063*V10 + 
      1.56702833055732708e-12*V015*V07*V10 - 2.42080753641504605e-11*V01*V023*V07*V10 - 
      5.84464302508044611e-11*V012*V02*V03*V07*V10 + 6.54945995226612351e-12*V033*V07*V10 - 
      1.10924818236506235e-11*V013*V04*V07*V10 + 2.87861317449249527e-11*V02*V03*V04*V07*V10 + 
      8.96441383695503272e-12*V01*V042*V07*V10 + 8.85344192486745488e-12*V022*V05*V07*V10 + 
      1.50143085890138743e-11*V01*V03*V05*V07*V10 + 7.89574405478324287e-12*V01*V02*V06*V07*V10 - 
      1.01924751124370417e-12*V05*V06*V07*V10 + 7.33171770982017078e-13*V012*V072*V10 - 
      3.76860299897428e-13*V04*V072*V10 - 1.19050246522828233e-11*V012*V022*V08*V10 - 
      5.98652873642704457e-12*V013*V03*V08*V10 + 7.94956231723882349e-12*V02*V032*V08*V10 + 
      5.74726153507317702e-12*V022*V04*V08*V10 + 9.83982588123790598e-12*V01*V03*V04*V08*V10 + 
      6.11525615021845605e-12*V01*V02*V05*V08*V10 - 3.95051246757576031e-13*V052*V08*V10 + 
      1.2997524596332676e-12*V012*V06*V08*V10 - 6.66029317351406599e-13*V04*V06*V08*V10 - 
      4.1680793987594165e-13*V03*V07*V08*V10 - 8.45108818648456279e-14*V02*V082*V10 - 
      2.20065508013541766e-12*V013*V02*V09*V10 + 2.87970278530161378e-12*V022*V03*V09*V10 + 
      2.42512285759781008e-12*V01*V032*V09*V10 + 3.60142136514721176e-12*V01*V02*V04*V09*V10 + 
      9.03714410423918975e-13*V012*V05*V09*V10 - 4.65190593954010018e-13*V04*V05*V09*V10 - 
      3.31858397845958292e-13*V03*V06*V09*V10 - 1.52279416745642462e-13*V02*V07*V09*V10 - 
      5.27254845904200069e-14*V01*V08*V09*V10 - 6.56810768566815887e-14*V014*V102 + 
      1.56198001881880789e-13*V023*V102 + 8.07924695672299842e-13*V01*V02*V03*V102 + 
      2.42278807723785745e-13*V012*V04*V102 - 6.20557676119495052e-14*V042*V102 - 
      1.05029126575190559e-13*V03*V05*V102 - 5.49398962402857943e-14*V02*V06*V102 - 
      2.15238251568381231e-14*V01*V07*V102 + 1.08316711720738943e-16*V103 - 
      8.00595746747635866e-12*V015*V022*V11 + 1.52530450113544024e-11*V01*V025*V11 - 
      1.61545963906107525e-12*V016*V03*V11 + 1.23427634249150061e-10*V012*V023*V03*V11 + 
      9.08750659537549805e-11*V013*V02*V032*V11 - 4.07097379073308541e-11*V022*V033*V11 - 
      1.67918119583709385e-11*V01*V034*V11 + 6.89232479336388141e-11*V013*V022*V04*V11 + 
      2.40512228946492116e-11*V014*V03*V04*V11 - 5.85675308302244727e-11*V023*V03*V04*V11 - 
      1.49765362070319439e-10*V01*V02*V032*V04*V11 - 5.50734313325826733e-11*V01*V022*V042*V11 - 
      4.42997965581902591e-11*V012*V03*V042*V11 + 7.22145514124928207e-12*V03*V043*V11 + 
      1.48769938497538353e-11*V014*V02*V05*V11 - 8.88179041481730078e-12*V024*V05*V11 - 
      9.2538729791610379e-11*V01*V022*V03*V05*V11 - 3.6676617442101529e-11*V012*V032*V05*V11 - 
      5.5080589304095102e-11*V012*V02*V04*V05*V11 + 1.82998216684023145e-11*V032*V04*V05*V11 + 
      1.33355854449968964e-11*V02*V042*V05*V11 - 4.32387539075250346e-12*V013*V052*V11 + 
      1.1308908198724197e-11*V02*V03*V052*V11 + 7.01810319216222777e-12*V01*V04*V052*V11 + 
      1.03481009371839195e-12*V015*V06*V11 - 1.60128926377862921e-11*V01*V023*V06*V11 - 
      3.87113808944970348e-11*V012*V02*V03*V06*V11 + 4.33578192196176161e-12*V033*V06*V11 - 
      7.34786794238706559e-12*V013*V04*V06*V11 + 1.90404734592287369e-11*V02*V03*V04*V06*V11 + 
      5.93463534303329936e-12*V01*V042*V06*V11 + 5.85341875678682346e-12*V022*V05*V06*V11 + 
      9.94352866031313203e-12*V01*V03*V05*V06*V11 + 2.61381704522532906e-12*V01*V02*V062*V11 - 
      3.37253126709828369e-13*V05*V062*V11 - 8.89590811354143176e-12*V012*V022*V07*V11 - 
      4.47338339415050112e-12*V013*V03*V07*V11 + 5.94906381508627453e-12*V02*V032*V07*V11 + 
      4.31497440521220811e-12*V022*V04*V07*V11 + 7.35922434731519948e-12*V01*V03*V04*V07*V11 + 
      4.57469495732040887e-12*V01*V02*V05*V07*V11 - 2.95546473893302104e-13*V052*V07*V11 + 
      9.71672110888664054e-13*V012*V06*V07*V11 - 4.98761739951227791e-13*V04*V06*V07*V11 - 
      1.55915929991741425e-13*V03*V072*V11 - 1.83072140364904813e-12*V013*V02*V08*V11 + 
      2.39432043352258837e-12*V022*V03*V08*V11 + 2.01717510739153553e-12*V01*V032*V08*V11 + 
      2.99518033091024407e-12*V01*V02*V04*V08*V11 + 7.51756786214206763e-13*V012*V05*V08*V11 - 
      3.86782853348795323e-13*V04*V05*V08*V11 - 2.75951210990875889e-13*V03*V06*V08*V11 - 
      1.26614742930311462e-13*V02*V07*V08*V11 - 2.19270059219001046e-14*V01*V082*V11 - 
      1.20333243277689019e-13*V014*V09*V11 + 2.87126878822985714e-13*V023*V09*V11 + 
      1.48062811014742855e-12*V01*V02*V03*V09*V11 + 4.43864858939275204e-13*V012*V04*V09*V11 - 
      1.13833527501423344e-13*V042*V09*V11 - 1.92489526223967135e-13*V03*V05*V09*V11 - 
      1.00785826564609848e-13*V02*V06*V09*V11 - 3.94420323304990069e-14*V01*V07*V09*V11 + 
      2.45853134487776466e-13*V01*V022*V10*V11 + 1.97729250149831743e-13*V012*V03*V10*V11 - 
      1.02957066098077763e-13*V03*V04*V10*V11 - 6.38761806668268206e-14*V02*V05*V10*V11 - 
      2.85274543570382837e-14*V01*V06*V10*V11 + 5.95687568593732994e-16*V09*V10*V11 + 
      3.03961982261209344e-14*V012*V02*V112 - 1.06508778622800134e-14*V032*V112 - 
      1.56351860290811251e-14*V02*V04*V112 - 8.27046308290092957e-15*V01*V05*V112 + 
      2.47709021047733191e-16*V08*V112 - 4.19499016635239545e-13*V016*V02*V12 + 
      8.59461370187025475e-12*V012*V024*V12 + 2.53608396962641735e-11*V013*V022*V03*V12 + 
      4.40424042186489126e-12*V014*V032*V12 - 1.12086507407540217e-11*V023*V032*V12 - 
      1.88092511771499367e-11*V01*V02*V033*V12 + 6.68815242119704144e-12*V014*V02*V04*V12 - 
      3.93616510274106526e-12*V024*V04*V12 - 4.17289610970460849e-11*V01*V022*V03*V04*V12 - 
      1.65837833831399286e-11*V012*V032*V04*V12 - 1.24545487677701759e-11*V012*V02*V042*V12 + 
      4.12763754160398111e-12*V032*V042*V12 + 1.9933071960285221e-12*V02*V043*V12 + 
      5.47832671452573345e-13*V015*V05*V12 - 8.56518111830193152e-12*V01*V023*V05*V12 - 
      2.06349648734761388e-11*V012*V02*V03*V05*V12 + 2.31728745049513855e-12*V033*V05*V12 - 
      3.91204179170238733e-12*V013*V04*V05*V12 + 1.01931390666041244e-11*V02*V03*V04*V05*V12 + 
      3.17161745424683156e-12*V01*V042*V05*V12 + 1.56842846009456079e-12*V022*V052*V12 + 
      2.65541125463479617e-12*V01*V03*V052*V12 - 5.44008107095467384e-12*V012*V022*V06*V12 - 
      2.73458009815117744e-12*V013*V03*V06*V12 + 3.63188592104745251e-12*V02*V032*V06*V12 + 
      2.62424692611618561e-12*V022*V04*V06*V12 + 4.49672423749712586e-12*V01*V03*V04*V06*V12 + 
      2.79469835696856085e-12*V01*V02*V05*V06*V12 - 1.80435782676575135e-13*V052*V06*V12 + 
      2.97098512623103007e-13*V012*V062*V12 - 1.52088450990176283e-13*V04*V062*V12 - 
      1.2624078172672916e-12*V013*V02*V07*V12 + 1.6536027057116877e-12*V022*V03*V07*V12 + 
      1.39186299909975605e-12*V01*V032*V07*V12 + 2.06739673801999597e-12*V01*V02*V04*V07*V12 + 
      5.18628868005359063e-13*V012*V05*V07*V12 - 2.66945370349106611e-13*V04*V05*V07*V12 - 
      1.90439866060657692e-13*V03*V06*V07*V12 - 4.37068582521253713e-14*V02*V072*V12 - 
      9.23564199073933697e-14*V014*V08*V12 + 2.19604508155447486e-13*V023*V08*V12 + 
      1.13621242194804145e-12*V01*V02*V03*V08*V12 + 3.40736293602955469e-13*V012*V04*V08*V12 - 
      8.72272220370080429e-14*V042*V08*V12 - 1.47647968899197469e-13*V03*V05*V08*V12 - 
      7.72309166405038087e-14*V02*V06*V08*V12 - 3.02638594493921811e-14*V01*V07*V08*V12 + 
      2.07858479388890272e-13*V01*V022*V09*V12 + 1.67142735974225196e-13*V012*V03*V09*V12 - 
      8.70281318035008979e-14*V03*V04*V09*V12 - 5.39971725945516486e-14*V02*V05*V09*V12 - 
      2.41128352281635414e-14*V01*V06*V09*V12 + 2.51746573203525123e-16*V092*V12 + 
      5.61000163347059356e-14*V012*V02*V10*V12 - 1.96496032763610591e-14*V032*V10*V12 - 
      2.88190149210721101e-14*V02*V04*V10*V12 - 1.52593415921104257e-14*V01*V05*V10*V12 + 4.56850777389276673e-16*V08*V10*V12 + 
      4.39273976121665118e-15*V013*V11*V12 - 1.19850636383477395e-14*V02*V03*V11*V12 - 
      7.50039877050195784e-15*V01*V04*V11*V12 + 3.42023826439951795e-16*V07*V11*V12 - 
      8.37929931954732678e-16*V022*V122 - 1.4263994111979598e-15*V01*V03*V122 + 
      1.04506253370338685e-16*V06*V122 - 8.32339318720713384e-15*V017*V13 + 
      2.19348907167486971e-12*V013*V023*V13 + 2.27121183829863381e-12*V014*V02*V03*V13 - 
      1.42117570900619973e-12*V024*V03*V13 - 7.32046420173600694e-12*V01*V022*V032*V13 - 
      1.92041582677376483e-12*V012*V033*V13 + 2.27864046671821617e-13*V015*V04*V13 - 
      3.58093908819955881e-12*V01*V023*V04*V13 - 8.66524568091972585e-12*V012*V02*V03*V04*V13 + 
      9.72016349173255871e-13*V033*V04*V13 - 8.21867830135441179e-13*V013*V042*V13 + 
      2.13209895116106675e-12*V02*V03*V042*V13 + 4.4359827705685779e-13*V01*V043*V13 - 
      2.69257510203205076e-12*V012*V022*V05*V13 - 1.35199654954250226e-12*V013*V03*V05*V13 + 
      1.80465118239322141e-12*V02*V032*V05*V13 + 1.3103066152004742e-12*V022*V04*V05*V13 + 
      2.23091625720809256e-12*V01*V03*V04*V05*V13 + 6.93642150189549252e-13*V01*V02*V052*V13 - 
      2.98771835534169752e-14*V053*V13 - 7.16722591133683539e-13*V013*V02*V06*V13 + 
      9.37009680177171651e-13*V022*V03*V06*V13 + 7.89986966666635419e-13*V01*V032*V06*V13 + 
      1.17275028604264065e-12*V01*V02*V04*V06*V13 + 2.94466448946941349e-13*V012*V05*V06*V13 - 
      1.51314737233559677e-13*V04*V05*V06*V13 - 5.39943699664587549e-14*V03*V062*V13 - 
      5.91257092955207698e-14*V014*V07*V13 + 1.41281330370302552e-13*V023*V07*V13 + 
      7.28167357100337066e-13*V01*V02*V03*V07*V13 + 2.18252006833106655e-13*V012*V04*V07*V13 - 
      5.59528378615241846e-14*V042*V07*V13 - 9.46099708958241988e-14*V03*V05*V07*V13 - 
      4.95498553747026348e-14*V02*V06*V07*V13 - 9.69533617767601318e-15*V01*V072*V13 + 
      1.48094847186989803e-13*V01*V022*V08*V13 + 1.19125774995733806e-13*V012*V03*V08*V13 - 
      6.19804729552403889e-14*V03*V04*V08*V13 - 3.84519163194843156e-14*V02*V05*V08*V13 - 
      1.71777254369454537e-14*V01*V06*V08*V13 + 4.40259248822647891e-14*V012*V02*V09*V13 - 
      1.54214471118238585e-14*V032*V09*V13 - 2.26390594592213659e-14*V02*V04*V09*V13 - 
      1.19748630346168169e-14*V01*V05*V09*V13 + 3.58571594241885172e-16*V08*V09*V13 + 
      3.76326235383595136e-15*V013*V10*V13 - 1.0264379038176416e-14*V02*V03*V10*V13 - 
      6.42400408068795509e-15*V01*V04*V10*V13 + 2.92876935191368577e-16*V07*V10*V13 - 
      1.55728116728068998e-15*V022*V11*V13 - 2.64856100704223562e-15*V01*V03*V11*V13 + 
      1.94087950881787752e-16*V06*V11*V13 - 7.51986583004849614e-16*V01*V02*V12*V13 + 1.04027103137953303e-16*V05*V12*V13 - 
      4.01486267448180713e-17*V012*V132 + 2.18949587810134295e-17*V04*V132 + 
      2.73136671021456014e-13*V014*V022*V14 - 6.59794466802425807e-14*V025*V14 + 
      7.17974086895185798e-14*V015*V03*V14 - 1.17808612387926968e-12*V01*V023*V03*V14 - 
      1.40633446011785291e-12*V012*V02*V032*V14 + 8.0008767534176267e-14*V034*V14 - 
      1.05610366580205457e-12*V012*V022*V04*V14 - 5.30282435792232792e-13*V013*V03*V04*V14 + 
      7.05841556230467724e-13*V02*V032*V04*V14 + 2.54583599547743168e-13*V022*V042*V14 + 
      4.37369655970112486e-13*V01*V03*V042*V14 - 3.30785666590757969e-13*V013*V02*V05*V14 + 
      4.35223356748460316e-13*V022*V03*V05*V14 + 3.65783226433976697e-13*V01*V032*V05*V14 + 
      5.43625087717327098e-13*V01*V02*V04*V05*V14 + 6.81187611631598145e-14*V012*V052*V14 - 
      3.50931248191199661e-14*V04*V052*V14 - 3.13184376987959814e-14*V014*V06*V14 + 
      7.44721261692456442e-14*V023*V06*V14 + 3.85728861665576034e-13*V01*V02*V03*V06*V14 + 
      1.15692171815758378e-13*V012*V04*V06*V14 - 2.95718839705605022e-14*V042*V06*V14 - 
      5.00758201938217778e-14*V03*V05*V06*V14 - 1.30948340251311134e-14*V02*V062*V14 + 
      8.86196297452235307e-14*V01*V022*V07*V14 + 7.12324676765851934e-14*V012*V03*V07*V14 - 
      3.7070113726543228e-14*V03*V04*V07*V14 - 2.30039362873512637e-14*V02*V05*V07*V14 - 
      1.02717603959161161e-14*V01*V06*V07*V14 + 2.92921539875572724e-14*V012*V02*V08*V14 - 
      1.02512844439784947e-14*V032*V08*V14 - 1.50321560949968318e-14*V02*V04*V08*V14 - 
      7.96154394968132433e-15*V01*V05*V08*V14 + 1.19109192369878942e-16*V082*V14 + 
      2.75657721299609116e-15*V013*V09*V14 - 7.51845196536633975e-15*V02*V03*V09*V14 - 
      4.70480425778596386e-15*V01*V04*V09*V14 + 2.14439726396869774e-16*V07*V09*V14 - 
      1.24353686435113175e-15*V022*V10*V14 - 2.11705314100123566e-15*V01*V03*V10*V14 + 
      1.55039513768331436e-16*V06*V10*V14 - 6.51532275547228593e-16*V01*V02*V11*V14 + 9.01130257324268198e-17*V05*V11*V14 - 
      7.49382824838777591e-17*V012*V12*V14 + 4.08494063554899965e-17*V04*V12*V14 + 
      1.45552798853071004e-17*V03*V13*V14 + 1.78647659383284125e-18*V02*V142 + 
      1.59908668025963142e-14*V015*V02*V15 - 6.62909792419512409e-14*V01*V024*V15 - 
      3.21719117467921163e-13*V012*V022*V03*V15 - 8.01987164097714197e-14*V013*V032*V15 + 
      7.28947396349252611e-14*V02*V033*V15 - 1.21738697660430244e-13*V013*V02*V04*V15 + 
      1.59373127746027243e-13*V022*V03*V04*V15 + 1.34621745105101862e-13*V01*V032*V04*V15 + 
      9.98697967955944916e-14*V01*V02*V042*V15 - 1.35446202045551734e-14*V014*V05*V15 + 
      3.25875010790874115e-14*V023*V05*V15 + 1.67621038429984839e-13*V01*V02*V03*V05*V15 + 
      5.02000907607566122e-14*V012*V04*V05*V15 - 1.28801960999998382e-14*V042*V05*V15 - 
      1.08867051921786984e-14*V03*V052*V15 + 4.40098418671406137e-14*V01*V022*V06*V15 + 
      3.54118570097815915e-14*V012*V03*V06*V15 - 1.83972249138684895e-14*V03*V04*V06*V15 - 
      1.14126097720675843e-14*V02*V05*V06*V15 - 2.5510018594259246e-15*V01*V062*V15 + 
      1.64251449597279821e-14*V012*V02*V07*V15 - 5.74875419015373247e-15*V032*V07*V15 - 
      8.44083486266602822e-15*V02*V04*V07*V15 - 4.46393474174600825e-15*V01*V05*V07*V15 + 
      1.71971670934975282e-15*V013*V08*V15 - 4.68564432922033301e-15*V02*V03*V08*V15 - 
      2.93291574750291421e-15*V01*V04*V08*V15 + 1.33593610023485428e-16*V07*V08*V15 - 
      8.54827868432315554e-16*V022*V09*V15 - 1.45373041672115475e-15*V01*V03*V09*V15 + 
      1.06448909164573911e-16*V06*V09*V15 - 4.88260647650825387e-16*V01*V02*V10*V15 + 6.75007084782122866e-17*V05*V10*V15 - 
      6.08681222599066042e-17*V012*V11*V15 + 3.31815960182467984e-17*V04*V11*V15 + 
      1.27321179575607725e-17*V03*V12*V15 + 3.35032930843095657e-18*V02*V13*V15 + 7.02181198873766766e-19*V01*V14*V15 + 
      3.48315910551602883e-16*V016*V16 - 2.3087765783558107e-14*V012*V023*V16 - 
      3.46601472498368371e-14*V013*V02*V03*V16 + 2.33523608623614263e-14*V022*V032*V16 + 
      1.29932671616681692e-14*V01*V033*V16 - 4.68748775381717699e-15*V014*V04*V16 + 
      1.11768285978783729e-14*V023*V04*V16 + 5.80624513869547722e-14*V01*V02*V03*V04*V16 + 
      8.71121518872702109e-15*V012*V042*V16 - 1.48173633369997191e-15*V043*V16 + 
      1.80272518443990767e-14*V01*V022*V05*V16 + 1.44699096506980789e-14*V012*V03*V05*V16 - 
      7.53470138319689829e-15*V03*V04*V05*V16 - 2.33888225786774571e-15*V02*V052*V16 + 
      7.68988728502093659e-15*V012*V02*V06*V16 - 2.68729219974542151e-15*V032*V06*V16 - 
      3.93860068101647773e-15*V02*V04*V06*V16 - 2.08766022701877185e-15*V01*V05*V06*V16 + 
      9.07772277963184829e-16*V013*V07*V16 - 2.47463295113537888e-15*V02*V03*V07*V16 - 
      1.54829491416306644e-15*V01*V04*V07*V16 + 3.52506440279712769e-17*V072*V16 - 
      5.01014294528866397e-16*V022*V08*V16 - 8.53236846546344718e-16*V01*V03*V08*V16 + 
      6.240454743217524e-17*V06*V08*V16 - 3.156394477221918e-16*V01*V02*V09*V16 + 4.36116241436933948e-17*V05*V09*V16 - 
      4.29434515978900819e-17*V012*V10*V16 + 2.3388383619923299e-17*V04*V10*V16 + 9.73176000627811119e-18*V03*V11*V16 + 
      2.75759580693306898e-18*V02*V12*V16 + 6.19540385696577007e-19*V01*V13*V16 - 1.22560005409895832e-21*V162 - 
      3.54065887487692836e-15*V013*V022*V17 - 1.25431424325693012e-15*V014*V03*V17 + 
      3.12264926597876816e-15*V023*V03*V17 + 7.96169411199300016e-15*V01*V02*V032*V17 + 
      5.89494204257381268e-15*V01*V022*V04*V17 + 4.74716351032902813e-15*V012*V03*V04*V17 - 
      1.23153226593784661e-15*V03*V042*V17 + 2.97003002925340257e-15*V012*V02*V05*V17 - 
      1.03964064592687355e-15*V032*V05*V17 - 1.52754193418343273e-15*V02*V04*V05*V17 - 
      4.03562279322023161e-16*V01*V052*V17 + 4.01643093211065336e-16*V013*V06*V17 - 
      1.09260761134365207e-15*V02*V03*V06*V17 - 6.84150055645763339e-16*V01*V04*V06*V17 - 
      2.5032033640942042e-16*V022*V07*V17 - 4.25554475883056777e-16*V01*V03*V07*V17 + 
      3.11196667902625974e-17*V06*V07*V17 - 1.75012383273834693e-16*V01*V02*V08*V17 + 2.4159185201687785e-17*V05*V08*V17 - 
      2.62219825325316861e-17*V012*V09*V17 + 1.4278559705734714e-17*V04*V09*V17 + 6.4815533737061201e-18*V03*V10*V17 + 
      1.99146345200063823e-18*V02*V11*V17 + 4.81791629796880866e-19*V01*V12*V17 - 2.3152075051050582e-21*V15*V17 - 
      2.42162490193019148e-16*V014*V02*V18 + 1.4670770324449289e-16*V024*V18 + 
      1.53762099690310209e-15*V01*V022*V03*V18 + 6.1284301230818924e-16*V012*V032*V18 + 
      9.239002937611888e-16*V012*V02*V04*V18 - 3.22572848122823502e-16*V032*V04*V18 - 
      2.36089450103439826e-16*V02*V042*V18 + 1.46911942629502191e-16*V013*V05*V18 - 
      4.01125331860260334e-16*V02*V03*V05*V18 - 2.50806713794005768e-16*V01*V04*V05*V18 - 
      1.04606890777371107e-16*V022*V06*V18 - 1.78300884312216465e-16*V01*V03*V06*V18 + 
      6.50714792549854279e-18*V062*V18 - 8.27539553722959208e-17*V01*V02*V07*V18 + 
      1.14144549688450281e-17*V05*V07*V18 - 1.37839678366519871e-17*V012*V08*V18 + 7.4937100759948917e-18*V04*V08*V18 + 
      3.74879328932454959e-18*V03*V09*V18 + 1.25645594196578016e-18*V02*V10*V18 + 3.29594241312216024e-19*V01*V11*V18 - 
      1.94947299100812982e-21*V14*V18 - 5.97112989517033514e-18*V015*V19 + 
      9.37137658628366275e-17*V01*V023*V19 + 2.27003699431811308e-16*V012*V02*V03*V19 - 
      2.67371694806188122e-17*V033*V19 + 4.3480351145458898e-17*V013*V04*V19 - 
      1.18178475069742318e-16*V02*V03*V04*V19 - 3.70405889744385934e-17*V01*V042*V19 - 
      3.65935223996267776e-17*V022*V05*V19 - 6.2125464203129441e-17*V01*V03*V05*V19 - 
      3.29524016632877424e-17*V01*V02*V06*V19 + 4.53891264756335866e-18*V05*V06*V19 - 
      6.19250449873418034e-18*V012*V07*V19 + 3.36637831432435269e-18*V04*V07*V19 + 
      1.87063814507913533e-18*V03*V08*V19 + 6.90849857937301987e-19*V02*V09*V19 + 1.97683403839461958e-19*V01*V10*V19 - 
      1.46223631862670367e-21*V13*V19 + 2.00189501500888165e-17*V012*V022*V20 + 
      1.01208194468036288e-17*V013*V03*V20 - 1.40528563165322782e-17*V02*V032*V20 - 
      1.02462635301747167e-17*V022*V04*V20 - 1.75054606249901774e-17*V01*V03*V04*V20 - 
      1.09511681605538666e-17*V01*V02*V05*V20 + 7.53996615682736014e-19*V052*V20 - 
      2.35191390623539539e-18*V012*V06*V20 + 1.27511704452730377e-18*V04*V06*V20 + 
      8.00470284875155506e-19*V03*V07*V20 + 3.28326780032984844e-19*V02*V08*V20 + 1.03517729257272857e-19*V01*V09*V20 - 
      9.74698902541034532e-22*V12*V20 + 1.71239964843490836e-18*V013*V02*V21 - 
      2.34109507402240107e-18*V022*V03*V21 - 1.97385484430938874e-18*V01*V032*V21 - 
      2.94594914843317087e-18*V01*V02*V04*V21 - 7.45591191554791124e-19*V012*V05*V21 + 
      4.04951114988768796e-19*V04*V05*V21 + 2.8982220479256024e-19*V03*V06*V21 + 1.34266934242131858e-19*V02*V07*V21 + 
      4.70147573326374612e-20*V01*V08*V21 - 5.76032488519322351e-22*V11*V21 + 4.99129942368919476e-20*V014*V22 - 
      1.23492199701043522e-19*V023*V22 - 6.37590240169918047e-19*V01*V02*V03*V22 - 
      1.92500113784459261e-19*V012*V04*V22 + 5.20137259166581321e-20*V042*V22 + 
      8.8051234371220301e-20*V03*V05*V22 + 4.64977509863137087e-20*V02*V06*V22 + 1.83881617767533043e-20*V01*V07*V22 - 
      3.00467862949575018e-22*V10*V22 - 4.92336864493997408e-20*V01*V022*V23 - 
      3.96846217357114521e-20*V012*V03*V23 + 2.17294819648278443e-20*V03*V04*V23 + 
      1.35673301992474252e-20*V02*V05*V23 + 6.11575957459354879e-21*V01*V06*V23 - 1.37746898629258761e-22*V09*V23 - 
      5.94574852978650159e-21*V012*V02*V24 + 2.17679999394212364e-21*V032*V24 + 
      3.2116752152228925e-21*V02*V04*V24 + 1.71119930956805183e-21*V01*V05*V24 - 5.50675964654281015e-23*V08*V24 - 
      2.19053893202660585e-22*V013*V25 + 6.21725253912274854e-22*V02*V03*V25 + 3.91377971630329636e-22*V01*V04*V25 - 
      1.90726465974876972e-23*V07*V25 + 4.2554555597075999e-23*V022*V26 + 7.24585525768478091e-23*V01*V03*V26 - 
      5.64076775681756904e-24*V06*V26 + 9.70477597573821967e-24*V01*V02*V27 - 1.41278766418843171e-24*V05*V27 + 
      5.09585669671201733e-25*V012*V28 - 2.89794678813016743e-25*V04*V28 - 4.8715801754281551e-26*V03*V29 - 
      5.88266285334720615e-27*V02*V30 - 5.88266285334720615e-28*V01*V31 + 2.62618877381571703e-31*V34) + 
   delta6*eps14*(-8.32015342418028952e-10*V024*V034 - 
      2.11724308498033162e-9*V01*V022*V035 - 3.05911582708541081e-10*V012*V036 - 
      8.19157705138225126e-10*V025*V032*V04 - 7.70542928434262393e-9*V01*V023*V033*V04 - 
      5.55388176883381934e-9*V012*V02*V034*V04 + 9.6298371278726587e-10*V036*V04 - 
      1.59924972891624396e-12*V026*V042 - 2.69785329635905881e-9*V01*V024*V03*V042 - 
      9.65705266277910662e-9*V012*V022*V032*V042 - 
      1.86779099315830903e-9*V013*V033*V042 + 8.4344831926884187e-9*V02*V034*V042 - 
      1.16562781619410719e-9*V012*V023*V043 - 
      2.28269994638976331e-9*V013*V02*V03*V043 + 
      8.90526339351947119e-9*V022*V032*V043 + 6.5123066868154277e-9*V01*V033*V043 - 
      7.1474939937846266e-11*V014*V044 + 5.34559467656326695e-10*V023*V044 + 
      5.48532480897715314e-9*V01*V02*V03*V044 + 3.27906681230929127e-10*V012*V045 - 
      4.89531412255654985e-11*V046 - 1.22381227003277034e-10*V026*V03*V05 - 
      2.86733794582531083e-9*V01*V024*V032*V05 - 
      5.70358520131174999e-9*V012*V022*V033*V05 - 7.78586177596454e-10*V013*V034*V05 + 
      3.053518435682196e-9*V02*V035*V05 - 4.91494623082935076e-10*V01*V025*V04*V05 - 
      6.49678306595263581e-9*V012*V023*V03*V04*V05 - 
      5.79690044473457506e-9*V013*V02*V032*V04*V05 + 1.73875759571085808e-8*V022*V033*V04*V05 + 
      8.61089052732608373e-9*V01*V034*V04*V05 - 1.75783290165175813e-9*V013*V022*V042*V05 - 
      7.04705635253575317e-10*V014*V03*V042*V05 + 8.73241329269195131e-9*V023*V03*V042*V05 + 
      3.0633383212232089e-8*V01*V02*V032*V042*V05 + 5.47661270008773602e-9*V01*V022*V043*V05 + 
      5.7984001191733118e-9*V012*V03*V043*V05 - 1.51026626450662569e-9*V03*V044*V05 - 
      4.06469572856358249e-10*V012*V024*V052 - 
      1.49435859085345172e-9*V013*V022*V03*V052 - 
      2.87539489444126565e-10*V014*V032*V052 + 
      4.43345850469859358e-9*V023*V032*V052 + 
      9.13214918951396902e-9*V01*V02*V033*V052 - 3.6542288906886477e-10*V014*V02*V04*V052 + 
      1.05423244140616295e-9*V024*V04*V052 + 1.58568590382443009e-8*V01*V022*V03*V04*V052 + 
      7.55671770894991757e-9*V012*V032*V04*V052 + 
      4.56948442395092546e-9*V012*V02*V042*V052 - 
      4.21386872121527481e-9*V032*V042*V052 - 1.56633246665682084e-9*V02*V043*V052 - 
      9.09884805877413447e-12*V015*V053 + 9.02520459430095951e-10*V01*V023*V053 + 
      2.68195107723690257e-9*V012*V02*V03*V053 - 8.41280424248760395e-10*V033*V053 + 
      4.80948056430287934e-10*V013*V04*V053 - 2.98346976433633965e-9*V02*V03*V04*V053 - 
      8.96247088211360041e-10*V01*V042*V053 - 1.95965512603468095e-10*V022*V054 - 
      3.98997057145342891e-10*V01*V03*V054 - 1.47340445523952884e-13*V027*V06 - 
      3.70302177681821182e-10*V01*V025*V03*V06 - 2.19562145837354773e-9*V012*V023*V032*V06 - 
      1.26286456374684072e-9*V013*V02*V033*V06 + 3.06872368489815927e-9*V022*V034*V06 + 
      1.1841377543363892e-9*V01*V035*V06 - 6.03189629275884901e-10*V012*V024*V04*V06 - 
      2.32580083715145089e-9*V013*V022*V03*V04*V06 - 
      4.55082620798095141e-10*V014*V032*V04*V06 + 6.39859656440964322e-9*V023*V032*V04*V06 + 
      1.42384657960401051e-8*V01*V02*V033*V04*V06 - 2.88611817130589129e-10*V014*V02*V042*V06 + 
      5.60658180727541451e-10*V024*V042*V06 + 1.18672664543596253e-8*V01*V022*V03*V042*V06 + 
      5.98618841978655008e-9*V012*V032*V042*V06 + 
      2.37262221792714688e-9*V012*V02*V043*V06 - 2.18016941910450533e-9*V032*V043*V06 - 
      5.4742252515708956e-10*V02*V044*V06 - 3.97766157931225236e-10*V013*V023*V05*V06 - 
      4.72188054049917837e-10*V014*V02*V03*V05*V06 + 1.56133211224686147e-9*V024*V03*V05*V06 + 
      1.11236255929621567e-8*V01*V022*V032*V05*V06 + 3.43963871056325478e-9*V012*V033*V05*V06 - 
      4.34624177838305705e-11*V015*V04*V05*V06 + 3.93239031033223395e-9*V01*V023*V04*V05*V06 + 
      1.26480293431152578e-8*V012*V02*V03*V04*V05*V06 - 3.99728129217981424e-9*V033*V04*V05*V06 + 
      1.15382182516101985e-9*V013*V042*V05*V06 - 6.83614174824678777e-9*V02*V03*V042*V05*V06 - 
      1.39705776018358275e-9*V01*V043*V05*V06 + 1.65585974741705286e-9*V012*V022*V052*V06 + 
      9.77345026815759463e-10*V013*V03*V052*V06 - 3.20018049527841011e-9*V02*V032*V052*V06 - 
      1.7625507571654235e-9*V022*V04*V052*V06 - 3.80478063813273569e-9*V01*V03*V04*V052*V06 - 
      6.78979015982496664e-10*V01*V02*V053*V06 + 3.65390460207461803e-11*V054*V06 - 
      4.82487358591196111e-11*V014*V022*V062 + 3.90849335219632313e-11*V025*V062 - 
      1.38403769637754127e-11*V015*V03*V062 + 1.42198456378276142e-9*V01*V023*V03*V062 + 
      2.17536426814229976e-9*V012*V02*V032*V062 - 3.54037870625610881e-10*V034*V062 + 
      1.28373302769315754e-9*V012*V022*V04*V062 + 
      7.82960012693076212e-10*V013*V03*V04*V062 - 2.47033529239346723e-9*V02*V032*V04*V062 - 
      6.09499663856934701e-10*V022*V042*V062 - 
      1.49626339360855781e-9*V01*V03*V042*V062 + 4.1803772946385311e-10*V013*V02*V05*V062 - 
      1.28402234106888414e-9*V022*V03*V05*V062 - 1.34035217395962297e-9*V01*V032*V05*V062 - 
      1.57948625997445493e-9*V01*V02*V04*V05*V062 - 2.07961589686034497e-10*V012*V052*V062 + 
      1.72433275683269223e-10*V04*V052*V062 + 1.21942783934077286e-11*V014*V063 - 
      5.00551462859277048e-11*V023*V063 - 3.7629814798801733e-10*V01*V02*V03*V063 - 
      1.1071951077972466e-10*V012*V04*V063 + 4.38139750416633071e-11*V042*V063 + 
      8.29596944301915392e-11*V03*V05*V063 + 8.43188324185581378e-12*V02*V064 - 
      1.74830324290395763e-11*V01*V026*V07 - 3.68839980785161181e-10*V012*V024*V03*V07 - 
      6.59677820880118933e-10*V013*V022*V032*V07 - 
      8.33303070125164726e-11*V014*V033*V07 + 1.43236129205164348e-9*V023*V033*V07 + 
      2.18825836000096754e-9*V01*V02*V034*V07 - 2.67646499335294493e-10*V013*V023*V04*V07 - 
      3.19178787036322018e-10*V014*V02*V03*V04*V07 + 1.02780309575801491e-9*V024*V03*V04*V07 + 
      7.63891298875224875e-9*V01*V022*V032*V04*V07 + 2.39893548214145513e-9*V012*V033*V04*V07 - 
      1.46990823419368488e-11*V015*V042*V07 + 1.30804618189801242e-9*V01*V023*V042*V07 + 
      4.37411033993293148e-9*V012*V02*V03*V042*V07 - 1.40830078635613781e-9*V033*V042*V07 + 
      2.67912552508281749e-10*V013*V043*V07 - 1.57904249656825271e-9*V02*V03*V043*V07 - 
      2.43785154510998599e-10*V01*V044*V07 - 8.25155772660236486e-11*V014*V022*V05*V07 + 
      9.78508454070073443e-11*V025*V05*V07 - 2.35084908283334384e-11*V015*V03*V05*V07 + 
      2.61226675673886858e-9*V01*V023*V03*V05*V07 + 3.83177070795624565e-9*V012*V02*V032*V05*V07 - 
      6.3052033665142199e-10*V034*V05*V07 + 2.2795109966941677e-9*V012*V022*V04*V05*V07 + 
      1.36473406731407332e-9*V013*V03*V04*V05*V07 - 4.489182616410458e-9*V02*V032*V04*V05*V07 - 
      1.21175855012191686e-9*V022*V042*V05*V07 - 2.68180962889802918e-9*V01*V03*V042*V05*V07 + 
      3.6495612292729525e-10*V013*V02*V052*V07 - 1.18027750325800679e-9*V022*V03*V052*V07 - 
      1.18962255218809513e-9*V01*V032*V052*V07 - 1.42928607342580737e-9*V01*V02*V04*V052*V07 - 
      1.22519470219770893e-10*V012*V053*V07 + 1.03812989113159181e-10*V04*V053*V07 - 
      9.69634165766874122e-12*V015*V02*V06*V07 + 2.33575748090318714e-10*V01*V024*V06*V07 + 
      1.58202650684110599e-9*V012*V022*V03*V06*V07 + 
      4.61026981774190815e-10*V013*V032*V06*V07 - 1.06751879551738663e-9*V02*V033*V06*V07 + 
      5.81558858097368372e-10*V013*V02*V04*V06*V07 - 1.77389687667270808e-9*V022*V03*V04*V06*V07 - 
      1.89289007494186778e-9*V01*V032*V04*V06*V07 - 1.09922959688127401e-9*V01*V02*V042*V06*V07 + 
      6.33714467512239683e-11*V014*V05*V06*V07 - 3.00828747360725263e-10*V023*V05*V06*V07 - 
      2.02791438875600594e-9*V01*V02*V03*V05*V06*V07 - 5.87891611674672945e-10*V012*V04*V05*V06*V07 + 
      2.4357244229151041e-10*V042*V05*V06*V07 + 2.23674852550563371e-10*V03*V052*V06*V07 - 
      2.05721774862888094e-10*V01*V022*V062*V07 - 2.05255849291287754e-10*V012*V03*V062*V07 + 
      1.76261044541209263e-10*V03*V04*V062*V07 + 9.40884660210022894e-11*V02*V05*V062*V07 + 
      1.39018875448643975e-11*V01*V063*V07 - 1.88898988010272609e-13*V016*V072 + 
      9.38269588738328835e-11*V012*V023*V072 + 
      1.72043753398166522e-10*V013*V02*V03*V072 - 
      2.9544417182527478e-10*V022*V032*V072 - 1.96550520038186716e-10*V01*V033*V072 + 
      2.21353706296834719e-11*V014*V04*V072 - 1.02517145320025389e-10*V023*V04*V072 - 
      7.11430734324582835e-10*V01*V02*V03*V04*V072 - 1.0367976264914572e-10*V012*V042*V072 + 
      2.85949749454976931e-11*V043*V072 - 1.87828912833007642e-10*V01*V022*V05*V072 - 
      1.81127031493012437e-10*V012*V03*V05*V072 + 1.58909391977224353e-10*V03*V04*V05*V072 + 
      4.27588833998982113e-11*V02*V052*V072 - 7.80655239214054788e-11*V012*V02*V06*V072 + 
      5.69577625785001465e-11*V032*V06*V072 + 6.61041563016771666e-11*V02*V04*V06*V072 + 
      3.73098189878003124e-11*V01*V05*V06*V072 - 2.9602778999335474e-12*V013*V073 + 
      1.45327372258427226e-11*V02*V03*V073 + 8.8411699505942318e-12*V01*V04*V073 - 
      1.26372510578192128e-13*V074 - 2.10229684964006062e-11*V012*V025*V08 - 
      1.30882206749876053e-10*V013*V023*V03*V08 - 7.53629998331817383e-11*V014*V02*V032*V08 + 
      3.00010161706711719e-10*V024*V032*V08 + 1.36600153274204957e-9*V01*V022*V033*V08 + 
      3.10407276073932767e-10*V012*V034*V08 - 4.78965048060465445e-11*V014*V022*V04*V08 + 
      4.01058668601465163e-11*V025*V04*V08 - 1.36664544785235357e-11*V015*V03*V04*V08 + 
      1.49187510842063131e-9*V01*V023*V03*V04*V08 + 2.29969296169399012e-9*V012*V02*V032*V04*V08 - 
      3.87034282750867067e-10*V034*V04*V08 + 6.74587710300224765e-10*V012*V022*V042*V08 + 
      4.13867535389967103e-10*V013*V03*V042*V08 - 1.34278865288730075e-9*V02*V032*V042*V08 - 
      2.18459457971559982e-10*V022*V043*V08 - 5.42870752568953756e-10*V01*V03*V043*V08 - 
      7.07812015009132589e-12*V015*V02*V05*V08 + 1.84148468342776953e-10*V01*V024*V05*V08 + 
      1.20884141758490856e-9*V012*V022*V03*V05*V08 + 
      3.49237003115309271e-10*V013*V032*V05*V08 - 8.28171655355514213e-10*V02*V033*V05*V08 + 
      4.4122934138201324e-10*V013*V02*V04*V05*V08 - 1.39163455753414705e-9*V022*V03*V04*V05*V08 - 
      1.4625872847134165e-9*V01*V032*V04*V05*V08 - 8.57114981131655334e-10*V01*V02*V042*V05*V08 + 
      2.39177753949639783e-11*V014*V052*V08 - 1.18573676459565813e-10*V023*V052*V08 - 
      7.84900256176407871e-10*V01*V02*V03*V052*V08 - 2.2653956813570574e-10*V012*V04*V052*V08 + 
      9.5203068615781162e-11*V042*V052*V08 + 5.79919855076131287e-11*V03*V053*V08 - 
      3.24779923160537811e-13*V016*V06*V08 + 1.61494307180309753e-10*V012*V023*V06*V08 + 
      2.98999234095668125e-10*V013*V02*V03*V06*V08 - 5.03938797106364988e-10*V022*V032*V06*V08 - 
      3.42167600002039601e-10*V01*V033*V06*V08 + 3.85784460710903852e-11*V014*V04*V06*V08 - 
      1.61077762228514547e-10*V023*V04*V06*V08 - 1.2259803463196608e-9*V01*V02*V03*V04*V06*V08 - 
      1.80572067110027055e-10*V012*V042*V06*V08 + 4.82332500565930374e-11*V043*V06*V08 - 
      3.21037308189571779e-10*V01*V022*V05*V06*V08 - 3.15905630074533532e-10*V012*V03*V05*V06*V08 + 
      2.7501133327307974e-10*V03*V04*V05*V06*V08 + 7.36065983052636213e-11*V02*V052*V06*V08 - 
      6.78724029344586626e-11*V012*V02*V062*V08 + 4.94285002890076159e-11*V032*V062*V08 + 
      5.55895323191419275e-11*V02*V04*V062*V08 + 3.24238276574317523e-11*V01*V05*V062*V08 + 
      5.514961123044643e-11*V013*V022*V07*V08 + 2.22912908178727765e-11*V014*V03*V07*V08 - 
      1.19010319948558551e-10*V023*V03*V07*V08 - 3.89256657580986852e-10*V01*V02*V032*V07*V08 - 
      2.22355335279242774e-10*V01*V022*V04*V07*V08 - 2.23307067084848263e-10*V012*V03*V04*V07*V08 + 
      9.72794897146081488e-11*V03*V042*V07*V08 - 1.20394999331909025e-10*V012*V02*V05*V07*V08 + 
      8.85506445706559402e-11*V032*V05*V07*V08 + 1.03595086227576061e-10*V02*V04*V05*V07*V08 + 
      2.89559939217861235e-11*V01*V052*V07*V08 - 1.55351783071885047e-11*V013*V06*V07*V08 + 
      7.51322995046263265e-11*V02*V03*V06*V07*V08 + 4.60131356136135814e-11*V01*V04*V06*V07*V08 + 
      6.96193972104700525e-12*V022*V072*V08 + 1.46437013955856789e-11*V01*V03*V072*V08 - 
      1.3165099877254469e-12*V06*V072*V08 + 3.63831230460733499e-12*V014*V02*V082 - 
      3.94953402259852642e-12*V024*V082 - 6.21735259790573181e-11*V01*V022*V03*V082 - 
      2.98363388710362537e-11*V012*V032*V082 - 
      3.6765731415077869e-11*V012*V02*V04*V082 + 2.73058429810500246e-11*V032*V04*V082 + 
      1.52558980333851337e-11*V02*V042*V082 - 5.9507687582559531e-12*V013*V05*V082 + 
      2.93358740920728826e-11*V02*V03*V05*V082 + 1.78911208473378139e-11*V01*V04*V05*V082 + 
      5.82606898512348327e-12*V022*V06*V082 + 1.27507077236464561e-11*V01*V03*V06*V082 - 
      5.67589452725691675e-13*V062*V082 + 4.8846827928932932e-12*V01*V02*V07*V082 - 
      1.02758803415193914e-12*V05*V07*V082 + 2.65340878684030331e-13*V012*V083 - 
      2.10338866998975164e-13*V04*V083 - 8.48762298300538304e-12*V013*V024*V09 - 
      1.9846865939408707e-11*V014*V022*V03*V09 + 2.84103983691439563e-11*V025*V03*V09 - 
      2.77691825535682864e-12*V015*V032*V09 + 3.72381232471893169e-10*V01*V023*V032*V09 + 
      3.57837109012679555e-10*V012*V02*V033*V09 - 3.81326651189862155e-11*V035*V09 - 
      3.60684070731503447e-12*V015*V02*V04*V09 + 9.1593307775013791e-11*V01*V024*V04*V09 + 
      6.43704708010518865e-10*V012*V022*V03*V04*V09 + 
      1.89335479510606006e-10*V013*V032*V04*V09 - 4.54822425173694461e-10*V02*V033*V04*V09 + 
      1.18881777747141284e-10*V013*V02*V042*V09 - 3.71689468020132513e-10*V022*V03*V042*V09 - 
      4.04278277598348634e-10*V01*V032*V042*V09 - 1.54403087844636014e-10*V01*V02*V043*V09 - 
      2.07166173691368077e-13*V016*V05*V09 + 1.10899918339645791e-10*V012*V023*V05*V09 + 
      2.02391144234794846e-10*V013*V02*V03*V05*V09 - 3.59034799063028441e-10*V022*V032*V05*V09 - 
      2.37947465706292278e-10*V01*V033*V05*V09 + 2.5967789916085854e-11*V014*V04*V05*V09 - 
      1.25046099278942728e-10*V023*V04*V05*V09 - 8.62457935137179026e-10*V01*V02*V03*V04*V05*V09 - 
      1.25376454935834444e-10*V012*V042*V05*V09 + 3.50973920415609974e-11*V043*V05*V09 - 
      1.13867116707112431e-10*V01*V022*V052*V09 - 1.09370551750652791e-10*V012*V03*V052*V09 + 
      9.73298308527312395e-11*V03*V04*V052*V09 + 1.74667521345442292e-11*V02*V053*V09 + 
      4.27295472498268405e-11*V013*V022*V06*V09 + 1.73227024526062263e-11*V014*V03*V06*V09 - 
      9.20443884007525805e-11*V023*V03*V06*V09 - 3.04789431245533712e-10*V01*V02*V032*V06*V09 - 
      1.72693300674054576e-10*V01*V022*V04*V06*V09 - 1.7519578649987044e-10*V012*V03*V04*V06*V09 + 
      7.63612318068586077e-11*V03*V042*V06*V09 - 9.42925452258353974e-11*V012*V02*V05*V06*V09 + 
      6.97250901733927008e-11*V032*V05*V06*V09 + 8.111704156176555e-11*V02*V04*V05*V06*V09 + 
      2.2802221340919515e-11*V01*V052*V06*V09 - 6.09877568622785849e-12*V013*V062*V09 + 
      2.94587232792321559e-11*V02*V03*V062*V09 + 1.80837814157748901e-11*V01*V04*V062*V09 + 
      6.48744869235813658e-12*V014*V02*V07*V09 - 7.8001449522192033e-12*V024*V07*V09 - 
      1.13016232130811736e-10*V01*V022*V03*V07*V09 - 5.36893313847327605e-11*V012*V032*V07*V09 - 
      6.62328336291145773e-11*V012*V02*V04*V07*V09 + 4.95531302316974781e-11*V032*V04*V07*V09 + 
      2.84159483246991332e-11*V02*V042*V07*V09 - 1.06839139635737447e-11*V013*V05*V07*V09 + 
      5.33996487135655372e-11*V02*V03*V05*V07*V09 + 3.24246085644806755e-11*V01*V04*V05*V07*V09 + 
      1.08733117394741404e-11*V022*V06*V07*V09 + 2.30655167393284781e-11*V01*V03*V06*V07*V09 - 
      1.03700514599982709e-12*V062*V07*V09 + 4.43566396945122759e-12*V01*V02*V072*V09 - 
      9.32408334544763487e-13*V05*V072*V09 + 3.14747553728024968e-13*V015*V08*V09 - 
      1.15013688933241805e-11*V01*V023*V08*V09 - 3.56941924212692767e-11*V012*V02*V03*V08*V09 + 
      9.17300214756597892e-12*V033*V08*V09 - 6.61078659254364218e-12*V013*V04*V08*V09 + 
      3.24192546422852223e-11*V02*V03*V04*V08*V09 + 9.96379650600361263e-12*V01*V042*V08*V09 + 
      8.54029794496392809e-12*V022*V05*V08*V09 + 1.78846376636052594e-11*V01*V03*V05*V08*V09 + 
      7.66838160285995907e-12*V01*V02*V06*V08*V09 - 1.61960622094948286e-12*V05*V06*V08*V09 + 
      1.43503348408061552e-12*V012*V07*V08*V09 - 1.15349012291992498e-12*V04*V07*V08*V09 - 
      3.2550344839517765e-13*V03*V082*V09 - 2.60938158151527931e-12*V012*V022*V092 - 
      1.56009811933554127e-12*V013*V03*V092 + 4.15489846970911675e-12*V02*V032*V092 + 
      2.32265408375899485e-12*V022*V04*V092 + 5.00867737808661592e-12*V01*V03*V04*V092 + 
      2.70986708693682348e-12*V01*V02*V05*V092 - 2.866453629624902e-13*V052*V092 + 
      5.65299384997528901e-13*V012*V06*V092 - 4.54020205653222841e-13*V04*V06*V092 - 
      2.95122478077263041e-13*V03*V07*V092 - 9.87725421855319084e-14*V02*V08*V092 - 
      1.03614669352823788e-14*V01*V093 - 1.54536433747192125e-12*V014*V023*V10 + 
      7.25630283759792069e-13*V026*V10 - 1.30525602318851782e-12*V015*V02*V03*V10 + 
      4.34095173393192931e-11*V01*V024*V03*V10 + 1.3685882791543484e-10*V012*V022*V032*V10 + 
      2.59060063486902184e-11*V013*V033*V10 - 5.11001304354679493e-11*V02*V034*V10 - 
      9.40358465861357076e-14*V016*V04*V10 + 5.26825103396069606e-11*V012*V023*V04*V10 + 
      9.84807940139763497e-11*V013*V02*V03*V04*V10 - 1.73923058702527204e-10*V022*V032*V04*V10 - 
      1.19178487833842661e-10*V01*V033*V04*V10 + 6.34974785100963528e-12*V014*V042*V10 - 
      2.72927753859271045e-11*V023*V042*V10 - 2.11962638557333192e-10*V01*V02*V03*V042*V10 - 
      2.08513142527456244e-11*V012*V043*V10 + 4.25565738951617622e-12*V044*V10 + 
      2.6110633666915766e-11*V013*V022*V05*V10 + 1.05102958546482523e-11*V014*V03*V05*V10 - 
      5.9485068717523268e-11*V023*V03*V05*V10 - 1.92051038958365786e-10*V01*V02*V032*V05*V10 - 
      1.10511008023067177e-10*V01*V022*V04*V05*V10 - 1.09724967623305569e-10*V012*V03*V04*V05*V10 + 
      4.88099898097685738e-11*V03*V042*V05*V10 - 2.95898749907054319e-11*V012*V02*V052*V10 + 
      2.21382370551517812e-11*V032*V052*V10 + 2.60375217715568692e-11*V02*V04*V052*V10 + 
      4.81625025079166151e-12*V01*V053*V10 + 4.54347917326414687e-12*V014*V02*V06*V10 - 
      4.99177019196053289e-12*V024*V06*V10 - 7.91973612577035638e-11*V01*V022*V03*V06*V10 - 
      3.81011201753733225e-11*V012*V032*V06*V10 - 4.6864500707407465e-11*V012*V02*V04*V06*V10 + 
      3.51222135717826538e-11*V032*V04*V06*V10 + 1.95647458455257324e-11*V02*V042*V06*V10 - 
      7.59147080469421844e-12*V013*V05*V06*V10 + 3.76969247413413667e-11*V02*V03*V05*V06*V10 + 
      2.30023914425805128e-11*V01*V04*V05*V06*V10 + 3.73252575393207049e-12*V022*V062*V10 + 
      8.19855692376075746e-12*V01*V03*V062*V10 - 2.43934467049015238e-13*V063*V10 + 
      2.52927278016377295e-13*V015*V07*V10 - 9.4332529356871184e-12*V01*V023*V07*V10 - 
      2.90507679258322037e-11*V012*V02*V03*V07*V10 + 7.49351246502037664e-12*V033*V07*V10 - 
      5.37053611944255835e-12*V013*V04*V07*V10 + 2.65620512300850442e-11*V02*V03*V04*V07*V10 + 
      8.14873912270096069e-12*V01*V042*V07*V10 + 7.00808909131617202e-12*V022*V05*V07*V10 + 
      1.46020081385438842e-11*V01*V03*V05*V07*V10 + 6.27303788786293705e-12*V01*V02*V06*V07*V10 - 
      1.32560874372118266e-12*V05*V06*V07*V10 + 5.85242835023923204e-13*V012*V072*V10 - 
      4.72268458664782379e-13*V04*V072*V10 - 4.71717403102040681e-12*V012*V022*V08*V10 - 
      2.82382715169386532e-12*V013*V03*V08*V10 + 7.48018599152590612e-12*V02*V032*V08*V10 + 
      4.08348703487909338e-12*V022*V04*V08*V10 + 9.04230877007358148e-12*V01*V03*V04*V08*V10 + 
      4.88265395574772284e-12*V01*V02*V05*V08*V10 - 5.17120607864792727e-13*V052*V08*V10 + 
      1.02308731417616447e-12*V012*V06*V08*V10 - 8.13492125551739491e-13*V04*V06*V08*V10 - 
      5.32608464218933859e-13*V03*V07*V08*V10 - 8.83893975780198588e-14*V02*V082*V10 - 
      8.49726507143725107e-13*V013*V02*V09*V10 + 2.18830391631438086e-12*V022*V03*V09*V10 + 
      2.24642601741130047e-12*V01*V032*V09*V10 + 2.70427782905710515e-12*V01*V02*V04*V09*V10 + 
      7.12788062625213913e-13*V012*V05*V09*V10 - 5.81133324099848111e-13*V04*V05*V09*V10 - 
      4.19978675578574934e-13*V03*V06*V09*V10 - 1.61887799312321104e-13*V02*V07*V09*V10 - 
      5.61595448733834409e-14*V01*V08*V09*V10 - 2.37524232873425737e-14*V014*V102 + 
      8.99905761124128684e-14*V023*V102 + 6.1535586983241998e-13*V01*V02*V03*V102 + 
      1.80889058786967289e-13*V012*V04*V102 - 7.28135964042001702e-14*V042*V102 - 
      1.3392285513530849e-13*V03*V05*V102 - 5.69381285468925113e-14*V02*V06*V102 - 
      2.29557254220012332e-14*V01*V07*V102 + 1.43506047097641425e-16*V103 - 
      1.37847722133020073e-13*V015*V022*V11 + 1.68379714504151575e-12*V01*V025*V11 - 
      3.02971512014339672e-14*V016*V03*V11 + 2.06918923229071042e-11*V012*V023*V03*V11 + 
      1.845748187166695e-11*V013*V02*V032*V11 - 2.44440903289178255e-11*V022*V033*V11 - 
      1.19671972848778848e-11*V01*V034*V11 + 1.15083106263620668e-11*V013*V022*V04*V11 + 
      4.67994128133224487e-12*V014*V03*V04*V11 - 2.58459249558461647e-11*V023*V03*V04*V11 - 
      8.72518063915747762e-11*V01*V02*V032*V04*V11 - 2.43656319652395856e-11*V01*V022*V042*V11 - 
      2.51186188414745317e-11*V012*V03*V042*V11 + 7.45962530989848901e-12*V03*V043*V11 + 
      2.50933418377857534e-12*V014*V02*V05*V11 - 3.21649242515098511e-12*V024*V05*V11 - 
      4.61276025600333392e-11*V01*V022*V03*V05*V11 - 2.17942675877964421e-11*V012*V032*V05*V11 - 
      2.6929592856065608e-11*V012*V02*V04*V05*V11 + 2.05455473337279646e-11*V032*V04*V05*V11 + 
      1.1826380282745755e-11*V02*V042*V05*V11 - 2.16021604097279529e-12*V013*V052*V11 + 
      1.10762463340369294e-11*V02*V03*V052*V11 + 6.70825915793639029e-12*V01*V04*V052*V11 + 
      1.61368630913238755e-13*V015*V06*V11 - 6.00752235069989199e-12*V01*V023*V06*V11 - 
      1.88208005806170059e-11*V012*V02*V03*V06*V11 + 4.89232170677109749e-12*V033*V06*V11 - 
      3.48911481500958038e-12*V013*V04*V06*V11 + 1.72162777585287684e-11*V02*V03*V04*V06*V11 + 
      5.30065929373243452e-12*V01*V042*V06*V11 + 4.52394656869599049e-12*V022*V05*V06*V11 + 
      9.53465441140879132e-12*V01*V03*V05*V06*V11 + 2.03751473313081541e-12*V01*V02*V062*V11 - 
      4.32878279839122479e-13*V05*V062*V11 - 3.51417351711703072e-12*V012*V022*V07*V11 - 
      2.09766234996808952e-12*V013*V03*V07*V11 + 5.62888847903842922e-12*V02*V032*V07*V11 + 
      3.15112260725025646e-12*V022*V04*V07*V11 + 6.78094733593032572e-12*V01*V03*V04*V07*V11 + 
      3.66934283241947446e-12*V01*V02*V05*V07*V11 - 3.88889344585165452e-13*V052*V07*V11 + 
      7.64671886857996802e-13*V012*V06*V07*V11 - 6.16208368436009052e-13*V04*V06*V07*V11 - 
      2.00186831192065515e-13*V03*V072*V11 - 7.03223208112923519e-13*V013*V02*V08*V11 + 
      1.80877508167721627e-12*V022*V03*V08*V11 + 1.86249505227206541e-12*V01*V032*V08*V11 + 
      2.23803609131536266e-12*V01*V02*V04*V08*V11 + 5.91050496607637513e-13*V012*V05*V08*V11 - 
      4.81607661273965398e-13*V04*V05*V08*V11 - 3.48202371943654372e-13*V03*V06*V08*V11 - 
      1.34080996978381659e-13*V02*V07*V08*V11 - 2.32909230220011209e-14*V01*V082*V11 - 
      4.3433376990719597e-14*V014*V09*V11 + 1.69330393645160312e-13*V023*V09*V11 + 
      1.13035657281723475e-12*V01*V02*V03*V09*V11 + 3.31496010218353562e-13*V012*V04*V09*V11 - 
      1.34717466508751426e-13*V042*V09*V11 - 2.46100983953090081e-13*V03*V05*V09*V11 - 
      1.05396986756822345e-13*V02*V06*V09*V11 - 4.21561306154730185e-14*V01*V07*V09*V11 + 
      1.50090753937566421e-13*V01*V022*V10*V11 + 1.46644922431072565e-13*V012*V03*V10*V11 - 
      1.24972127399501802e-13*V03*V04*V10*V11 - 6.76186037045483997e-14*V02*V05*V10*V11 - 
      3.00493655034805177e-14*V01*V06*V10*V11 + 7.9251927564098066e-16*V09*V10*V11 + 
      1.85605315826105034e-14*V012*V02*V112 - 1.31784523389298518e-14*V032*V112 - 
      1.55794916936443733e-14*V02*V04*V112 - 8.7716404664567717e-15*V01*V05*V112 + 
      3.28727396942486467e-16*V08*V112 - 5.82637523104499369e-15*V016*V02*V12 + 
      1.04732702922069182e-12*V012*V024*V12 + 3.97615288426946544e-12*V013*V022*V03*V12 + 
      7.88082027711031486e-13*V014*V032*V12 - 5.16167172373382652e-12*V023*V032*V12 - 
      1.08604533070103991e-11*V01*V02*V033*V12 + 1.02192423426148027e-12*V014*V02*V04*V12 - 
      1.16513864879198838e-12*V024*V04*V12 - 1.89733006247250378e-11*V01*V022*V03*V04*V12 - 
      9.21158987806466552e-12*V012*V032*V04*V12 - 5.62665536613985914e-12*V012*V02*V042*V12 + 
      4.36524854377817445e-12*V032*V042*V12 + 1.60255930289034054e-12*V02*V043*V12 + 
      8.13715558924216906e-14*V015*V05*V12 - 3.2643678452413666e-12*V01*V023*V05*V12 - 
      9.93863354729698327e-12*V012*V02*V03*V05*V12 + 2.62300618926190241e-12*V033*V05*V12 - 
      1.8292923424959431e-12*V013*V04*V05*V12 + 9.33482111280366048e-12*V02*V03*V04*V05*V12 + 
      2.8535554316638353e-12*V01*V042*V05*V12 + 1.23335437010111376e-12*V022*V052*V12 + 
      2.5495932398596449e-12*V01*V03*V052*V12 - 2.09169080789037623e-12*V012*V022*V06*V12 - 
      1.25550315890929866e-12*V013*V03*V06*V12 + 3.36593435737033555e-12*V02*V032*V06*V12 + 
      1.82835044839905631e-12*V022*V04*V06*V12 + 4.07152949678493545e-12*V01*V03*V04*V06*V12 + 
      2.1955867941673983e-12*V01*V02*V05*V06*V12 - 2.33960565663935452e-13*V052*V06*V12 + 
      2.30245169915089434e-13*V012*V062*V12 - 1.83793520536424018e-13*V04*V062*V12 - 
      4.81236835504366666e-13*V013*V02*V07*V12 + 1.25577394265796751e-12*V022*V03*V07*V12 + 
      1.2845555172013499e-12*V01*V032*V07*V12 + 1.54917121937486594e-12*V01*V02*V04*V07*V12 + 
      4.07213029807199502e-13*V012*V05*V07*V12 - 3.33619100593907952e-13*V04*V05*V07*V12 - 
      2.40995989829745801e-13*V03*V06*V07*V12 - 4.64950943931994232e-14*V02*V072*V12 - 
      3.31182417783872789e-14*V014*V08*V12 + 1.25786412800529717e-13*V023*V08*V12 + 
      8.61822549653148764e-13*V01*V02*V03*V08*V12 + 2.53386819787624516e-13*V012*V04*V08*V12 - 
      1.02083518935705982e-13*V042*V08*V12 - 1.87864352003092055e-13*V03*V05*V08*V12 - 
      7.98144224382503049e-14*V02*V06*V08*V12 - 3.22018952646712026e-14*V01*V07*V08*V12 + 
      1.26993337372687213e-13*V01*V022*V09*V12 + 1.23861955251808266e-13*V012*V03*V09*V12 - 
      1.05720073540389667e-13*V03*V04*V09*V12 - 5.7224900050783803e-14*V02*V05*V09*V12 - 
      2.54097255257437132e-14*V01*V06*V09*V12 + 3.35208941296306604e-16*V092*V12 + 
      3.42212267296614045e-14*V012*V02*V10*V12 - 2.42671974446375042e-14*V032*V10*V12 - 
      2.84884974150475012e-14*V02*V04*V10*V12 - 1.61565818585932061e-14*V01*V05*V10*V12 + 6.04240252759949806e-16*V08*V10*V12 + 
      2.58551977427104172e-15*V013*V11*V12 - 1.22992454425403757e-14*V02*V03*V11*V12 - 
      7.55625899100647398e-15*V01*V04*V11*V12 + 4.55335612893363992e-16*V07*V11*V12 - 
      6.89747051264105742e-16*V022*V122 - 1.45090058834723612e-15*V01*V03*V122 + 
      1.37085799083286092e-16*V06*V122 - 9.24821465245237093e-17*V017*V13 + 
      2.60578165159835447e-13*V013*V023*V13 + 3.17963337078302408e-13*V014*V02*V03*V13 - 
      4.77800781565166162e-13*V024*V03*V13 - 3.34388319605345064e-12*V01*V022*V032*V13 - 
      1.03603730347326109e-12*V012*V033*V13 + 3.0654949882806744e-14*V015*V04*V13 - 
      1.21159018479542232e-12*V01*V023*V04*V13 - 3.86209993280997433e-12*V012*V02*V03*V04*V13 + 
      1.04191462567493522e-12*V033*V04*V13 - 3.58361378981513893e-13*V013*V042*V13 + 
      1.81564374639624286e-12*V02*V03*V042*V13 + 3.73798078238867192e-13*V01*V043*V13 - 
      1.02691863957438542e-12*V012*V022*V05*V13 - 6.09390950360706178e-13*V013*V03*V05*V13 + 
      1.68706092122393977e-12*V02*V032*V05*V13 + 9.48983850078562156e-13*V022*V04*V05*V13 + 
      2.0264722085893103e-12*V01*V03*V04*V05*V13 + 5.48517826400506288e-13*V01*V02*V052*V13 - 
      3.91248725313365473e-14*V053*V13 - 2.66612603897272553e-13*V013*V02*V06*V13 + 
      6.93383968289223664e-13*V022*V03*V06*V13 + 7.17786610691465074e-13*V01*V032*V06*V13 + 
      8.59381992860797012e-13*V01*V02*V04*V06*V13 + 2.27632213110118339e-13*V012*V05*V06*V13 - 
      1.86250839058502067e-13*V04*V05*V06*V13 - 6.73795893281557204e-14*V03*V062*V13 - 
      2.09751107564224693e-14*V014*V07*V13 + 8.31420932391716135e-14*V023*V07*V13 + 
      5.5312642064515117e-13*V01*V02*V03*V07*V13 + 1.62040455140388567e-13*V012*V04*V07*V13 - 
      6.6178290674209231e-14*V042*V07*V13 - 1.20797232629923972e-13*V03*V05*V07*V13 - 
      5.17804614778565818e-14*V02*V06*V07*V13 - 1.03408185645793428e-14*V01*V072*V13 + 
      8.97528511765013126e-14*V01*V022*V08*V13 + 8.78823277907466085e-14*V012*V03*V08*V13 - 
      7.49686827254392391e-14*V03*V04*V08*V13 - 4.05373201868271965e-14*V02*V05*V08*V13 - 
      1.80323462540913194e-14*V01*V06*V08*V13 + 2.68258875899958404e-14*V012*V02*V09*V13 - 
      1.9071138839121566e-14*V032*V09*V13 - 2.25526845071554999e-14*V02*V04*V09*V13 - 
      1.26922850063897747e-14*V01*V05*V09*V13 + 4.75835455000521904e-16*V08*V09*V13 + 
      2.21233974464166828e-15*V013*V10*V13 - 1.05190426827044109e-14*V02*V03*V10*V13 - 
      6.46483096808337e-15*V01*V04*V10*V13 + 3.89571642889259411e-16*V07*V10*V13 - 
      1.29051590656790515e-15*V022*V11*V13 - 2.69556963585564923e-15*V01*V03*V11*V13 + 
      2.5523251875757844e-16*V06*V11*V13 - 6.33437189403493964e-16*V01*V02*V12*V13 + 1.38112879285232511e-16*V05*V12*V13 - 
      3.33527515519282995e-17*V012*V132 + 2.77251894263133455e-17*V04*V132 + 
      2.95400038888005839e-14*V014*V022*V14 - 1.43873376014239041e-14*V025*V14 + 
      8.69734273619759927e-15*V015*V03*V14 - 4.11590972668499578e-13*V01*V023*V03*V14 - 
      6.11685732092793155e-13*V012*V02*V032*V14 + 8.60612907262662216e-14*V034*V14 - 
      3.68139742461944747e-13*V012*V022*V04*V14 - 2.22629469854591973e-13*V013*V03*V04*V14 + 
      6.17215740170933123e-13*V02*V032*V04*V14 + 1.65307659902080393e-13*V022*V042*V14 + 
      3.73970727042726051e-13*V01*V03*V042*V14 - 1.20652300418343692e-13*V013*V02*V05*V14 + 
      3.26883366415926232e-13*V022*V03*V05*V14 + 3.32044291411178233e-13*V01*V032*V05*V14 + 
      4.0172802289747456e-13*V01*V02*V04*V05*V14 + 5.24727123989222249e-14*V012*V052*V14 - 
      4.36772178397308151e-14*V04*V052*V14 - 1.08410119781273197e-14*V014*V06*V14 + 
      4.15858890320888596e-14*V023*V06*V14 + 2.87096444645283407e-13*V01*V02*V03*V06*V14 + 
      8.44696603230167697e-14*V012*V04*V06*V14 - 3.41831011350792818e-14*V042*V06*V14 - 
      6.30415533547619729e-14*V03*V05*V06*V14 - 1.33528382402518002e-14*V02*V062*V14 + 
      5.38956054471582591e-14*V01*V022*V07*V14 + 5.24125839801174751e-14*V012*V03*V07*V14 - 
      4.49875998593182483e-14*V03*V04*V07*V14 - 2.43637951046842941e-14*V02*V05*V07*V14 - 
      1.08031346059583299e-14*V01*V06*V07*V14 + 1.77505144736133772e-14*V012*V02*V08*V14 - 
      1.262148395900715e-14*V032*V08*V14 - 1.47966529198985403e-14*V02*V04*V08*V14 - 
      8.40231513776769433e-15*V01*V05*V08*V14 + 1.57175898185139978e-16*V082*V14 + 
      1.61707121396321771e-15*V013*V09*V14 - 7.71430638322918211e-15*V02*V03*V09*V14 - 
      4.73731799904372399e-15*V01*V04*V09*V14 + 2.85558250407388671e-16*V07*V09*V14 - 
      1.02216732961986447e-15*V022*V10*V14 - 2.15143396801277877e-15*V01*V03*V10*V14 + 
      2.03252766349266923e-16*V06*V10*V14 - 5.48894122586467302e-16*V01*V02*V11*V14 + 1.19674316074995024e-16*V05*V11*V14 - 
      6.22397542526050703e-17*V012*V12*V14 + 5.16112250205437219e-17*V04*V12*V14 + 
      1.88403032066421671e-17*V03*V13*V14 + 1.92207904754363046e-18*V02*V142 + 
      1.51288728825443677e-15*V015*V02*V15 - 1.67655108884821934e-14*V01*V024*V15 - 
      1.10381948706260912e-13*V012*V022*V03*V15 - 3.2187969908876453e-14*V013*V032*V15 + 
      6.46233667908438993e-14*V02*V033*V15 - 4.10385504239681589e-14*V013*V02*V04*V15 + 
      1.10163362647982516e-13*V022*V03*V04*V15 + 1.15429344361567066e-13*V01*V032*V04*V15 + 
      6.84841243168660194e-14*V01*V02*V042*V15 - 4.56268600111108784e-15*V014*V05*V15 + 
      1.89721244798387192e-14*V023*V05*V15 + 1.25088962935420377e-13*V01*V02*V03*V05*V15 + 
      3.65219343344244953e-14*V012*V04*V05*V15 - 1.51700810207372437e-14*V042*V05*V15 - 
      1.38122939221805155e-14*V03*V052*V15 + 2.60479849401700531e-14*V01*V022*V06*V15 + 
      2.56243728863461108e-14*V012*V03*V06*V15 - 2.19852365390114915e-14*V03*V04*V06*V15 - 
      1.18695177131191276e-14*V02*V05*V06*V15 - 2.64486028149618833e-15*V01*V062*V15 + 
      9.92701968857377658e-15*V012*V02*V07*V15 - 7.09430481626062487e-15*V032*V07*V15 - 
      8.40004920563570605e-15*V02*V04*V07*V15 - 4.71886427696127925e-15*V01*V05*V07*V15 + 
      1.00363868415238697e-15*V013*V08*V15 - 4.78054874381622237e-15*V02*V03*V08*V15 - 
      2.93958475574600308e-15*V01*V04*V08*V15 + 1.77242276416778446e-16*V07*V08*V15 - 
      7.0798231668580429e-16*V022*V09*V15 - 1.47772874052489762e-15*V01*V03*V09*V15 + 
      1.3997513439823279e-16*V06*V09*V15 - 4.10581346874772992e-16*V01*V02*V10*V15 + 8.95392271426299581e-17*V05*V10*V15 - 
      5.0537286005807267e-17*V012*V11*V15 + 4.20153550053292244e-17*V04*V11*V15 + 1.64751830607325406e-17*V03*V12*V15 + 
      3.61160760034287335e-18*V02*V13*V15 + 7.58662069856116498e-19*V01*V14*V15 + 2.81467402465941724e-17*V016*V16 - 
      6.07555765228760983e-15*V012*V023*V16 - 1.11865533227437198e-14*V013*V02*V03*V16 + 
      1.66264069803104588e-14*V022*V032*V16 + 1.10723593727680659e-14*V01*V033*V16 - 
      1.46535615606420601e-15*V014*V04*V16 + 5.75630995264543605e-15*V023*V04*V16 + 
      4.04809294331919569e-14*V01*V02*V03*V04*V16 + 5.96551339186358916e-15*V012*V042*V16 - 
      1.63372611879508659e-15*V043*V16 + 1.07724093165182396e-14*V01*V022*V05*V16 + 
      1.04056759066740637e-14*V012*V03*V05*V16 - 9.08858832722970679e-15*V03*V04*V05*V16 - 
      2.46330800480799328e-15*V02*V052*V16 + 4.55661462637714243e-15*V012*V02*V06*V16 - 
      3.2705966776258731e-15*V032*V06*V16 - 3.81925894089393034e-15*V02*V04*V06*V16 - 
      2.17630514046559174e-15*V01*V05*V06*V16 + 5.2692708223070476e-16*V013*V07*V16 - 
      2.5345046180153791e-15*V02*V03*V07*V16 - 1.55487792590262543e-15*V01*V04*V07*V16 + 
      4.69322782432934407e-17*V072*V16 - 4.09462089116147292e-16*V022*V08*V16 - 
      8.6369763490613292e-16*V01*V03*V08*V16 + 8.1596382305475371e-17*V06*V08*V16 - 2.65589217808604231e-16*V01*V02*V09*V16 + 
      5.79169244633246023e-17*V05*V09*V16 - 3.56119410658790482e-17*V012*V10*V16 + 
      2.95223294502523969e-17*V04*V10*V16 + 1.25966826375158817e-17*V03*V11*V16 + 2.96586563658571451e-18*V02*V12*V16 + 
      6.69397097535933268e-19*V01*V13*V16 - 1.63322093893113511e-21*V162 - 
      9.03705825389607616e-16*V013*V022*V17 - 3.68605019146022849e-16*V014*V03*V17 + 
      1.72283786333224402e-15*V023*V03*V17 + 5.56434667106185606e-15*V01*V02*V032*V17 + 
      3.23514006425470297e-15*V01*V022*V04*V17 + 3.2180949977826856e-15*V012*V03*V04*V17 - 
      1.40598744777272906e-15*V03*V042*V17 + 1.75154623529394384e-15*V012*V02*V05*V17 - 
      1.27270491767513077e-15*V032*V05*V17 - 1.51194810744541425e-15*V02*V04*V05*V17 - 
      4.22440211549309587e-16*V01*V052*V17 + 2.29082632984378629e-16*V013*V06*V17 - 
      1.09893932141632405e-15*V02*V03*V06*V17 - 6.76466529603519026e-16*V01*V04*V06*V17 - 
      2.0699681386689234e-16*V022*V07*V17 - 4.31043058324991163e-16*V01*V03*V07*V17 + 
      4.09091189815725082e-17*V06*V07*V17 - 1.46416967345741308e-16*V01*V02*V08*V17 + 3.19629086325423319e-17*V05*V08*V17 - 
      2.17269709965442764e-17*V012*V09*V17 + 1.80770203930780101e-17*V04*V09*V17 + 
      8.37909277814395073e-18*V03*V10*V17 + 2.14644576610590283e-18*V02*V11*V17 + 5.20343066201598834e-19*V01*V12*V17 - 
      3.08693823202783327e-21*V15*V17 - 5.72317051680748172e-17*V014*V02*V18 + 
      5.8790386755936808e-17*V024*V18 + 8.59905811683255744e-16*V01*V022*V03*V18 + 
      4.08116005767179419e-16*V012*V032*V18 + 5.08989678461253208e-16*V012*V02*V04*V18 - 
      3.75407336237099779e-16*V032*V04*V18 - 2.17012136725305505e-16*V02*V042*V18 + 
      8.2739688516550786e-17*V013*V05*V18 - 4.07668061782580618e-16*V02*V03*V05*V18 - 
      2.49395086727733406e-16*V01*V04*V05*V18 - 8.39731766729139637e-17*V022*V06*V18 - 
      1.78095698084182446e-16*V01*V03*V06*V18 + 8.42730816118984281e-18*V062*V18 - 
      6.93831989847724362e-17*V01*V02*V07*V18 + 1.51513596578055957e-17*V05*V07*V18 - 
      1.13764409456726398e-17*V012*V08*V18 + 9.43037379148288422e-18*V04*V08*V18 + 
      4.85081852626319602e-18*V03*V09*V18 + 1.34952437786993927e-18*V02*V10*V18 + 3.56019062860021105e-19*V01*V11*V18 - 
      2.59766502418962775e-21*V14*V18 - 1.26660331109673776e-18*V015*V19 + 
      4.04288272480469965e-17*V01*V023*V19 + 1.23619477922318513e-16*V012*V02*V03*V19 - 
      3.14389525608306029e-17*V033*V19 + 2.30521244152537887e-17*V013*V04*V19 - 
      1.12897072293163322e-16*V02*V03*V04*V19 - 3.48307822407853862e-17*V01*V042*V19 - 
      3.00514733857161254e-17*V022*V05*V19 - 6.21819802107408262e-17*V01*V03*V05*V19 - 
      2.71283182105251032e-17*V01*V02*V06*V19 + 5.9492696781122004e-18*V05*V06*V19 - 
      5.1036689584983727e-18*V012*V07*V19 + 4.25998355182123664e-18*V04*V07*V19 + 2.4115679258535257e-18*V03*V08*V19 + 
      7.44354537833608311e-19*V02*V09*V19 + 2.13267209909938438e-19*V01*V10*V19 - 1.94964331672336058e-21*V13*V19 + 
      8.72158020696549981e-18*V012*V022*V20 + 5.19932840666253462e-18*V013*V03*V20 - 
      1.3711610699938968e-17*V02*V032*V20 - 7.74183419331194274e-18*V022*V04*V20 - 
      1.66372388342514845e-17*V01*V03*V04*V20 - 9.07195501778301002e-18*V01*V02*V05*V20 + 
      9.97307387616929643e-19*V052*V20 - 1.91160560827182646e-18*V012*V06*V20 + 
      1.5880823302395201e-18*V04*V06*V20 + 1.034730587106487e-18*V03*V07*V20 + 3.51309139681554195e-19*V02*V08*V20 + 
      1.1172910451521941e-19*V01*V09*V20 - 1.29843406964305966e-21*V12*V20 + 7.1930558407962885e-19*V013*V02*V21 - 
      1.84628779514601409e-18*V022*V03*V21 - 1.87894360675595509e-18*V01*V032*V21 - 
      2.29150638500510565e-18*V01*V02*V04*V21 - 6.04398921457478429e-19*V012*V05*V21 + 
      5.10749054725700457e-19*V04*V05*V21 + 3.7000563693041864e-19*V03*V06*V21 + 1.44549545655364484e-19*V02*V07*V21 + 
      5.05612742889315539e-20*V01*V08*V21 - 7.68038209913518811e-22*V11*V21 + 1.95463473934681753e-20*V014*V22 - 
      7.55352845148821461e-20*V023*V22 - 5.01895500636300256e-19*V01*V02*V03*V22 - 
      1.48075502805831777e-19*V012*V04*V22 + 6.21671055258646151e-20*V042*V22 + 
      1.13266096277386428e-19*V03*V05*V22 + 4.91457350596162935e-20*V02*V06*V22 + 1.9805183634597004e-20*V01*V07*V22 - 
      3.99967861140199455e-22*V10*V22 - 3.12216791826060255e-20*V01*V022*V23 - 
      3.02525462441072216e-20*V012*V03*V23 + 2.66590762259828529e-20*V03*V04*V23 + 
      1.45434313577892187e-20*V02*V05*V23 + 6.50565639676495655e-21*V01*V06*V23 - 1.83657423393434025e-22*V09*V23 - 
      3.74317366956194736e-21*V012*V02*V24 + 2.7130137681236136e-21*V032*V24 + 
      3.24082693587634426e-21*V02*V04*V24 + 1.82840706417330789e-21*V01*V05*V24 - 7.31377018013647059e-23*V08*V24 - 
      1.32395210177432222e-22*V013*V25 + 6.45869908260981793e-22*V02*V03*V25 + 3.98540643093936661e-22*V01*V04*V25 - 
      2.54250873510726065e-23*V07*V25 + 3.58020691416487563e-23*V022*V26 + 7.43785851011137148e-23*V01*V03*V26 - 
      7.429175699739831e-24*V06*V26 + 8.28063232113330562e-24*V01*V02*V27 - 1.87860877334025246e-24*V05*V27 + 
      4.27081323153007167e-25*V012*V28 - 3.68097823610112513e-25*V04*V28 - 6.31896034830379061e-26*V03*V29 - 
      6.37288475779280667e-27*V02*V30 - 6.37288475779280667e-28*V01*V31 + 3.50158503175428938e-31*V34) + 
   delta2*eps16*(1.71721241125556891e-14*V029 + 1.50036282796221567e-9*V01*V027*V03 + 
      1.57202736115274724e-8*V012*V025*V032 + 
      2.62204130199382028e-8*V013*V023*V033 + 6.57333173972985051e-9*V014*V02*V034 - 
      1.43160154682602411e-8*V024*V034 - 3.04004232904383143e-8*V01*V022*V035 - 
      4.00325176986032383e-9*V012*V036 + 3.56382536376130122e-9*V012*V026*V04 + 
      2.67475267090827405e-8*V013*V024*V03*V04 + 
      2.68190980768158021e-8*V014*V022*V032*V04 - 
      2.06719374348637256e-8*V025*V032*V04 + 2.24426946570368084e-9*V015*V033*V04 - 
      1.34915111401390556e-7*V01*V023*V033*V04 - 8.32993449367811571e-8*V012*V02*V034*V04 + 
      2.86224441974634004e-9*V036*V04 + 6.07770714339931939e-9*V014*V023*V042 - 
      1.58463391176416606e-9*V026*V042 + 4.5767513938993057e-9*V015*V02*V03*V042 - 
      6.46254094485855126e-8*V01*V024*V03*V042 - 
      1.71287517510381033e-7*V012*V022*V032*V042 - 
      2.9203778177715465e-8*V013*V033*V042 + 2.90530999851718874e-8*V02*V034*V042 + 
      1.04210975442691813e-10*V016*V043 - 2.58680832210536282e-8*V012*V023*V043 - 
      4.09403943097738183e-8*V013*V02*V03*V043 + 
      3.79137865312714383e-8*V022*V032*V043 + 2.30071180680596285e-8*V01*V033*V043 - 
      1.30363620036189041e-9*V014*V044 + 3.70687203668986364e-9*V023*V044 + 
      2.32820348323210552e-8*V01*V02*V03*V044 + 1.37711104338905093e-9*V012*V045 - 
      1.21950914958299276e-10*V046 + 2.76877855637452495e-9*V013*V025*V05 + 
      9.25181864470957301e-9*V014*V023*V03*V05 - 3.48890271463943853e-9*V026*V03*V05 + 
      3.48301565846903609e-9*V015*V02*V032*V05 - 5.51270193975709113e-8*V01*V024*V032*V05 - 
      9.35648916931912462e-8*V012*V022*V033*V05 - 
      1.18127594246069447e-8*V013*V034*V05 + 9.89473463102661832e-9*V02*V035*V05 + 
      2.36688003900151917e-9*V015*V022*V04*V05 - 1.34360686554769549e-8*V01*V025*V04*V05 + 
      4.7571854357891141e-10*V016*V03*V04*V05 - 1.26561564158277235e-7*V012*V023*V03*V04*V05 - 
      9.9124596594023335e-8*V013*V02*V032*V04*V05 + 6.59736609922428502e-8*V022*V033*V04*V05 + 
      2.89745452421021562e-8*V01*V034*V04*V05 - 3.45890334831423129e-8*V013*V022*V042*V05 - 
      1.2545749688462905e-8*V014*V03*V042*V05 + 4.19678617165430145e-8*V023*V03*V042*V05 + 
      1.18805357363271739e-7*V01*V02*V032*V042*V05 + 2.61857386941283913e-8*V01*V022*V043*V05 + 
      2.2923952273411778e-8*V012*V03*V043*V05 - 3.24801316899777134e-9*V03*V044*V05 + 
      1.22913766767004334e-10*V016*V02*V052 - 8.61796389763687856e-9*V012*V024*V052 - 
      2.78096714032240888e-8*V013*V022*V03*V052 - 
      5.02472557661231371e-9*V014*V032*V052 + 
      1.85138705117071612e-8*V023*V032*V052 + 
      3.33972521512796961e-8*V01*V02*V033*V052 - 7.09266317719178009e-9*V014*V02*V04*V052 + 
      5.70344898079354752e-9*V024*V04*V052 + 6.75085190093185096e-8*V01*V022*V03*V04*V052 + 
      2.85819736415963874e-8*V012*V032*V04*V052 + 
      1.9765185926788768e-8*V012*V02*V042*V052 - 
      8.40990201894535212e-9*V032*V042*V052 - 3.71261142628674375e-9*V02*V043*V052 - 
      1.82213056204998102e-10*V015*V053 + 4.21147516593707897e-9*V01*V023*V053 + 
      1.09864589136309258e-8*V012*V02*V03*V053 - 1.596280574271041e-9*V033*V053 + 
      2.03021064108913625e-9*V013*V04*V053 - 6.46837699468117147e-9*V02*V03*V04*V053 - 
      1.97813607839764198e-9*V01*V042*V053 - 4.620657442106736e-10*V022*V054 - 
      8.38368507777236008e-10*V01*V03*V054 + 9.67144661844992635e-10*V014*V024*V06 - 
      1.58274848444047548e-10*V027*V06 + 1.45589996970516284e-9*V015*V022*V03*V06 - 
      9.64264430374501505e-9*V01*V025*V03*V06 + 1.46277642422070588e-10*V016*V032*V06 - 
      4.34919480820409889e-8*V012*V023*V032*V06 - 
      2.23969382344215947e-8*V013*V02*V033*V06 + 1.17278541590452657e-8*V022*V034*V06 + 
      4.06095474347403116e-9*V01*V035*V06 + 1.98702700879558465e-10*V016*V02*V04*V06 - 
      1.4579580990444329e-8*V012*V024*V04*V06 - 4.67771142284125558e-8*V013*V022*V03*V04*V06 - 
      8.42983312900730625e-9*V014*V032*V04*V06 + 3.02761236225131187e-8*V023*V032*V04*V06 + 
      5.57843832732749844e-8*V01*V02*V033*V04*V06 - 5.94631449813653028e-9*V014*V02*V042*V06 + 
      4.35754051583739457e-9*V024*V042*V06 + 5.59526614474215803e-8*V01*V022*V03*V042*V06 + 
      2.39964032226999575e-8*V012*V032*V042*V06 + 
      1.1060438967141975e-8*V012*V02*V043*V06 - 4.65300366444310586e-9*V032*V043*V06 - 
      1.49809279108509196e-9*V02*V044*V06 + 8.59640048374752783e-12*V017*V05*V06 - 
      8.68795534902192212e-9*V013*V023*V05*V06 - 9.50040556901028736e-9*V014*V02*V03*V05*V06 + 
      8.29427385648450609e-9*V024*V03*V05*V06 + 4.76890883137565595e-8*V01*V022*V032*V05*V06 + 
      1.32690963290631984e-8*V012*V033*V05*V06 - 9.14280913724932261e-10*V015*V04*V05*V06 + 
      2.07864324279890342e-8*V01*V023*V04*V05*V06 + 5.52654844592396897e-8*V012*V02*V03*V04*V05*V06 - 
      7.99010441729749766e-9*V033*V04*V05*V06 + 5.12990326914344099e-9*V013*V042*V05*V06 - 
      1.60260602730829946e-8*V02*V03*V042*V05*V06 - 3.29598612850565894e-9*V01*V043*V05*V06 + 
      7.88571336924013436e-9*V012*V022*V052*V06 + 
      4.21071396712965089e-9*V013*V03*V052*V06 - 6.93513447625115572e-9*V02*V032*V052*V06 - 
      4.55060157668344879e-9*V022*V04*V052*V06 - 8.41652073462899836e-9*V01*V03*V04*V052*V06 - 
      1.62626005081406066e-9*V01*V02*V053*V06 + 5.7690966684667075e-11*V054*V06 - 
      1.11558954686290786e-9*V014*V022*V062 + 3.37718029215679809e-10*V025*V062 - 
      3.03892429892254787e-10*V015*V03*V062 + 7.41177238986471039e-9*V01*V023*V03*V062 + 
      9.63699977819797087e-9*V012*V02*V032*V062 - 7.10371016921167816e-10*V034*V062 + 
      6.61262002593140731e-9*V012*V022*V04*V062 + 
      3.54523043870816458e-9*V013*V03*V04*V062 - 5.74698047218947249e-9*V02*V032*V04*V062 - 
      1.83083953378998826e-9*V022*V042*V062 - 
      3.51442760612581157e-9*V01*V03*V042*V062 + 2.04654972686095943e-9*V013*V02*V05*V062 - 
      3.27919831646815183e-9*V022*V03*V05*V062 - 2.97876792585269801e-9*V01*V032*V05*V062 - 
      4.05900677774007817e-9*V01*V02*V04*V05*V062 - 5.08999009268852432e-10*V012*V052*V062 + 
      2.87808308192644891e-10*V04*V052*V062 + 6.22421534424610409e-11*V014*V063 - 
      1.64763031837368679e-10*V023*V063 - 9.62589738342791227e-10*V01*V02*V03*V063 - 
      2.8509159368473228e-10*V012*V04*V063 + 7.91173905962283025e-11*V042*V063 + 
      1.37566725235995806e-10*V03*V05*V063 + 1.64506201628972568e-11*V02*V064 + 
      1.70223822664513853e-10*V015*V023*V07 - 5.73802815426298673e-10*V01*V026*V07 + 
      1.02575500024775788e-10*V016*V02*V03*V07 - 8.58428009418876281e-9*V012*V024*V03*V07 - 
      1.36238720521450094e-8*V013*V022*V032*V07 - 1.6264440841062415e-9*V014*V033*V07 + 
      6.39290962227704497e-9*V023*V033*V07 + 8.55438570714457691e-9*V01*V02*V034*V07 + 
      5.83303394559475939e-12*V017*V04*V07 - 6.30587845393493281e-9*V013*V023*V04*V07 - 
      6.87095296643619894e-9*V014*V02*V03*V04*V07 + 5.95921833468666815e-9*V024*V03*V04*V07 + 
      3.47145846549346453e-8*V01*V022*V032*V04*V07 + 9.69811361884425359e-9*V012*V033*V04*V07 - 
      3.29548179005529064e-10*V015*V042*V07 + 7.51466551478664359e-9*V01*V023*V042*V07 + 
      2.01712519439879651e-8*V012*V02*V03*V042*V07 - 2.92193842593621981e-9*V033*V042*V07 + 
      1.25055992288798911e-9*V013*V043*V07 - 3.88853911676820708e-9*V02*V03*V043*V07 - 
      6.02036151886657626e-10*V01*V044*V07 - 1.92507846509875451e-9*V014*V022*V05*V07 + 
      6.3572172194945146e-10*V025*V05*V07 - 5.23890492726183734e-10*V015*V03*V05*V07 + 
      1.30139959893035567e-8*V01*V023*V03*V05*V07 + 1.67749199644447905e-8*V012*V02*V032*V05*V07 - 
      1.24535541839148557e-9*V034*V05*V07 + 1.14952511145954787e-8*V012*V022*V04*V05*V07 + 
      6.15519177783520895e-9*V013*V03*V04*V05*V07 - 1.01278357969709472e-8*V02*V032*V04*V05*V07 - 
      3.30234481094644703e-9*V022*V042*V05*V07 - 6.16170325175973013e-9*V01*V03*V042*V05*V07 + 
      1.7754654367586463e-9*V013*V02*V052*V07 - 2.898861469174532e-9*V022*V03*V052*V07 - 
      2.60608811870388531e-9*V01*V032*V052*V07 - 3.5662203347090694e-9*V01*V02*V04*V052*V07 - 
      2.96225604596978794e-10*V012*V053*V07 + 1.69015985047170851e-10*V04*V053*V07 - 
      2.44799332162391172e-10*V015*V02*V06*V07 + 1.47399416453269471e-9*V01*V024*V06*V07 + 
      8.03615183018143122e-9*V012*V022*V03*V06*V07 + 2.12448897799970459e-9*V013*V032*V06*V07 - 
      2.40990959267417731e-9*V02*V033*V06*V07 + 2.99084498336588428e-9*V013*V02*V04*V06*V07 - 
      4.76846928349050791e-9*V022*V03*V04*V06*V07 - 4.36412143336059422e-9*V01*V032*V04*V06*V07 - 
      2.96290633215068236e-9*V01*V02*V042*V06*V07 + 3.23762195559119169e-10*V014*V05*V06*V07 - 
      8.93220861864396145e-10*V023*V05*V06*V07 - 5.06510859262246816e-9*V01*V02*V03*V05*V06*V07 - 
      1.49278587763948056e-9*V012*V04*V05*V06*V07 + 4.21004871373401508e-10*V042*V05*V06*V07 + 
      3.62987925575458863e-10*V03*V052*V06*V07 - 6.04291064613707617e-10*V01*V022*V062*V07 - 
      5.24704601039929136e-10*V012*V03*V062*V07 + 3.02186700166708305e-10*V03*V04*V062*V07 + 
      1.75249491428347591e-10*V02*V05*V062*V07 + 2.59407841009612556e-11*V01*V063*V07 - 
      5.27387007277175732e-12*V016*V072 + 5.50681090701331191e-10*V012*V023*V072 + 
      8.9485731254235165e-10*V013*V02*V03*V072 - 
      7.57108980457446039e-10*V022*V032*V072 - 4.49715813410724108e-10*V01*V033*V072 + 
      1.18221332353704392e-10*V014*V04*V072 - 3.23202923864611377e-10*V023*V04*V072 - 
      1.85208768744233345e-9*V01*V02*V03*V04*V072 - 2.73591059769154473e-10*V012*V042*V072 + 
      5.12893549768920935e-11*V043*V072 - 5.31806959689862965e-10*V01*V022*V05*V072 - 
      4.57863961022397626e-10*V012*V03*V05*V072 + 2.65997461970580527e-10*V03*V04*V05*V072 + 
      7.73263160444478673e-11*V02*V052*V072 - 2.23937439316695471e-10*V012*V02*V06*V072 + 
      9.51212494545790668e-11*V032*V06*V072 + 1.27989929890375496e-10*V02*V04*V06*V072 + 
      6.82702886169820472e-11*V01*V05*V06*V072 - 8.6126686583157971e-12*V013*V073 + 
      2.70721978725517999e-11*V02*V03*V073 + 1.67013439855303947e-11*V01*V04*V073 - 
      1.90534946293131236e-13*V074 + 1.54888359142100112e-11*V016*V022*V08 - 
      5.90110739689161568e-10*V012*V025*V08 + 2.59390225286123119e-12*V017*V03*V08 - 
      3.21783460472600486e-9*V013*V023*V03*V08 - 1.74296897904911581e-9*V014*V02*V032*V08 + 
      1.67907212443596594e-9*V024*V032*V08 + 6.29120559084595004e-9*V01*V022*V033*V08 + 
      1.29666839309064735e-9*V012*V034*V08 - 1.22381746320111601e-9*V014*V022*V04*V08 + 
      3.75930685260076599e-10*V025*V04*V08 - 3.3207186605029515e-10*V015*V03*V04*V08 + 
      8.31231526881188402e-9*V01*V023*V03*V04*V08 + 1.08267537414059532e-8*V012*V02*V032*V04*V08 - 
      8.04789800436977764e-10*V034*V04*V08 + 3.71111492585872934e-9*V012*V022*V042*V08 + 
      1.99010190163195021e-9*V013*V03*V042*V08 - 3.25048826162737021e-9*V02*V032*V042*V08 - 
      6.88309485838437576e-10*V022*V043*V08 - 1.32631581383683852e-9*V01*V03*V043*V08 - 
      1.85551903589394578e-10*V015*V02*V05*V08 + 1.14311319869291164e-9*V01*V024*V05*V08 + 
      6.18359207100110556e-9*V012*V022*V03*V05*V08 + 1.63117049045553663e-9*V013*V032*V05*V08 - 
      1.86637890535305752e-9*V02*V033*V05*V08 + 2.29557743849096016e-9*V013*V02*V04*V05*V08 - 
      3.70497461116733745e-9*V022*V03*V04*V05*V08 - 3.37376966630400444e-9*V01*V032*V04*V05*V08 - 
      2.29553088459843067e-9*V01*V02*V042*V05*V08 + 1.24070351837020408e-10*V014*V052*V08 - 
      3.47651411289415379e-10*V023*V052*V08 - 1.95893635988809819e-9*V01*V02*V03*V052*V08 - 
      5.76243087506114474e-10*V012*V04*V052*V08 + 1.63418367355999251e-10*V042*V052*V08 + 
      9.37939147517774045e-11*V03*V053*V08 - 9.27285862226079674e-12*V016*V06*V08 + 
      9.75803964831470406e-10*V012*V023*V06*V08 + 1.58335718572128622e-9*V013*V02*V03*V06*V08 - 
      1.33111682649166345e-9*V022*V032*V06*V08 - 7.94825815906773866e-10*V01*V033*V06*V08 + 
      2.09033648164931422e-10*V014*V04*V06*V08 - 5.56930628613312107e-10*V023*V04*V06*V08 - 
      3.26732497138028778e-9*V01*V02*V03*V04*V06*V08 - 4.841141502786453e-10*V012*V042*V06*V08 + 
      8.97942959384664881e-11*V043*V06*V08 - 9.36603670525279475e-10*V01*V022*V05*V06*V08 - 
      8.09933505882835079e-10*V012*V03*V05*V06*V08 + 4.6888267043188589e-10*V03*V04*V05*V06*V08 + 
      1.36105981851364076e-10*V02*V052*V06*V08 - 1.98104424529441533e-10*V012*V02*V062*V08 + 
      8.39093899057866338e-11*V032*V062*V08 + 1.11973492246208001e-10*V02*V04*V062*V08 + 
      6.02845676657898543e-11*V01*V05*V062*V08 + 3.30937163523620427e-10*V013*V022*V07*V08 + 
      1.23840854024734607e-10*V014*V03*V07*V08 - 3.64581268379197984e-10*V023*V03*V07*V08 - 
      1.01561028583561639e-9*V01*V02*V032*V07*V08 - 6.82824284428490038e-10*V01*V022*V04*V07*V08 - 
      5.94010710786333625e-10*V012*V03*V04*V07*V08 + 1.71647466469327597e-10*V03*V042*V07*V08 - 
      3.45798612696143464e-10*V012*V02*V05*V07*V08 + 1.47450567614002918e-10*V032*V05*V07*V08 + 
      1.98907085741266766e-10*V02*V04*V05*V07*V08 + 5.28666908113010115e-11*V01*V052*V07*V08 - 
      4.57493752868286524e-11*V013*V06*V07*V08 + 1.43036816307670243e-10*V02*V03*V06*V07*V08 + 
      8.8458842244726047e-11*V01*V04*V06*V07*V08 + 1.50309630921878615e-11*V022*V072*V08 + 
      2.75975452678450592e-11*V01*V03*V072*V08 - 2.01653062935715045e-12*V06*V072*V08 + 
      2.29878152650512306e-11*V014*V02*V082 - 1.57343112222611565e-11*V024*V082 - 
      1.88559021238261267e-10*V01*V022*V03*V082 - 
      8.04315798650743282e-11*V012*V032*V082 - 
      1.12047561311174395e-10*V012*V02*V04*V082 + 4.76910994745348093e-11*V032*V04*V082 + 
      3.17586782815426319e-11*V02*V042*V082 - 1.76249565460459406e-11*V013*V05*V082 + 
      5.55157626407073347e-11*V02*V03*V05*V082 + 3.42671748475580048e-11*V01*V04*V05*V082 + 
      1.31376954748069132e-11*V022*V06*V082 + 2.43843595192399267e-11*V01*V03*V06*V082 - 
      8.87692088056189736e-13*V062*V082 + 1.04578720437723004e-11*V01*V02*V07*V082 - 
      1.56541054680403714e-12*V05*V07*V082 + 5.72290302991487892e-13*V012*V083 - 
      3.37142688881609239e-13*V04*V083 + 6.87512277263309255e-13*V017*V02*V09 - 
      2.52983432103490214e-10*V013*V024*V09 - 5.52003551925423086e-10*V014*V022*V03*V09 + 
      2.04564490095487002e-10*V025*V03*V09 - 7.45108770886584753e-11*V015*V032*V09 + 
      2.04594380042427302e-9*V01*V023*V032*V09 + 1.73327772061745134e-9*V012*V02*V033*V09 - 
      7.95418910269359716e-11*V035*V09 - 1.04828448348045057e-10*V015*V02*V04*V09 + 
      6.51134583042070638e-10*V01*V024*V04*V09 + 3.57584390795569512e-9*V012*V022*V03*V04*V09 + 
      9.45415178544254649e-10*V013*V032*V04*V09 - 1.08251824824184652e-9*V02*V033*V04*V09 + 
      6.65532066465275072e-10*V013*V02*V042*V09 - 1.06647886772375814e-9*V022*V03*V042*V09 - 
      9.8145720089894071e-10*V01*V032*V042*V09 - 4.42993923699790095e-10*V01*V02*V043*V09 - 
      6.26138350365239586e-12*V016*V05*V09 + 6.72200793728318218e-10*V012*V023*V05*V09 + 
      1.08953301811686258e-9*V013*V02*V03*V05*V09 - 9.31383657641077801e-10*V022*V032*V05*V09 - 
      5.5215126168914946e-10*V01*V033*V05*V09 + 1.43675392684187989e-10*V014*V04*V05*V09 - 
      3.98366432351306874e-10*V023*V04*V05*V09 - 2.275452557944187e-9*V01*V02*V03*V04*V05*V09 - 
      3.35692150715641502e-10*V012*V042*V05*V09 + 6.32248542447805934e-11*V043*V05*V09 - 
      3.26787690260994856e-10*V01*V022*V052*V09 - 2.80791906519654869e-10*V012*V03*V052*V09 + 
      1.63839134219010292e-10*V03*V04*V052*V09 + 3.17649488823274477e-11*V02*V053*V09 + 
      2.62571450342882352e-10*V013*V022*V06*V09 + 9.81782205796382681e-11*V014*V03*V06*V09 - 
      2.88645921915552905e-10*V023*V03*V06*V09 - 8.06577850688829235e-10*V01*V02*V032*V06*V09 - 
      5.41504944389827094e-10*V01*V022*V04*V06*V09 - 4.72026259136785915e-10*V012*V03*V04*V06*V09 + 
      1.36278961108423433e-10*V03*V042*V06*V09 - 2.74725051506927047e-10*V012*V02*V05*V06*V09 + 
      1.17161732808531732e-10*V032*V05*V06*V09 + 1.57815410915662443e-10*V02*V04*V05*V06*V09 + 
      4.20208168185421462e-11*V01*V052*V06*V09 - 1.81812102581293094e-11*V013*V062*V09 + 
      5.67735464391151256e-11*V02*V03*V062*V09 + 3.5144822099532173e-11*V01*V04*V062*V09 + 
      4.12302899755209866e-11*V014*V02*V07*V09 - 2.89155640917704098e-11*V024*V07*V09 - 
      3.39493329810715807e-10*V01*V022*V03*V07*V09 - 1.44509780170670592e-10*V012*V032*V07*V09 - 
      2.01241941622215034e-10*V012*V02*V04*V07*V09 + 8.59144146816622989e-11*V032*V04*V07*V09 + 
      5.76023399479801263e-11*V02*V042*V07*V09 - 3.16462200856701506e-11*V013*V05*V07*V09 + 
      1.0009078399794753e-10*V02*V03*V05*V07*V09 + 6.16890050637392476e-11*V01*V04*V05*V07*V09 + 
      2.3839053381462846e-11*V022*V06*V07*V09 + 4.38792277076481852e-11*V01*V03*V06*V07*V09 - 
      1.60226467694962765e-12*V062*V07*V09 + 9.41726647544558597e-12*V01*V02*V072*V09 - 
      1.41028836486877358e-12*V05*V072*V09 + 2.14780716204173614e-12*V015*V08*V09 - 
      4.12369247433387213e-11*V01*V023*V08*V09 - 1.09242393630872146e-10*V012*V02*V03*V08*V09 + 
      1.5856003863102985e-11*V033*V08*V09 - 2.05628846909109809e-11*V013*V04*V08*V09 + 
      6.44771315260340196e-11*V02*V03*V04*V08*V09 + 1.99768590865483067e-11*V01*V042*V08*V09 + 
      1.85426067267902716e-11*V022*V05*V08*V09 + 3.3974405226464487e-11*V01*V03*V05*V08*V09 + 
      1.66182989967458168e-11*V01*V02*V06*V08*V09 - 2.48805094923271849e-12*V05*V06*V08*V09 + 
      3.08622906607918735e-12*V012*V07*V08*V09 - 1.82588039647953681e-12*V04*V07*V08*V09 - 
      5.09069720298081003e-13*V03*V082*V09 - 9.17669885467573341e-12*V012*V022*V092 - 
      4.95062503576085627e-12*V013*V03*V092 + 8.09397912961175151e-12*V02*V032*V092 + 
      5.35927331646873636e-12*V022*V04*V092 + 9.91933549994609227e-12*V01*V03*V04*V092 + 
      5.79971400597300837e-12*V01*V02*V05*V092 - 4.35003379055612975e-13*V052*V092 + 
      1.2274392237854573e-12*V012*V06*V092 - 7.25372777042427955e-13*V04*V06*V092 - 
      4.58525131654162351e-13*V03*V07*V092 - 1.73907271802714594e-13*V02*V08*V092 - 
      1.81061255983743716e-14*V01*V093 + 1.16527504620899874e-14*V018*V10 - 
      5.22254079995707348e-11*V014*V023*V10 + 8.51791287152391314e-12*V026*V10 - 
      4.22634161402420899e-11*V015*V02*V03*V10 + 2.94958419217660058e-10*V01*V024*V03*V10 + 
      7.80159044708435987e-10*V012*V022*V032*V10 + 
      1.35598489167278618e-10*V013*V033*V10 - 1.21877960598664432e-10*V02*V034*V10 - 
      3.17742760457236599e-12*V016*V04*V10 + 3.52890027123507913e-10*V012*V023*V04*V10 + 
      5.72643259798578121e-10*V013*V02*V03*V04*V10 - 4.87249211610640211e-10*V022*V032*V04*V10 - 
      2.91744669353175273e-10*V01*V033*V04*V10 + 3.77159918545025749e-11*V014*V042*V10 - 
      1.01442718648839877e-10*V023*V042*V10 - 5.98739285344593205e-10*V01*V02*V03*V042*V10 - 
      5.91879572120173679e-11*V012*V043*V10 + 8.25818452525963549e-12*V044*V10 + 
      1.63760692684651147e-10*V013*V022*V05*V10 + 6.11702231176474253e-11*V014*V03*V05*V10 - 
      1.83506563166653025e-10*V023*V03*V05*V10 - 5.08807801430719023e-10*V01*V02*V032*V05*V10 - 
      3.4276178113657216e-10*V01*V022*V04*V05*V10 - 2.97073141465461108e-10*V012*V03*V04*V05*V10 + 
      8.63809863899849415e-11*V03*V042*V05*V10 - 8.6479201165395728e-11*V012*V02*V052*V10 + 
      3.70658408703659285e-11*V032*V052*V10 + 5.0092368913935575e-11*V02*V04*V052*V10 + 
      8.85267489571827363e-12*V01*V053*V10 + 2.96335325914419194e-11*V014*V02*V06*V10 - 
      2.03446036677968704e-11*V024*V06*V10 - 2.44276271940654224e-10*V01*V022*V03*V06*V10 - 
      1.04233692281435515e-10*V012*V032*V06*V10 - 1.45187047110643762e-10*V012*V02*V04*V06*V10 + 
      6.18710817303870708e-11*V032*V04*V06*V10 + 4.11706102767356106e-11*V02*V042*V06*V10 - 
      2.28341964989400359e-11*V013*V05*V06*V10 + 7.20074540282226878e-11*V02*V03*V05*V06*V10 + 
      4.4460969265998055e-11*V01*V04*V05*V06*V10 + 8.51493987111813812e-12*V022*V062*V10 + 
      1.58213663251975619e-11*V01*V03*V062*V10 - 3.84031782351243496e-13*V063*V10 + 
      1.74575189576473074e-12*V015*V07*V10 - 3.36791441677022776e-11*V01*V023*V07*V10 - 
      8.90743847682586587e-11*V012*V02*V03*V07*V10 + 1.29438079804636558e-11*V033*V07*V10 - 
      1.67588023527633435e-11*V013*V04*V07*V10 + 5.26747529325687965e-11*V02*V03*V04*V07*V10 + 
      1.63095798681877876e-11*V01*V042*V07*V10 + 1.51553828571284345e-11*V022*V05*V07*V10 + 
      2.77281318914955894e-11*V01*V03*V05*V07*V10 + 1.35687687487309703e-11*V01*V02*V06*V07*V10 - 
      2.03202737446534833e-12*V05*V06*V07*V10 + 1.25904764462555153e-12*V012*V072*V10 - 
      7.45724777477728205e-13*V04*V072*V10 - 1.66671392084751982e-11*V012*V022*V08*V10 - 
      8.98830902631708441e-12*V013*V03*V08*V10 + 1.46713378763542081e-11*V02*V032*V08*V10 + 
      9.65589998830922097e-12*V022*V04*V08*V10 + 1.79957571453278879e-11*V01*V03*V04*V08*V10 + 
      1.05176461857017082e-11*V01*V02*V05*V08*V10 - 7.8870540371483369e-13*V052*V08*V10 + 
      2.22852080714019682e-12*V012*V06*V08*V10 - 1.31285682195663371e-12*V04*V06*V08*V10 - 
      8.31494789153458386e-13*V03*V07*V08*V10 - 1.57348940213766915e-13*V02*V082*V10 - 
      3.05820508952472961e-12*V013*V02*V09*V10 + 4.92140302754627414e-12*V022*V03*V09*V10 + 
      4.45309426172345717e-12*V01*V032*V09*V10 + 6.12651398255255596e-12*V01*V02*V04*V09*V10 + 
      1.54901618379712191e-12*V012*V05*V09*V10 - 9.20462667300802425e-13*V04*V05*V09*V10 - 
      6.61066166698457871e-13*V03*V06*V09*V10 - 2.8420581427039175e-13*V02*V07*V09*V10 - 
      9.85560715478582278e-14*V01*V08*V09*V10 - 8.95977520026302259e-14*V014*V102 + 
      2.43093525194668056e-13*V023*V102 + 1.38242731271410904e-12*V01*V02*V03*V102 + 
      4.11419211854589104e-13*V012*V04*V102 - 1.21414198726295496e-13*V042*V102 - 
      2.09533350012933776e-13*V03*V05*V102 - 1.02147010622807062e-13*V02*V06*V102 - 
      4.02383294150045562e-14*V01*V07*V102 + 2.16434767675334863e-16*V103 - 
      5.41153731459459014e-12*V015*V022*V11 + 1.49903093315386173e-11*V01*V025*V11 - 
      1.15498178330081925e-12*V016*V03*V11 + 1.40966409452440299e-10*V012*V023*V03*V11 + 
      1.12547738622644237e-10*V013*V02*V032*V11 - 6.75871283997715579e-11*V022*V033*V11 - 
      2.97163934479947051e-11*V01*V034*V11 + 7.87736732183310696e-11*V013*V022*V04*V11 + 
      2.93701931701402129e-11*V014*V03*V04*V11 - 8.74802370014844152e-11*V023*V03*V04*V11 - 
      2.45819107202596439e-10*V01*V02*V032*V04*V11 - 8.22731065904040082e-11*V01*V022*V042*V11 - 
      7.19664022822061385e-11*V012*V03*V042*V11 + 1.39052978636816982e-11*V03*V043*V11 + 
      1.68858757066385122e-11*V014*V02*V05*V11 - 1.21054453487773757e-11*V024*V05*V11 - 
      1.41441517514902719e-10*V01*V022*V03*V05*V11 - 6.00619545311393738e-11*V012*V032*V05*V11 - 
      8.3683705985443729e-11*V012*V02*V04*V05*V11 + 3.59167719708829032e-11*V032*V04*V05*V11 + 
      2.41166030772601757e-11*V02*V042*V05*V11 - 6.56541403337586804e-12*V013*V052*V11 + 
      2.09311164538702636e-11*V02*V03*V052*V11 + 1.28853246924168425e-11*V01*V04*V052*V11 + 
      1.14674792050783156e-12*V015*V06*V11 - 2.2172569650468691e-11*V01*V023*V06*V11 - 
      5.8834678397440203e-11*V012*V02*V03*V06*V11 + 8.55222949037305131e-12*V033*V06*V11 - 
      1.10743424406642739e-11*V013*V04*V06*V11 + 3.47405707357742642e-11*V02*V03*V04*V06*V11 + 
      1.07719565695313831e-11*V01*V042*V06*V11 + 9.98434352446874233e-12*V022*V05*V06*V11 + 
      1.83278792350314595e-11*V01*V03*V05*V06*V11 + 4.48020518368827619e-12*V01*V02*V062*V11 - 
      6.7101770504143178e-13*V05*V062*V11 - 1.24400710422021355e-11*V012*V022*V07*V11 - 
      6.70814340073489987e-12*V013*V03*V07*V11 + 1.09870963432346183e-11*V02*V032*V07*V11 + 
      7.27779617415942509e-12*V022*V04*V07*V11 + 1.34618793238051604e-11*V01*V03*V04*V07*V11 + 
      7.87151261829446382e-12*V01*V02*V05*V07*V11 - 5.90512193850946076e-13*V052*V07*V11 + 
      1.66548478898024942e-12*V012*V06*V07*V11 - 9.84819722800197287e-13*V04*V06*V07*V11 - 
      3.11254198020472843e-13*V03*V072*V11 - 2.54234789229643379e-12*V013*V02*V08*V11 + 
      4.08850311536452284e-12*V022*V03*V08*V11 + 3.70243085791018679e-12*V01*V032*V08*V11 + 
      5.09193830632201115e-12*V01*V02*V04*V08*V11 + 1.28801795775862192e-12*V012*V05*V08*V11 - 
      7.64954963380905006e-13*V04*V05*V08*V11 - 5.49469236265810743e-13*V03*V06*V08*V11 - 
      2.3617034437974114e-13*V02*V07*V08*V11 - 4.09713961490180214e-14*V01*V082*V11 - 
      1.64096934432364298e-13*V014*V09*V11 + 4.48319846897750659e-13*V023*V09*V11 + 
      2.53405007478564611e-12*V01*V02*V03*V09*V11 + 7.53677225392608711e-13*V012*V04*V09*V11 - 
      2.22996612021022484e-13*V042*V09*V11 - 3.84161263818617427e-13*V03*V05*V09*V11 - 
      1.87630189915512727e-13*V02*V06*V09*V11 - 7.37547783969604316e-14*V01*V07*V09*V11 + 
      3.88213029740543013e-13*V01*V022*V10*V11 + 3.35704759183468394e-13*V012*V03*V10*V11 - 
      2.03537008835883092e-13*V03*V04*V10*V11 - 1.19193198153793788e-13*V02*V05*V10*V11 - 
      5.3238238588412713e-14*V01*V06*V10*V11 + 1.191008432796957e-15*V09*V10*V11 + 
      4.80029843898462845e-14*V012*V02*V112 - 2.12152555541171886e-14*V032*V112 - 
      2.88480305296267609e-14*V02*V04*V112 - 1.54500815809066907e-14*V01*V05*V112 + 
      4.95081262360070305e-16*V08*V112 - 2.6801326062806971e-13*V016*V02*V12 + 
      8.67415846730462427e-12*V012*V024*V12 + 2.84685807301253949e-11*V013*V022*V03*V12 + 
      5.26059649958340883e-12*V014*V032*V12 - 1.69716145777837284e-11*V023*V032*V12 - 
      3.09059061450674705e-11*V01*V02*V033*V12 + 7.46732767431962621e-12*V014*V02*V04*V12 - 
      5.19132229919702996e-12*V024*V04*V12 - 6.28291563759490924e-11*V01*V022*V03*V04*V12 - 
      2.68595442722496183e-11*V012*V032*V04*V12 - 1.8688572056503129e-11*V012*V02*V042*V12 + 
      8.0171442507546127e-12*V032*V042*V12 + 3.54507845282388235e-12*V02*V043*V12 + 
      6.01069315430909253e-13*V015*V05*V12 - 1.18773615962177763e-11*V01*V023*V05*V12 - 
      3.12881649385271561e-11*V012*V02*V03*V05*V12 + 4.57401573066136362e-12*V033*V05*V12 - 
      5.87534625700027666e-12*V013*V04*V05*V12 + 1.86397949160903742e-11*V02*V03*V04*V05*V12 + 
      5.76254230153785644e-12*V01*V042*V05*V12 + 2.68366228933573796e-12*V022*V052*V12 + 
      4.89519343856981557e-12*V01*V03*V052*V12 - 7.58381997969849317e-12*V012*V022*V06*V12 - 
      4.08936046252697356e-12*V013*V03*V06*V12 + 6.68807755466399942e-12*V02*V032*V06*V12 + 
      4.39606752877290173e-12*V022*V04*V06*V12 + 8.20658130934097079e-12*V01*V03*V04*V06*V12 + 
      4.79515666783177599e-12*V01*V02*V05*V06*V12 - 3.59716513176195244e-13*V052*V06*V12 + 
      5.08242623479132799e-13*V012*V062*V12 - 2.99313516689747863e-13*V04*V062*V12 - 
      1.75030603728218136e-12*V013*V02*V07*V12 + 2.82551226807610668e-12*V022*V03*V07*V12 + 
      2.55421572791362831e-12*V01*V032*V07*V12 + 3.51535191547682964e-12*V01*V02*V04*V07*V12 + 
      8.88229632486398275e-13*V012*V05*V07*V12 - 5.28245556965859082e-13*V04*V05*V07*V12 - 
      3.79362431005864318e-13*V03*V06*V07*V12 - 8.1579739530456341e-14*V02*V072*V12 - 
      1.25817281056493341e-13*V014*V08*V12 + 3.4146489304200423e-13*V023*V08*V12 + 
      1.94298241583196446e-12*V01*V02*V03*V08*V12 + 5.78279937430379913e-13*V012*V04*V08*V12 - 
      1.70598647857368312e-13*V042*V08*V12 - 2.94468548072975466e-13*V03*V05*V08*V12 - 
      1.43529983600230167e-13*V02*V06*V08*V12 - 5.65585402968067512e-14*V01*V07*V08*V12 + 
      3.28222696777747191e-13*V01*V022*V09*V12 + 2.83727176278017056e-13*V012*V03*V09*V12 - 
      1.72065611399964936e-13*V03*V04*V09*V12 - 1.00774422360687596e-13*V02*V05*V09*V12 - 
      4.50011315951951714e-14*V01*V06*V09*V12 + 5.03400239797930704e-16*V092*V12 + 
      8.85888905391965321e-14*V012*V02*V10*V12 - 3.91296839478204439e-14*V032*V10*V12 - 
      5.31120209490721364e-14*V02*V04*V10*V12 - 2.84998774203792422e-14*V01*V05*V10*V12 + 9.12635497321760715e-16*V08*V10*V12 + 
      6.86549117689362663e-15*V013*V11*V12 - 2.23409011785798385e-14*V02*V03*V11*V12 - 
      1.38838160588205837e-14*V01*V04*V11*V12 + 6.83919838507176706e-16*V07*V11*V12 - 
      1.44648579422221156e-15*V022*V122 - 2.65275653782053046e-15*V01*V03*V122 + 
      2.08506093408851012e-16*V06*V122 - 4.9940359123242803e-15*V017*V13 + 
      2.20816102914074436e-12*V013*V023*V13 + 2.47245188337120199e-12*V014*V02*V03*V13 - 
      1.92904585645881534e-12*V024*V03*V13 - 1.1061807471068084e-11*V01*V022*V032*V13 - 
      3.0956900854638804e-12*V012*V033*V13 + 2.45545828894732076e-13*V015*V04*V13 - 
      4.87052616069154497e-12*V01*V023*V04*V13 - 1.29738701173919969e-11*V012*V02*V03*V04*V13 + 
      1.90034989361422097e-12*V033*V04*V13 - 1.22054504466770031e-12*V013*V042*V13 + 
      3.84952119297568991e-12*V02*V03*V042*V13 + 7.97156372517853808e-13*V01*V043*V13 - 
      3.74345846959826174e-12*V012*V022*V05*V13 - 2.01378186364592745e-12*V013*V03*V05*V13 + 
      3.32831092635078958e-12*V02*V032*V05*V13 + 2.20863707847687754e-12*V022*V04*V05*V13 + 
      4.07286716814917776e-12*V01*V03*V04*V05*V13 + 1.19114841818415081e-12*V01*V02*V052*V13 - 
      5.96778467045424851e-14*V053*V13 - 9.90617740650185032e-13*V013*V02*V06*V13 + 
      1.59514727358790487e-12*V022*V03*V06*V13 + 1.44666437380842633e-12*V01*V032*V06*V13 + 
      1.9881718199988401e-12*V01*V02*V04*V06*V13 + 5.03277028223642558e-13*V012*V05*V06*V13 - 
      2.987453867773307e-13*V04*V05*V06*V13 - 1.07337269300145596e-13*V03*V062*V13 - 
      8.03856432068685048e-14*V014*V07*V13 + 2.20501031032264595e-13*V023*V07*V13 + 
      1.24517230510601282e-12*V01*V02*V03*V07*V13 + 3.70212794508120577e-13*V012*V04*V07*V13 - 
      1.09603477213090036e-13*V042*V07*V13 - 1.88785462899914654e-13*V03*V05*V07*V13 - 
      9.2235632608041792e-14*V02*V06*V07*V13 - 1.8123514661644668e-14*V01*V072*V13 + 
      2.33599732338555409e-13*V01*V022*V08*V13 + 2.02096879271161028e-13*V012*V03*V08*V13 - 
      1.22469039626892971e-13*V03*V04*V08*V13 - 7.1706821240030201e-14*V02*V05*V08*V13 - 
      3.20418034104556543e-14*V01*V06*V08*V13 + 6.95008867508467928e-14*V012*V02*V09*V13 - 
      3.07154302309512146e-14*V032*V09*V13 - 4.17684756971170276e-14*V02*V04*V09*V13 - 
      2.2367843943989884e-14*V01*V05*V09*V13 + 7.16654532476973885e-16*V08*V09*V13 + 
      5.88062026367632498e-15*V013*V10*V13 - 1.91296780469873438e-14*V02*V03*V10*V13 - 
      1.18896046312898448e-14*V01*V04*V10*V13 + 5.85571454583830976e-16*V07*V10*V13 - 
      2.69082274023713513e-15*V022*V11*V13 - 4.92597067126431356e-15*V01*V03*V11*V13 + 
      3.87376090448790355e-16*V06*V11*V13 - 1.30610824025623166e-15*V01*V02*V12*V13 + 2.08009475310643737e-16*V05*V12*V13 - 
      6.94539203844953067e-17*V012*V132 + 4.33934471559389324e-17*V04*V132 + 
      2.68963213111392263e-13*V014*V022*V14 - 7.77650123220796663e-14*V025*V14 + 
      7.50251361272967665e-14*V015*V03*V14 - 1.61629293610004851e-12*V01*V023*V03*V14 - 
      2.09674772964977287e-12*V012*V02*V032*V14 + 1.57136665610121516e-13*V034*V14 - 
      1.44729473249748358e-12*V012*V022*V04*V14 - 7.80615904726332967e-13*V013*V03*V04*V14 + 
      1.28661310861875037e-12*V02*V032*V04*V14 + 4.2115402532590326e-13*V022*V042*V14 + 
      7.90325563051086593e-13*V01*V03*V042*V14 - 4.55085548042718427e-13*V013*V02*V05*V14 + 
      7.42768293842852646e-13*V022*V03*V05*V14 + 6.69661521086091326e-13*V01*V032*V05*V14 + 
      9.22552067228184405e-13*V01*V02*V04*V05*V14 + 1.16304334606808637e-13*V012*V052*V14 - 
      6.94318123439530013e-14*V04*V052*V14 - 4.242970762993209e-14*V014*V06*V14 + 
      1.15346489818058618e-13*V023*V06*V14 + 6.57798058417096162e-13*V01*V02*V03*V06*V14 + 
      1.9582742451465429e-13*V012*V04*V06*V14 - 5.77304647984422642e-14*V042*V06*V14 - 
      9.97145213700781658e-14*V03*V05*V06*V14 - 2.42860903736162553e-14*V02*V062*V14 + 
      1.39807012972435943e-13*V01*V022*V07*V14 + 1.20770786920646549e-13*V012*V03*V07*V14 - 
      7.32831442299512402e-14*V03*V04*V07*V14 - 4.29274303932774916e-14*V02*V05*V07*V14 - 
      1.91633670607082917e-14*V01*V06*V07*V14 + 4.62094445579511635e-14*V012*V02*V08*V14 - 
      2.04054500568057588e-14*V032*V08*V14 - 2.76855113184571415e-14*V02*V04*V08*V14 - 
      1.48627632727206289e-14*V01*V05*V08*V14 + 2.37860713851187683e-16*V082*V14 + 
      4.30578645735909387e-15*V013*V09*V14 - 1.40141823079532022e-14*V02*V03*V09*V14 - 
      8.70800946928055852e-15*V01*V04*V09*V14 + 4.28816974140546598e-16*V07*V09*V14 - 
      2.1461588966113801e-15*V022*V10*V14 - 3.93667818815821397e-15*V01*V03*V10*V14 + 
      3.09301299522127305e-16*V06*V10*V14 - 1.13162736970621434e-15*V01*V02*V11*V14 + 1.80194901472126373e-16*V05*V11*V14 - 
      1.2963487395773749e-16*V012*V12*V14 + 8.09329423495077033e-17*V04*V12*V14 + 2.90834803184861952e-17*V03*V13*V14 + 
      3.34395625810712613e-18*V02*V142 + 1.51992397331608531e-14*V015*V02*V15 - 
      8.10258804141694111e-14*V01*V024*V15 - 4.3944611888004652e-13*V012*V022*V03*V15 - 
      1.16858193635372047e-13*V013*V032*V15 + 1.33794318686457101e-13*V02*V033*V15 - 
      1.65340812976429276e-13*V013*V02*V04*V15 + 2.68041857572554432e-13*V022*V03*V04*V15 + 
      2.44060345578270463e-13*V01*V032*V04*V15 + 1.67359791513565687e-13*V01*V02*V042*V15 - 
      1.82423597383466903e-14*V014*V05*V15 + 5.08075996818402053e-14*V023*V05*V15 + 
      2.85890851145691892e-13*V01*V02*V03*V05*V15 + 8.48756490000057663e-14*V012*V04*V05*V15 - 
      2.52264381529229357e-14*V042*V05*V15 - 2.1711371891091995e-14*V03*V052*V15 + 
      6.91765546717510548e-14*V01*V022*V06*V15 + 5.99061211150570269e-14*V012*V03*V06*V15 - 
      3.62876553450177898e-14*V03*V04*V06*V15 - 2.12383798327895778e-14*V02*V05*V06*V15 - 
      4.74975811449828682e-15*V01*V062*V15 + 2.58910860711777941e-14*V012*V02*V07*V15 - 
      1.14467451924089924e-14*V032*V07*V15 - 1.55704372062326726e-14*V02*V04*V07*V15 - 
      8.33453813558447912e-15*V01*V05*V07*V15 + 2.6842497524331636e-15*V013*V08*V15 - 
      8.72681409492998197e-15*V02*V03*V08*V15 - 5.42511596786370894e-15*V01*V04*V08*V15 + 2.67003470364053113e-16*V07*V08*V15 - 
      1.47683279476160164e-15*V022*V09*V15 - 2.70320539849510244e-15*V01*V03*V09*V15 + 
      2.12457872286461968e-16*V06*V09*V15 - 8.47824119125221497e-16*V01*V02*V10*V15 + 1.34955336282108294e-16*V05*V10*V15 - 
      1.05286753866358336e-16*V012*V11*V15 + 6.57618761145564442e-17*V04*V11*V15 + 
      2.54394405897292893e-17*V03*V12*V15 + 6.27292195124278539e-18*V02*V13*V15 + 1.31577690649417165e-18*V01*V14*V15 + 
      3.1665082777418444e-16*V016*V16 - 2.85453684553365624e-14*V012*V023*V16 - 
      4.65561157048790909e-14*V013*V02*V03*V16 + 3.96893588088209076e-14*V022*V032*V16 + 
      2.35915080655543117e-14*V01*V033*V16 - 6.23274379335519705e-15*V014*V04*V16 + 
      1.70581672584442344e-14*V023*V04*V16 + 9.78833291033464726e-14*V01*V02*V03*V04*V16 + 
      1.45813926963579165e-14*V012*V042*V16 - 2.86833112043806062e-15*V043*V16 + 
      2.83645737572010857e-14*V01*V022*V05*V16 + 2.44421572456885844e-14*V012*V03*V05*V16 - 
      1.4887759614884944e-14*V03*V04*V05*V16 - 4.36272103908893855e-15*V02*V052*V16 + 
      1.20906634782908381e-14*V012*V02*V06*V16 - 5.34021875143788405e-15*V032*V06*V16 - 
      7.23735298628854597e-15*V02*V04*V06*V16 - 3.89020626007117989e-15*V01*V05*V06*V16 + 
      1.41530186965901271e-15*V013*V07*V16 - 4.61126498583606844e-15*V02*V03*V07*V16 - 
      2.86440697802269405e-15*V01*V04*V07*V16 + 7.04908919548131894e-17*V072*V16 - 
      8.63869317729487562e-16*V022*V08*V16 - 1.58570407452973458e-15*V01*V03*V08*V16 + 
      1.24448360621273996e-16*V06*V08*V16 - 5.48085079551053393e-16*V01*V02*V09*V16 + 8.72082063921850714e-17*V05*V09*V16 - 
      7.42695561039430893e-17*V012*V10*V16 + 4.63318940538183031e-17*V04*V10*V16 + 
      1.94454278437179169e-17*V03*V11*V16 + 5.16140037460826774e-18*V02*V12*V16 + 1.16092178904757874e-18*V01*V13*V16 - 
      2.45100406912378844e-21*V162 - 4.34761586533955235e-15*V013*V022*V17 - 
      1.6402512878702754e-15*V014*V03*V17 + 4.85396578964006524e-15*V023*V03*V17 + 
      1.34660479568649296e-14*V01*V02*V032*V17 + 9.14165698171728637e-15*V01*V022*V04*V17 + 
      7.93907093017677079e-15*V012*V03*V04*V17 - 2.40946555870003598e-15*V03*V042*V17 + 
      4.66246820975576086e-15*V012*V02*V05*V17 - 2.06838154324175684e-15*V032*V05*V17 - 
      2.81675730311328729e-15*V02*V04*V05*V17 - 7.52484151833864965e-16*V01*V052*V17 + 
      6.24717737473760234e-16*V013*V06*V17 - 2.03056647949599258e-15*V02*V03*V06*V17 - 
      1.26299858123836036e-15*V01*V04*V06*V17 - 4.32316598451081442e-16*V022*V07*V17 - 
      7.90857924967200126e-16*V01*V03*V07*V17 + 6.21098189365311669e-17*V06*V07*V17 - 3.03654706337474246e-16*V01*V02*V08*V17 + 
      4.82834795620527513e-17*V05*V08*V17 - 4.53411167554302417e-17*V012*V09*V17 + 
      2.82977211581274649e-17*V04*V09*V17 + 1.29488010141315527e-17*V03*V10*V17 + 3.72852124162163206e-18*V02*V11*V17 + 
      9.02749000633080871e-19*V01*V12*V17 - 4.63041493667683073e-21*V15*V17 - 2.91318761552249684e-16*V014*V02*V18 + 
      2.04544587262172413e-16*V024*V18 + 2.39998494127835844e-15*V01*V022*V03*V18 + 
      1.02247647282643239e-15*V012*V032*V18 + 1.4338843427829536e-15*V012*V02*V04*V18 - 
      6.35952739269001607e-16*V032*V04*V18 - 4.29637549454484763e-16*V02*V042*V18 + 
      2.27833322207149378e-16*V013*V05*V18 - 7.46871780645716029e-16*V02*V03*V05*V18 - 
      4.63382489649814143e-16*V01*V04*V05*V18 - 1.79857785057889857e-16*V022*V06*V18 - 
      3.30719842116950194e-16*V01*V03*V06*V18 + 1.29579173630817492e-17*V062*V18 - 
      1.43598711203762692e-16*V01*V02*V07*V18 + 2.28240135070425522e-17*V05*V07*V18 - 
      2.38217882853990522e-17*V012*V08*V18 + 1.48382797599351153e-17*V04*V08*V18 + 
      7.49031034086319133e-18*V03*V09*V18 + 2.35118072352432221e-18*V02*V10*V18 + 6.17574962342319519e-19*V01*V11*V18 - 
      3.89859518299237609e-21*V14*V18 - 6.96631821103205767e-18*V015*V19 + 
      1.33246452918650435e-16*V01*V023*V19 + 3.51778605828113098e-16*V012*V02*V03*V19 - 
      5.30195453663738807e-17*V033*V19 + 6.67434963315523738e-17*V013*V04*V19 - 
      2.17594005264516657e-16*V02*V03*V04*V19 - 6.77736679324305903e-17*V01*V042*V19 - 
      6.3157999304959283e-17*V022*V05*V19 - 1.15261903455573263e-16*V01*V03*V05*V19 - 
      5.70349207682145938e-17*V01*V02*V06*V19 + 9.05850032210164094e-18*V05*V06*V19 - 
      1.06974737999581559e-17*V012*V07*V19 + 6.67130720694047361e-18*V04*V07*V19 + 
      3.73569071446876165e-18*V03*V08*V19 + 1.29332686754321592e-18*V02*V09*V19 + 3.70344626890027507e-19*V01*V10*V19 - 
      2.92447256372012168e-21*V13*V19 + 2.85551192903505611e-17*V012*V022*V20 + 
      1.54241623449528333e-17*V013*V03*V20 - 2.60909349336520287e-17*V02*V032*V20 - 
      1.74207676726838155e-17*V022*V04*V20 - 3.21839761953255226e-17*V01*V03*V04*V20 - 
      1.89693422445892274e-17*V01*V02*V05*V20 + 1.507450166579103e-18*V052*V20 - 
      4.05533372058364586e-18*V012*V06*V20 + 2.52091669100062144e-18*V04*V06*V20 + 
      1.59919233332147535e-18*V03*V07*V20 + 6.14017508186687117e-19*V02*V08*V20 + 1.93937832199031591e-19*V01*V09*V20 - 
      1.94914725536023387e-21*V12*V20 + 2.41886048994168669e-18*V013*V02*V21 - 
      4.03228292355933047e-18*V022*V03*V21 - 3.63989495156020115e-18*V01*V032*V21 - 
      5.04680018356289994e-18*V01*V02*V04*V21 - 1.28449282700284264e-18*V012*V05*V21 + 
      8.02432402920504752e-19*V04*V05*V21 + 5.77949536614653012e-19*V03*V06*V21 + 2.51317854740469661e-19*V02*V07*V21 + 
      8.80375045386575354e-20*V01*V08*V21 - 1.15206490350535903e-21*V11*V21 + 6.91102997126196197e-20*V014*V22 - 
      1.94729901305199939e-19*V023*V22 - 1.09790203300549076e-18*V01*V02*V03*V22 - 
      3.2865030430387618e-19*V012*V04*V22 + 1.02061871055122142e-19*V042*V22 + 
      1.75845457303328882e-19*V03*V05*V22 + 8.67898354472437892e-20*V02*V06*V22 + 3.44372143995019866e-20*V01*V07*V22 - 
      6.00794142809976083e-22*V10*V22 - 7.84203308922966536e-20*V01*V022*V23 - 
      6.77148541973494841e-20*V012*V03*V23 + 4.30198952102732732e-20*V03*V04*V23 + 
      2.53873898188616646e-20*V02*V05*V23 + 1.14334767451384403e-20*V01*V06*V23 - 2.75493723725231856e-22*V09*V23 - 
      9.45301800666866063e-21*V012*V02*V24 + 4.33914485660688024e-21*V032*V24 + 
      5.94323928835021042e-21*V02*V04*V24 + 3.20125128791523463e-21*V01*V05*V24 - 1.10072937550259637e-22*V08*V24 - 
      3.44227546461323776e-22*V013*V25 + 1.16186179777947863e-21*V02*V03*V25 + 7.259036540340276e-22*V01*V04*V25 - 
      3.81452196616897276e-23*V07*V25 + 7.38423607731549391e-23*V022*V26 + 1.34965463231316683e-22*V01*V03*V26 - 
      1.1260832742293394e-23*V06*V26 + 1.69085378393758746e-23*V01*V02*V27 - 2.82550179509119659e-24*V05*V27 + 
      8.83281827430083004e-25*V012*V28 - 5.74647920829221833e-25*V04*V28 - 9.73580702228962619e-26*V03*V29 - 
      1.10299928500260115e-26*V02*V30 - 1.10299928500260115e-27*V01*V31 + 5.25237754763143407e-31*V34) + 
   delta4*eps15*(-5.75595163384990213e-9*V024*V034 - 
      1.33753460237746165e-8*V01*V022*V035 - 1.84964378725148528e-9*V012*V036 - 
      6.95441630575759625e-9*V025*V032*V04 - 5.35763171174342526e-8*V01*V023*V033*V04 - 
      3.57644961382211394e-8*V012*V02*V034*V04 + 2.25795449233558217e-9*V036*V04 - 
      3.01110179246578381e-10*V026*V042 - 2.21355886291351093e-8*V01*V024*V03*V042 - 
      6.74061071399976892e-8*V012*V022*V032*V042 - 
      1.22581636390638721e-8*V013*V033*V042 + 2.12418184605975976e-8*V02*V034*V042 - 
      9.13035250564225638e-9*V012*V023*V043 - 
      1.59923908041281846e-8*V013*V02*V03*V043 + 
      2.49941339471928581e-8*V022*V032*V043 + 1.65930222085874917e-8*V01*V033*V043 - 
      5.04329951736614096e-10*V014*V044 + 1.99854473307210245e-9*V023*V044 + 
      1.53445653677719903e-8*V01*V02*V03*V044 + 9.10316240010937881e-10*V012*V045 - 
      1.0075222178954846e-10*V046 - 1.07216877683769801e-9*V026*V03*V05 - 
      2.04176650869791358e-8*V01*V024*V032*V05 - 
      3.77783772565079877e-8*V012*V022*V033*V05 - 
      4.99403236427675556e-9*V013*V034*V05 + 7.42192171853216571e-9*V02*V035*V05 - 
      4.17264978345455775e-9*V01*V025*V04*V05 - 4.65818212226313071e-8*V012*V023*V03*V04*V05 - 
      3.92349304159717121e-8*V013*V02*V032*V04*V05 + 4.55613657250034717e-8*V022*V033*V04*V05 + 
      2.13132461718077461e-8*V01*V034*V04*V05 - 1.27008818615788108e-8*V013*V022*V042*V05 - 
      4.87328584619900829e-9*V014*V03*V042*V05 + 2.57810004963820056e-8*V023*V03*V042*V05 + 
      8.111826612885037e-8*V01*V02*V032*V042*V05 + 1.61202952004238376e-8*V01*V022*V043*V05 + 
      1.54985170660626691e-8*V012*V03*V043*V05 - 2.84217107135235463e-9*V03*V044*V05 - 
      2.98327394347689178e-9*V012*V024*V052 - 
      1.04190156665139714e-8*V013*V022*V03*V052 - 
      1.96079347000926979e-9*V014*V032*V052 + 
      1.20670956519854897e-8*V023*V032*V052 + 
      2.33782881980548082e-8*V01*V02*V033*V052 - 2.61095180042503996e-9*V014*V02*V04*V052 + 
      3.26277629182316442e-9*V024*V04*V052 + 4.35837922403754774e-8*V01*V022*V03*V04*V052 + 
      1.96735316702525641e-8*V012*V032*V04*V052 + 
      1.26663103060685134e-8*V012*V02*V042*V052 - 
      7.5989538240400972e-9*V032*V042*V052 - 3.07602417913331699e-9*V02*V043*V052 - 
      6.5996771182409034e-11*V015*V053 + 2.57124167686087436e-9*V01*V023*V053 + 
      7.20805482093957709e-9*V012*V02*V03*V053 - 1.47581119100673938e-9*V033*V053 + 
      1.31324917791420645e-9*V013*V04*V053 - 5.5729337145363851e-9*V02*V03*V04*V053 - 
      1.68961258659508966e-9*V01*V042*V053 - 3.79098548665604991e-10*V022*V054 - 
      7.32298684707509985e-10*V01*V03*V054 - 2.90387133828066229e-11*V027*V06 - 
      3.0797340587922726e-9*V01*V025*V03*V06 - 1.58525757277245207e-8*V012*V023*V032*V06 - 
      8.68682657750367891e-9*V013*V02*V033*V06 + 8.08920666026613653e-9*V022*V034*V06 + 
      2.96536997623783671e-9*V01*V035*V06 - 4.7791083114074611e-9*V012*V024*V04*V06 - 
      1.69210521944280378e-8*V013*V022*V03*V04*V06 - 3.20192144783208961e-9*V014*V032*V04*V06 + 
      1.87667613277483657e-8*V023*V032*V04*V06 + 3.79598446836659101e-8*V01*V02*V033*V04*V06 - 
      2.13027479549262067e-9*V014*V02*V042*V06 + 2.19137492285588835e-9*V024*V042*V06 + 
      3.46864861300344703e-8*V01*V022*V03*V042*V06 + 
      1.61287062384268433e-8*V012*V032*V042*V06 + 
      6.88230449453901794e-9*V012*V02*V043*V06 - 4.09164185478500891e-9*V032*V043*V06 - 
      1.17525315795729364e-9*V02*V044*V06 - 2.98237768616752879e-9*V013*V023*V05*V06 - 
      3.43216655856408616e-9*V014*V02*V03*V05*V06 + 4.80124788789336841e-9*V024*V03*V05*V06 + 
      3.07426798687405541e-8*V01*V022*V032*V05*V06 + 9.05835338698472372e-9*V012*V033*V05*V06 - 
      3.23738378576919328e-10*V015*V04*V05*V06 + 1.20533916707527946e-8*V01*V023*V04*V05*V06 + 
      3.52827690241580592e-8*V012*V02*V03*V04*V05*V06 - 7.22682014570659194e-9*V033*V04*V05*V06 + 
      3.24706763374748056e-9*V013*V042*V05*V06 - 1.3369344382552071e-8*V02*V03*V042*V05*V06 - 
      2.73983633969211508e-9*V01*V043*V05*V06 + 4.77997808797116643e-9*V012*V022*V052*V06 + 
      2.69957868963648185e-9*V013*V03*V052*V06 - 5.98798627622073727e-9*V02*V032*V052*V06 - 
      3.59292329016266517e-9*V022*V04*V052*V06 - 7.19202253714579297e-9*V01*V03*V04*V052*V06 - 
      1.32699472166455017e-9*V01*V02*V053*V06 + 5.68863070462896819e-11*V054*V06 - 
      3.73872575795294671e-10*V014*V022*V062 + 1.59384680541473208e-10*V025*V062 - 
      1.053073777932816e-10*V015*V03*V062 + 4.33038526642093922e-9*V01*V023*V03*V062 + 
      6.11670437329990172e-9*V012*V02*V032*V062 - 6.42409156954803167e-10*V034*V062 + 
      3.87917504358491185e-9*V012*V022*V04*V062 + 
      2.22479698450497756e-9*V013*V03*V04*V062 - 4.81849589361648092e-9*V02*V032*V04*V062 - 
      1.36312961716195411e-9*V022*V042*V062 - 
      2.93001615458549223e-9*V01*V03*V042*V062 + 1.22561791263936001e-9*V013*V02*V05*V062 - 
      2.60721004576174814e-9*V022*V03*V05*V062 - 2.54324526275267657e-9*V01*V032*V05*V062 - 
      3.21592722689475587e-9*V01*V02*V04*V05*V062 - 4.11535547937541332e-10*V012*V052*V062 + 
      2.77171982421965853e-10*V04*V052*V062 + 3.65436173305002659e-11*V014*V063 - 
      1.1646676742631176e-10*V023*V063 - 7.65041215221972639e-10*V01*V02*V03*V063 - 
      2.25635842369847522e-10*V012*V04*V063 + 7.38212988542909675e-11*V042*V063 + 
      1.33066439467911994e-10*V03*V05*V063 + 1.47074976180538271e-11*V02*V064 - 
      1.53166968119671144e-10*V01*V026*V07 - 2.79781888023315714e-9*V012*V024*V03*V07 - 
      4.80517007122848849e-9*V013*V022*V032*V07 - 
      5.9779694949534361e-10*V014*V033*V07 + 4.04575176409858335e-9*V023*V033*V07 + 
      5.81507599444817803e-9*V01*V02*V034*V07 - 2.06229013602439365e-9*V013*V023*V04*V07 - 
      2.38717470045169697e-9*V014*V02*V03*V04*V07 + 3.30399633960128068e-9*V024*V03*V04*V07 + 
      2.17647649672820157e-8*V01*V022*V032*V04*V07 + 6.47917223532373546e-9*V012*V033*V04*V07 - 
      1.12737130331353195e-10*V015*V042*V07 + 4.1879019502630149e-9*V01*V023*V042*V07 + 
      1.25554705143598651e-8*V012*V02*V03*V042*V07 - 2.59949339324589366e-9*V033*V042*V07 + 
      7.73954046437383548e-10*V013*V043*V07 - 3.17388322217429567e-9*V02*V03*V043*V07 - 
      4.90546602154796121e-10*V01*V044*V07 - 6.36977157048299374e-10*V014*V022*V05*V07 + 
      3.28007957508665784e-10*V025*V05*V07 - 1.79426619054559102e-10*V015*V03*V05*V07 + 
      7.70397125408190138e-9*V01*V023*V03*V05*V07 + 1.0672195909367988e-8*V012*V02*V032*V05*V07 - 
      1.13262042335921197e-9*V034*V05*V07 + 6.77042962149892942e-9*V012*V022*V04*V05*V07 + 
      3.8603631340077956e-9*V013*V03*V04*V05*V07 - 8.58476254818736277e-9*V02*V032*V04*V05*V07 - 
      2.54294920622232393e-9*V022*V042*V05*V07 - 5.17520807677548291e-9*V01*V03*V042*V05*V07 + 
      1.0629008328174887e-9*V013*V02*V052*V07 - 2.33767201646529964e-9*V022*V03*V052*V07 - 
      2.23610875188765931e-9*V01*V032*V052*V07 - 2.85426418477382507e-9*V01*V02*V04*V052*V07 - 
      2.40435649560066415e-10*V012*V053*V07 + 1.64315176731550045e-10*V04*V053*V07 - 
      7.83298267200232204e-11*V015*V02*V06*V07 + 7.74711358122686302e-10*V01*V024*V06*V07 + 
      4.72188228530046237e-9*V012*V022*V03*V06*V07 + 1.31909051422137973e-9*V013*V032*V06*V07 - 
      2.04577183730862022e-9*V02*V033*V06*V07 + 1.74775789278447183e-9*V013*V02*V04*V06*V07 - 
      3.70281056634845367e-9*V022*V03*V04*V06*V07 - 3.66419066976416459e-9*V01*V032*V04*V06*V07 - 
      2.29711726863401593e-9*V01*V02*V042*V06*V07 + 1.8958725801536419e-10*V014*V05*V06*V07 - 
      6.54573593874488193e-10*V023*V05*V06*V07 - 4.05832172632011219e-9*V01*V02*V03*V05*V06*V07 - 
      1.18637013288946206e-9*V012*V04*V05*V06*V07 + 3.99111205396922537e-10*V042*V05*V06*V07 + 
      3.53988425428413597e-10*V03*V052*V06*V07 - 4.4590418184461056e-10*V01*V022*V062*V07 - 
      4.16031476682539208e-10*V012*V03*V062*V07 + 2.87948835500346869e-10*V03*V04*V062*V07 + 
      1.59358108325511764e-10*V02*V05*V062*V07 + 2.35855620983580903e-11*V01*V063*V07 - 
      1.60417849867865653e-12*V016*V072 + 2.97236073761393718e-10*V012*V023*V072 + 
      5.18338448550685856e-10*V013*V02*V03*V072 - 
      5.99587554307019128e-10*V022*V032*V072 - 3.78692650879710484e-10*V01*V033*V072 + 
      6.77040198218783748e-11*V014*V04*V072 - 2.30086131717902153e-10*V023*V04*V072 - 
      1.45530606536020248e-9*V01*V02*V03*V04*V072 - 2.13582113432048964e-10*V012*V042*V072 + 
      4.78228413844842261e-11*V043*V072 - 3.97409721093610732e-10*V01*V022*V05*V072 - 
      3.64271588583076804e-10*V012*V03*V05*V072 + 2.55745187829473887e-10*V03*V04*V05*V072 + 
      7.11082642232362267e-11*V02*V052*V072 - 1.6659728794499109e-10*V012*V02*V06*V072 + 
      9.16908808560598132e-11*V032*V06*V072 + 1.14328139061316781e-10*V02*V04*V06*V072 + 
      6.25133557525449488e-11*V01*V05*V06*V072 - 6.35586940835653129e-12*V013*V073 + 
      2.4593591159044371e-11*V02*V03*V073 + 1.5068247986582401e-11*V01*V04*V073 - 
      1.90252869888437769e-13*V074 - 1.70427473395641574e-10*V012*V025*V08 - 
      1.0251761662631159e-9*V013*V023*V03*V08 - 5.83212329912033601e-10*V014*V02*V032*V08 + 
      9.48538965944331317e-10*V024*V032*V08 + 3.92904784024486053e-9*V01*V022*V033*V08 + 
      8.54847442399214339e-10*V012*V034*V08 - 3.86210599345706359e-10*V014*V022*V04*V08 + 
      1.69524881415384083e-10*V025*V04*V08 - 1.08989886832385142e-10*V015*V03*V04*V08 + 
      4.69996481634274118e-9*V01*V023*V03*V04*V08 + 6.6830190329802379e-9*V012*V02*V032*V04*V08 - 
      7.16811629185232385e-10*V034*V04*V08 + 2.1092195385807579e-9*V012*V022*V042*V08 + 
      1.21521852185385816e-9*V013*V03*V042*V08 - 2.67835810245486395e-9*V02*V032*V042*V08 - 
      5.01628167628244246e-10*V022*V043*V08 - 1.08694389418565378e-9*V01*V03*V043*V08 - 
      5.81830658413412229e-11*V015*V02*V05*V08 + 6.05141311117271337e-10*V01*V024*V05*V08 + 
      3.62470254477943789e-9*V012*V022*V03*V05*V08 + 1.00770080800228547e-9*V013*V032*V05*V08 - 
      1.5866208858981361e-9*V02*V033*V05*V08 + 1.33506815303449444e-9*V013*V02*V04*V05*V08 - 
      2.89020732682354652e-9*V022*V03*V04*V05*V08 - 2.83362160948654039e-9*V01*V032*V04*V05*V08 - 
      1.78493147449694085e-9*V01*V02*V042*V05*V08 + 7.21920653758054096e-11*V014*V052*V08 - 
      2.5634119009217024e-10*V023*V052*V08 - 1.57103363040277634e-9*V01*V02*V03*V052*V08 - 
      4.57808690557083329e-10*V012*V04*V052*V08 + 1.55428008990830736e-10*V042*V052*V08 + 
      9.16435501824056351e-11*V03*V053*V08 - 2.79807929147735512e-12*V016*V06*V08 + 
      5.23562299514965585e-10*V012*V023*V06*V08 + 9.13205012418143163e-10*V013*V02*V03*V06*V08 - 
      1.04394611893298068e-9*V022*V032*V06*V08 - 6.6619970325423184e-10*V01*V033*V06*V08 + 
      1.19271179750055746e-10*V014*V04*V06*V08 - 3.84654019583296442e-10*V023*V04*V06*V08 - 
      2.54900110197523918e-9*V01*V02*V03*V04*V06*V08 - 3.76251387256650976e-10*V012*V042*V06*V08 + 
      8.26711505026440578e-11*V043*V06*V08 - 6.93362702480925264e-10*V01*V022*V05*V06*V08 - 
      6.41678976648299219e-10*V012*V03*V05*V06*V08 + 4.47992885725382122e-10*V03*V04*V05*V06*V08 + 
      1.24200024167960258e-10*V02*V052*V06*V08 - 1.46658383424150585e-10*V012*V02*V062*V08 + 
      8.04373156790374936e-11*V032*V062*V08 + 9.86787956771517725e-11*V02*V04*V062*V08 + 
      5.49108799730389564e-11*V01*V05*V062*V08 + 1.77346660877094329e-10*V013*V022*V07*V08 + 
      6.9612553021177551e-11*V014*V03*V07*V08 - 2.63717906411762154e-10*V023*V03*V07*V08 - 
      7.98691072871886839e-10*V01*V02*V032*V07*V08 - 4.93303462736083573e-10*V01*V022*V04*V07*V08 - 
      4.62535731197482185e-10*V012*V03*V04*V07*V08 + 1.61492916462588577e-10*V03*V042*V07*V08 - 
      2.57216665326567429e-10*V012*V02*V05*V07*V08 + 1.42374971826806857e-10*V032*V05*V07*V08 + 
      1.78378076018700729e-10*V02*V04*V05*V07*V08 + 4.84742025996056677e-11*V01*V052*V07*V08 - 
      3.36482391251835687e-11*V013*V06*V07*V08 + 1.28979799393310563e-10*V02*V03*V06*V07*V08 + 
      7.93510315371045315e-11*V01*V04*V06*V07*V08 + 1.26620143438213477e-11*V022*V072*V08 + 
      2.49635835348212831e-11*V01*V03*V072*V08 - 2.00236360260664183e-12*V06*V072*V08 + 
      1.20429293483982228e-11*V014*V02*V082 - 1.00499246549205338e-11*V024*V082 - 
      1.37194458049735669e-10*V01*V022*V03*V082 - 
      6.23201454931039772e-11*V012*V032*V082 - 
      8.1278808852014213e-11*V012*V02*V04*V082 + 4.51486821351529246e-11*V032*V04*V082 + 
      2.75762792260793433e-11*V02*V042*V082 - 1.29348850315525789e-11*V013*V05*V082 + 
      5.02086041304707485e-11*V02*V03*V05*V082 + 3.07962445323965014e-11*V01*V04*V05*V082 + 
      1.09035892855245555e-11*V022*V06*V082 + 2.19521604462425818e-11*V01*V03*V06*V082 - 
      8.75073082907095486e-13*V062*V082 + 8.85606794123703722e-12*V01*V02*V07*V082 - 
      1.55851258337419731e-12*V05*V07*V082 + 4.83146090328530368e-13*V012*V083 - 
      3.28709416948661768e-13*V04*V083 - 7.23120123246767472e-11*V013*V024*V09 - 
      1.67208405284223148e-10*V014*V022*V03*V09 + 1.01227466768531537e-10*V025*V03*V09 - 
      2.33226656105749263e-11*V015*V032*V09 + 1.16263811857571034e-9*V01*V023*V032*V09 + 
      1.05650652400631741e-9*V012*V02*V033*V09 - 7.08523549922023828e-11*V035*V09 - 
      3.12912048015674627e-11*V015*V02*V04*V09 + 3.24480615147292507e-10*V01*V024*V04*V09 + 
      2.02127200749165868e-9*V012*V022*V03*V04*V09 + 
      5.67472908333291817e-10*V013*V032*V04*V09 - 8.99261746242881386e-10*V02*V033*V04*V09 + 
      3.75012735131806508e-10*V013*V02*V042*V09 - 8.0609322192995553e-10*V022*V03*V042*V09 - 
      8.06827601940068547e-10*V01*V032*V042*V09 - 3.34754420284646701e-10*V01*V02*V043*V09 - 
      1.84076464442411991e-12*V016*V05*V09 + 3.59478488409636815e-10*V012*V023*V05*V09 + 
      6.23928262174748019e-10*V013*V02*V03*V05*V09 - 7.35474044442901287e-10*V022*V032*V05*V09 - 
      4.63022496151580414e-10*V01*V033*V05*V09 + 8.12581793135418172e-11*V014*V04*V05*V09 - 
      2.83192115289919769e-10*V023*V04*V05*V09 - 1.78151707244549023e-9*V01*V02*V03*V04*V05*V09 - 
      2.60914537313875954e-10*V012*V042*V05*V09 + 5.89174788008642096e-11*V043*V05*V09 - 
      2.43362983988671966e-10*V01*V022*V052*V09 - 2.22317381264484215e-10*V012*V03*V052*V09 + 
      1.57336614719793988e-10*V03*V04*V052*V09 + 2.91801831888890386e-11*V02*V053*V09 + 
      1.3978895515332503e-10*V013*V022*V06*V09 + 5.48544709288380268e-11*V014*V03*V06*V09 - 
      2.07178981455940555e-10*V023*V03*V06*V09 - 6.3140889502984958e-10*V01*V02*V032*V06*V09 - 
      3.88601993876568087e-10*V01*V022*V04*V06*V09 - 3.66065889154477524e-10*V012*V03*V04*V06*V09 + 
      1.27717855903041671e-10*V03*V042*V06*V09 - 2.03421524676885456e-10*V012*V02*V05*V06*V09 + 
      1.12775109633385867e-10*V032*V05*V06*V09 + 1.40877946687492648e-10*V02*V04*V05*V06*V09 + 
      3.84070752049486682e-11*V01*V052*V06*V09 - 1.33206754471036951e-11*V013*V062*V09 + 
      5.09782525062199766e-11*V02*V03*V062*V09 + 3.14114809174157161e-11*V01*V04*V062*V09 + 
      2.15460467596588886e-11*V014*V02*V07*V09 - 1.89063957780593667e-11*V024*V07*V09 - 
      2.47656191512090137e-10*V01*V022*V03*V07*V09 - 1.11982135615739036e-10*V012*V032*V07*V09 - 
      1.46023858746673802e-10*V012*V02*V04*V07*V09 + 8.15295467106662529e-11*V032*V04*V07*V09 + 
      5.04659620584989891e-11*V02*V042*V07*V09 - 2.32132254952394711e-11*V013*V05*V07*V09 + 
      9.08116063502813697e-11*V02*V03*V05*V07*V09 + 5.5556214766579499e-11*V01*V04*V05*V07*V09 + 
      1.99737910559292885e-11*V022*V06*V07*V09 + 3.95652927394372068e-11*V01*V03*V06*V07*V09 - 
      1.58609521460157897e-12*V062*V07*V09 + 7.99567475469760818e-12*V01*V02*V072*V09 - 
      1.40755879485908188e-12*V05*V072*V09 + 1.08605174457313821e-12*V015*V08*V09 - 
      2.74715927306433635e-11*V01*V023*V08*V09 - 7.90899273120070338e-11*V012*V02*V03*V08*V09 + 
      1.50946315406139285e-11*V033*V08*V09 - 1.47679101743175746e-11*V013*V04*V08*V09 + 
      5.70779401598736952e-11*V02*V03*V04*V08*V09 + 1.76066781478965416e-11*V01*V042*V08*V09 + 
      1.56080762501629177e-11*V022*V05*V08*V09 + 3.06652377582535973e-11*V01*V03*V05*V08*V09 + 
      1.40152430231266507e-11*V01*V02*V06*V08*V09 - 2.4697067774447241e-12*V05*V06*V08*V09 + 
      2.60722764754216501e-12*V012*V07*V08*V09 - 1.78786182423184093e-12*V04*V07*V08*V09 - 
      5.01935657490403965e-13*V03*V082*V09 - 6.16386321932891155e-12*V012*V022*V092 - 
      3.5229445701407384e-12*V013*V03*V092 + 7.23673659127846216e-12*V02*V032*V092 + 
      4.39261981981223271e-12*V022*V04*V092 + 8.79318411220634135e-12*V01*V03*V04*V092 + 
      4.91420123128997871e-12*V01*V02*V05*V092 - 4.33939756493681477e-13*V052*V092 + 
      1.0336523502424746e-12*V012*V06*V092 - 7.07940020800860348e-13*V04*V06*V092 - 
      4.53112002429293489e-13*V03*V07*V092 - 1.61187445002127568e-13*V02*V08*V092 - 
      1.68369268356491718e-14*V01*V093 - 1.42552905474366091e-11*V014*V023*V10 + 
      3.39088398299485686e-12*V026*V10 - 1.19897554040253518e-11*V015*V02*V03*V10 + 
      1.49946885108921459e-10*V01*V024*V03*V10 + 4.36183401236934008e-10*V012*V022*V032*V10 + 
      7.97215752804704171e-11*V013*V033*V10 - 1.01369595382999041e-10*V02*V034*V10 - 
      8.86996267316706896e-13*V016*V04*V10 + 1.80576832806172297e-10*V012*V023*V04*V10 + 
      3.1710638201049227e-10*V013*V02*V03*V04*V10 - 3.72774843403986934e-10*V022*V032*V04*V10 - 
      2.39319980237375375e-10*V01*V033*V04*V10 + 2.06873173505869717e-11*V014*V042*V10 - 
      6.79143282663454739e-11*V023*V042*V10 - 4.5584496971459782e-10*V01*V02*V03*V042*V10 - 
      4.49186392468863781e-11*V012*V043*V10 + 7.47365920311140093e-12*V044*V10 + 
      8.63965058203940387e-11*V013*V022*V05*V10 + 3.38096419823143957e-11*V014*V03*V05*V10 - 
      1.32642583791978555e-10*V023*V03*V05*V10 - 3.98317282388185222e-10*V01*V02*V032*V05*V10 - 
      2.47046788894989731e-10*V01*V022*V04*V05*V10 - 2.29998304756227949e-10*V012*V03*V04*V05*V10 + 
      8.12522209624350587e-11*V03*V042*V05*V10 - 6.39681289449328915e-11*V012*V02*V052*V10 + 
      3.57468045760170845e-11*V032*V052*V10 + 4.49361976745918174e-11*V02*V04*V052*V10 + 
      8.1029120464098437e-12*V01*V053*V10 + 1.53647476833999626e-11*V014*V02*V06*V10 - 
      1.28961209158556382e-11*V024*V06*V10 - 1.76736402512024239e-10*V01*V022*V03*V06*V10 - 
      8.03646336662714128e-11*V012*V032*V06*V10 - 1.04747195935327316e-10*V012*V02*V04*V06*V10 + 
      5.84010035095451818e-11*V032*V04*V06*V10 + 3.56160092432287142e-11*V02*V042*V06*V10 - 
      1.66705925383192257e-11*V013*V05*V06*V10 + 6.49130523094259842e-11*V02*V03*V05*V06*V10 + 
      3.98324634579214365e-11*V01*V04*V05*V06*V10 + 7.0384696537963398e-12*V022*V062*V10 + 
      1.41991426157655704e-11*V01*V03*V062*V10 - 3.77693216669010668e-13*V063*V10 + 
      8.78952440713143856e-13*V015*V07*V10 - 2.24611934772031693e-11*V01*V023*V07*V10 - 
      6.44307547881218426e-11*V012*V02*V03*V07*V10 + 1.23250522004714388e-11*V033*V07*V10 - 
      1.20192130019920008e-11*V013*V04*V07*V10 + 4.66756864589918011e-11*V02*V03*V04*V07*V10 + 
      1.43818068836910167e-11*V01*V042*V07*V10 + 1.2774614251483927e-11*V022*V05*V07*V10 + 
      2.5029178504517518e-11*V01*V03*V05*V07*V10 + 1.14497288812298019e-11*V01*V02*V06*V07*V10 - 
      2.0186155714004623e-12*V05*V06*V07*V10 + 1.06338403287593309e-12*V012*V072*V10 - 
      7.30842053204762098e-13*V04*V072*V10 - 1.1183238757925844e-11*V012*V022*V08*V10 - 
      6.39081509517365356e-12*V013*V03*V08*V10 + 1.30886693015718865e-11*V02*V032*V08*V10 + 
      7.84991303515339436e-12*V022*V04*V08*V10 + 1.59286137411111036e-11*V01*V03*V04*V08*V10 + 
      8.89375166090471332e-12*V01*V02*V05*V08*V10 - 7.85442984750771433e-13*V052*V08*V10 + 
      1.87500693999472891e-12*V012*V06*V08*V10 - 1.27694092570043371e-12*V04*V06*V08*V10 - 
      8.20357711444097007e-13*V03*V07*V08*V10 - 1.45297814877884683e-13*V02*V082*V10 - 
      2.03400314693430551e-12*V013*V02*V09*V10 + 4.08718462889542036e-12*V022*V03*V09*V10 + 
      3.95104383202251977e-12*V01*V032*V09*V10 + 5.06811707238638464e-12*V01*V02*V04*V09*V10 + 
      1.30424278689770725e-12*V012*V05*V09*V10 - 9.01747332246723662e-13*V04*V05*V09*V10 - 
      6.50330660949607716e-13*V03*V06*V09*V10 - 2.6369148314470303e-13*V02*V07*V09*V10 - 
      9.15224462810823263e-14*V01*V08*V09*V10 - 5.83199085720695954e-14*V014*V102 + 
      1.84286879051645089e-13*V023*V102 + 1.14915062594351224e-12*V01*V02*V03*V102 + 
      3.3974562624120075e-13*V012*V04*V102 - 1.16462184664327472e-13*V042*V102 - 
      2.06701820957322756e-13*V03*V05*V102 - 9.40656725034832996e-14*V02*V06*V102 - 
      3.73804473724789227e-14*V01*V07*V102 + 2.16039546984966416e-16*V103 - 
      1.3878425800349175e-12*V015*V022*V11 + 6.62485948610316709e-12*V01*V025*V11 - 
      3.0452521207595167e-13*V016*V03*V11 + 7.16202074867547917e-11*V012*V023*V03*V11 + 
      6.10170436741924928e-11*V013*V02*V032*V11 - 5.20793838275978437e-11*V022*V033*V11 - 
      2.42592007366060956e-11*V01*V034*V11 + 3.99780487670988742e-11*V013*V022*V04*V11 + 
      1.57070019070981645e-11*V014*V03*V04*V11 - 6.08037262302499026e-11*V023*V03*V04*V11 - 
      1.8752779509070234e-10*V01*V02*V032*V04*V11 - 5.72426034575836551e-11*V01*V022*V042*V11 - 
      5.44169338694261605e-11*V012*V03*V042*V11 + 1.28026148500474309e-11*V03*V043*V11 + 
      8.64074603854811807e-12*V014*V02*V05*V11 - 7.89647692594503388e-12*V024*V05*V11 - 
      1.02567207439240856e-10*V01*V022*V03*V05*V11 - 4.61844032647395782e-11*V012*V032*V05*V11 - 
      6.02895540789022624e-11*V012*V02*V04*V05*V11 + 3.40128149743122095e-11*V032*V04*V05*V11 + 
      2.11091362948575779e-11*V02*V042*V05*V11 - 4.77345974948265293e-12*V013*V052*V11 + 
      1.89543607099110105e-11*V02*V03*V052*V11 + 1.15737088953182751e-11*V01*V04*V052*V11 + 
      5.71883555326742509e-13*V015*V06*V11 - 1.46324135603078241e-11*V01*V023*V06*V11 - 
      4.22993415511816775e-11*V012*V02*V03*V06*V11 + 8.1106677721933127e-12*V033*V06*V11 - 
      7.90050624101424103e-12*V013*V04*V06*V11 + 3.06026203925457916e-11*V02*V03*V04*V06*V11 + 
      9.45111459967072209e-12*V01*V042*V06*V11 + 8.35681910644645314e-12*V022*V05*V06*V11 + 
      1.64765440558254571e-11*V01*V03*V05*V06*V11 + 3.7599127787847865e-12*V01*V02*V062*V11 - 
      6.63975340716985795e-13*V05*V062*V11 - 8.33565404051738458e-12*V012*V022*V07*V11 - 
      4.76015665980226975e-12*V013*V03*V07*V11 + 9.81704463973043759e-12*V02*V032*V07*V11 + 
      5.96346382613951346e-12*V022*V04*V07*V11 + 1.1923510273596684e-11*V01*V03*V04*V07*V11 + 
      6.66427979629626257e-12*V01*V02*V05*V07*V11 - 5.88976793157540067e-13*V052*V07*V11 + 
      1.40097141848514522e-12*V012*V06*V07*V11 - 9.61087873654005754e-13*V04*V06*V07*V11 - 
      3.0751371779985391e-13*V03*V072*V11 - 1.68854512603409838e-12*V013*V02*V08*V11 + 
      3.3897874329969295e-12*V022*V03*V08*V11 + 3.28204323212034194e-12*V01*V032*V08*V11 + 
      4.20651566146135539e-12*V01*V02*V04*V08*V11 + 1.08353433911635919e-12*V012*V05*V08*V11 - 
      7.4869255842370735e-13*V04*V05*V08*V11 - 5.40089608349442748e-13*V03*V06*V08*V11 - 
      2.18875230744263716e-13*V02*V07*V08*V11 - 3.80177599807543308e-14*V01*V082*V11 - 
      1.06747922534082891e-13*V014*V09*V11 + 3.42132853692993397e-13*V023*V09*V11 + 
      2.1076898936046518e-12*V01*V02*V03*V09*V11 + 6.22376500020486741e-13*V012*V04*V09*V11 - 
      2.14429595150989571e-13*V042*V09*V11 - 3.79258325320734191e-13*V03*V05*V09*V11 - 
      1.73234690439640037e-13*V02*V06*V09*V11 - 6.85564771654696818e-14*V01*V07*V09*V11 + 
      2.99799155175718529e-13*V01*V022*V10*V11 + 2.76588204400222534e-13*V012*V03*V10*V11 - 
      1.97390691620690555e-13*V03*V04*V10*V11 - 1.10525688809560278e-13*V02*V05*V10*V11 - 
      4.92776334242037896e-14*V01*V06*V10*V11 + 1.19027201591124669e-15*V09*V10*V11 + 
      3.70717508119865881e-14*V012*V02*V112 - 2.07050163598410782e-14*V032*V112 - 
      2.61929541759672535e-14*V02*V04*V112 - 1.43353100506352355e-14*V01*V05*V112 + 
      4.94410842262440639e-16*V08*V112 - 6.40901275414949306e-14*V016*V02*V12 + 
      3.96090666181877551e-12*V012*V024*V12 + 1.41547274717872882e-11*V013*V022*V03*V12 + 
      2.73503496764522163e-12*V014*V032*V12 - 1.19656575816468386e-11*V023*V032*V12 - 
      2.3509256545649613e-11*V01*V02*V033*V12 + 3.68306730715457157e-12*V014*V02*V04*V12 - 
      3.1644614769628394e-12*V024*V04*V12 - 4.41105987307176078e-11*V01*V022*V03*V04*V12 - 
      2.01708121669298411e-11*V012*V032*V04*V12 - 1.30943213736233436e-11*V012*V02*V042*V12 + 
      7.43952907229556044e-12*V032*V042*V12 + 3.00394592730879446e-12*V02*V043*V12 + 
      2.94931462678948253e-13*V015*V05*V12 - 7.88095952192383788e-12*V01*V023*V05*V12 - 
      2.24360706605801828e-11*V012*V02*V03*V05*V12 + 4.34408783360454413e-12*V033*V05*V12 - 
      4.17178988396019595e-12*V013*V04*V05*V12 + 1.64931944792854631e-11*V02*V03*V04*V05*V12 + 
      5.0690930770577343e-12*V01*V042*V05*V12 + 2.25991940146370708e-12*V022*V052*V12 + 
      4.40435803750995723e-12*V01*V03*V052*V12 - 5.04515246198643235e-12*V012*V022*V06*V12 - 
      2.8850251859051624e-12*V013*V03*V06*V12 + 5.94019179814890314e-12*V02*V032*V06*V12 + 
      3.55337254784802649e-12*V022*V04*V06*V12 + 7.23272397456735734e-12*V01*V03*V04*V06*V12 + 
      4.035671376617211e-12*V01*V02*V05*V06*V12 - 3.57221701340026881e-13*V052*V06*V12 + 
      4.25687586043336912e-13*V012*V062*V12 - 2.90208582777971192e-13*V04*V062*V12 - 
      1.15953993922015053e-12*V013*V02*V07*V12 + 2.34614553680158319e-12*V022*V03*V07*V12 + 
      2.26375661872343896e-12*V01*V032*V07*V12 + 2.90618298366261679e-12*V01*V02*V04*V07*V12 + 
      7.46847867293630477e-13*V012*V05*V07*V12 - 5.17586469103732062e-13*V04*V05*V07*V12 - 
      3.73205320541160441e-13*V03*V06*V07*V12 - 7.57084213832246918e-14*V02*V072*V12 - 
      8.16948854786364225e-14*V014*V08*V12 + 2.58425164105029037e-13*V023*V08*V12 + 
      1.61320204391467274e-12*V01*V02*V03*V08*V12 + 4.7699434733056455e-13*V012*V04*V08*V12 - 
      1.63517488066355372e-13*V042*V08*V12 - 2.90310351090206909e-13*V03*V05*V08*V12 - 
      1.32066202321863396e-13*V02*V06*V08*V12 - 5.25062188849326061e-14*V01*V07*V08*V12 + 
      2.53515261355306849e-13*V01*V022*V09*V12 + 2.33702061286885273e-13*V012*V03*V09*V12 - 
      1.66906646221739802e-13*V03*V04*V09*V12 - 9.34765232692454237e-14*V02*V05*V09*V12 - 
      4.16577198680349129e-14*V01*V06*V09*V12 + 5.03211410408688742e-16*V092*V12 + 
      6.83998030940585659e-14*V012*V02*V10*V12 - 3.81685018321718988e-14*V032*V10*V12 - 
      4.81136435000060925e-14*V02*V04*V10*V12 - 2.64311526570258692e-14*V01*V05*V10*V12 + 9.10517981460738865e-16*V08*V10*V12 + 
      5.23846898288724319e-15*V013*V11*V12 - 2.04858530267767868e-14*V02*V03*V11*V12 - 
      1.26536392353806405e-14*V01*V04*V11*V12 + 6.83648840327817766e-16*V07*V11*V12 - 
      1.23290249736541168e-15*V022*V122 - 2.42547683749418192e-15*V01*V03*V122 + 
      2.07510568539319633e-16*V06*V122 - 1.10978575829428451e-15*V017*V13 + 
      1.0012901270508949e-12*V013*V023*V13 + 1.18475158521891881e-12*V014*V02*V03*V13 - 
      1.22434910072765092e-12*V024*V03*V13 - 7.77833026821133104e-12*V01*V022*V032*V13 - 
      2.30219592328667981e-12*V012*V033*V13 + 1.1617928923442058e-13*V015*V04*V13 - 
      3.09775831905577177e-12*V01*V023*V04*V13 - 9.04980676335295248e-12*V012*V02*V03*V04*V13 + 
      1.77141001418445482e-12*V033*V04*V13 - 8.45435971369507974e-13*V013*V042*V13 + 
      3.32256128823920851e-12*V02*V03*V042*V13 + 6.8571947222341276e-13*V01*V043*V13 - 
      2.48452572673524829e-12*V012*V022*V05*V13 - 1.41275123053804934e-12*V013*V03*V05*V13 + 
      2.96548926069250409e-12*V02*V032*V05*V13 + 1.80734491647764506e-12*V022*V04*V05*V13 + 
      3.59432871925036302e-12*V01*V03*V04*V05*V13 + 1.00494825196489317e-12*V01*V02*V052*V13 - 
      5.9471384042397107e-14*V053*V13 - 6.5191691242990053e-13*V013*V02*V06*V13 + 
      1.31458983652548874e-12*V022*V03*V06*V13 + 1.2764417331268707e-12*V01*V032*V06*V13 + 
      1.63321576960691756e-12*V01*V02*V04*V06*V13 + 4.21302786579730467e-13*V012*V05*V06*V13 - 
      2.91400048437152503e-13*V04*V05*V06*V13 - 1.05160885434851591e-13*V03*V062*V13 - 
      5.20171925495202346e-14*V014*V07*V13 + 1.68179159941431467e-13*V023*V07*V13 + 
      1.03413893491935274e-12*V01*V02*V03*V07*V13 + 3.05176334163477258e-13*V012*V04*V07*V13 - 
      1.05378156055815678e-13*V042*V07*V13 - 1.8630876623203021e-13*V03*V05*V07*V13 - 
      8.51450785021197108e-14*V02*V06*V07*V13 - 1.68360003978571251e-14*V01*V072*V13 + 
      1.80025178427086255e-13*V01*V022*V08*V13 + 1.66256982532884397e-13*V012*V03*V08*V13 - 
      1.18650384386747686e-13*V03*V04*V08*V13 - 6.6413078608162689e-14*V02*V05*V08*V13 - 
      2.96291924526899452e-14*V01*V06*V08*V13 + 5.36395156957499654e-14*V012*V02*V09*V13 - 
      2.99721353292119956e-14*V032*V09*V13 - 3.79213699303647611e-14*V02*V04*V09*V13 - 
      2.07499667667118546e-14*V01*V05*V09*V13 + 7.15680367844738453e-16*V08*V09*V13 + 
      4.48547702342032313e-15*V013*V10*V13 - 1.75344096578876677e-14*V02*V03*V10*V13 - 
      1.0832833629976717e-14*V01*V04*V10*V13 + 5.85194334792429912e-16*V07*V10*V13 - 
      2.29790663101466007e-15*V022*V11*V13 - 4.50458405107458601e-15*V01*V03*V11*V13 + 
      3.85804405032428283e-16*V06*V11*V13 - 1.12158981622581749e-15*V01*V02*V12*V13 + 2.07861203857689333e-16*V05*V12*V13 - 
      5.93685011022915468e-17*V012*V132 + 4.26594731587995445e-17*V04*V132 + 
      1.18364079421990143e-13*V014*V022*V14 - 4.28348839158210253e-14*V025*V14 + 
      3.4282729620351702e-14*V015*V03*V14 - 1.03914624709792263e-12*V01*V023*V03*V14 - 
      1.4507811415767192e-12*V012*V02*V032*V14 + 1.46664669165581283e-13*V034*V14 - 
      9.29744177500547544e-13*V012*V022*V04*V14 - 5.33917881708764935e-13*V013*V03*V04*V14 + 
      1.12033774246997738e-12*V02*V032*V04*V14 + 3.32243109213899647e-13*V022*V042*V14 + 
      6.83099314944863851e-13*V01*V03*V042*V14 - 2.9764919951296944e-13*V013*V02*V05*V14 + 
      6.15327079086100769e-13*V022*V03*V05*V14 + 5.90924414493301506e-13*V01*V032*V05*V14 + 
      7.60106072542790058e-13*V01*V02*V04*V05*V14 + 9.72833716792564991e-14*V012*V052*V14 - 
      6.79874022182466545e-14*V04*V052*V14 - 2.7268781276149109e-14*V014*V06*V14 + 
      8.66466737500054404e-14*V023*V06*V14 + 5.4315393637263535e-13*V01*V02*V03*V06*V14 + 
      1.60672018218935255e-13*V012*V04*V06*V14 - 5.51327074568390102e-14*V042*V06*V14 - 
      9.79987870932840004e-14*V03*V05*V06*V14 - 2.22578492911947743e-14*V02*V062*V14 + 
      1.07835948476379621e-13*V01*V022*V07*V14 + 9.92644416860280666e-14*V012*V03*V07*V14 - 
      7.10671182675504163e-14*V03*V04*V07*V14 - 3.98129026408113772e-14*V02*V05*V07*V14 - 
      1.77295250435522016e-14*V01*V06*V07*V14 + 3.56108496997571336e-14*V012*V02*V08*V14 - 
      1.98866304505970751e-14*V032*V08*V14 - 2.5048937434673181e-14*V02*V04*V08*V14 - 
      1.37710688148305858e-14*V01*V05*V08*V14 + 2.37151204436541143e-16*V082*V14 + 
      3.28204845554484519e-15*V013*V09*V14 - 1.28498117931707491e-14*V02*V03*V09*V14 - 
      7.93508417349814912e-15*V01*V04*V09*V14 + 4.2868126663387884e-16*V07*V09*V14 - 
      1.82849938591943904e-15*V022*V10*V14 - 3.59844217471910695e-15*V01*V03*V10*V14 + 
      3.07772228518966079e-16*V06*V10*V14 - 9.71785723468669284e-16*V01*V02*V11*V14 + 1.8008154256283398e-16*V05*V11*V14 - 
      1.10804786890180203e-16*V012*V12*V14 + 7.95128775648398026e-17*V04*V12*V14 + 2.880137077133087e-17*V03*V13*V14 + 
      3.11421472518842702e-18*V02*V142 + 6.40338340610017422e-15*V015*V02*V15 - 
      4.67961571371463845e-14*V01*V024*V15 - 2.80905931961663146e-13*V012*V022*V03*V15 - 
      7.87325242285058417e-14*V013*V032*V15 + 1.17044505110552058e-13*V02*V033*V15 - 
      1.05086122774852167e-13*V013*V02*V04*V15 + 2.15765054734249452e-13*V022*V03*V04*V15 + 
      2.11146061613718914e-13*V01*V032*V04*V15 + 1.34375399794479698e-13*V01*V02*V042*V15 - 
      1.16225731355827461e-14*V014*V05*V15 + 3.86809169923827817e-14*V023*V05*V15 + 
      2.36353316462083084e-13*V01*V02*V03*V05*V15 + 6.95779224769615018e-14*V012*V04*V05*V15 - 
      2.42388359866608381e-14*V042*V05*V15 - 2.13980277873194131e-14*V03*V052*V15 + 
      5.29457010143509482e-14*V01*V022*V06*V15 + 4.90063707256884303e-14*V012*V03*V06*V15 - 
      3.50316227799251362e-14*V03*V04*V06*V15 - 1.95916530057797718e-14*V02*V05*V06*V15 - 
      4.37617245916216772e-15*V01*V062*V15 + 1.99332084726158967e-14*V012*V02*V07*V15 - 
      1.11631206321368453e-14*V032*V07*V15 - 1.41325508244753122e-14*V02*V04*V07*V15 - 
      7.72579251379088e-15*V01*V05*V07*V15 + 2.04311750011570369e-15*V013*V08*V15 - 
      7.98875511270690028e-15*V02*V03*V08*V15 - 4.93716646829284181e-15*V01*V04*V08*V15 + 2.66632107710236975e-16*V07*V08*V15 - 
      1.26095709848823258e-15*V022*V09*V15 - 2.47106289923661146e-15*V01*V03*V09*V15 + 
      2.11592846425688834e-16*V06*V09*V15 - 7.27690309190637932e-16*V01*V02*V10*V15 + 1.34825113482092697e-16*V05*V10*V15 - 
      8.99831613479611201e-17*V012*V11*V15 + 6.46486524979714298e-17*V04*V11*V15 + 2.5190401307325293e-17*V03*V12*V15 + 
      5.84518112373773328e-18*V02*V13*V15 + 1.22703147235763829e-18*V01*V14*V15 + 1.26660331109673776e-16*V016*V16 - 
      1.67054421706067237e-14*V012*V023*V16 - 2.91692878641360665e-14*V013*V02*V03*V16 + 
      3.22655632145655518e-14*V022*V032*V16 + 2.03691403341444714e-14*V01*V033*V16 - 
      3.8648992701104623e-15*V014*V04*V16 + 1.24548711132347608e-14*V023*V04*V16 + 
      7.90228070554046947e-14*V01*V02*V03*V04*V16 + 1.17031237057194191e-14*V012*V042*V16 - 
      2.69571180259962317e-15*V043*V16 + 2.17836342578911413e-14*V01*V022*V05*V16 + 
      1.99619603772064574e-14*V012*V03*V05*V16 - 1.44197561245264989e-14*V03*V04*V05*V16 - 
      4.04224132998005154e-15*V02*V052*V16 + 9.25707100091688438e-15*V012*V02*V06*V16 - 
      5.18681164183064889e-15*V032*V06*V16 - 6.51917039811206745e-15*V02*V04*V06*V16 - 
      3.59148087668001901e-15*V01*V05*V06*V16 + 1.07535116117014559e-15*V013*V07*V16 - 
      4.22598033026682537e-15*V02*V03*V07*V16 - 2.60812977713306406e-15*V01*V04*V07*V16 + 
      7.04670174084274211e-17*V072*V16 - 7.34765448190784902e-16*V022*V08*V16 - 
      1.4478262629827238e-15*V01*V03*V08*V16 + 1.23739078187670019e-16*V06*V08*V16 - 4.7048935875576849e-16*V01*V02*V09*V16 + 
      8.71531953250713656e-17*V05*V09*V16 - 6.34534470086816395e-17*V012*V10*V16 + 
      4.55065172408356582e-17*V04*V10*V16 + 1.92567481087498725e-17*V03*V11*V16 + 4.80629418143005869e-18*V02*V12*V16 + 
      1.08262931012158612e-18*V01*V13*V16 - 2.45061235864196038e-21*V162 - 
      2.51983692057634328e-15*V013*V022*V17 - 9.96394604729433703e-16*V014*V03*V17 + 
      3.62432123077146061e-15*V023*V03*V17 + 1.08806322429734029e-14*V01*V02*V032*V17 + 
      6.81388374712531768e-15*V01*V022*V04*V17 + 6.35053742260113505e-15*V012*V03*V04*V17 - 
      2.29030108365664614e-15*V03*V042*V17 + 3.56542357844788904e-15*V012*V02*V05*V17 - 
      2.01339392141142467e-15*V032*V05*V17 - 2.5543892247265667e-15*V02*V04*V05*V17 - 
      6.95842949185909636e-16*V01*V052*V17 + 4.72331620858940415e-16*V013*V06*V17 - 
      1.85102724834307656e-15*V02*V03*V06*V17 - 1.14484807721765924e-15*V01*V04*V06*V17 - 
      3.68964586242253894e-16*V022*V07*V17 - 7.22186153623210291e-16*V01*V03*V07*V17 + 
      6.18539729341282496e-17*V06*V07*V17 - 2.60242557763906784e-16*V01*V02*V08*V17 + 4.82003475622162396e-17*V05*V08*V17 - 
      3.8726852070208872e-17*V012*V09*V17 + 2.78174220789880787e-17*V04*V09*V17 + 1.28185492114115562e-17*V03*V10*V17 + 
      3.47411097733288187e-18*V02*V11*V17 + 8.41767650212877335e-19*V01*V12*V17 - 4.63041405427740273e-21*V15*V17 - 
      1.64658430442575909e-16*V014*V02*V18 + 1.37413534730413427e-16*V024*V18 + 
      1.80019956716758898e-15*V01*V022*V03*V18 + 8.13053536105151605e-16*V012*V032*V18 + 
      1.07022295390728281e-15*V012*V02*V04*V18 - 6.08381948510965894e-16*V032*V04*V18 - 
      3.79976089256209743e-16*V02*V042*V18 + 1.71599976650074612e-16*V013*V05*V18 - 
      6.83348588084798972e-16*V02*V03*V05*V18 - 4.20903966838599793e-16*V01*V04*V05*V18 - 
      1.52166953845965372e-16*V022*V06*V18 - 3.00786462165843516e-16*V01*V03*V06*V18 + 
      1.28475392436710038e-17*V062*V18 - 1.2313744133848373e-16*V01*V02*V07*V18 + 2.28072908716213765e-17*V05*V07*V18 - 
      2.03246574680228798e-17*V012*V08*V18 + 1.45610760461883285e-17*V04*V08*V18 + 
      7.41693214540305813e-18*V03*V09*V18 + 2.18854829635595661e-18*V02*V10*V18 + 5.75876847626202629e-19*V01*V11*V18 - 
      3.89789432027746566e-21*V14*V18 - 3.79980993329021327e-18*V015*V19 + 
      9.16917161702347871e-17*V01*V023*V19 + 2.61576800015319201e-16*V012*V02*V03*V19 - 
      5.08983643302971094e-17*V033*V19 + 4.919516460149305e-17*V013*V04*V19 - 
      1.94884209011626668e-16*V02*V03*V04*V19 - 6.03866630813505847e-17*V01*V042*V19 - 
      5.38384727408083237e-17*V022*V05*V19 - 1.04932266981994626e-16*V01*V03*V05*V19 - 
      4.86504986619984933e-17*V01*V02*V06*V19 + 9.01793146342935853e-18*V05*V06*V19 - 
      9.12231485445134237e-18*V012*V07*V19 + 6.55739608937096182e-18*V04*V07*V19 + 
      3.69514528407275138e-18*V03*V08*V19 + 1.20494853725635922e-18*V02*V09*V19 + 3.45218681853079927e-19*V01*V10*V19 - 
      2.92447168132069368e-21*V13*V19 + 1.97152836816545788e-17*V012*V022*V20 + 
      1.12503190926118969e-17*V013*V03*V20 - 2.35333918938980768e-17*V02*V032*V20 - 
      1.44320270282494361e-17*V022*V04*V20 - 2.87769655188951457e-17*V01*V03*V04*V20 - 
      1.62180562954934623e-17*V01*V02*V05*V20 + 1.50552514134082908e-18*V052*V20 - 
      3.44452068104764934e-18*V012*V06*V20 + 2.46621683708518486e-18*V04*V06*V20 + 
      1.58309630551388216e-18*V03*V07*V20 + 5.70909310537323989e-19*V02*V08*V20 + 1.80800503623844145e-19*V01*V09*V20 - 
      1.94864689124942014e-21*V12*V20 + 1.6502701870770988e-18*V013*V02*V21 - 
      3.3878666499968055e-18*V022*V03*V21 - 3.25635785727418027e-18*V01*V032*V21 - 
      4.22099646555598261e-18*V01*V02*V04*V21 - 1.09039285179115704e-18*V012*V05*V21 + 
      7.88367870792225278e-19*V04*V05*V21 + 5.70032964190116849e-19*V03*V06*V21 + 2.34095038971662662e-19*V02*V07*V21 + 
      8.19901134272159632e-20*V01*V08*V21 - 1.15206402110593103e-21*V11*V21 + 4.60735331417464132e-20*V014*V22 - 
      1.50384452345748675e-19*V023*V22 - 9.21911750946411171e-19*V01*V02*V03*V22 - 
      2.73875482842338682e-19*V012*V04*V22 + 9.84542272986960941e-20*V042*V22 + 
      1.73908172049421319e-19*V03*V05*V22 + 8.04023160921363e-20*V02*V06*V22 + 3.20848144192557362e-20*V01*V07*V22 - 
      6.00511711964484846e-22*V10*V22 - 6.12845391983135806e-20*V01*V022*V23 - 
      5.62607427684899252e-20*V012*V03*V23 + 4.18581304764308748e-20*V03*V04*V23 + 
      2.36315571214898128e-20*V02*V05*V23 + 1.06139309813527188e-20*V01*V06*V23 - 2.75492841325803854e-22*V09*V23 - 
      7.37000003321039368e-21*V012*V02*V24 + 4.24421771277008895e-21*V032*V24 + 
      5.4185507165809113e-21*V02*V04*V24 + 2.97681506073870809e-21*V01*V05*V24 - 1.09949162121923174e-22*V08*V24 - 
      2.64790420354864443e-22*V013*V25 + 1.06951085408858974e-21*V02*V03*V25 + 6.63807323833408094e-22*V01*V04*V25 - 
      3.81443372622617255e-23*V07*V25 + 6.3373691612595318e-23*V022*V26 + 1.23748754662325431e-22*V01*V03*V26 - 
      1.12201625324665743e-23*V06*V26 + 1.4579003349450381e-23*V01*V02*V27 - 2.82461939566319451e-24*V05*V27 + 
      7.57098709225785432e-25*V012*V28 - 5.65500380092266928e-25*V04*V28 - 9.64756707948941809e-26*V03*V29 - 
      1.02946599933576108e-26*V02*V30 - 1.02946599933576108e-27*V01*V31 + 5.25237754763143407e-31*V34) + 
   9.67759295863189099e-41*delta34*V34 + 8.22595401483710734e-40*delta32*eps*V34;
}
#endif
